(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[   2408089,      47513]
NotebookOptionsPosition[   2393636,      47049]
NotebookOutlinePosition[   2393996,      47065]
CellTagsIndexPosition[   2393953,      47062]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Hunting for Turing Machines at the Wolfram Science Summer School\
\>", "Section",
 CellChangeTimes->{{3.558961210126718*^9, 3.5589612127696123`*^9}, 
   3.565003069721307*^9}],

Cell["\<\
This year is the 100th birthday of Alan Turing, so at the 2012 Wolfram \
Science Summer School we decided to turn a group of 40 unassuming nerds into \
ferocious hunters. No, we didn\[CloseCurlyQuote]t teach our geeks to take \
down big game. These are laptop warriors. And their prey? Turing machines!\
\>", "Text",
 CellChangeTimes->{{3.5635593244239187`*^9, 3.563559641789218*^9}, {
   3.563559693319769*^9, 3.563559706411171*^9}, {3.5635597840405293`*^9, 
   3.563559937492304*^9}, {3.563560150633162*^9, 3.563560152013514*^9}, {
   3.5635602475883102`*^9, 3.563560254841127*^9}, {3.563561132914111*^9, 
   3.563561230748103*^9}, {3.563561460166759*^9, 3.563561460740409*^9}, {
   3.563624422510186*^9, 3.563624422627729*^9}, {3.564831526380269*^9, 
   3.5648315344063377`*^9}, {3.5648318327626343`*^9, 
   3.5648318328249297`*^9}, {3.564843058776215*^9, 3.564843063654149*^9}, 
   3.565019508098597*^9}],

Cell["\<\
In this blog post, I\[CloseCurlyQuote]m going to teach you to be a fellow \
hunter-gatherer in the computational universe. Your mission, should you \
choose to accept it, is to FIND YOUR FAVORITE TURING MACHINE.\
\>", "Text",
 CellChangeTimes->{{3.563561601123011*^9, 3.563561739445045*^9}, {
   3.563624470050276*^9, 3.563624498513544*^9}, 3.563624528703803*^9, {
   3.563625538244934*^9, 3.563625586520261*^9}, 3.564831537133643*^9, 
   3.564831842745504*^9}],

Cell[TextData[{
 "First, I\[CloseCurlyQuote]ll show you how a Turing machine works, using \
pretty pictures that even my grandmother could understand. Then I'll show you \
some of the awesome Turing machines that our summer school students found \
using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". And I'll describe how I did an ",
 "\[UDoubleDot]",
 "ber-search through 373 ",
 StyleBox["million",
  FontSlant->"Italic"],
 " Turing machines using my Linux server back home, and had it send me email \
whenever it found an interesting one, for two weeks straight. I\
\[CloseCurlyQuote]ll keep the code to a minimum here, but you can find it all \
in the attached ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook."
}], "Text",
 CellChangeTimes->{{3.561390128483474*^9, 3.5613901292913523`*^9}, {
   3.561390429506611*^9, 3.5613905178246737`*^9}, {3.56139055987295*^9, 
   3.561391154813253*^9}, {3.561391205080576*^9, 3.561391211444652*^9}, {
   3.56139125233899*^9, 3.56139125363519*^9}, {3.561391305793934*^9, 
   3.561391341328714*^9}, {3.56139178943117*^9, 3.56139180782697*^9}, {
   3.56139222237646*^9, 3.561392223015217*^9}, {3.56146961295809*^9, 
   3.561469615722274*^9}, 3.563559301185713*^9, {3.563561822941338*^9, 
   3.5635618391455812`*^9}, {3.563561876421426*^9, 3.563561894840014*^9}, {
   3.563562841473032*^9, 3.5635628505636168`*^9}, {3.563626440017171*^9, 
   3.563626488963851*^9}, 3.563626744899695*^9, {3.564422226973255*^9, 
   3.56442227888043*^9}, {3.564422315431748*^9, 3.564422367246892*^9}, {
   3.5644224178472433`*^9, 3.56442245319559*^9}, {3.564422517616995*^9, 
   3.564422573839499*^9}, 3.5648314606545258`*^9, {3.5648315410765467`*^9, 
   3.5648315462038803`*^9}, 3.564831876540867*^9}],

Cell["Excited? Primed for the hunt? Let me break it down for you.", "Text",
 CellChangeTimes->{{3.556902198326805*^9, 3.5569022025426064`*^9}, {
   3.561383507070478*^9, 3.5613835118858757`*^9}, 3.5613878031915894`*^9, {
   3.561391743595936*^9, 3.56139174563558*^9}, {3.561392237878886*^9, 
   3.561392251214212*^9}, {3.563898196264886*^9, 3.563898220820219*^9}, {
   3.5638998457664137`*^9, 3.5638998481631327`*^9}, {3.564422282847993*^9, 
   3.564422306331099*^9}, {3.564831549305216*^9, 3.5648315514091363`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["TM explanation", "Section",
 CellChangeTimes->{{3.558961210126718*^9, 3.5589612127696123`*^9}}],

Cell[TextData[{
 "The rules of Turing machines are actually super simple. There\
\[CloseCurlyQuote]s a row of cells called the ",
 StyleBox["tape",
  FontSlant->"Italic"],
 ":"
}], "Text",
 CellChangeTimes->{{3.552589878014783*^9, 3.552590219302951*^9}, {
   3.552590302819165*^9, 3.5525903085281477`*^9}, 3.564831554541641*^9, 
   3.5648319477513676`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "1"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "21", "}"}]}], "]"}], "}"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.552590274756308*^9, 3.552590278683393*^9}}],

Cell[BoxData[
 GraphicsBox[{
   RasterBox[{{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1}}, {{0, 0}, {21, 1}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[LineBox[{{{0, 1}, {21, 1}}, {{0, 0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}, {{2, 0}, {2, 1}}, {{3, 
       0}, {3, 1}}, {{4, 0}, {4, 1}}, {{5, 0}, {5, 1}}, {{6, 0}, {6, 1}}, {{7,
        0}, {7, 1}}, {{8, 0}, {8, 1}}, {{9, 0}, {9, 1}}, {{10, 0}, {10, 
       1}}, {{11, 0}, {11, 1}}, {{12, 0}, {12, 1}}, {{13, 0}, {13, 1}}, {{14, 
       0}, {14, 1}}, {{15, 0}, {15, 1}}, {{16, 0}, {16, 1}}, {{17, 0}, {17, 
       1}}, {{18, 0}, {18, 1}}, {{19, 0}, {19, 1}}, {{20, 0}, {20, 1}}, {{21, 
       0}, {21, 1}}}],
      Antialiasing->False]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{3.5525902799812098`*^9, 3.5569031316364107`*^9, 
  3.5589613938860292`*^9, 3.563899200179352*^9, 3.564163762401812*^9, 
  3.5641659909159822`*^9, 3.564166787633258*^9, 3.5641669803491087`*^9, 
  3.564167267015375*^9, 3.564167488532654*^9, 3.564167731702498*^9, 
  3.5641680680955153`*^9, 3.5641683039216957`*^9, 3.564421402534492*^9, 
  3.5644215843108892`*^9}]
}, Open  ]],

Cell[TextData[{
 "Then there's a ",
 StyleBox["head",
  FontSlant->"Italic"],
 " that sits on the tape like so:"
}], "Text",
 CellChangeTimes->{{3.552589878014783*^9, 3.552590223215234*^9}, {
  3.552590311925726*^9, 3.5525903573371468`*^9}, {3.552590431089979*^9, 
  3.552590431921728*^9}, {3.552590649414701*^9, 3.552590655370511*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"statecolor", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589178343575*^9}}],

Cell[CellGroupData[{

Cell[BoxData["statecolor"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563899290335567*^9, 3.564163762189485*^9, 
  3.564165990736415*^9, 3.564166787304235*^9, 3.564166980055807*^9, 
  3.564167266764412*^9, 3.564167488214432*^9, 3.564167731522805*^9, 
  3.5641680677979317`*^9, 3.56416830360833*^9, 3.564420171456244*^9, 
  3.5644214027339363`*^9, 3.5644215844987164`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"case2index", "=", 
   RowBox[{"MapIndexed", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"#2", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "&"}], ",", "statecolor"}], "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589181429678*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rule", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.558960713178935*^9, 3.5589607149655447`*^9}, 
   3.558965645542191*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cases", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{"#", "/.", "rule"}]}], "}"}], "&"}], "/@", "statecolor"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.55258918318089*^9}, 
   3.556903122577168*^9, 3.558961382521369*^9, 3.558965658916*^9}],

Cell[CellGroupData[{

Cell[BoxData["cases"], "Input",
 CellChangeTimes->{{3.563899313743927*^9, 3.563899314444182*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563899315127612*^9, 3.564163762285511*^9, 
  3.564165990831909*^9, 3.564166787444512*^9, 3.564166980198305*^9, 
  3.564167266867139*^9, 3.564167488338046*^9, 3.5641677316071777`*^9, 
  3.564168067936562*^9, 3.5641683037523203`*^9, 3.564420171919697*^9, 
  3.564420245823496*^9, 3.5644214029348173`*^9, 3.56442158469917*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TuringStep", "[", 
    RowBox[{"list_", ",", "state_", ",", "position_", ",", "rules_"}], "]"}], 
   ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"newstate", ",", "newvalue", ",", "move", ",", "newpos"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"newstate", ",", "newvalue", ",", "move"}], "}"}], "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"state", ",", 
          RowBox[{"list", "[", 
           RowBox[{"[", "position", "]"}], "]"}]}], "}"}], "/.", "rules"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"newpos", "=", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{"position", "+", "move"}], ",", 
         RowBox[{"Length", "@", "list"}], ",", "1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ReplacePart", "[", 
         RowBox[{"list", ",", 
          RowBox[{"position", "\[Rule]", "newvalue"}]}], "]"}], ",", 
        "newstate", ",", "newpos"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589171242261*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TuringEvolve", "[", 
    RowBox[{
    "list_", ",", "state_", ",", "position_", ",", "rules_", ",", "t_"}], 
    "]"}], ":=", 
   RowBox[{"NestList", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"TuringStep", "[", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{"#", "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", "rules"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"list", ",", "state", ",", "position"}], "}"}], ",", "t"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589172666937*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmhead", "[", 
   RowBox[{"pos_List", ",", "state_", ",", "numstates_", ",", "scale_"}], 
   "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rt", "=", 
      RowBox[{"RotationTransform", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "state"}], "*", "2", "*", 
         RowBox[{"Pi", "/", "numstates"}]}], ",", "pos"}], "]"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Lighter", "@", 
       RowBox[{"Lighter", "@", "Orange"}]}], ",", 
      RowBox[{"EdgeForm", "[", 
       RowBox[{"Darker", "@", "Orange"}], "]"}], ",", 
      RowBox[{"Polygon", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rt", "[", 
          RowBox[{"pos", "+", 
           RowBox[{"#", "*", "scale"}]}], "]"}], "&"}], "/@", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", "3"}], "}"}], "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Chop", "@", 
             RowBox[{"N", "@", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Cos", "[", "theta", "]"}], ",", 
                RowBox[{"Sin", "[", "theta", "]"}]}], "}"}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"theta", ",", "Pi", ",", 
              RowBox[{"2", "Pi"}], ",", 
              RowBox[{"Pi", "/", "20."}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", "3"}], "}"}], "}"}]}], "]"}]}], "]"}]}], 
     "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.558959750845355*^9, 3.558959900494843*^9}, {
   3.558960036678689*^9, 3.558960071086587*^9}, {3.558960481460031*^9, 
   3.558960487933276*^9}, 3.558961879978109*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"TuringEvolve", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "21", "}"}]}], "]"}], ",", "0", ",", "10", ",", "rule", 
     ",", "20"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589184851856*^9}, 
   3.556903125865237*^9, 3.558961385465107*^9, 3.55896566018797*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"timestepcases", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{"Extract", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], "/.", 
      "case2index"}], "&"}], "/@", "e"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589186548045*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "1"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.552589009169128*^9, 3.5525890605530443`*^9}, {
  3.55896142928121*^9, 3.558961466990596*^9}}],

Cell[BoxData[
 GraphicsBox[{
   RasterBox[{{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1}}, {{0, 0}, {21, 1}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[LineBox[{{{0, 1}, {21, 1}}, {{0, 0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}, {{2, 0}, {2, 1}}, {{3, 
       0}, {3, 1}}, {{4, 0}, {4, 1}}, {{5, 0}, {5, 1}}, {{6, 0}, {6, 1}}, {{7,
        0}, {7, 1}}, {{8, 0}, {8, 1}}, {{9, 0}, {9, 1}}, {{10, 0}, {10, 
       1}}, {{11, 0}, {11, 1}}, {{12, 0}, {12, 1}}, {{13, 0}, {13, 1}}, {{14, 
       0}, {14, 1}}, {{15, 0}, {15, 1}}, {{16, 0}, {16, 1}}, {{17, 0}, {17, 
       1}}, {{18, 0}, {18, 1}}, {{19, 0}, {19, 1}}, {{20, 0}, {20, 1}}, {{21, 
       0}, {21, 1}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDmlg8M7eGAQ2KzlAxB/Y8/eed1TdouSgknD5
Y3f9Pfv0QxfLv25TcjiXGRTYz3HXXj83WHLSbiWHLfde3Hddctv+hY6KyL2D
Sg7iM1bWlUbfsr/OyLV940klhztWDg/NzG7aH/T5uvr2JSUHxrmtLYesb9h/
c/uvp3RXyeHB0lwt56Lr9n6Tu6pcXig5PPex+LXu3jV7xtl98X8+Kzk8XfjR
ckXLNXtU916z/59SuICZR9nhCVR+U05p625xZYdnUP1cOxku3lVShptvv5kr
REVX2YEBar/mv68efmbKcPdJXL79WtFO2UEM6v6Lk9Y8y3VRdtgM9d9MW70O
Lk9lh7NQ/38sMth3y1vZQRkaPmfPAIGPMjz80MMXAOGQoBY=
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{{3.5589614595324383`*^9, 3.558961468160767*^9}, 
   3.558961912235302*^9, 3.563899200233676*^9, 3.5641637624418573`*^9, 
   3.564165990949819*^9, 3.564166787677305*^9, 3.56416698040154*^9, 
   3.5641672670484133`*^9, 3.564167488586184*^9, 3.564167731726248*^9, 
   3.564168068146021*^9, 3.564168303975464*^9, 3.564420288325054*^9, 
   3.564421403244884*^9, 3.564421584966278*^9}]
}, Open  ]],

Cell[TextData[{
 "The head can point in different directions to show what ",
 StyleBox["state",
  FontSlant->"Italic"],
 " it\[CloseCurlyQuote]s in. Let\[CloseCurlyQuote]s say there are just three \
possible states, so the head can point in three different directions:"
}], "Text",
 CellChangeTimes->{{3.5525903725792723`*^9, 3.552590380004374*^9}, {
   3.552590460259757*^9, 3.552590631150511*^9}, {3.5525906957829647`*^9, 
   3.552590733547896*^9}, {3.552590835807911*^9, 3.552590836608562*^9}, {
   3.552590877051455*^9, 3.552590904590782*^9}, {3.552591088001979*^9, 
   3.552591104739255*^9}, {3.552591600131329*^9, 3.552591601073851*^9}, 
   3.564831557471546*^9, {3.564831971622532*^9, 3.5648319751439962`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"ArrayPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", "0", "}"}], "}"}], ",", 
         RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "35"}], ",", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"tmhead", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0.5", ",", "0.5"}], "}"}], ",", "state", ",", "3", 
              ",", "0.15"}], "]"}]}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"\"\<state \>\"", "<>", 
          RowBox[{"IntegerString", "[", 
           RowBox[{"state", "+", "1"}], "]"}]}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",",
        "Bottom"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"state", ",", "0", ",", "2", ",", "1"}], "}"}]}], "]"}], ",", 
   "\"\<    \>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5525909494528646`*^9, 3.5525910292445173`*^9}, {
  3.5570962480417013`*^9, 3.5570963543505907`*^9}, {3.558961486238945*^9, 
  3.558961511942004*^9}}],

Cell[BoxData[
 TemplateBox[{"    ","\"    \"",TemplateBox[{
     GraphicsBox[{
       RasterBox[{{1}}, {{0, 0}, {1, 1}}, {0, 1}], {{
         GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[
          LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}], Antialiasing -> 
          False]}, {
         GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[
          LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}], Antialiasing -> 
          False]}}}, Epilog -> {
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
          "]]}}, Frame -> False, FrameLabel -> {None, None}, 
      FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 35], 
     StyleBox[
     "\"state 1\"", StripOnInput -> False, FontFamily -> "Helvetica"]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Bottom"}], "]"}]& )],TemplateBox[{
     GraphicsBox[{
       RasterBox[{{1}}, {{0, 0}, {1, 1}}, {0, 1}], {{
         GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[
          LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}], Antialiasing -> 
          False]}, {
         GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[
          LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}], Antialiasing -> 
          False]}}}, Epilog -> {
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
          "]]}}, Frame -> False, FrameLabel -> {None, None}, 
      FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 35], 
     StyleBox[
     "\"state 2\"", StripOnInput -> False, FontFamily -> "Helvetica"]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Bottom"}], "]"}]& )],TemplateBox[{
     GraphicsBox[{
       RasterBox[{{1}}, {{0, 0}, {1, 1}}, {0, 1}], {{
         GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[
          LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}], Antialiasing -> 
          False]}, {
         GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[
          LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}], Antialiasing -> 
          False]}}}, Epilog -> {
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
          "]]}}, Frame -> False, FrameLabel -> {None, None}, 
      FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 35], 
     StyleBox[
     "\"state 3\"", StripOnInput -> False, FontFamily -> "Helvetica"]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Bottom"}], "]"}]& )]},
  "RowWithSeparators"]], "Output",
 CellChangeTimes->{{3.5589614947161627`*^9, 3.558961512136818*^9}, 
   3.5589619128011217`*^9, 3.563899200282503*^9, 3.5641637624983387`*^9, 
   3.564165991000399*^9, 3.564166787729579*^9, 3.564166980455968*^9, 
   3.564167267102216*^9, 3.564167488675185*^9, 3.564167731852503*^9, 
   3.564168068199381*^9, 3.564168304678866*^9, 3.564420293183538*^9, 
   3.564421403303997*^9, 3.564421585031221*^9}]
}, Open  ]],

Cell["\<\
In addition, each cell on the tape has a color. In the simplest case there \
are just two possible colors, black or white (binary):\
\>", "Text",
 CellChangeTimes->{{3.5525927110260963`*^9, 3.552592744508533*^9}, {
   3.552592849633902*^9, 3.552592962679942*^9}, {3.552593189419963*^9, 
   3.552593191373479*^9}, {3.552672895567645*^9, 3.552672897051648*^9}, 
   3.564831565466446*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ArrayPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", "color", "}"}], "}"}], ",", 
       RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "35"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"color", ",", "0", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", 
   "\"\<    \>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.55259277715005*^9, 3.552592797260536*^9}}],

Cell[BoxData[
 TemplateBox[{"    ","\"    \"",GraphicsBox[{
     RasterBox[{{1}}, {{0, 0}, {1, 1}}, {0, 1}], {{
       GrayLevel[
        NCache[-1 + GoldenRatio, 0.6180339887498949]], 
       StyleBox[
        LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}], Antialiasing -> 
        False]}, {
       GrayLevel[
        NCache[-1 + GoldenRatio, 0.6180339887498949]], 
       StyleBox[
        LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}], Antialiasing -> 
        False]}}}, Frame -> False, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 35],
   GraphicsBox[{
     RasterBox[{{0}}, {{0, 0}, {1, 1}}, {0, 1}], {{
       GrayLevel[
        NCache[-1 + GoldenRatio, 0.6180339887498949]], 
       StyleBox[
        LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}], Antialiasing -> 
        False]}, {
       GrayLevel[
        NCache[-1 + GoldenRatio, 0.6180339887498949]], 
       StyleBox[
        LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}], Antialiasing -> 
        False]}}}, Frame -> False, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 35]},
  "RowWithSeparators"]], "Output",
 CellChangeTimes->{3.558961943768766*^9, 3.563899200333593*^9, 
  3.564163762546646*^9, 3.564165991058902*^9, 3.564166787783731*^9, 
  3.5641669805066357`*^9, 3.564167267155179*^9, 3.5641674887699547`*^9, 
  3.564167731898322*^9, 3.564168068249206*^9, 3.564168304848624*^9, 
  3.564420296767187*^9, 3.564421403358041*^9, 3.5644215850715027`*^9}]
}, Open  ]],

Cell[TextData[{
 "So for each of the three head states, there are two possible cell colors, \
giving ",
 StyleBox["six",
  FontSlant->"Italic"],
 " different situations:"
}], "Text",
 CellChangeTimes->{{3.5525930040613327`*^9, 3.552593053106275*^9}, {
  3.5570963977021933`*^9, 3.5570964164781647`*^9}, {3.5613923310355597`*^9, 
  3.561392362946026*^9}, {3.561392397001947*^9, 3.561392482558495*^9}, {
  3.5648319849760494`*^9, 3.564831987889827*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"MapIndexed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#2", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", "\"\<white\>\""}], ",", 
               RowBox[{"2", "\[Rule]", "\"\<black\>\""}]}], "}"}]}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", "#"}], "}"}]}], "&"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"ArrayPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", "color", "}"}], "}"}], ",", 
          RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "35"}], ",", 
          RowBox[{"Epilog", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"tmhead", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0.5", ",", "0.5"}], "}"}], ",", "state", ",", "3", 
               ",", "0.15"}], "]"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"color", ",", "0", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"state", ",", "0", ",", "2", ",", "1"}], "}"}]}], "]"}]}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"#", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
       "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\>\"", ",", "\"\<state 1\>\"", ",", "\"\<state 2\>\"", ",", 
        "\"\<state 3\>\""}], "}"}]}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.552593069240266*^9, 3.552593102230916*^9}, {
  3.558961535366193*^9, 3.558961569882799*^9}, {3.558961662995336*^9, 
  3.5589617618899517`*^9}, {3.558961804638061*^9, 3.5589618461213017`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"white\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica"], 
     GraphicsBox[{RasterBox[{{1}}, {{0, 0}, {1, 1}}, {0, 1}], {
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
          Antialiasing->False]}, 
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}],
          Antialiasing->False]}}},
      Epilog->{
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
          "]]}},
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->35], 
     GraphicsBox[{RasterBox[{{1}}, {{0, 0}, {1, 1}}, {0, 1}], {
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
          Antialiasing->False]}, 
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}],
          Antialiasing->False]}}},
      Epilog->{
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
          "]]}},
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->35], 
     GraphicsBox[{RasterBox[{{1}}, {{0, 0}, {1, 1}}, {0, 1}], {
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
          Antialiasing->False]}, 
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}],
          Antialiasing->False]}}},
      Epilog->{
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
          "]]}},
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->35]},
    {
     StyleBox["\<\"black\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica"], 
     GraphicsBox[{RasterBox[{{0}}, {{0, 0}, {1, 1}}, {0, 1}], {
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
          Antialiasing->False]}, 
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}],
          Antialiasing->False]}}},
      Epilog->{
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
          "]]}},
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->35], 
     GraphicsBox[{RasterBox[{{0}}, {{0, 0}, {1, 1}}, {0, 1}], {
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
          Antialiasing->False]}, 
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}],
          Antialiasing->False]}}},
      Epilog->{
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
          "]]}},
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->35], 
     GraphicsBox[{RasterBox[{{0}}, {{0, 0}, {1, 1}}, {0, 1}], {
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
          Antialiasing->False]}, 
        {GrayLevel[
          NCache[-1 + GoldenRatio, 0.6180339887498949]], 
         StyleBox[LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}}],
          Antialiasing->False]}}},
      Epilog->{
        RGBColor[1, 0, 0], {
         RGBColor[1, 0.7777777777777778, 
          NCache[
           Rational[5, 9], 0.5555555555555556]], 
         EdgeForm[
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
         PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
          "]]}},
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->35]},
    {
     StyleBox["\<\"\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica"], 
     StyleBox["\<\"state 1\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica"], 
     StyleBox["\<\"state 2\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica"], 
     StyleBox["\<\"state 3\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.558961542202042*^9, 3.558961570384945*^9}, {
   3.558961756149572*^9, 3.5589617637696457`*^9}, 3.558961847543242*^9, 
   3.558961918756118*^9, 3.563899200417544*^9, 3.564163762634226*^9, 
   3.564165991147772*^9, 3.5641667878854628`*^9, 3.5641669806063643`*^9, 
   3.564167267261784*^9, 3.5641674889968567`*^9, 3.564167732000677*^9, 
   3.564168068441576*^9, 3.564168304975157*^9, 3.564420299988575*^9, 
   3.564421403479548*^9, 3.564421585157501*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["rule table",
  FontSlant->"Italic"],
 " tells the Turing machine what to do in each situation:"
}], "Text",
 CellChangeTimes->{{3.55259119365926*^9, 3.552591316535969*^9}, {
  3.552591365328238*^9, 3.552591386397245*^9}, {3.552591448175066*^9, 
  3.552591448596826*^9}, {3.552591544878612*^9, 3.552591551986381*^9}, {
  3.5525917261724463`*^9, 3.55259175422337*^9}, {3.55259203310113*^9, 
  3.5525920446427317`*^9}, {3.552592123731205*^9, 3.5525922261125307`*^9}, {
  3.55259230803148*^9, 3.552592354768631*^9}, {3.552592535053093*^9, 
  3.552592548678794*^9}, {3.552592582173531*^9, 3.5525925892980003`*^9}, {
  3.5525926473208027`*^9, 3.5525926840263147`*^9}, {3.55259312627785*^9, 
  3.552593151848476*^9}, {3.552593223821542*^9, 3.5525932596587667`*^9}, {
  3.5525934171645927`*^9, 3.552593419043231*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmruletable", "[", 
   RowBox[{"rules_", ",", 
    RowBox[{"highlightcase_Integer:", "0"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cases", ",", "statecolor", ",", "numstates"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"numstates", "=", 
      RowBox[{
       RowBox[{"Max", "@", 
        RowBox[{"rules", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1", ",", "1"}], "]"}], "]"}]}], "+", "1"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"statecolor", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Outer", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cases", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", 
          RowBox[{"#", "/.", "rules"}]}], "}"}], "&"}], "/@", 
       "statecolor"}]}], ";", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Module", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"i", "=", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"instate", "=", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"outstate", "=", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"incolor", "=", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
               RowBox[{"outcolor", "=", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", 
               RowBox[{"outdir", "=", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ",", "tackon"}], 
              "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"tackon", "=", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"outdir", "\[Equal]", "1"}], ",", "Append", ",", 
                 "Prepend"}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"Framed", "[", 
               RowBox[{
                RowBox[{"Pane", "[", 
                 RowBox[{
                  RowBox[{"Row", "[", 
                   RowBox[{"tackon", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"ArrayPlot", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "incolor", "}"}], ",", 
                    RowBox[{"{", "outcolor", "}"}]}], "}"}], ",", 
                    RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "20"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", 
                    RowBox[{"tmhead", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.5", ",", "1.5"}], "}"}], ",", "instate", ",", 
                    "numstates", ",", "0.15"}], "]"}]}], "}"}]}]}], "]"}], 
                    "}"}], ",", 
                    RowBox[{"ArrayPlot", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "0", "}"}], ",", 
                    RowBox[{"{", "0", "}"}]}], "}"}], ",", 
                    RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "20"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", 
                    RowBox[{"tmhead", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.5", ",", "0.5"}], "}"}], ",", "outstate", ",", 
                    "numstates", ",", "0.15"}], "]"}]}], "}"}]}], ",", 
                    RowBox[{"Frame", "\[Rule]", "None"}]}], "]"}]}], "]"}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"50", ",", "50"}], "}"}], ",", 
                  RowBox[{"Alignment", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"Center", ",", "Center"}], "}"}]}], ",", 
                  RowBox[{"ContentPadding", "\[Rule]", "False"}], ",", 
                  RowBox[{"ImageMargins", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"outdir", "\[Equal]", "1"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", 
                    RowBox[{"-", "3"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3"}], ",", "5"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}]}], "]"}], ",", 
                RowBox[{"FrameStyle", "\[Rule]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"i", "\[Equal]", "highlightcase"}], ",", 
                   RowBox[{"Directive", "[", "Red", "]"}], ",", "White"}], 
                  "]"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], "&"}], 
          ",", "cases"}], "]"}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "All"}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", "Gray"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589186548045*^9}, {
  3.552589265008855*^9, 3.552589334218017*^9}, {3.5525895336158524`*^9, 
  3.5525895780915194`*^9}, {3.552589624883624*^9, 3.552589632879258*^9}, {
  3.558960711537726*^9, 3.558960725465219*^9}, {3.558960761930565*^9, 
  3.558960848346589*^9}, {3.558960928110383*^9, 3.558960945412286*^9}, {
  3.5589609754765673`*^9, 3.558961006322661*^9}, {3.558961162568956*^9, 
  3.558961166590515*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmruletable", "[", "rule", "]"}]], "Input",
 CellChangeTimes->{{3.552588982402398*^9, 3.552588983545102*^9}, {
   3.552589737104405*^9, 3.552589741420981*^9}, 3.5569031335918417`*^9, {
   3.558961396960534*^9, 3.558961400816139*^9}, 3.558962025815864*^9, 
   3.558965661626809*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False]}
   },
   AutoDelete->False,
   FrameStyle->GrayLevel[0.5],
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.5525889841778803`*^9, 3.552589742517993*^9, 
  3.556903134039961*^9, 3.5589614014084587`*^9, 3.558961909053029*^9, 
  3.558962026295063*^9, 3.5638992005626183`*^9, 3.564163762795423*^9, 
  3.5641659913459167`*^9, 3.5641667880667562`*^9, 3.5641669807628527`*^9, 
  3.5641672674290543`*^9, 3.564167489224121*^9, 3.5641677321608677`*^9, 
  3.5641680691386557`*^9, 3.5641683052800283`*^9, 3.564420317414666*^9, 
  3.564421403701013*^9, 3.56442158533294*^9}]
}, Open  ]],

Cell["\<\
You can see how it works: the cell under the head changes color, then the \
head moves left or right and updates its state.\
\>", "Text",
 CellChangeTimes->{{3.552593343116274*^9, 3.552593386163507*^9}, {
  3.552593471904598*^9, 3.5525935261091948`*^9}, {3.552672923564138*^9, 
  3.552672923788525*^9}, {3.552672973264821*^9, 3.5526729752512417`*^9}}],

Cell["\<\
So let\[CloseCurlyQuote]s say the head is in state 1 on a blank tape:\
\>", "Text",
 CellChangeTimes->{{3.55259119365926*^9, 3.552591316535969*^9}, {
   3.552591365328238*^9, 3.552591386397245*^9}, {3.552591448175066*^9, 
   3.552591448596826*^9}, {3.552591544878612*^9, 3.552591551986381*^9}, {
   3.5525917261724463`*^9, 3.55259175422337*^9}, {3.55259203310113*^9, 
   3.5525920446427317`*^9}, {3.552592123731205*^9, 3.5525922261125307`*^9}, {
   3.55259230803148*^9, 3.552592354768631*^9}, 3.552592535053093*^9, {
   3.5569022468019123`*^9, 3.5569022475550003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "1"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.552589009169128*^9, 3.5525890605530443`*^9}, {
  3.55896142928121*^9, 3.558961466990596*^9}}],

Cell[BoxData[
 GraphicsBox[{
   RasterBox[{{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1}}, {{0, 0}, {21, 1}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[LineBox[{{{0, 1}, {21, 1}}, {{0, 0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 1}}, {{1, 0}, {1, 1}}, {{2, 0}, {2, 1}}, {{3, 
       0}, {3, 1}}, {{4, 0}, {4, 1}}, {{5, 0}, {5, 1}}, {{6, 0}, {6, 1}}, {{7,
        0}, {7, 1}}, {{8, 0}, {8, 1}}, {{9, 0}, {9, 1}}, {{10, 0}, {10, 
       1}}, {{11, 0}, {11, 1}}, {{12, 0}, {12, 1}}, {{13, 0}, {13, 1}}, {{14, 
       0}, {14, 1}}, {{15, 0}, {15, 1}}, {{16, 0}, {16, 1}}, {{17, 0}, {17, 
       1}}, {{18, 0}, {18, 1}}, {{19, 0}, {19, 1}}, {{20, 0}, {20, 1}}, {{21, 
       0}, {21, 1}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDmlg8M7eGAQ2KzlAxB/Y8/eed1TdouSgknD5
Y3f9Pfv0QxfLv25TcjiXGRTYz3HXXj83WHLSbiWHLfde3Hddctv+hY6KyL2D
Sg7iM1bWlUbfsr/OyLV940klhztWDg/NzG7aH/T5uvr2JSUHxrmtLYesb9h/
c/uvp3RXyeHB0lwt56Lr9n6Tu6pcXig5PPex+LXu3jV7xtl98X8+Kzk8XfjR
ckXLNXtU916z/59SuICZR9nhCVR+U05p625xZYdnUP1cOxku3lVShptvv5kr
REVX2YEBar/mv68efmbKcPdJXL79WtFO2UEM6v6Lk9Y8y3VRdtgM9d9MW70O
Lk9lh7NQ/38sMth3y1vZQRkaPmfPAIGPMjz80MMXAOGQoBY=
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{3.564164045862247*^9, 3.564165991455681*^9, 
  3.564166788197895*^9, 3.564166980806994*^9, 3.5641672674719763`*^9, 
  3.5641674892691813`*^9, 3.564167732214912*^9, 3.564168069286912*^9, 
  3.564168305350719*^9, 3.5644203531949043`*^9, 3.564421403849327*^9, 
  3.564421585454504*^9}]
}, Open  ]],

Cell["\<\
We look up the case in the rule table where the head is on a white cell in \
state 1:\
\>", "Text",
 CellChangeTimes->{{3.552593566376457*^9, 3.552593581306192*^9}, {
  3.559907228764192*^9, 3.559907239091639*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmruletable", "[", 
  RowBox[{"rule", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.552588982402398*^9, 3.552588983545102*^9}, 
   3.5525890883330917`*^9, {3.552589773390348*^9, 3.552589778523156*^9}, 
   3.55690314879974*^9, {3.5589619567520027`*^9, 3.558961960015538*^9}, 
   3.5589656629009943`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->Directive[
        RGBColor[1, 0, 0]],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False]}
   },
   AutoDelete->False,
   FrameStyle->GrayLevel[0.5],
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.558961960411338*^9, 3.5638992007149754`*^9, 
  3.5641637629606*^9, 3.5641659916101*^9, 3.564166788360985*^9, 
  3.564166980968115*^9, 3.564167267664353*^9, 3.564167489535769*^9, 
  3.564167732371336*^9, 3.564168069567823*^9, 3.56416830557038*^9, 
  3.5644203563331738`*^9, 3.5644214040143557`*^9, 3.564421585600119*^9}]
}, Open  ]],

Cell["\<\
The rule says the cell under the head changes to black; the head moves left, \
and goes into state 3:\
\>", "Text",
 CellChangeTimes->{{3.5525935914366407`*^9, 3.552593631233212*^9}, {
  3.5569022682026377`*^9, 3.55690227783366*^9}, {3.56494312471795*^9, 
  3.564943125936668*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "2"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.558961995277556*^9}],

Cell[BoxData[
 GraphicsBox[{
   RasterBox[{{1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}, {{0,
     0}, {21, 2}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 2}, {21, 2}}, {{0, 1}, {21, 1}}, {{0, 0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}, {{2, 0}, {2, 2}}, {{3, 
       0}, {3, 2}}, {{4, 0}, {4, 2}}, {{5, 0}, {5, 2}}, {{6, 0}, {6, 2}}, {{7,
        0}, {7, 2}}, {{8, 0}, {8, 2}}, {{9, 0}, {9, 2}}, {{10, 0}, {10, 
       2}}, {{11, 0}, {11, 2}}, {{12, 0}, {12, 2}}, {{13, 0}, {13, 2}}, {{14, 
       0}, {14, 2}}, {{15, 0}, {15, 2}}, {{16, 0}, {16, 2}}, {{17, 0}, {17, 
       2}}, {{18, 0}, {18, 2}}, {{19, 0}, {19, 2}}, {{20, 0}, {20, 2}}, {{21, 
       0}, {21, 2}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDsZg8N8eTG1WcoCI/7Dn7z3vqLpFyYHzRsmf
R/O/26cfulj+dZuSQ8mskCvKTt/t9XODJSftVnJYa/6rXPDlN/sXOioi9w4q
ObClrYq/O+2b/XVGru0bTyo5bOcL2NHr+83+oM/X1bcvKTk4pCsu/MD3zf6b
2389pbtKDhWZs09NuPPV3m9yV5XLCyUHK+G+fau3f7VnnN0X/+ezkkNlRg2f
1sKv9jD3zpoJAl/t/6cULmDmUYbLb8opbd0trgzXz7WT4eJdJWW4+fabuUJU
dJXh9mv+++rhZ6YMd5/E5duvFe2U4e6/OGnNs1wXZbj/ZtrqdXB5KjsUQ/3/
schg3y1vZXj4nD0DBD7K8PBDD18A23mdaA==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveyV875yCwWHBTNB4KJ9ehoQqCk6KMjUv12+/rr9
wSrbjyEGig4FW9dwinXdsDesSbgkZKno4HAyNKd78k37W3l67zMcFB0WOMXt
rzt6y57B6DqHppuiwwRR+7x0iTv2Rh737ut5KTow7P+m9Lb5rv3kXTMkEn2A
5itPSZD5f8/+2zHW2xuB/Ab7R+X+Dg/sM/YJacl7A/lid2Kq/z+wD/mv/GGT
u6IDR7P++ZgdD+3l2accaHJSdMgAuTPtkX3orE3+662B5q+5LuzP+th+W+Dc
JcnGQPWH2dV0Jz62f8PLynVFU9Gh4+2zT31sT+xD2PuO2MgrOryQL+6dkPTE
nsPrxbQHwiDzn/x9u+iJ/Yu43zLsHIoOGiu7OwWPPbHnvNPI8fu3goNHfswG
2dNP7GfYGXlxfFBwaHimvfDTxif2F9h5jaueKDgYfLVn0q9+Yj8LFIw3FRxe
FDpw6mg8sUcPXwA6P6Kk
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{{3.558961992664364*^9, 3.5589619970828733`*^9}, 
   3.5638992007559834`*^9, 3.564163763014565*^9, 3.564165991667431*^9, 
   3.564166788408246*^9, 3.5641669810895853`*^9, 3.56416726771313*^9, 
   3.564167489663319*^9, 3.5641677324164333`*^9, 3.5641680696265917`*^9, 
   3.5641683056456013`*^9, 3.564420359607561*^9, 3.564421404068009*^9, 
   3.564421585638454*^9}]
}, Open  ]],

Cell["\<\
Notice we are showing the updated tape right below the old one. That way we \
can see where the head was on the previous step and where it is currently.\
\>", "Text",
 CellChangeTimes->{{3.556902285705657*^9, 3.556902317024891*^9}, {
   3.557096096252077*^9, 3.557096147359473*^9}, {3.5599073398089657`*^9, 
   3.55990735119084*^9}, {3.559907500259556*^9, 3.5599075649207*^9}, 
   3.561392573951871*^9, 3.564831569923641*^9, {3.564832263332676*^9, 
   3.5648322635508575`*^9}}],

Cell["\<\
Now the head is in state 3 on a white cell, so we look that case up:\
\>", "Text",
 CellChangeTimes->{{3.552592436716926*^9, 3.552592439396977*^9}, {
  3.552592469882833*^9, 3.552592512928651*^9}, {3.552593640580237*^9, 
  3.552593657339899*^9}, {3.5526730103141203`*^9, 3.5526730149640903`*^9}, {
  3.556902356583415*^9, 3.556902375678431*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmruletable", "[", 
  RowBox[{"rule", ",", "6"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5525891083227262`*^9, {3.552589819223257*^9, 3.552589825068013*^9}, 
   3.556903155014165*^9, {3.5589620112879467`*^9, 3.558962015599854*^9}, 
   3.5589656644007874`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->Directive[
        RGBColor[1, 0, 0]],
      StripOnInput->False]}
   },
   AutoDelete->False,
   FrameStyle->GrayLevel[0.5],
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.558962015977167*^9, 3.563899200901311*^9, 
  3.5641637631943007`*^9, 3.564165991832819*^9, 3.564166788566226*^9, 
  3.5641669816732273`*^9, 3.5641672678877993`*^9, 3.564167489892889*^9, 
  3.564167732576522*^9, 3.5641680698961267`*^9, 3.564168305998843*^9, 
  3.564420363512034*^9, 3.56442140423836*^9, 3.5644215857855387`*^9}]
}, Open  ]],

Cell["\<\
The rule says the cell changes to black; the head moves right, and goes into \
state 2:\
\>", "Text",
 CellChangeTimes->{{3.5525936780069532`*^9, 3.552593697071967*^9}, {
  3.564943135977868*^9, 3.564943136162019*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "3"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.558961995277556*^9, 3.5589620514557447`*^9}],

Cell[BoxData[
 GraphicsBox[{
   RasterBox[{{1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {1, 
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}, {{0, 0}, {
    21, 3}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 3}, {21, 3}}, {{0, 2}, {21, 2}}, {{0, 1}, {21, 1}}, {{0, 
       0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 3}}, {{1, 0}, {1, 3}}, {{2, 0}, {2, 3}}, {{3, 
       0}, {3, 3}}, {{4, 0}, {4, 3}}, {{5, 0}, {5, 3}}, {{6, 0}, {6, 3}}, {{7,
        0}, {7, 3}}, {{8, 0}, {8, 3}}, {{9, 0}, {9, 3}}, {{10, 0}, {10, 
       3}}, {{11, 0}, {11, 3}}, {{12, 0}, {12, 3}}, {{13, 0}, {13, 3}}, {{14, 
       0}, {14, 3}}, {{15, 0}, {15, 3}}, {{16, 0}, {16, 3}}, {{17, 0}, {17, 
       3}}, {{18, 0}, {18, 3}}, {{19, 0}, {19, 3}}, {{20, 0}, {20, 3}}, {{21, 
       0}, {21, 3}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDrNmggC7gzEIbFZygIizOPD3nndU3aLkwJpj
VffxPLND+qGL5V+3KTlY+Wq9ElzI7KCfGyw5abeSwzXpv7s7SpgdXuioiNw7
qOTAbHx1fZ43s8N1Rq7tG08qOcSwa9w5psbscNDn6+rbl5QcFmyeEFDBzuzw
ze2/ntJdJYc9W3xTPd4xOfhN7qpyeaHkMJfT/f7V20wOjLP74v98VnKwNbFj
n3qByQHm3rNnQIDJ4X9K4QJmHmW4/Kac0tbd4spw/Vw7GS7eVVKGm2+/mStE
RVcZbr/mv68efmbKDtFQ90lcvv1a0U4Z7v6Lk9Y8y3VRhvtvpq1eB5enMtz/
H4sM9t3yVnZggYYP2F0+yvDwQw9fAA1hiu8=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvfSV875yCwWHjDQQ+GIPptQUHTiOx/9++fqr/YEq
248hBooOMbrZTa1K3+wNahIuCVkqOvgUid5+lPLN/mae3vsMB0WHFROur4/f
+M3+v+F1Dk03RYeUo/23Jdm+2xt63Luv56XocGD9Xo/fCd/tJ+2aIZHoo+hw
gkNV4vj+7/Zfj7He3gjkH5D/uFtd4Yd9xj4hLXlvRQcH7rx1e+t/2If8V/6w
yV3RoeXg9HS9Oz/s5dinHGhyUnQwMQaBn/Yhszb5r7dWdGC49rpzedNP+22B
c5ckGwPVP2SePO3ET/vXvKxcVzQVHY6UFVe6M/+yD2HvO2Ijr+jwpX+nm4fh
L3sOrxfTHggD1Tt++lcW+Mv+edxvGXYORYcpV44e4UgGyt9p5Pj9W8Fhibne
jb7UX/Yz7Iy8OD4oODh8nhrwM+KX/Xl2XuOqJwoOM37JN063/WU/ayYQ3FRw
+GKxgEVM5Jc9evgCACtXp+Q=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHSW6x7HjuLLDgpkgcNE+DQTUlB0+FDpw6mg8sTf4
8elMq7Syg8FXeyb96if2GQfPbv3Or+zQ8Ex74aeNT+y/K9d9Z2FRdgjIj9kg
e/qJvcRClsc/vis5GKzs7hQ89sT+x1bxTPk3Sg4CzU/+vl30xH7Nj0Lrww+U
HD7IF/dOSHpiL/Lp11fta0oOE94++9TH9sTea11S9JwzSg4Mh9nVdCc+tl+d
6rsh4AiQv+a6sD/rY/uHP7Lta/cqOSSAHfrIfg3DHX7fHUD5Zv3zMTse2s9w
fHv1wRYlhwaxOzHV/x/Yc1n+UvHbDDTf/lG5v8MD+1zX9OfzgHwF5SkJMv/v
2Z/brqhwcSuQv/+b0tvmu/YM5zS+X9up5LBA1D4vXeKOvdrEiwLT9wP5TnH7
647esj/fPF/37TElB4eToTndk2/a27ce4lt9HuierWs4xbpu2IOD8SbQPJn6
t8vXX7dHD18AH+qweQ==
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{3.558962051632154*^9, 3.563899200940609*^9, 
  3.564163763299885*^9, 3.5641659918897963`*^9, 3.564166788618718*^9, 
  3.564166981724346*^9, 3.564167268006854*^9, 3.564167489966441*^9, 
  3.564167732638666*^9, 3.564168070059659*^9, 3.5641683061822453`*^9, 
  3.564420365457445*^9, 3.564421404320372*^9, 3.564421585826859*^9}]
}, Open  ]],

Cell["\<\
Now the head is in state 2 and this time it\[CloseCurlyQuote]s on a black \
cell:\
\>", "Text",
 CellChangeTimes->{{3.552593775314674*^9, 3.552593823960638*^9}, {
  3.552594003215568*^9, 3.552594008813039*^9}, {3.552594052478601*^9, 
  3.552594064960184*^9}, {3.552594231679178*^9, 3.55259423378152*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmruletable", "[", 
  RowBox[{"rule", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{
  3.552594104527238*^9, 3.556903161974702*^9, {3.558962061951824*^9, 
   3.558962066127841*^9}, 3.558965665845559*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->Directive[
        RGBColor[1, 0, 0]],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{50, 50}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False]}
   },
   AutoDelete->False,
   FrameStyle->GrayLevel[0.5],
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.558962066564477*^9, 3.5638992012006617`*^9, 
  3.564163763460574*^9, 3.564165992045993*^9, 3.564166788781497*^9, 
  3.56416698188137*^9, 3.564167268153874*^9, 3.564167490176423*^9, 
  3.5641677327827873`*^9, 3.564168070391615*^9, 3.5641683064298773`*^9, 
  3.564421404501573*^9, 3.564421585976931*^9}]
}, Open  ]],

Cell["\<\
The rule says the cell stays black; the head moves right, and goes into state \
3:\
\>", "Text",
 CellChangeTimes->{{3.552593775314674*^9, 3.552593823960638*^9}, {
   3.552594003215568*^9, 3.552594008813039*^9}, {3.552594052478601*^9, 
   3.552594064960184*^9}, {3.552594231679178*^9, 3.5525942337793283`*^9}, 
   3.552594306927157*^9, {3.552594355502799*^9, 3.552594373445736*^9}, {
   3.5649431508540773`*^9, 3.564943151041247*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "4"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.558961995277556*^9, 3.5589620514557447`*^9, 
  3.558962088277604*^9}],

Cell[BoxData[
 GraphicsBox[{
   RasterBox[{{1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1}, {1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {1, 
    1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}, {{0, 0}, {21, 4}}, {
    0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 4}, {21, 4}}, {{0, 3}, {21, 3}}, {{0, 2}, {21, 2}}, {{0, 
       1}, {21, 1}}, {{0, 0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 4}}, {{1, 0}, {1, 4}}, {{2, 0}, {2, 4}}, {{3, 
       0}, {3, 4}}, {{4, 0}, {4, 4}}, {{5, 0}, {5, 4}}, {{6, 0}, {6, 4}}, {{7,
        0}, {7, 4}}, {{8, 0}, {8, 4}}, {{9, 0}, {9, 4}}, {{10, 0}, {10, 
       4}}, {{11, 0}, {11, 4}}, {{12, 0}, {12, 4}}, {{13, 0}, {13, 4}}, {{14, 
       0}, {14, 4}}, {{15, 0}, {15, 4}}, {{16, 0}, {16, 4}}, {{17, 0}, {17, 
       4}}, {{18, 0}, {18, 4}}, {{19, 0}, {19, 4}}, {{20, 0}, {20, 4}}, {{21, 
       0}, {21, 4}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDrNmggC/gzEIbFZygIjzOPD3nndU3aLkwJpj
VffxPLdD+qGL5V+3KTlY+Wq9ElzI7aCfGyw5abeSwzXpv7s7SrgdXuioiNw7
qOTAbHx1fZ43t8N1Rq7tG08qOcSwa9w5psbtcNDn6+rbl5QcFmyeEFDBzu3w
ze2/ntJdJYc9W3xTPd5xOfhN7qpyeaHkMJfT/f7V21wOjLP74v98VnKwNbFj
n3qBywHm3rNnQIDL4X9K4QJmHmW4/Kac0tbd4spw/Vw7GS7eVVKGm2+/mStE
RVcZbr/mv68efmbKDtFQ90lcvv1a0U4Z7v6Lk9Y8y3VRhvtvpq1eB5enMtz/
H4sM9t3yVnZggYYP2F0+yvDwQw9fAI1Ri6c=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveSV875yCwUHI2MQYHJIAwE1RYeWx+v/fvnK5HCg
yvZjiIGiw7pppgedBJkdDGoSLglZKjqo7ezKLTRidriZp/c+w0HRIezE6+vr
I5gd/hle59B0U3TY9Oj4W55moHqPe/f1vBQdHlyPW1K7gdlh0q4ZEok+ig4p
LUI9j+8zO3w5xnp7I5D/oP/HXWEBFof0fUJa8t6KDgtYza/fs2dxCP6v/GGT
u6LDoQenjcXzWBzk2KccaHJSdJg1EwRYHEJmbfJfb63owPD665HggywOWwPn
Lkk2Bqr/0Ojp/YTF4RUvK9cVTUWHpN079yxmZHUIZu87YiOv6PDreIzyEglW
Bw6vF9MeCAPVK1TW79ZgdXgW91uGnUPRwetVUlKLIVD+TiPH798KDpekxXOO
G7E6TLcz8uL4oOAw76fXihodVofz7LzGVU8UHHz+9h84LcfqAHbWTQWHKpkA
Jm4uVgf08AUABrGUXA==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLJDRhoIfLEHU2rKDj8sFrCIifyyN/zx
6UyrtLLDjF/yjdNtf9lnHDy79Tu/soPD56kBPyN+2f9QrvvOwqLssMJc70Zf
6i97yYUsj398V3KYceXoEY5koPxW8Uz5N0oOHY6f/pUF/rJf86PQ+vADJYcf
/TvdPAx/2Yt++vVV+5qSw4my4kp35l/2XuuSouecUXJoeMg8edqJn/ZrUn03
BBxRcmC49rpzedNP+0c/su1r9yo5GBiDAFCe4Q6/7w6g+oPT0/Xu/LCf4fj2
6oMtSg4O3Hnr9tb/sOe2/KXitxlovvzH3eoKP+zzXNOfzwPxOVQlju//bn9+
u6LCxa1A/vq9Hr8TvtszntP4fm2nkkPG0f7bkmzf7dUnXhSYvl/JYcWE6+vj
N36zv9A8X/ftMSWHgCLR249Svtk7tB7iW31eySFCN7upVemb/ayZQHBTyYHj
ePzvl6+/2qOHLwBUFLSy
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveyV875yCxWHBTNB4KJ9ehoQqKk6KMjUv12+/rr9
wSrbjyEGqg4JW9dwinXdsDesSbgkZKnq4HAyNKd78k37W3l67zMcVB0WOMXt
rzt6y57B6DqHphuQL2qfly5xx97I4959PS9VB4b935TeNt+1n7xrhkSiD9B8
5SkJMv/v2X87xnp7I5DfYP+o3N/hgX3GPiEteW9VhwKxOzHV/x/Yh/xX/rDJ
Hai/Wf98zI6H9vLsUw40OQHdA3Jn2iP70Fmb/Ndbqzp8WH1d2J/1sf22wLlL
ko2B6g+zq+lOfGz/hpeV64om0Py3zz71sT2xD2HvO2Ijr+rwQL64d0LSE3sO
rxfTHgirOgg0P/n7dtET+xdxv2XYOVQdDFZ2dwoee2LPeaeR4/dvFQeH/JgN
sqef2M+wM/Li+KDi0PBMe+GnjU/sL7DzGlc9UXFQ+GrPpF/9xH4WKBhvqjg8
KHTg1NF4Yo8evgDxMKOn
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{3.55896208840471*^9, 3.563899201242796*^9, 
  3.5641637635224133`*^9, 3.564165992090519*^9, 3.56416678884237*^9, 
  3.564166981942947*^9, 3.564167268208881*^9, 3.564167490233317*^9, 
  3.5641677328991547`*^9, 3.5641680705114*^9, 3.564168306495489*^9, 
  3.5644203698726*^9, 3.564421404570312*^9, 3.564421586026005*^9}]
}, Open  ]],

Cell["\<\
Getting the hang of it? Pretty simple, right? Here\[CloseCurlyQuote]s what \
the Turing machine evolution looks like after 20 steps:\
\>", "Text",
 CellChangeTimes->{{3.552593725155386*^9, 3.5525937538434877`*^9}, {
   3.552594567291936*^9, 3.552594571019063*^9}, {3.5529300224206877`*^9, 
   3.552930024553453*^9}, {3.557096490594775*^9, 3.557096497322391*^9}, {
   3.564831573321084*^9, 3.5648315753159127`*^9}, 3.5648323406157155`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "20"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.558961995277556*^9, 3.5589620514557447`*^9, {3.558962088277604*^9, 
   3.558962102612935*^9}}],

Cell[BoxData[
 GraphicsBox[{RasterBox[CompressedData["
1:eJx1j8ENwDAIxExmSAfoSh0hC2T/X4nUfohzCAlZOjjuMZ/RgJ59ZcevHFcV
CUSh2dd2gygMhSisKSX5d2iH8qT5AbPvLIzJ6ROU6EUvLq4DMQ==
    "], {{0, 0}, {21, 
    20}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 20}, {21, 20}}, {{0, 19}, {21, 19}}, {{0, 18}, {21, 
       18}}, {{0, 17}, {21, 17}}, {{0, 16}, {21, 16}}, {{0, 15}, {21, 15}}, {{
       0, 14}, {21, 14}}, {{0, 13}, {21, 13}}, {{0, 12}, {21, 12}}, {{0, 
       11}, {21, 11}}, {{0, 10}, {21, 10}}, {{0, 9}, {21, 9}}, {{0, 8}, {21, 
       8}}, {{0, 7}, {21, 7}}, {{0, 6}, {21, 6}}, {{0, 5}, {21, 5}}, {{0, 
       4}, {21, 4}}, {{0, 3}, {21, 3}}, {{0, 2}, {21, 2}}, {{0, 1}, {21, 
       1}}, {{0, 0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 20}}, {{1, 0}, {1, 20}}, {{2, 0}, {2, 20}}, {{3, 
       0}, {3, 20}}, {{4, 0}, {4, 20}}, {{5, 0}, {5, 20}}, {{6, 0}, {6, 
       20}}, {{7, 0}, {7, 20}}, {{8, 0}, {8, 20}}, {{9, 0}, {9, 20}}, {{10, 
       0}, {10, 20}}, {{11, 0}, {11, 20}}, {{12, 0}, {12, 20}}, {{13, 0}, {13,
        20}}, {{14, 0}, {14, 20}}, {{15, 0}, {15, 20}}, {{16, 0}, {16, 
       20}}, {{17, 0}, {17, 20}}, {{18, 0}, {18, 20}}, {{19, 0}, {19, 20}}, {{
       20, 0}, {20, 20}}, {{21, 0}, {21, 20}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDsYg8NkYQm9WcgALNxg78Peed1TdouTQ6Htc
/1+lsUP6oYvlX7cpOSz3dLVVKjF20M8Nlpy0W8mhenG9+MQ8Y4cXOioi9w4q
OSQs+3U1N9PY4Toj1/aNJ5UcXjO03r6RYuxw0Ofr6tuXlBxKxIS43icYO3xz
+6+ndFfJYfq2lTwnY40d/CZ3Vbm8UHIwefhid1W0sQPj7L74P5+VHDqOPV8g
FGXsAHPvrJlAEGns8D+lcAEzjzJcflNOaetucWW4fq6dDBfvKinDzbffzBWi
oqsMt1/z31cPPzNluPskLt9+rWinDHf/xUlrnuW6KMP9N9NWr4PLUxnu/49F
BvtueSvDw+fsGSDwUYaHH3r4AgAG9Y8k
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveSV875yCwWH9DQgcDNyAFFpaooOhX+2zt8XZ+Sw
r8r2Y4iBosO1TWoRGklGDgY1CZeELBUdVMM36vqlGTncyNN7n+Gg6MBd+feX
aLaRA4PRdQ5NN0WH8D875iYWGDkYedy7r+el6PDnVvcW/jIjh0m7Zkgk+ig6
9AY0Ff6pNnL4coz19kYg/4/g/mqmJiOHjH1CWvLeig5bHjy79bvdyCHov/KH
Te6KDhI1lc8O9Ro5yLBPOdDkpOhgDAKTgfKzNvmvt1Z0SNg7r0JrhpHDlsC5
S5KNgertDDI75xg5vOFl5bqiqeiQaz693GQBUD173xEbeUUHhpnZLSKLjRw4
vF5MeyCs6CCp8j5ffKmRw4u43zLsHIoOXrE+PQbLgPJ3Gjl+/1ZwqHrc9DYC
yJ9hZ+TF8UHBwSSec2o/UP05dl7jqicKDqv+C1bcBJo3ayYQ3FRwmMDsleC4
0MgBPXwBQhGTbg==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLJDGgi4GUJoNWWHfmavBMeFhg5GPz6d
aZVWdlj5X7Di5mJDh4yDZ7d+51d2MInnnNq/1NDhh3LddxYWZYeqx01vI5YZ
OkgsZHn847uSg2esT48BkP9jq3im/BslBwmV9/niQPVrfhRaH36g5PB/RnaL
CNA8kU+/vmpfU3LIMZ9ebrLA0MF7XVL0nDNA9XYGmZ1zgOpTfTcEHFFySNg7
r0JrhqHDox/Z9rV7lRyMjIFgsqHDOoY7/L47gOprKp8d6jV0mOn49uqDLUoO
Wx48u/W73dCBy/KXit9mJYc/gvurmZoMHfJc05/PA/J7ApoK/1QbOpzbrqhw
cStQ/lb3Fv4yQweGcxrfr+1Ucgj7s2NuYoGhg8bEiwLT9ys5cFX+/SWabehw
oXm+7ttjSg4q4Rt1/dIMHRxaD/GtPq/kcHWTWoRGkqHDrJlAcFPJoeDP1vn7
4gwd0MMXALgCogI=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveyV875yCxWHNBBwM3DIANFqqg4Ff7bO3xdn4HCg
yvZjiIGqw7VNahEaSQYORjUJl4QsVR1Uwzfq+qUZONzK03uf4aDqwFX595do
toEDg9F1Dk03VYewPzvmJhYA1Xvcu6/nperw51b3Fv4yA4cpu2ZIJPqoOvQE
NBX+qTZw+HaM9fZGIP+P4P5qpiag/fuEtOS9VR22PHh263e7gUPIf+UPm9xV
HSRqKp8d6jVwkGOfcqDJSdXBGAQmA+VnbfJfb63qkLB3XoXWDAOHbYFzlyQb
A9XbGWR2zjFweMPLynVFU9Uhx3x6uckCoHr2viM28qoO/2dkt4gsNnDg8nox
7YEwUL3K+3zxpQYOL+J+y7BzqDp4xfr0GCwzcOC408jx+7eKQ9XjprcRQP4M
OyMvjg8qDibxnFP7geovsPMaVz1RcVj5X7DiJtC8WTOB4KaKQz+zV4LjQgMH
9PAFAO3ulK4=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLrDGRDo0XNIAwE1dQcZ9ikHmpz0HQx+
fDrTKq3uEPRf+cMmd32HjINnt37nV3dI2yekJe+t7/BDue47C4u6w5djrLc3
+ug7SC5kefzju5rDhF0zJBKB/B9bxTPl36g56Hncu6/npe+w5keh9eEHag5/
DK9zaLrpO4h++vVV+5qaw7U8vfcZDvoOXuuSouecAaqvSbgkZAlUn+q7IeCI
msO+KtuPIQb6Dg9/ZNvX7lVzSAG7EyjPcIffdwdQPdid+g4zHN9efbBFzSEN
7E59B27LXyp+m9UcvoHdqe+Q55r+fB6QLwF2p57Due2KChe3AuXB7tRzYDyn
8f3aTjWHVWB36jmoTbwoMH2/moMI2J1A9c3zdd8eU3PwALtTz8Gh9RDf6vNA
9WB36jnMmgkEN9UcHoDdqeeAHr4AzvCoaQ==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGaDmkg8EzXwRgENms4QMR1Hfh7zzuqbtFwYJzd
F//ns45D+qGL5V+3aTj4Te6qcnmh46CfGyw5abeGwze3/3pKd3UcXuioiNw7
qOFw0Ofr6tuXdByuM3Jt33hSA0rrQMU1oOp0oPo0oOboQM3VgNqjA7VXA+oO
HQeYeyHu1HH4n1K4gJlHEy6/Kae0dbe4Jlw/106Gi3eVNOHm22/mClHR1YTb
r/nvq4efmSbcfRKXb79WtNOEu//ipDXPcl004f6baavXweWpCff/xyKDfbe8
NeHhc/YMEPhowsMPPXwBdUGSqA==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveyV875yCzWHs2eAoEfLISMNCNTUHR79yLav3avl
cKDK9mOIgbrDmlTfDQFHtByMahIuCVmqO3itS4qec0bL4Vae3vsMB3UH0U+/
vmpf03JgMLrOoekGVP+j0PrwA6B6j3v39bzUHX5sFc+Uf6PlMGXXDIlEH3UH
yYUsj39813L4coz19kYg/4dy3XcWFm2HjH1CWvLe6g4ZB89u/c6v7RDyX/nD
Jnd1B4Mfn860Sms7KLBPOdDkpO6QBnYnUH7WJv/11upQd2o77AicuyTZGKge
7E5thze8rFxXNNWh7gSqZ+87YiOv7vDfEORObQcOrxfTHgirQ92p7fAi7rcM
O4e6wySwO4Hydxo5fv9Wc/gKdqe2www7Iy+OD2pQd2o7XGDnNa56ogZ1p7bD
rJlAcFPNQR7sTm0H9PAFANUbmtQ=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGqDmkg8EzTwRgENqs4QMQ1Hfh7zzuqblFxYJzd
F//ns4ZD+qGL5V+3qTj4Te6qcnmh4aCfGyw5abeKwze3/3pKdzUcXuioiNw7
qOJw0Ofr6tuXNByuM3Jt33hSBUprQMVVoOo0oPpUoOZoQM1VgdqjAbVXBeoO
DQeYeyHu1HD4n1K4gJlHFS6/Kae0dbe4Klw/106Gi3eVVOHm22/mClHRVYXb
r/nvq4efmSrcfRKXb79WtFOFu//ipDXPcl1U4f6baavXweWpCvf/xyKDfbe8
VeHhc/YMEPiowsMPPXwB8mKR8A==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLrD2TNA0KPmkAYCauoOcuxTDjQ5qTsY
/Ph0plVa3SHkv/KHTe7qDhkHz279zg+k9wlpyXurO/xQrvvOwqLu8PUY6+2N
PuoOkgtZHv/4ruYwadcMiUQg/8dW8Uz5N2oOBh737ut5qTus+VFoffiBmsN/
w+scmm7qDqKffn3VvqbmcCNP732Gg7qD17qk6DlngOprEi4JWQLVp/puCDii
5nCgyvZjiIG6w6Mf2fa1exHuXMNwh993hxrcnTMc3159sEUN7k5uy18qfpvV
4O7Mc01/Pg/Ih7nzwnZFhYtb1eDuZDyn8f3aTjW4OzUmXhSYvl8N7s4LzfN1
3x5Tg7vTofUQ3+rzanB3zpoJBDfVHB5C3YkevgBwWKfh
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGaDmkg8EzVwRgENms4QMRVHfh7zzuqbtFwYJzd
F//ns4pD+qGL5V+3aTj4Te6qcnmh4qCfGyw5abeGwze3/3pKd1UcXuioiNw7
qOFw0Ofr6tuXVByuM3Jt33hSA0qrQMU1oOpUoPo0oOaoQM3VgNqjArVXA+oO
FQeYeyHuVHH4n1K4gJlHEy6/Kae0dbe4Jlw/106Gi3eVNOHm22/mClHR1YTb
r/nvq4efmSbcfRKXb79WtNOEu//ipDXPcl004f6baavXweWpCff/xyKDfbe8
NeHhc/YMEPhowsMPPXwB9UKR8A==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLbDuTNA0KPkkAYCatoOCuxTDjQ5KTsY
/Ph0plVa2yHkv/KHTe7KDhkHz279zq/tkLFPSEveW9nhh3LddxYWbYcvx1hv
b/RRdpBcyPL4x3cthym7ZkgkAvk/topnyr/RcjDyuHdfz0vZYc2PQuvDD7Qc
GIyuc2i6KTuIfvr1VfualsOtPL33GQ7KDl7rkqLnnAGqr0m4JGQJVJ/quyHg
iJbDgSrbjyEGyg4Pf2Tb1+7VcsgAuxMoz3CH33cHUD3YncoOMxzfXn2wRQvq
TmUHbstfKn6btaDuVHbIc01/Pg/IlwK7U8nhwnZFhYtbtaDuVHJgPKfx/dpO
LYd1YHcqOWhMvCgwfb+WgxjYnUD1zfN13x7TcvABu1PJwaH1EN/q81pQdyo5
zJoJBDe1HB6B3ankgB6+AIvIpvg=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQG6Dmkg8EzRwRgENus4QMQVHfh7zzuqbtFxYJzd
F//ns4JD+qGL5V+36Tj4Te6qcnmh4KCfGyw5abeOwze3/3pKdxUcXuioiNw7
qONw0Ofr6tuXFByuM3Jt33hSB0orQMV1oOoUoPp0oOYoQM3VgdqjALVXB+oO
BQeYeyHuVHD4n1K4gJlHFy6/Kae0dbe4Llw/106Gi3eVdOHm22/mClHR1YXb
r/nvq4efmS7cfRKXb79WtNOFu//ipDXPcl104f6baavXweWpC/f/xyKDfbe8
deHhc/YMEPjowsMPPXwB+CKR8A==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvfSV875yCy2HWTOBQFLWIT0NCNS0HY58vF73q0rW
4UCV7ccQA22HyNOzEhZ2yDoY1CRcErLUdpgSc3SbxUxZh1t5eu8zHLQddJ58
fR2+RtaBweg6h6abtkPUx8dlbQdlHQw97t3X89J2+Jitf8nuhqzD5F0zJBJ9
tB1MnDiPfXwv6/D1GOvtjUD+R/c/7zg55Bwy9glpyXtrO1xsmp39Xl7OIeS/
8odN7toOyR+ezuQ2l3OQZ59yoMlJ2+HcGSDwAcrP2uS/3lrboelr1aOVCXIO
2wLnLkk21nZI+nFgiWqRnMNrXlauK5raDpvuxty72ABUz953xEZe2+Ff8jrB
oB45Bw6vF9MeCAPVT9izP3aKnMOLuN8y7BzaDmqlhoaHZgDl7zRy/P6t5fCq
l3tb8kw5hxl2Rl4cH7QcLtSohthNk3O4wM5rXPVEy2HZP/cHqf1ykHC8qeVg
x6fRyNoq54AevgATAJ3z
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGaDmfPgIC0gzEIbNZwgIhLOfD3nndU3aLhwGQm
u//Hc0mH9EMXy79u03CYqyb6teOCpIN+brDkpN0aDq97/8W67JJ0eKGjInLv
oIZD48xX4duXSjpcZ+TavvGkhsM6ZpG85MmSDgd9vq6+fUnD4UKkh8aeZkmH
b27/9ZTuajjE3VpmpFIu6eA3uavK5YWGw7mWxe9f5Uo6MM7ui//zWcNBTmp+
s1eGpAPMvWlgIOnwP6VwATOPJlx+U05p625xTbh+rp0MF+8qacLNt9/MFaKi
qwm3X/PfVw8/M024+yQu336taKcJd//FSWue5bpowv0301avg8tTE+7/j0UG
+255a8LDBxyOPprw8EMPXwAi3pIZ
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveSV875yCzWHWTOBQFLUIQ0E1NQdjny8XverStTh
QJXtxxADdYfw07MSFnaIOhjUJFwSslR3mBJzdJvFTFGHm3l67zMc1B20nnx9
Hb5G1OG/4XUOTTd1h6iPj8vaDgLVe9y7r+el7vAxW/+S3Q1Rh0m7Zkgk+qg7
GDlxHvv4XtThyzHW2xuB/I/uf95xcog5ZOwT0pL3Vne42DQ7+728mEPwf+UP
m9zVHRI/PJ3JbS7mIMc+5UCTk7rD2TNA4CPmEDJrk/96a3WHxq9Vj1YmiDls
C5y7JNkYqP7HgSWqRWIOr3hZua5oqjtsvhtz72ID0Dz2viM28uoO/5LXCQb1
iDlweL2Y9kBY3SF5wp79sVPEHJ7H/ZZh51B3UCs1NDw0Ayh/p5Hj9281h1e9
3NuSZ4o5TLcz8uL4oOZwoUY1xG6amMN5dl7jqidqDsv/uT9I7RdzAAXjzJtq
DnZ8Go2srWIO6OELAFoZncY=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGqDmfPgICwgzEIbFZxgIgLOfD3nndU3aLiwGQm
u//Hc0GH9EMXy79uU3GYqyb6teOCoIN+brDkpN0qDq97/8W67BJ0eKGjInLv
oIpD48xX4duXCjpcZ+TavvGkisM6ZpG85MmCDgd9vq6+fUnF4UKkh8aeZkGH
b27/9ZTuqjjE3VpmpFIu6OA3uavK5YWKw7mWxe9f5Qo6MM7ui//zWcVBTmp+
s1eGoAPMvWlgIOjwP6VwATOPKlx+U05p625xVbh+rp0MF+8qqcLNt9/MFaKi
qwq3X/PfVw8/M1W4+yQu336taKcKd//FSWue5bqowv0301avg8tTFe7/j0UG
+255q8LDBxyOPqrw8EMPXwBgB5EF
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveSV875yCyUHE2MQ4HJITQMCNWWHlsfr/375yuWw
v8r2Y4iBssO6aaYHnQS5HfRrEi4JWSo7aOzsyi004na4kaf3PsNB2SHkxOvr
6yO4Hf4ZXufQdFN22PTo+FueZm4HA4979/W8lB0eXY9bUruB22HirhkSiT7K
DiktQj2P73M7fDnGensjkP+o/8ddYQEeh7R9Qlry3soOi1jNr9+z53EI+q/8
YZO7ssOhB6eNxfN4HGTZpxxoclJ2mDUTBHgcgmdt8l9vrezA9PrrkeCDPA5b
AucuSTYGqv/Q6On9hMfhFS8r1xVNZYek3Tv3LGbkdQhi7ztiI6/s8Od4jPIS
CV4Hdq8X0x4IA9UrVNbv1uB1eBb3W4adQ9nB61VSUoshUP5OI8fv30oOV6TF
c44b8TpMszPy4vig5LDgp9eKGh1eh3PsvMZVT5Qc/P72Hzgtx+swA+Ssm0oO
NTIBTNxcvA7o4QsAqK2VSA==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGKDrNmggC7gzEIbFZwgIizOPD3nndU3aLgwJpj
VffxPLND+qGL5V+3KThY+Wq9ElzI7KCfGyw5abeCwzXpv7s7SpgdXuioiNw7
qODAbHx1fZ43s8N1Rq7tG08qOMSwa9w5psbscNDn6+rblxQcFmyeEFDBzuzw
ze2/ntJdBYc9W3xTPd4xOfhN7qpyeaHgMJfT/f7V20wOjLP74v98VnCwNbFj
n3qByQHm3rNnQIDJ4X9K4QJmHkW4/Kac0tbd4opw/Vw7GS7eVVKEm2+/mStE
RVcRbr/mv68efmaKDtFQ90lcvv1a0U4R7v6Lk9Y8y3VRhPtvpq1eB5enItz/
H4sM9t3yVnRggYYP2F0+ivDwQw9fAOvmisE=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLJDRhoIfLEHU2rKDj8sFrCIifyyN/zx
6UyrtLLDjF/yjdNtf9lnHDy79Tu/soPD56kBPyN+2f9QrvvOwqLssMJc70Zf
6i97yYUsj398V3KYceXoEY5koPxW8Uz5N0oOHY6f/pUF/rJf86PQ+vADJYcf
/TvdPAx/2Yt++vVV+5qSw4my4kp35l/2XuuSouecUXJoeMg8edqJn/ZrUn03
BBxRcmC49rpzedNP+0c/su1r9yo5GBiDAFCe4Q6/7w6g+oPT0/Xu/LCf4fj2
6oMtSg4O3Hnr9tb/sOe2/KXitxlovvzH3eoKP+zzXNOfzwPxOVQlju//bn9+
u6LCxa1A/vq9Hr8TvtszntP4fm2nkkPG0f7bkmzf7dUnXhSYvl/JYcWE6+vj
N36zv9A8X/ftMSWHgCLR249Svtk7tB7iW31eySFCN7upVemb/ayZQHBTyYHj
ePzvl6+/2qOHLwBUFLSy
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGqDmlg8M7eGAQ2qzhAxB/Y8/eed1TdouKgknD5
Y3f9Pfv0QxfLv25TcTiXGRTYz3HXXj83WHLSbhWHLfde3Hddctv+hY6KyL2D
Kg7iM1bWlUbfsr/OyLV940kVhztWDg/NzG7aH/T5uvr2JRUHxrmtLYesb9h/
c/uvp3RXxeHB0lwt56Lr9n6Tu6pcXqg4PPex+LXu3jV7xtl98X8+qzg8XfjR
ckXLNXtU916z/59SuICZR9XhCVR+U05p625xVYdnUP1cOxku3lVShZtvv5kr
REVX1YEBar/mv68efmaqcPdJXL79WtFO1UEM6v6Lk9Y8y3VRddgM9d9MW70O
Lk9Vh7NQ/38sMth3y1vVQRkaPmfPAIGPKjz80MMXAAMLoEQ=
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{3.558962103168098*^9, 3.5638992013245783`*^9, 
  3.564163763622239*^9, 3.564165992177672*^9, 3.564166788948143*^9, 
  3.564166982025586*^9, 3.564167268300232*^9, 3.564167490361305*^9, 
  3.564167732991255*^9, 3.564168070628811*^9, 3.5641683065938177`*^9, 
  3.564420373107926*^9, 3.564421404659412*^9, 3.564421586106832*^9}]
}, Open  ]],

Cell[TextData[{
 "You can use this handy little ",
 ButtonBox["CDF",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/cdf"], None},
  ButtonNote->"http://www.wolfram.com/cdf"],
 " to follow along. It shows the evolution step by step, indicating which \
case in the rule table is used each time:"
}], "Text",
 CellChangeTimes->{{3.55267304718157*^9, 3.552673081888905*^9}, {
  3.5526731348275957`*^9, 3.552673211177349*^9}, {3.556902416292542*^9, 
  3.556902458451044*^9}, {3.5569025281731987`*^9, 3.556902531937615*^9}, {
  3.5612217042331657`*^9, 3.5612217129655447`*^9}, {3.56500487616798*^9, 
  3.5650048761714907`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Column", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmruletable", "[", 
        RowBox[{"rule", ",", 
         RowBox[{"timestepcases", "[", 
          RowBox[{"[", "t", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"ArrayPlot", "[", 
        RowBox[{
         RowBox[{"PadRight", "[", 
          RowBox[{
           RowBox[{"tmevolution", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "20", 
           ",", 
           RowBox[{"{", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
         RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"MapIndexed", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"tmhead", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], 
                   ",", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"20", "+", "0.5"}], ")"}], "-", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], 
                "]"}], "&"}], ",", 
              RowBox[{"tmevolution", "[", 
               RowBox[{"[", 
                RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], 
         ",", 
         RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Alignment", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Center", ",", "Center"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Control", "[", 
    RowBox[{"{", 
     RowBox[{"t", ",", "1", ",", "20", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"TuringStep", "[", 
        RowBox[{"list_", ",", "state_", ",", "position_", ",", "rules_"}], 
        "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"newstate", ",", "newvalue", ",", "move", ",", "newpos"}], 
          "}"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"newstate", ",", "newvalue", ",", "move"}], "}"}], "=", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"state", ",", 
              RowBox[{"list", "[", 
               RowBox[{"[", "position", "]"}], "]"}]}], "}"}], "/.", 
            "rules"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newpos", "=", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"position", "+", "move"}], ",", 
             RowBox[{"Length", "@", "list"}], ",", "1"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ReplacePart", "[", 
             RowBox[{"list", ",", 
              RowBox[{"position", "\[Rule]", "newvalue"}]}], "]"}], ",", 
            "newstate", ",", "newpos"}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"TuringEvolve", "[", 
        RowBox[{
        "list_", ",", "state_", ",", "position_", ",", "rules_", ",", "t_"}], 
        "]"}], ":=", 
       RowBox[{"NestList", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"TuringStep", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", "rules"}], "]"}], "&"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"list", ",", "state", ",", "position"}], "}"}], ",", "t"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tmhead", "[", 
        RowBox[{"pos_List", ",", "state_", ",", "numstates_", ",", "scale_"}],
         "]"}], ":=", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"rt", "=", 
           RowBox[{"RotationTransform", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "state"}], "*", "2", "*", 
              RowBox[{"Pi", "/", "numstates"}]}], ",", "pos"}], "]"}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Lighter", "@", 
            RowBox[{"Lighter", "@", "Orange"}]}], ",", 
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Darker", "@", "Orange"}], "]"}], ",", 
           RowBox[{"Polygon", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"rt", "[", 
               RowBox[{"pos", "+", 
                RowBox[{"#", "*", "scale"}]}], "]"}], "&"}], "/@", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "3"}], "}"}], "}"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Chop", "@", 
                  RowBox[{"N", "@", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Cos", "[", "theta", "]"}], ",", 
                    RowBox[{"Sin", "[", "theta", "]"}]}], "}"}]}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"theta", ",", "Pi", ",", 
                   RowBox[{"2", "Pi"}], ",", 
                   RowBox[{"Pi", "/", "20."}]}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "3"}], "}"}], "}"}]}], "]"}]}], "]"}]}], 
          "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rule", "=", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], 
        "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"statecolor", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Outer", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"case2index", "=", 
       RowBox[{"MapIndexed", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "->", 
           RowBox[{"#2", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "&"}], ",", "statecolor"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"cases", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#", ",", 
           RowBox[{"#", "/.", "rule"}]}], "}"}], "&"}], "/@", 
        "statecolor"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmevolution", "=", 
       RowBox[{"TuringEvolve", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "21", "}"}]}], "]"}], ",", "0", ",", "10", ",", 
         "rule", ",", "20"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"timestepcases", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"Extract", "[", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"#", "[", 
               RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], "/.", 
          "case2index"}], "&"}], "/@", "tmevolution"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tmruletable", "[", 
        RowBox[{"rules_", ",", 
         RowBox[{"highlightcase_Integer:", "0"}]}], "]"}], ":=", 
       RowBox[{"Module", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"cases", ",", "statecolor", ",", "numstates"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"numstates", "=", 
           RowBox[{
            RowBox[{"Max", "@", 
             RowBox[{"rules", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "1", ",", "1"}], "]"}], "]"}]}], "+", 
            "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"statecolor", "=", 
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Outer", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"cases", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"#", ",", 
               RowBox[{"#", "/.", "rules"}]}], "}"}], "&"}], "/@", 
            "statecolor"}]}], ";", 
          RowBox[{"Grid", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"MapIndexed", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Module", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"i", "=", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", 
                    RowBox[{"instate", "=", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
                    RowBox[{"outstate", "=", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
                    RowBox[{"incolor", "=", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
                    RowBox[{"outcolor", "=", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", 
                    RowBox[{"outdir", "=", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ",", "tackon"}], 
                   "}"}], ",", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"tackon", "=", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"outdir", "\[Equal]", "1"}], ",", "Append", ",", 
                    "Prepend"}], "]"}]}], ";", "\[IndentingNewLine]", 
                   RowBox[{"Framed", "[", 
                    RowBox[{
                    RowBox[{"Pane", "[", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{"tackon", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"ArrayPlot", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "incolor", "}"}], ",", 
                    RowBox[{"{", "outcolor", "}"}]}], "}"}], ",", 
                    RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "20"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", 
                    RowBox[{"tmhead", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.5", ",", "1.5"}], "}"}], ",", "instate", ",", 
                    "numstates", ",", "0.15"}], "]"}]}], "}"}]}]}], "]"}], 
                    "}"}], ",", 
                    RowBox[{"ArrayPlot", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "0", "}"}], ",", 
                    RowBox[{"{", "0", "}"}]}], "}"}], ",", 
                    RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "20"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", 
                    RowBox[{"tmhead", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.5", ",", "0.5"}], "}"}], ",", "outstate", ",", 
                    "numstates", ",", "0.15"}], "]"}]}], "}"}]}], ",", 
                    RowBox[{"Frame", "\[Rule]", "None"}]}], "]"}]}], "]"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"43", ",", "43"}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Center", ",", "Center"}], "}"}]}], ",", 
                    RowBox[{"ContentPadding", "\[Rule]", "False"}], ",", 
                    RowBox[{"ImageMargins", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"outdir", "\[Equal]", "1"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", 
                    RowBox[{"-", "3"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3"}], ",", "5"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}]}], "]"}], ",", 
                    RowBox[{"FrameStyle", "\[Rule]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"i", "\[Equal]", "highlightcase"}], ",", 
                    RowBox[{"Directive", "[", "Red", "]"}], ",", "White"}], 
                    "]"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], "&"}],
                ",", "cases"}], "]"}], "}"}], ",", 
            RowBox[{"Frame", "\[Rule]", "All"}], ",", 
            RowBox[{"FrameStyle", "\[Rule]", "Gray"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"SynchronousInitialization", "\[Rule]", "True"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.5524047468670473`*^9, 3.552404775013761*^9}, {
   3.552406051091916*^9, 3.55240614720894*^9}, {3.552406189408704*^9, 
   3.552406207275564*^9}, {3.552406261125786*^9, 3.5524062995757732`*^9}, {
   3.552406361753644*^9, 3.552406398551684*^9}, {3.55240645349432*^9, 
   3.5524064645155077`*^9}, {3.552406548919224*^9, 3.55240654934128*^9}, {
   3.55240659275745*^9, 3.552406611506963*^9}, {3.552406658469256*^9, 
   3.552406706045288*^9}, {3.552410380479425*^9, 3.55241040003972*^9}, {
   3.552410495517188*^9, 3.5524104966883383`*^9}, {3.552410532727171*^9, 
   3.5524106415913553`*^9}, {3.55241097742211*^9, 3.552411009366679*^9}, {
   3.552411091596505*^9, 3.552411099096323*^9}, {3.5525886910955153`*^9, 
   3.552588710208647*^9}, {3.55258874636275*^9, 3.552588748055073*^9}, {
   3.552588871659472*^9, 3.552588915934703*^9}, {3.5570966636430597`*^9, 
   3.5570966638495617`*^9}, {3.5570967817531157`*^9, 
   3.5570968251415052`*^9}, {3.558963953984288*^9, 3.5589639640324583`*^9}, 
   3.558964002334818*^9, 3.558964055162757*^9, {3.558964092711553*^9, 
   3.558964092796083*^9}, {3.558964167673418*^9, 3.558964168985867*^9}, {
   3.558964247566021*^9, 3.558964284273802*^9}, {3.564167172775744*^9, 
   3.5641671764063263`*^9}, {3.5641672255711517`*^9, 3.564167231344849*^9}, {
   3.5641674562427177`*^9, 3.564167465849949*^9}, {3.564167664392352*^9, 
   3.564167691481147*^9}, 3.5641680448621893`*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 1, 20, 1}}, Typeset`size$$ = {
    400., {221.625, 227.375}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`t$3989$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`t$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$3989$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         $CellContext`tmruletable[$CellContext`rule, 
          Part[$CellContext`timestepcases, $CellContext`t$$]], 
         ArrayPlot[
          PadRight[
           Part[$CellContext`tmevolution, 
            Span[1, $CellContext`t$$], 1], 20, {
            Table[0, {21}]}], Mesh -> True, Epilog -> {Red, 
            
            MapIndexed[$CellContext`tmhead[{
              Part[#, 3] - 1 + 0.5, (20 + 0.5) - Part[#2, 1]}, 
              Part[#, 2], 3, 0.15]& , 
             Part[$CellContext`tmevolution, 
              Span[1, $CellContext`t$$]]]}, ImageSize -> 400]}, 
        Alignment -> {Center, Center}], 
      "Specifications" :> {{$CellContext`t$$, 1, 20, 1, Appearance -> 
         "Labeled"}}, "Options" :> {SynchronousInitialization -> True}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{445., {267., 272.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`TuringStep[
         Pattern[$CellContext`list, 
          Blank[]], 
         Pattern[$CellContext`state, 
          Blank[]], 
         Pattern[$CellContext`position, 
          Blank[]], 
         Pattern[$CellContext`rules, 
          Blank[]]] := 
       Module[{$CellContext`newstate, $CellContext`newvalue, \
$CellContext`move, $CellContext`newpos}, {$CellContext`newstate, \
$CellContext`newvalue, $CellContext`move} = ReplaceAll[{$CellContext`state, 
             
             Part[$CellContext`list, $CellContext`position]}, \
$CellContext`rules]; $CellContext`newpos = 
          Mod[$CellContext`position + $CellContext`move, 
            Length[$CellContext`list], 1]; {
           
           ReplacePart[$CellContext`list, $CellContext`position -> \
$CellContext`newvalue], $CellContext`newstate, $CellContext`newpos}]; \
$CellContext`TuringEvolve[
         Pattern[$CellContext`list, 
          Blank[]], 
         Pattern[$CellContext`state, 
          Blank[]], 
         Pattern[$CellContext`position, 
          Blank[]], 
         Pattern[$CellContext`rules, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]]] := NestList[$CellContext`TuringStep[
          Part[#, 1], 
          Part[#, 2], 
          
          Part[#, 3], $CellContext`rules]& , {$CellContext`list, \
$CellContext`state, $CellContext`position}, $CellContext`t]; \
$CellContext`tmhead[
         Pattern[$CellContext`pos, 
          Blank[List]], 
         Pattern[$CellContext`state, 
          Blank[]], 
         Pattern[$CellContext`numstates, 
          Blank[]], 
         Pattern[$CellContext`scale, 
          Blank[]]] := 
       With[{$CellContext`rt = 
          RotationTransform[((-$CellContext`state) 2) (
             Pi/$CellContext`numstates), $CellContext`pos]}, {
          Lighter[
           Lighter[Orange]], 
          EdgeForm[
           Darker[Orange]], 
          Polygon[
           Map[$CellContext`rt[$CellContext`pos + # $CellContext`scale]& , 
            Join[{{0, 3}}, 
             Table[
              Chop[
               N[{
                 Cos[$CellContext`theta], 
                 Sin[$CellContext`theta]}]], {$CellContext`theta, Pi, 2 Pi, 
               Pi/20.}], {{0, 3}}]]]}]; $CellContext`rule = {{0, 1} -> {1, 0, 
          1}, {0, 0} -> {2, 1, -1}, {1, 1} -> {2, 1, 1}, {1, 0} -> {0, 1, 
          1}, {2, 1} -> {0, 0, -1}, {2, 0} -> {1, 1, 
          1}}; $CellContext`statecolor = Flatten[
         Outer[{#, #2}& , {0, 1, 2}, {1, 0}], 1]; $CellContext`case2index = 
       MapIndexed[# -> 
         Part[#2, 1]& , $CellContext`statecolor]; $CellContext`cases = Map[{#, 
          
          ReplaceAll[#, $CellContext`rule]}& , $CellContext`statecolor]; \
$CellContext`tmevolution = $CellContext`TuringEvolve[
         Table[0, {21}], 0, 10, $CellContext`rule, 
         20]; $CellContext`timestepcases = Map[ReplaceAll[{
           Part[#, 2], 
           Extract[
            Part[#, 1], 
            
            Part[#, 3]]}, $CellContext`case2index]& , \
$CellContext`tmevolution]; $CellContext`tmruletable[
         Pattern[$CellContext`rules, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`highlightcase, 
           Blank[Integer]], 0]] := 
       Module[{$CellContext`cases, $CellContext`statecolor, \
$CellContext`numstates}, $CellContext`numstates = Max[
             Part[$CellContext`rules, All, 1, 1]] + 
           1; $CellContext`statecolor = Flatten[
            Outer[{#, #2}& , {0, 1, 2}, {1, 0}], 1]; $CellContext`cases = 
          Map[{#, 
             ReplaceAll[#, $CellContext`rules]}& , $CellContext`statecolor]; 
         Grid[{
            MapIndexed[
            Module[{$CellContext`i = Part[#2, 1], $CellContext`instate = 
               Part[#, 1, 1], $CellContext`outstate = 
               Part[#, 2, 1], $CellContext`incolor = 
               Part[#, 1, 2], $CellContext`outcolor = 
               Part[#, 2, 2], $CellContext`outdir = 
               Part[#, 2, 3], $CellContext`tackon}, $CellContext`tackon = 
               If[$CellContext`outdir == 1, Append, Prepend]; Framed[
                Pane[
                 Row[
                  $CellContext`tackon[{
                    
                    ArrayPlot[{{$CellContext`incolor}, \
{$CellContext`outcolor}}, Mesh -> True, ImageSize -> 20, Epilog -> {Red, 
                    $CellContext`tmhead[{0.5, 
                    1.5}, $CellContext`instate, $CellContext`numstates, 
                    0.15]}]}, 
                   
                   ArrayPlot[{{0}, {0}}, Mesh -> None, ImageSize -> 20, 
                    Epilog -> {Red, 
                    $CellContext`tmhead[{0.5, 
                    0.5}, $CellContext`outstate, $CellContext`numstates, 
                    0.15]}, Frame -> None]]], {43, 43}, 
                 Alignment -> {Center, Center}, ContentPadding -> False, 
                 ImageMargins -> {
                   If[$CellContext`outdir == 1, {5, -3}, {-3, 5}], {0, 0}}], 
                FrameStyle -> If[$CellContext`i == $CellContext`highlightcase, 
                  Directive[Red], White]]]& , $CellContext`cases]}, Frame -> 
           All, FrameStyle -> Gray]]; Null); Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.558964186305646*^9, {3.5589642628705587`*^9, 3.5589642851723967`*^9}, 
   3.563900351967462*^9, 3.564163776791827*^9, 3.564164133791428*^9, 
   3.5641659924645967`*^9, 3.5641667890670223`*^9, 3.564166890636393*^9, 
   3.564166982128849*^9, 3.564167189641572*^9, {3.5641672445363903`*^9, 
   3.5641672684446783`*^9}, 3.5641673774104853`*^9, 3.5641674904957438`*^9, 
   3.5641677334426823`*^9, 3.564168070721939*^9, 3.564168306757594*^9, 
   3.564420400852511*^9, 3.564421419475814*^9, 3.564421586176908*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Using the TuringMachine Function\
\>", "Section",
 CellChangeTimes->{{3.564164167937811*^9, 3.56416418164729*^9}, {
  3.565003200348712*^9, 3.565003200691526*^9}}],

Cell[TextData[{
 "Now let\[CloseCurlyQuote]s use the built-in ",
 StyleBox[ButtonBox["TuringMachine",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/mathematica/ref/TuringMachine.html"], 
    None},
  ButtonNote->
   "http://reference.wolfram.com/mathematica/ref/TuringMachine.html"], 
  "FunctionLink"],
 " function to run this Turing machine rule. Here are the ",
 ButtonBox["rules",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/nksonline/page-888a-text"], None},
  ButtonNote->"http://www.wolframscience.com/nksonline/page-888a-text"],
 ", in the form ",
 StyleBox["{state, cell color} -> {new state, new color, head movement}", 
  "Input",
  FontWeight->"Plain"],
 ":"
}], "Text",
 CellChangeTimes->{{3.552673347450786*^9, 3.552673364984811*^9}, {
   3.552673761069306*^9, 3.552673792855302*^9}, {3.552673876006336*^9, 
   3.5526738849809237`*^9}, {3.552674127320899*^9, 3.552674127380645*^9}, {
   3.552930068091156*^9, 3.552930123478715*^9}, {3.5569025575679626`*^9, 
   3.556902650684557*^9}, {3.561392634802742*^9, 3.561392635002008*^9}, {
   3.561472237534803*^9, 3.5614722414045343`*^9}, {3.563899778416443*^9, 
   3.56389978008622*^9}, 3.5648315782458177`*^9, {3.5649149841579027`*^9, 
   3.564914993737638*^9}, {3.5649150254769793`*^9, 3.5649150302401876`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rule", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552589161990251*^9, 3.552589176592683*^9}, 
   3.552673634034667*^9}],

Cell["\<\
We just plug in the rules with the initial condition\[LongDash]a blank tape \
with the head in state 1 (note that states 1, 2, and 3 are denoted 0, 1, and \
2)\[LongDash]and the number of time steps to run for:\
\>", "Text",
 CellChangeTimes->{{3.5569026750778217`*^9, 3.556902713173543*^9}, {
  3.5641642084821663`*^9, 3.5641642375896387`*^9}, {3.5641643813401403`*^9, 
  3.564164536620541*^9}, {3.564164573430236*^9, 3.564164579219225*^9}, {
  3.564832509955806*^9, 3.5648325240752726`*^9}, {3.5649150565092487`*^9, 
  3.564915060866053*^9}, {3.564943185016103*^9, 3.564943189887906*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evolution", "=", 
   RowBox[{"TuringMachine", "[", 
    RowBox[{"rule", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "200"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5526733921043587`*^9, 3.55267345117946*^9}, {
   3.552673499542612*^9, 3.552673563930232*^9}, 3.552673637370534*^9, {
   3.552673733543768*^9, 3.552673735077949*^9}, {3.552674065860374*^9, 
   3.5526740777207737`*^9}, 3.55896215704828*^9, 3.5589656789647083`*^9, 
   3.563899428340893*^9}],

Cell["\<\
Here\[CloseCurlyQuote]s what the tape looks like after 200 steps:\
\>", "Text",
 CellChangeTimes->{{3.552673799085997*^9, 3.552673855567316*^9}, {
  3.552674020158016*^9, 3.552674031444312*^9}, {3.5529301325295067`*^9, 
  3.5529301385158663`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Framed", "@", 
  RowBox[{"ArrayPlot", "[", 
   RowBox[{
    RowBox[{"evolution", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"PixelConstrained", "\[Rule]", "2"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5526734006398497`*^9, 3.552673407754815*^9}, {
   3.5526734565672693`*^9, 3.552673470467187*^9}, 3.552673558898941*^9, {
   3.552673597330921*^9, 3.5526736003694*^9}, {3.552673738084041*^9, 
   3.5526737389142017`*^9}, 3.552674082471545*^9}],

Cell[BoxData[
 FrameBox[
  GraphicsBox[RasterBox[CompressedData["
1:eJzt1sFNA0EQRNFfJMGZlAjBCThOssIHrz3u+QXaK8LIl+dRd1fvrMTH5fp5
eQO+bt/32zf65/x/9u+fpdwJvAxeCG+LN8bHPA4WTmEKpzCFU5jCKUzhFKZw
ClM4hdsT9hsRf77KUUY5yihHGeUooxxllKM855SzD943IGfvbLvVF/CHR+9F
rMz9ShSWOBboea8Kz8Xaal8uZ+EUpnAKUziFKZzCFI4XUUY5yihHGeUooxxl
lKOM8lyKXc2D9xXatT/Yi8wyT7YB54gr7+Fn/Feei52rnUzhFKZwClM4XkQZ
5SijHGWUo4xylFGeMffrs7IXwVviA64jTt7Dr/F3notdV2tM4XgRZZSjjHKU
UY4yhb0I3hIfEI+Dh8dXtRbeWhpHmcJeBG+5alx/45zgnOCc4Jzg+fruPwwt
nMIS5/hXQnlb1aOwM4U9zfbREvGG8fHiYeLR2yhtbC+Ct8QHxOPg4cvYmvxo
aazRvcr+Oj1YW5rqGJ01TPt8A3jLDHs=
    
    "], {{0, 0}, Offset[{46, 402}, {0, 0}]}, {0, 1}],
   Frame->False,
   FrameLabel->{None, None},
   FrameTicks->{{None, None}, {None, None}},
   ImageSize->{46, 402},
   PlotRange->{{0, 46}, {0, 402}},
   PlotRangeClipping->True],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.558962162604105*^9, 3.563899236625675*^9, 
  3.563899432230401*^9, 3.564163777223544*^9, 3.56416599304174*^9, 
  3.564166789581335*^9, 3.5641669824979877`*^9, 3.564167268752425*^9, 
  3.564167491090659*^9, 3.564167733743198*^9, 3.564168071183881*^9, 
  3.5641683072842073`*^9, 3.564420408247057*^9, 3.564421422079493*^9, 
  3.56442158716745*^9}]
}, Open  ]],

Cell["\<\
See the pattern? The head zigzags back and forth, and as soon as it reaches \
further left than ever before, it zooms to the right and repeats the process.\
\
\>", "Text",
 CellChangeTimes->{{3.5526741468137836`*^9, 3.552674202269394*^9}, 
   3.5648315810977993`*^9, {3.564832586712429*^9, 3.56483260720723*^9}}],

Cell["\<\
Another way to view the evolution is to look at the position of the head over \
time:\
\>", "Text",
 CellChangeTimes->{{3.55544766578398*^9, 3.555447691290872*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"evolution", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5554476084422483`*^9, 3.5554476471436367`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxd1keOFFkUheEUI4Y9YMCgB9EhhBBqIWi8f7juxkPhfVD4EVt4S8mlxJxN
5BJYAqA6H1LclEpHf11dfzMj/tr+uvVh12q1+vbz75fufL5f3NHdLf8ourvo
H0X3FN1b9M9iH4r/WOz7iv/+EudAiXOw2P8u/odK/MMl/5Go/v6J6v9osR8r
/sdL/BMl/8lS36lS/+noGD0TNYezxX6u+J8v8S+U/BdLfW1Zf8f6uxRN/x27
k8vFjvlfKfGx/FeX9XWs/mvR9NfxGP03mvl07E7+i+ZOOnYn/xc75n+92DH/
G9HcWcfu7GaxY/63Snws/+2o/vAYvVPsmP/dEh/Lf29ZX8Opv+N8T2bse3J/
aW+YP078Gcu/tayv4dTfcfqb8Rh9EM19NJz76cU+Y/4Pl/Eblh+nvhmr/1HU
/LD+sflh83scze9Mw/md6cU+Y/5PlvEblh+bP1b/06j5Y/1j88dj9FnU/LH5
43y/Z+z7/3xpb5g/tj8s/4tlfQ2rH9sf1v/LqP1h88P2h83/VdT+sP3hPCdm
7DnxemlvmD+2fyz/m2V9Dasf2z/W/xTNfAac+TWc+U54THyc/axx9jfj7HeD
7f9tNM+HAef50Yp9wvHvOPHXWH6c+jY49a+2o+lvwPrHmc+EM7+OM981zvxn
nP1ssP29i2a/A87+G859TDj303HeM9Y47xlzsW+K/+r9Mv6A5cepb8Kpv+P0
t8b6x5nPBru/D1H3h80fuz88Jj92f9j+sfvD7u9j1P1h94fzfjPhvP/0Yl8X
/7nE32D5Py3rG3Dqbzj9TXjc0Y4znzXO/Gac+W6w+X+OZj8Dzv4azn4nbP84
97HGuZ8Z57422P19ieY+B+w92XtmPr/tq9UPJ9QHdw==
    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{1, 202, 203, 201, 200, 199, 198, 197, 196, 195, 194, 193,
          192, 191, 190, 189, 188, 187, 186, 185, 184, 183, 182, 181, 180, 
         179, 178, 177, 176, 175, 174, 173, 172, 171, 170, 169, 168, 167, 166,
          165, 164, 163, 162, 161, 160, 159, 158, 157, 156, 155, 154, 153, 
         152, 151, 150, 149, 148, 147, 146, 145, 144, 143, 142, 141, 140, 139,
          138, 137, 136, 135, 134, 133, 132, 131, 130, 129, 128, 127, 126, 
         125, 124, 123, 122, 121, 120, 119, 118, 117, 116, 115, 114, 113, 112,
          111, 110, 109, 108, 107, 106, 105, 104, 103, 102, 101, 100, 99, 98, 
         97, 96, 95, 94, 93, 92, 91, 90, 89, 88, 87, 86, 85, 84, 83, 82, 81, 
         80, 79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 
         63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47, 
         46, 45, 44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 
         29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 
         12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2}}]]}, {}, {}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 
        201}]}}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 201.}, {0, 23.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{4.0200000000000005`, 4.0200000000000005`}, {0.46, 
   0.46}}]], "Output",
 CellChangeTimes->{3.563899450898533*^9, 3.564163778274135*^9, 
  3.564165994889007*^9, 3.564166789946453*^9, 3.564166982579073*^9, 
  3.564167268835998*^9, 3.564167491218753*^9, 3.564167733836542*^9, 
  3.5641680712932053`*^9, 3.564168307426012*^9, 3.564420412153521*^9, 
  3.5644214251963377`*^9, 3.5644215872433043`*^9}]
}, Open  ]],

Cell["The pattern is clearer if we run it for more steps:", "Text",
 CellChangeTimes->{{3.555447710943986*^9, 3.555447714580132*^9}, {
  3.555447876571313*^9, 3.5554478914597178`*^9}, {3.559907714915744*^9, 
  3.559907715603241*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"TuringMachine", "[", 
     RowBox[{"rule", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "2000"}], 
     "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5554476084422483`*^9, 3.5554476471436367`*^9}, {
   3.5554477303998127`*^9, 3.555447759081628*^9}, {3.555448453399151*^9, 
   3.555448459969802*^9}, 3.558963228946212*^9, 3.558965680094316*^9}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxd3T9wm0Fax3ENkxlcpFCRwkUKkckwHibDCDBgwHBCBDAQQBw5MGA4ceTA
QOAEBDCcuRMQwEAAAQEMhENFChcpVKRwkUJFChcpNEMKFylUpHCRQkUKFymA
0e/jGT1pdr75Zt93/zy7++6+r51v+MKXPvvFr2s0Gv/z9Y3G/6fLP4vPLNP1
Tv4i6c2ka51V30x6o6TN8u/8/c3y963y97fK398uf/+N5e83iv+mkv9O8d9c
8rfLdb+lXPdbi/+2kn+zXP/by/2/I6n6fWdS9d8q/rtK/u8u1/+ecv/tUr7v
LeX/vqTa5TNJtUtn1Q+x/N+/ev0hdv/uavmGWPl/IGnqN8Tqfzdp4mOIxc8P
Fo/l/6Fyfez+P1zKh5V/J6n6YfX/kaTaB2u/H02auBpicfVjxWP575XrY/f/
8VI+rPw/kfRWPFb/n0yqfbD26yVN+3Zw2n+IM+6nxTd+quTHuf4Q5/5TrHyf
XS1/B6d+Q5z6T7H2+emkab8OTvsOcdp/ivXP/aQZ9x2ccT/EGffT4hufK/k/
t+qHWH5s3viZpJk3Oj+z6odYfuz+P1vuj1O/IVb/4hu7JT9Wfuz+WPl/rpQf
Z94b4sx70+IbP1/yY/XH7o/V/xdK+bH6Y/XHxt9eUvGzt+qHWH6s/X6x3B9r
P6z8WPv9UlL1x9oPaz9s3fh80qwbnc+v+iGWH2v//ur9Wzjl6+CUv4/VD6f+
Y5z2meK03xxr/19OmvZv4YzvDs747xc/LPnHONefYvfH+u8Lq+Vv4dSvg9Uf
i0+c9hvjtO8Up/3nWP/9StL0Xwtn3e/grPv94ocl/xjn+lPs/lj/P1gtfwvr
f6z+WP9j/Y/1P9b+WP9/Man+x/of639sfcC3cv/ipyX/vFy/8avl/jjl6+CU
v4/NL1j9cdpnitN+c2z8/1pS7Y/TPx2c/utj4xvrf5z4mOLEzxx7btxPmufG
1v6q72Dxh8Ufdn8s/rD4w+Lv15OqPxZ/WPxh8Ye1PxZ/WPxh8fcbSfU/Fn9Y
/GHxh2/l/jjPN1Oc55958Y3fXM3fwrl+B7s/Nv9h8x82/2H1x+a/h0nNf9j8
h7U/Nv9h8x82/2H9j81/v5XU/IfNf1j84cTnECd+xzj7ninOvmdefOO3V/O3
sPjH7o/FPxb/WPxj9cfi/0tJxT8W/1j7Y/GPxT8W/1j/Y/E/SJr4aeLEVwsn
/tpYfOJby7SHE999nPgfYPsDnP3DqPhxyT8p15+W+89K+eal/ItSv8bvJFV/
nPZp4bRfG6d9Ozjt38Ppnz5O/w2w8YPT/yOc+BjjxM8Eiy+c+JvhxOccJ34X
2Pz/u0kT/02c8dHCGT9tnHOCTti5Qa/4fsk/KNcflvuPcMo3xin/BFvfsPrj
tM8cp/0W2Pj7vaRp/yZO/7Rw+q+NzY9Y/+PERx8nfgbY/gIn/kY48TnGid8J
9nyDby3TGc74mOOMnwW2/3+UNOOvibO/b+Hs/9vFd0r+Hs71+9j4xynfEKf8
I5z6jbH647TPFKf9ZjjtO8dp/wW2/v1+0vRfE6d/W1j/Y/MzTvz0cOKrjxN/
A+z5DSd+RzjxPcbiH2d8THHGzwxnfM1xxt8CO+f7g5Qj3Aw792vx4XbxnZK/
xxv/2PjHxj82/rHxj9UfG//Y+MfGPzb+sfH/h0mNf2z8Y/2PjX9s/GPjHxv/
2PjHxj82/rH4x8Y/vrVMZ9j4x8Y/Nv4Pkhr/2PjHxj/Oe4FO8b2Sv1+uP8DW
f5zyjXDKP8a3lukEqz9O+8xw2m+O074L7Pnnj5Kmf5o4/dfC6d821v848dHD
iZ8+TnwNsPMdnPgc4cTvGCe+J1j844yPGc74meOMrwX2/PvHSTM+mzjjtxU2
vtu88c+He3x3mfb58IDPe4Bh8aOSf1z8pOSf8uEZn/cI8+IXJX/jy6vXb355
9f4t3vzHq3/xvZK/X64/4NWfD4/4lH/Mhyd83oNMi5+V/PNy/UW5f+NwtXzN
w9Xyt3j159WfN//z5v/iByX/sFx/VO4/LuWb8Pqf1/+8+vPhBe890p/Eh5th
75Vaxbf5cIfP9Xt8uM+nfANe//Op34gPj/m0z4QPT/m074wPz7H1Hxv/X1n1
TWz8f2X1+m1e//Pin0/5+3x4wKs/L/558c+Lf1788+EZn/6b8+EF7z3gV1d9
86ur+Vu8/uf1P6//ef3P639e/fnuMh3x4TGv/3n9z+t/Xv9j/Y/1/zBp1oc1
nPWjWfw6tj/Euf4GFi/D1fJt8eKHD+/w3WXa48O7fNqvz4f3+bT/gA8f8Om/
IR8+4tP/Iz58zCd+xnz4hM975EnxpyX/tFz/rNx/Vsp3Xso/L/W7KPVflPa5
LO3X+NP47jJdC2v/Jp/+WeftD/j07wav/3HiYwsnfjo48bWDE389nOebXZzn
n37x+yX/oFz/oNx/WMp3VMo/KvU7LvUfl/Y5Ke03Ke17ylu/+PAZbz3nw+e8
/ufDF7z5jg9f8ua/P4sPr4XFb5MPr/P5DqJV/EbJ3y7X3+LDHT7l2+HDPT71
2+XDfT7ts88b/3za94A3//LdZXrEh0d8+veY1/984uOED09w4usUO5/Gic8z
nPid4cT3OXa+h7M/uMDZPyyKvyz5G3++ev01bP7H5n9s/sfmf2z8h6/mf978
z5v/+e4y7fHhXd78z5v/ef3Pm/958z9v/ufN/7z5nzf/8+Z/3vzPh0/5jJ8p
Hz7j8x3RrPjzkn9ern9R7r8o5bss5W88Xq3fWlj9m3zaZ50Pt/i07wYfbvPp
ny0+3OG7y3SHD/f4xMcuH+7zia993n4DJz4PsPkfJ76PcOJ/hDM+jrHzOZzx
dYIz/iY4+/tT7P1Y8Wcl/6xc/7zcf17Kd1HKvyj1uyz1b/xF0rTPGnYeGNa+
67z1nw9v8N1l2ubDW7z+58M7vOdpPrzLm//58D6f+B3w4QM+8T/kw0d8xs+I
Dx/zGX9jPnzCZ/xO+PApn+8Ap8Wflfyzcv3zcv95Kd9FKf+i1O+y1L/xl/HG
f/hq/PPGP2/888Y/b/zzxj+v//nuMt3hwz3e+OeNf974541/bPxj4x8b/9j4
x8Y/Nv6x8Y+Nf2z8Y+Mf53zwDOf8cFb8eck/L9e/KPdflPJdlvI3/mq1fmvY
+o+t/9j6j63/2Pofvlr/ees/b/3nu8u0x4d3ees/b/3nrf+89Z+3/vPWf976
z1v/ees/b/3nrf+89Z+3/vPWf97458PnfOaPOR++4PMd8aL4y5K/cbR6/bWj
1fs3+ZRvnff8z3v+5z3/857/ec//vOd/3vM/7/mfN//znv95/c97/uc9//Pd
ZXrEh0e853/e8z/v+Z/3/I89/2PP/9jzP/b8jz3/Y+s/9vyPjX+c+eESe//1
10kzv6zhzD9NnPcb69j70eI3Sv52uf4W9n0bTvl2cMrfw6nfLrb/x/b/2P4f
2/9j8z+2/8f2/+Gr/T+v/3n7f767TCd8+JS3/+ft/3n7f97+n7f/5+3/eft/
3v6ft/7/Tbz9f/hq/8/b//PGPx/e4DN/tPnwFp/5p8OHd/jMXz0+vMvn5yD6
xe+X/INy/YNy/2Ep31Ep/6jU77jUf1za56S036S07ynv/I93/sc7/+Od//H6
n3f+xzv/453/8c7//ja+u0zXwlfnf7zzP97zP+/8j7f+Y+d/2Pkfdv6Hnf9h
53/Y+MeZH/Zx5o8BzvxygL1/xZmfjnDmrxHO/HaMM/+Ncd4Pn+C8P54Uf1ry
T8v1z8r9Z6V856X881K/i1L/RWmfy9J+jSdJPf9hz3/Y8x/2/Ic9/2H9H756
/uM9//Ge//juMu3x4V3e8x/v+Y+3/vOe/3jPf7znP97zH+/5j/f8x3v+441/
3vMf7/mP9/zHe/7jPf/xnv94z3+85z8+fMn7ObK/iw+vhf1cWbP4dT7c4nP9
DT7c5lO+Ld78z6d+O3y4x6d9dvlwn0/77vPhAZ/+OeDt//n07xGv//nExzEf
HvOJrxPe+0o+8XnKW//57jI948MzPuPjnA/P+YyvCz68wBmfl9j5z98n9f4P
G/8488M6zvzRwplfNnDmnzbO/LSFPf/hzG87OPNfD2d+3MW+r8WZX/dx5t8B
zvc9B9j3V8Uflfyjcv3jcv9xKd9JKf+k1O+01H9a2uestN+stO95af956Z+L
0n+L0r+XWP//Q1Lnf9j5X/jq/I+3/vPO//juMm3z4S3e+Q/v/I93/sc7/+Pt
/3jnf7zzP975H2/8887/eOd/vPM/3vMf7/yPd/7HO//jnf/x4TM+8+eMD5/z
mX/nfPiCz/y94MOXvJ8DHq36a6PV/Gt8rn+dDzf5lO8GH17nU7+bfLjFp31u
8+ENPu17hw+3+fTPJh/e4tO/27zzBz7xcZd3HsEnvu7x4R6f+LzPi1c+8b3H
e37hu8v0AR/e5zO+HvLhAZ/x+YgPH+CM70Ns/4szPzzGmT+OcOaXJzjzzwhn
fnqKM38d48xvz7Cfb8CZH5/jzJ8nOPPrC5z5d4IzP7/Emb9Pceb3V9jPR+F8
H/oa5/vRs+LflPyzcv235f7npXzvSvnnpX7vS/0vSvt8KO23KO37sbT/Zemf
T6X/Gv+YNP17Daf/13Di4zpO/DRx4usGtl6ExedN3vrBh2/z3WW6wYfv8Bk/
bT68yWf8bfHhbd73W3z4Lm/88+F7fOaPHh++z2f+2eXDe7znVz78gM/8t8+H
H/KZPwd8+BGf+feADx/ymb+HfPgxn/n/iA8/4bN+jPjwUz6/J+K4+Gcl/7hc
/3m5/0kp34tS/kmp38tS/9PSPq9K+01L+74u7X9W+udN6b9Z6d+3pf/PS3y8
K/EzL/H1vsTfRYnPDyV+FyW+P5b4vyzj41MZP41/iu8u02th42+Nz/i8zoeb
fMb3Dd74x5kfbmLnBzjzy22c+WcDZ366gzN/tXHmt02c+W8LZ37cxvYfOPPr
XZz5dwdnfr6HM3/3cOb3+zjz/y7O+rCHs370cdaXBzjrzz7Ozzc8xPn5h0Hx
j0r+g3L9w3L/YSnf41L+o1K/J6X+o9I+T0v7HZf2fVbaf1z653npv5PSvy9K
/09KfLws8XNa4utVib9pic/XJX7PSny/KfE/K+PjbRk/52V8veMz/uZ8+D3v
PJcPf+CNfz78kXfez4c/8c7//zk+fC1s/lrjw9f5zH9NPnyDz/y5zodv8p7/
+fBt3nkSH77DZ/5v8+FNPuvHFh/e5rP+dPjwXT7r107Y70W659+He8XfL/l3
y/X3yv37pXwPSvn3S/0elvoPSvs8Ku13UNr3sLT/sPTP49J/R6V/n5T+H5X4
eFri57jE1zPe+Smf+HzOh0/4xPcLPjzhMz5e8uFTPuPrFe/8je8u09d8+IzP
+H7DG/985oe3fPgcZ355h/18Js789B5n/rrAmd8+4Mx/C5z58SP2/I8zv37C
3v8+TZr5+RrO/L2GM79fx5n/mzjrww2c9WMdZ325if18Pc76dBtn/drAWd/u
4Kx/bXxrmW7i1jLdKn675O+U698t998p5btXyt8r9btf6r9b2mevtF+/tO+D
0v77pX8e4vTfAKd/H+H0/wFOfBxiv78CJ74eY/t/nPh8ghO/I5z4foq9Lw8b
H89478/58HO+u0xP+PALPuN3wodf8sY/H37F+/khPvya9z6WD7/hM3/N+PBb
3vM/H37H+36PD7/nM/9e8OEPfObvBR/+yHvfw4c/8d7//Et8+Fr46vyPD1/n
s341+fANPuvfetj6eNO/D7fCfq/gbfnzewI3ir9T8rfL9TfL/bdK+bZL+Tul
fndL/XdK+9zjwz0+7Xuf970Cn/7Z48N9Pv37gLf/5xMfD/nwgE98PeLDB3zi
85B3/s0nvh/z3ofxGR9P+PCIz/h6yoeP+YzPZ3x4zHeX6XM+fMJnfnjB+3k4
PvPLSz58ijM/vcKe/3Hmt9c4898Zzvz4Bmf+nOHMr29x5t9znPn5Hfb+Hmd+
f4+d/+GsDx9w1o8FzvryEWf9ucRZnz5hP//+r0mzvl3DWf/WcNbH6zjrZxPf
WqY3cNbfdZyf77+J8/P/reJvl/wb5fp3yv3bpXybpfxbpX7b2O93w2mfuzjt
t4PTvvew/T9O/9zH6b9dnP7dw34/CE58PMCJn32c+HqIE38DnPh8hBO/Bzjx
fYid/+OMj8c44+cobHw94f28Nh9+yneX6TEffsYb/3z4Oe99Oh9+wXv+58Mv
+cxfp3z4Fe/7Kz78ms/8ecaH3/DO//jwW973Gnz4He/7DT78ns/6ccGHP/BZ
fxZ8+CPvfR8f/sR7//dv8eFrYevnWtj6et2/DzfD1ucb8mf9Xpc/fFP+cKv4
2yX/Rrn+nXL/dinfZin/VqnfNm/9563/vPWft/7z1n/e+s9b/3nrP2/9563/
vPWft/7z1n/e+s9b/3nrP2/9563/vPWft/7z1n/e+s9b/3nrP2/8891l+pwP
n/DWf976z1v/ees/tv5j6z+2/mPrP7b+Y+s/tv5j6z+2/mPrP7b+Y+s/tv5j
6z+2/mPrP7b+Y+v/cVLrP7b+Y+s/tv7jW8v0Brb+Y+s/tv7j/H6g2zi/P2ij
+Dslf7tcf7Pcf6uUb7uUv1Pqd7fUf6e0zz1s/4/t/7H9P7b/x/b/2P4f2/9j
+39s/4/t/7H9P7b/x/b/2P4f2/9j+39s/4/t/7H9f/hq/8/b//P2/3x3mZ7w
4Re8/T9v/8/b//P2/7z9P2//z9v/8/b/vP0/b//P2//z9v+8/T9v/8/b//P2
/7z9P2//z9v/8/b/vP3/v8fb/4ev9v+8/T9v/8/b//P2/+Gr/b9/b/8fvtr/
y2/9lz98R/5wW/7wpvz5fwK2it8u+Tvl+nfL/XdK+e6V8vdK/e6X+u+W9tkr
7dcv7fugtP9+6Z+HvPN/3vk/7/yfd/7PO//nnf/zzv955/+883/e+T/v/J93
/s87/+ed//PO/3nn/7znf975P2/8887/eef/fHeZvubDZ7zzf975P+/8n3f+
j53/Y+f/2Pk/dv6Pnf9j5//Y+T92/o+d/2Pn//+R1Pk/dv6Pnf9j5//Y+T92
/o+d/2Pn/9j5P3b+j53/Y/t/fGuZbmLrP87zwTbO80MH5/niLs7zxw7O7ze8
hxvLtFf8/ZJ/t1x/r9y/X8r3oJR/v9TvYan/oLTPo9J+B6V9D0v7D0v/PC79
d1T690np/1GJj6clfo5LfD3D3v9j7/+x9//Y+3/s/T/2/h97/4+9/8ee/7H3
/9j7//DV+3/e+Oe9/+e7y/ScD7/jvf/nvf/nvf/nvf/nvf/nvf/nvf/nvf/n
vf//z3jv/8NX7/957/957/957/957/957/957/957/957/957/957/957/95
7/957/95+3/e+3/e+//w1ft//976H/Z8cF/+PD/syh/ekz/clz/8QP48v+zL
H34of3hQ/KOS/6Bc/7Dcf1jK97iU/6jU70mp/6i0z9PSfselfZ+V9h+X/nle
+u+k9O+L0v+TEh8vS/yclvh6VeJvWuLzdYnfsxLfb0r8z8r4eFvGz3kZX+94
3//xvv/jff/H+/6PN/553//xvv/jff/H+/7vWXx3mV4LX33/x/v+j/f9H+/7
P973f9j3f9j3f9j3f9j3f9j3f9j3f9j3f9j3f9j3f9j3f9j3f9j3f9j3f9j5
P/b9H7b/x77/w77/w77/w77/w77/w9Z/fGuZPsJ5fjjAeb44xH7/Ms7zyWOc
55cjnOebJzjPPyOc/zfyafHHJf+zcv1xuf/zUr6TUv4XpX6TUv+XpX1OS/u9
Ku07Le3/uvTPWem/N6V/Z6X/35b4OC/x867E17zE3/sSnxclfj+U+F6U+P9Y
xsdlGT+fyvhq/FfSjL9rOONzDWf8Xsd+Pix8Nf55Py/Oh2/y3WXa4sO3+cxP
G3z4Du/3C/HhTT7z4xYf3uYzv3Z4P//DZ37e4cP3+MzvPT58n/fzqnx4j8/6
0ued//NZn/b58EPe7zfg7f/5rI8HfPiQz/o65MOP+azPR3z4CW/9D1+t//69
9T/s+eGZ/Hm+GMsffi5/+ET+8Av583wzkT/8Uv7wqfzhV/Ln/4Gcyh9+XfxZ
yf+m+FnJ/9b9w+fyh98VPy/535frX5T7fyj1W5T6fyz+suT/VK7f+Nrq/a99
bbV8a19bLf/1sP83syl/+Ebx6yX/zXL9Vrn/bfnDG/Kn/HfkD7flD2/K7/xP
fud/xXdK/rvl+jvl/vdK+Xql/PdL/XZL/fdK+/RL+z2QP7wvf/hh8YOS/1G5
/kG5/2Ep37CU/3Gp31Gp/5PSPqPSfk9L+x6X9n8mv/Evv/Ff/EnJ/6Jcf1Lu
/7KU77SU/1Wp37TU/3Vpn7PSfm9K+85K+78t/XNe+u+d/Pl/YOfyh98Xf1Hy
fyjXX5T7fyzluyzl/1Tq1/jv5Df+w9pnLaz9roe1b1P+8A35w+vye/8vv/f/
8nv/L7/zf/m9/y++XfJvlutvlftvl/J1Svnvlvpd/X/o+cP/35//BYMRqBo=

    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl2dMWIMiSBdCybdu2bdu2bdu2bdu2bZvdZfPW7Jp+2CvyB87KzDgJG7Wv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         "]]]}, {}, {}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl2UMUGNgOANCpbdu2bdu2bdu2bdu2bduYqe32356/uCeLt07ykiRo2K5i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        "]]}}}], {}},
  
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 2001.}, {0, 85.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{40.02, 40.02}, {1.7, 1.7}}]], "Output",
 CellChangeTimes->{3.558963229474771*^9, 3.563899453501705*^9, 
  3.564163778515472*^9, 3.564165995143846*^9, 3.564166790114957*^9, 
  3.5641669827481747`*^9, 3.56416726897961*^9, 3.56416749146215*^9, 
  3.564167734061173*^9, 3.564168071557497*^9, 3.56416830760855*^9, 
  3.564420413878232*^9, 3.564421425473681*^9, 3.564421587396893*^9}]
}, Open  ]],

Cell["\<\
The overall growth goes in sections of zigzags, where each section takes \
longer than the last. When the head reaches the left side, it zooms to the \
right and starts a new section.\
\>", "Text",
 CellChangeTimes->{{3.555447896462246*^9, 3.555447910353858*^9}, {
   3.555447972107188*^9, 3.555448059231739*^9}, {3.555448589959993*^9, 
   3.555448621107353*^9}, {3.555448657685166*^9, 3.555448679697298*^9}, 
   3.5648315843082275`*^9, 3.564832618771597*^9}],

Cell[TextData[{
 "Now let\[CloseCurlyQuote]s try ",
 StyleBox["compressing",
  FontSlant->"Italic"],
 " it to show just the steps where the head goes further to the right than \
ever before:"
}], "Text",
 CellChangeTimes->{{3.555448685590186*^9, 3.555448819547173*^9}, {
  3.559908145935094*^9, 3.5599081477492657`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rightcompress", "[", "evol_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"maxright", "=", 
      RowBox[{"evol", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], ">", "maxright"}], ",", 
          RowBox[{
           RowBox[{"maxright", "=", 
            RowBox[{"#", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
           RowBox[{"Sow", "[", "#", "]"}]}]}], "]"}], "&"}], "/@", "evol"}], 
      "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.549842038664111*^9, 3.54984205209445*^9}, {
   3.549842470247589*^9, 3.549842473027644*^9}, {3.549842566740756*^9, 
   3.549842573913184*^9}, 3.549842747237935*^9, {3.55544841664398*^9, 
   3.555448428188651*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Framed", "@", 
  RowBox[{"ArrayPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"rightcompress", "[", 
      RowBox[{"TuringMachine", "[", 
       RowBox[{"rule", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "2000"}], 
       "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"PixelConstrained", "\[Rule]", "2"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5554483386312513`*^9, 3.5554483767634163`*^9}, 
   3.558963256924918*^9, 3.558965682969486*^9, {3.559907906007886*^9, 
   3.559907932063957*^9}, {3.55990798261406*^9, 3.559907997741781*^9}, 
   3.564420435473311*^9}],

Cell[BoxData[
 FrameBox[
  GraphicsBox[RasterBox[CompressedData["
1:eJzN19sJwzAMhWGpm3SiQqELZIHu/9YLITi2bMv2OY7/0NcPUiSV3rf3c7uJ
yOP7eQkmTR48qhBU6KjCUKGiCkWFhiocFQqqBFTDjC3reghoZC6Lxv2/4wXR
tH0eFkOtjtldCLUL9mwRNNfpJiyA5ovu18VoqeTWXoiWM34XLkJrpaiDJaD1
LLTCElBPNlpgCaivHJphCai3PGqwBNRfCU3+y8DRlsqoUNG2aqjQ0NbqqFDQ
ZtPz+j2NH/pmtNOcjva2j+I0tL9jbaagIwUrTkfHCvaRjI52uh1EdLzozpFQ
RJCbXEEhZvz6qJADaqBAk4oiA858gmIDz1KAgk1lmD8W7H0AGOYSjg==
    
    "], {{0, 0}, Offset[{170, 158}, {0, 0}]}, {0, 1}],
   Frame->False,
   FrameLabel->{None, None},
   FrameTicks->{{None, None}, {None, None}},
   ImageSize->{170, 158},
   PlotRange->{{0, 170}, {0, 158}},
   PlotRangeClipping->True],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.559907998003579*^9, 3.564163779601321*^9, 
  3.564165995341264*^9, 3.56416679028832*^9, 3.564166982922061*^9, 
  3.564167269206534*^9, 3.56416749175183*^9, 3.564167734232006*^9, 
  3.564168071871632*^9, 3.564168307804965*^9, 3.5644204365079107`*^9, 
  3.564421425689763*^9, 3.56442158758879*^9}]
}, Open  ]],

Cell["\<\
The compressed tape is easier to visualize. The head in the compressed \
evolution is just steadily moving to the right:\
\>", "Text",
 CellChangeTimes->{{3.5554488298664913`*^9, 3.555448839521245*^9}, {
   3.5554488801653547`*^9, 3.555448965386446*^9}, {3.556902966659059*^9, 
   3.556902989562336*^9}, {3.559908175728568*^9, 3.559908178004035*^9}, 
   3.5648315876900854`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rightcompress", "[", 
     RowBox[{"TuringMachine", "[", 
      RowBox[{"rule", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "2000"}], 
      "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5554476084422483`*^9, 3.5554476471436367`*^9}, {
   3.5554477303998127`*^9, 3.555447759081628*^9}, {3.555448271163739*^9, 
   3.555448278302237*^9}, {3.555448444858882*^9, 3.555448464744972*^9}, 
   3.558963243288311*^9, 3.558965681773356*^9, {3.559907898681348*^9, 
   3.559907899064652*^9}, {3.5641647136341753`*^9, 3.56416471745788*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxd1DlKBGEQhuHCyNDAwMBgFBERkXHfnV9n36cXLyAYe4U6Wh/JIzgy9Qvv
V9C8VFfzhH3w+V1+bZlZsX7+upmfzqb7KV5EW9Ht6GF0J3oU3Y0eR/eiJ4nu
qbhn4p6L2xb3QtxLca/EvRb3Rtxbce/EvRf3QdxHcZ/EfRb3RdxXcTviJrqe
9+y+0fW8Z/edruc9O1263hW3R9d74vbpep+uDej6gK4N6fqQro3o+oiujen6
mK5N6PqErk3p+pSuzej6jK7N6fqcri3o+oKuLen6kq6t6KaVuPkee5Pv2Sno
pkLcgm6Tv89OSTeV4pZ0m5KuVXRTRdcruk1F12q6qabrNd2mpmsfdFPs//+7
mHxfzy8GVHKW
    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{1, 80, 81, 79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 
         68, 67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 
         51, 50, 49, 48, 47, 46, 45, 44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 
         34, 33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 
         17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 
         2}}]]}, {}, {}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79}]}}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 79.}, {0, 85.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{1.58, 1.58}, {1.7, 1.7}}]], "Output",
 CellChangeTimes->{3.5589632438199387`*^9, 3.559907901373788*^9, 
  3.564163778674356*^9, 3.564164721977108*^9, 3.5641659954620867`*^9, 
  3.564166790504074*^9, 3.564166983064468*^9, 3.564167269342202*^9, 
  3.5641674919868307`*^9, 3.564167734358265*^9, 3.5641680720842333`*^9, 
  3.564168307994297*^9, 3.564420469854128*^9, 3.5644214258105927`*^9, 
  3.564421587815308*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Try Changing the Rule Slightly", "Section",
 CellChangeTimes->{{3.564164731768137*^9, 3.564164736998453*^9}, {
  3.5650033196143312`*^9, 3.565003326335415*^9}}],

Cell["\<\
Let's try changing the rule slightly to see if we can make it do something \
more interesting. Here\[CloseCurlyQuote]s the rule table again:\
\>", "Text",
 CellChangeTimes->{{3.5599090192991323`*^9, 3.559909106245319*^9}, {
   3.559909193337919*^9, 3.559909223640808*^9}, {3.561392850087496*^9, 
   3.5613928667164927`*^9}, {3.561392903843739*^9, 3.5613929574970512`*^9}, 
   3.5648315907602515`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmruletable", "[", "rule", "]"}]], "Input",
 CellChangeTimes->{{3.552588982402398*^9, 3.552588983545102*^9}, {
   3.552589737104405*^9, 3.552589741420981*^9}, 3.5569031335918417`*^9, {
   3.558961396960534*^9, 3.558961400816139*^9}, 3.558962025815864*^9, 
   3.558965661626809*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False]}
   },
   AutoDelete->False,
   FrameStyle->GrayLevel[0.5],
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.564164776567861*^9, 3.5641659956536837`*^9, 
  3.564166790663562*^9, 3.564166983336995*^9, 3.56416726950504*^9, 
  3.56416749227566*^9, 3.564167734541209*^9, 3.5641680724408417`*^9, 
  3.564168308181406*^9, 3.564420476057369*^9, 3.5644214259585876`*^9, 
  3.564421588017148*^9}]
}, Open  ]],

Cell[TextData[{
 "Now we are going to change the rule so when the head is in state 1 on a \
white cell, it goes to the ",
 StyleBox["right",
  FontSlant->"Italic"],
 " rather than the left:"
}], "Text",
 CellChangeTimes->{{3.561392888485819*^9, 3.561392898651613*^9}, {
  3.561392965809*^9, 3.561392966800556*^9}, {3.561393051474971*^9, 
  3.561393086669541*^9}, {3.5648339115115643`*^9, 3.564833911698592*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rule2", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5569032072991*^9, 3.556903242385168*^9}, 
   3.5569034902312727`*^9, 3.558963268219591*^9, 3.5589656858111486`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmruletable", "[", 
  RowBox[{"rule2", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{
  3.556903323361252*^9, {3.558963277983015*^9, 3.558963283887239*^9}, 
   3.558965687935401*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7I3B4L99Ghhcs4eI/7B/svCj5YqWa/acN0r+
PJr/3f6Zj8Wvdfeu2ZfMCrmi7PTd/sHSXC3nouv2a81/lQu+/GbPMLe15ZD1
DXu2tFXxd6d9s79j5fDQzOym/Xa+gB29vt/sxWesrCuNvmXvkK648APfN/vN
917cd11y274ic/apCXe+2p/NDArs57hrbyXct2/19q/2KgmXP3bX37OvzKjh
01r41R7m3lkzQeCr/Tt/MXarAw/g8pKnw8J3VD+E6182gVvgru4juPlfjFc7
uF56BLd/0qP4/icpj+Huqzfcu1fu0WO4+wV0T2bdc3sC91/PzcdNKyY8sS+G
+p9Pn/3x6r1P4OFz9gwIPIGHH3r4AgB3l7Cq
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->Directive[
        RGBColor[1, 0, 0]],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRD0VfG+9R77WTNB4KJ9Ghg8sjeWqX+7fP11e6Y1
14X9WR/bl2xdwynWdcOe6TC7mu7Ex/b2J0NzuifftJ/09tmnPrYn9qud4vbX
Hb1l/16+uHdC0hP7KaL2eekSd+z5m5/8fbvoiT3L/m9Kb5vv2muu7O4UPPbE
XkF5SoLM/3v2AfkxG2RPP7GvsX9U7u/wwL7imfbCTxuf2HeK3Ymp/v/A3uir
PZN+9RN77mb98zE7Hto/K3Tg1NF4Anen61LN3192PbZnhrozQfqqp5XZY3sW
qDtX3QtY4DD3kf0UqDvNSh94nPn80P4D1J21C1ryOO0e2gtA3Vnwbuv5woYH
9lpQd7I1Wgsk1t+3D4S6880ldzdOxnv2lVB3vvi5INGt/469CdSdBsYgcBvu
TvTwBQDYn7YC
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvSn0oHRLxRv7NDD4AqUf2X+2WMAiJvLLnqdZ/3zM
jof2s37JN063/WXfIXYnpvr/A3ubz1MDfkb8sq+xf1Tu7/DAfoW53o2+1F/2
CspTEmT+37OfeuXoEY7kX/YM+78pvW2+a9/h+OlfWeAv+wmi9nnpEnfsf/Tv
dPMw/GW/yiluf93RW/anyoor3Zl/2dudDM3pnnzTvvEh8+RpJ37aF21dwynW
dcOe8drrzuVNP+1NZOrfLl9/3d7IGAR+2k8Tbfi9kPO6fevB6el6d37Y8xiv
2Cs155q9C3feur31P+zjFN3nH8m8Zr9P/uNudYUf9ivWvnhzp/ia/QkOVYnj
+7/b3/tpxqKy65r9gfV7PX4nfLdXOCD59J7VdfuUo/23Jdm+299QMZJ69Om6
/aoJ19fHb/xm/6Pyw+ald2/YBxSJ3n6U8s3+1/KAG4lfb9rH6GY3tSp9szcB
u+u2Pc/x+N8vX3+1Rw9fAI7mvSo=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7NPA4B2UvmYPE3+y8KPlipZr9ioJlz9219+z
f+Zj8WvdvWv25zKDAvs57to/WJqr5Vx03X7LvRf3XZfctmeY29pyyPqGvfiM
lXWl0bfs71g5PDQzuwmnYeKMUHWbofpg5pyFmvscag/M3qdQd6C695r9O38x
dqsDCHdKng4L31H9EO7OZRO4Be7qPoKb/8V4tYPrpUdwd056FN//JOUx3H31
hnv3yj16bC8GdaeA7smse25P4O7sufm4acWEJ3B38umzP16994m9MtSdZ8+A
wBO4O9HDFwB9rrNY
              "]]}}, Frame -> None, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[{
           RasterBox[{{1}, {0}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{-3, 5}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False], 
     FrameBox[
      PaneBox[
       TemplateBox[{GraphicsBox[{
           RasterBox[{{0}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 2}, {1, 2}}, {{0, 1}, {1, 1}}, {{0, 0}, {1, 0}}}],
               Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              LineBox[{{{0, 0}, {0, 2}}, {{1, 0}, {1, 2}}}], Antialiasing -> 
              False]}}}, Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXRD0VfG+9R779DQQ+GIPptIe2fMej//98vVXe5Y1
14X9WR/bx+lmN7UqfbNnOcyupjvxsX1AkejtRynf7Ke8ffapj+2J/eoJ19fH
b/xm/0G+uHdC0hP71KP9tyXZvtsLND/5+3bRE/tD6/d6/E74bq+zsrtT8NgT
+xMcqhLH93+3D8qP2SB7+on9PvmPu9UVfthXPdNe+GnjE3tX7rx1e+t/2Jt8
tWfSr35i33ZwerrenR/2zwodOHU0ntibGIPAT3uPpZq/v+x6bM907XXn8qaf
9knSVz2tzB7bNz1knjztxE/7NfcCFjjMfWR/qqy40p35l71F6QOPM58f2v/o
3+nmYfjLvmFBSx6n3UP7DsdP/8oCf9kXvNt6vrDhgf20K0ePcCT/sudotBZI
rL9vv9Jc70Zf6i/7D5fc3TgZ79nbfp4a8DPil/2LnwsS3frv2M/6Jd843fYX
1F237b9YLGAREwGahxa+AM0Xun4=
              "]]}}, Frame -> False, 
          FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20],
         GraphicsBox[
          RasterBox[{{1}, {1}}, {{0, 0}, {1, 2}}, {0, 1}], Epilog -> {
            RGBColor[1, 0, 0], {
             RGBColor[1, 0.7777777777777778, 
              NCache[
               Rational[5, 9], 0.5555555555555556]], 
             EdgeForm[
              RGBColor[
               NCache[
                Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 
               0]], 
             PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvTn0oHRLxRv7GTNB4KJ9Ghg8sn9W6MCpo/HEnrtZ
/3zMjof2xl/tmfSrn9h3id2Jqf7/wL7imfbCTxuf2NfYPyr3d3hgH5Afs0H2
9BN7BeUpCTL/79lrrezuFDz2xJ5l/zelt8137fmbn/x9u+iJ/RRR+7x0iTv2
7+WLeyckPbFf4xS3v+7oLfvJb5996mN7Yu9wMjSne/JNe+bD7Gq6Ex/bl25d
wynWdcOeac11YX/Wx/bGMvVvl6+/DnfnDNGG3ws5r9tzQd3Ja7xir9Sca/Yd
UHfGK7rPP5J5De7O1WtfvLlTfM1eDurOBz/NWFR2XbNngrpT4YDk03tW1+Hu
vKFiJPXo03X7FVB3/qz8sHnp3Rtwd/5cHnAj8etN+yKoO43B4La9EdSd6OEL
AGEsuQo=
              "]]}}, Frame -> None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 20]},
        "RowDefault"],
       Alignment->{Center, Center},
       ContentPadding->False,
       ImageMargins->{{5, -3}, {0, 0}},
       ImageSize->{43, 43}],
      FrameStyle->GrayLevel[1],
      StripOnInput->False]}
   },
   AutoDelete->False,
   FrameStyle->GrayLevel[0.5],
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.558963284311364*^9, 3.561393282820562*^9, 
  3.5641637798273373`*^9, 3.5641659958689823`*^9, 3.564166790848802*^9, 
  3.564166983556039*^9, 3.56416726971315*^9, 3.5641674925935907`*^9, 
  3.564167734750073*^9, 3.564168072709343*^9, 3.564168308494471*^9, 
  3.564420479289555*^9, 3.56442142618095*^9, 3.564421588258635*^9}]
}, Open  ]],

Cell["\<\
Here\[CloseCurlyQuote]s what this new rule does:\
\>", "Text",
 CellChangeTimes->{{3.556903904788567*^9, 3.556903946866829*^9}, {
   3.5569039780888968`*^9, 3.5569039857926598`*^9}, 3.561392883633264*^9, {
   3.5613929821840343`*^9, 3.561392987616056*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"e2", "=", 
   RowBox[{"TuringEvolve", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "21", "}"}]}], "]"}], ",", "0", ",", "10", ",", "rule2", 
     ",", "20"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.55690364574341*^9, 3.556903648966339*^9}, 
   3.558963300183778*^9, 3.5589656893681583`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "10"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e2", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e2", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.558961995277556*^9, 3.5589620514557447`*^9, {3.558962088277604*^9, 
   3.558962102612935*^9}, {3.5589633252866707`*^9, 3.558963347852647*^9}}],

Cell[BoxData[
 GraphicsBox[{
   RasterBox[{{1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 
    1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1}, {1, 
    1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 
    1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 1, 
    1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 
    0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1, 
    1, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 
    1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1, 1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1}}, {{0, 0}, {21, 10}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 10}, {21, 10}}, {{0, 9}, {21, 9}}, {{0, 8}, {21, 8}}, {{0,
        7}, {21, 7}}, {{0, 6}, {21, 6}}, {{0, 5}, {21, 5}}, {{0, 4}, {21, 
       4}}, {{0, 3}, {21, 3}}, {{0, 2}, {21, 2}}, {{0, 1}, {21, 1}}, {{0, 
       0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 10}}, {{1, 0}, {1, 10}}, {{2, 0}, {2, 10}}, {{3, 
       0}, {3, 10}}, {{4, 0}, {4, 10}}, {{5, 0}, {5, 10}}, {{6, 0}, {6, 
       10}}, {{7, 0}, {7, 10}}, {{8, 0}, {8, 10}}, {{9, 0}, {9, 10}}, {{10, 
       0}, {10, 10}}, {{11, 0}, {11, 10}}, {{12, 0}, {12, 10}}, {{13, 0}, {13,
        10}}, {{14, 0}, {14, 10}}, {{15, 0}, {15, 10}}, {{16, 0}, {16, 
       10}}, {{17, 0}, {17, 10}}, {{18, 0}, {18, 10}}, {{19, 0}, {19, 10}}, {{
       20, 0}, {20, 10}}, {{21, 0}, {21, 10}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDmkg8EzZwRgENis5wMT5e887qm5RcmCc3Rf/
57OSQ/qhi+Vftyk5+E3uqnJ5oeSgnxssOWm3ksM3t/96SneVHF7oqIjcO6jk
cNDn6+rbl5QcrjNybd94EkHDxGHqYPpg5sDMhdkDsxfmDpi7YO78n1K4gJkH
4c5NOaWtu8WV4fq5djJcvKukDDfffjNXiIquMtx+zX9fPfzMlOHuk7h8+7Wi
nTLcnRcnrXmW66IMd+dMW70OLk9luDs/Fhnsu+WtDHfn2TNA4KMMdyd6+AIA
cQKROA==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvfSV875yCxWHs2eAoEfBIQ0E1FQdHv7Itq/dq+Bw
oMr2Y4iBqsOaVN8NAUcUHAxqEi4JWao6eK1Lip5zRsHhRp7e+wwHVQfRT7++
al9TcPhneJ1D0w2o/keh9eEHQPUe9+7reak6/Ngqnin/RsFh0q4ZEok+qg6S
C1ke//iu4PDlGOvtjUD+D+W67ywsig4Z+4S05L1VHTIOnt36nV/RIfi/8odN
7qoOBj8+nWmVVnSQY59yoMlJFepORYeQWZv811urQt2p6LAtcO6SZGNVqDsV
HV7xsnJd0VSFuhNoHnvfERt5Vag7FR04vF5MeyCsCnWnosOzuN8y7ByqUHcC
5e80cvz+rQJ1p6LDDDsjL44PKlB3KjqcZ+c1rnqi4hAEdqeiw0wQuKkCdaei
A3r4AgAYk5qb
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLrDrJlAICnrkAYCauoONnwajaytcg4G
Pz6daZVWd1jxz/1Bar+cQ8bBs1u/86s7XKhRDbGbJufwQ7nuOwuLusOrXu5t
yTPlHCQWsjz+8V3NQa3U0PDQDKD8VvFM+TdqDgkT9uyPnSLnsOZHofXhB2oO
/5LXCQb1yDmIfvr1VfuamsOGuzH3LjbIOXitS4qecwao/seBJapFQPWpvhsC
jqg5NHyterQyQc7h4Y9s+9q9ag5nQMAHKM9wh993B1D9h6czuc3lHGY4vr36
YIuaw4Wm2dnv5eUcuC1/qfhtVnP44P7nHSeHnEOua/rzeUC+kRPnsY/vZR3O
b1dUuLgVKJ+tf8nuhqwDwzmN79d2qjlEfXxc1nZQ1kFt4kWB6fvVHLSefH0d
vkbW4ULzfN23x9QcpsQc3WYxU9bBofUQ3+rzag4Rp2clLOyQdQAF48ybag6H
Pl6v+1Ul64AevgCgdqrx
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGaDmfPgIC0gzEIbNZwgIhLOfD3nndU3aLhwGQm
u//Hc0mH9EMXy79u03CYqyb6teOCpIN+brDkpN0aDq97/8W67JJ0eKGjInLv
oIZD48xX4duXSjpcZ+TavvGkhsM6ZpG85MmSDgd9vq6+fUnD4UKkh8aeZkmH
b27/9ZTuajjE3VpmpFIu6eA3uavK5YWGw7mWxe9f5Uo6MM7ui//zWcNBTmp+
s1eGpAPMvWlgIOnwP6VwATOPJlx+U05p625xTbh+rp0MF+8qacLNt9/MFaKi
qwm3X/PfVw8/M024+yQu336taKcJd//FSWue5bpowv0301avg8tTE+7/j0UG
+255a8LDBxyOPprw8EMPXwAi3pIZ
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveSV875yCy2HWTOBQFLUIQ0E1LQdjny8XverStTh
QJXtxxADbYeo07MSFnaIOhjUJFwSstR2mBJzdJvFTFGHm3l67zMctB10nnx9
Hb5G1OG/4XUOTTeg+o+Py9oOAtV73Luv56Xt8Clb/5LdDVGHSbtmSCT6aDuY
OHEe+/he1OHLMdbbG4H8T+5/3nFyiDlk7BPSkvfWdrjUNDv7vbyYQ/B/5Q+b
3LUdkj48ncltLuYgxz7lQJOTtsO5M0DgI+YQMmuT/3prbYemr1WPViaIOWwL
nLsk2Rio/seBJapFYg6veFm5rmhqO2y6G3PvYgPQPPa+Izby2g7/ktcJBvWI
OXB4vZj2QBiofsKe/bFTxByex/2WYefQdlArNTQ8NAMof6eR4/dvLYdXvdzb
kmeKOUy3M/Li+KDlcKFGNcRumpjDeXZe46onWg7L/rk/SO0XcwAF48ybWg52
fBqNrK1iDujhCwCpeZ4t
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuK7DrJlAICnokAYCaroOdnwajaytQg4G
Pz6daZXWdVjxz/1Bar+QQ8bBs1u/8+s6XKhRDbGbJuTwQ7nuOwuLrsOrXu5t
yTOFHCQWsjz+8V3HQa3U0PDQDKD8VvFM+Tc6DgkT9uyPnSLksOZHofXhBzoO
/5LXCQb1CDmIfvr1VfuajsOGuzH3LjYIOXitS4qecwao/seBJapFQPWpvhsC
jug4NHyterQyQcjh4Y9s+9q9Og5nQMAHKM9wh993B1D9h6czuc2FHGY4vr36
YIuOw4Wm2dnv5YUcuC1/qfht1nH44P7nHSeHkEOua/rzeUC+kRPnsY/vBR3O
b1dUuLgVKJ+tf8nuhqADwzmN79d26jhEfXxc1nZQ0EFt4kWB6ft1HLSefH0d
vkbQ4ULzfN23x3QcpsQc3WYxU9DBofUQ3+rzOg4Rp2clLOwQdAAF48ybOg6H
Pl6v+1Ul6IAevgBHgqpp
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQH6DrNmggC/gzEIbNZzgIjzOPD3nndU3aLnwJpj
VffxPLdD+qGL5V+36TlY+Wq9ElzI7aCfGyw5abeewzXpv7s7SrgdXuioiNw7
qOfAbHx1fZ43t8N1Rq7tG0/qOcSwa9w5psbtcNDn6+rbl/QcFmyeEFDBzu3w
ze2/ntJdPYc9W3xTPd5xOfhN7qpyeaHnMJfT/f7V21wOjLP74v981nOwNbFj
n3qBywHm3rNnQIDL4X9K4QJmHn24/Kac0tbd4vpw/Vw7GS7eVdKHm2+/mStE
RVcfbr/mv68efmb6DtFQ90lcvv1a0U4f7v6Lk9Y8y3XRh/tvpq1eB5enPtz/
H4sM9t3y1ndggYYP2F0++vDwQw9fAFXojLs=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHfRV8b61jIGDiTEIMDmAqckGDj2P1//98pXJIWHv
vAqtGQYOG6aZHnQSZHaQsDPI7Jxj4KCzsyu30IjZIcd8ernJAgOHkBOvr6+P
YHb4PyO7RWSxgcOWR8ff8jQD1au8zxdfauBw53rcktoNzA6esT49BssMHFJa
hHoe32d2qHrc9DYCyH/S/+OusACLg0k859R+oPoFrObX79mzOKz8L1hxE2je
kQenjcXzWBz6mb0SHBcaOMyYCQIsDlq+N5dfn2vg8OfV1yPBB1kcbq3wu7Rx
JlD9h0ZP7ycsDl/bmFhfTQHat3vnnsWMrA4rmd2T5vUbODCciFFeIsHqwKJa
4v2h08DhjEJl/W4NVofi9bV9zC0GDj6vkpJaDIHy7xxa/tYaONyQFs85bsTq
4CMvqcpSYeAw56fXihodVocXzW2StkVA9X/7D5yWY3U4ewYIcgwcKmQCmLi5
WB3QwxcAbq+XEQ==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvY7rnsKRx4YOCWkg8MXeGAQmGzp8sFjAIibyy16i
pvLZoV5Dhwm/5Bun2/6y3/Lg2a3f7YYOFp+nBvyM+GX/R3B/NVOTocMGc70b
fam/7HsCmgr/VBs6zLhy9AhHMlD+VvcW/jKgfsdP/8oCf9mH/dkxN7HA0IFh
wk43D8Nf9lyVf3+JZhs6HCgrrnRn/mWvGr5R1y/N0KHhIfPkaSd+2l/bpBah
kWTo8OPq687lTT/tC/9snb8vztDBAOzQn/ZhDO/a1WIMHToOTk/Xu/PD/syC
b1kFUYYODtx56/bW/7Bvk6kVWh4JNF/+4251hR/22xZtLj4P4nOoShzf/93+
+W2BCS+A6g+s3+vxO+G7PUP6lOrXQPMyjvbflmT7bj/5REbH6XhDhwUTrq+P
3/jN/sXB89PKkg0dAopEbz9K+Wa/wCmx/Wo6MPx0s5talb7Znz0DBDmGDgLH
43+/fP3VHj18AXXqtLM=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYNRg5pYPDOftZMIIg0coBIPLDvOPZ8gVCUkYNK
wuWP3fX37E0evthdFW3kcC4zKLCf46799G0reU7GGjlsuffivuuS2/YlYkJc
7xOMHMRnrKwrjb5l/5qh9faNFCOHO1YOD83MbtonLPt1NTfTyIFxbmvLIesb
9tWL68Un5hk5PFiaq+VcdN1+uaerrVKJkcNzH4tf6+5ds2/0Pa7/r9LI4enC
j5YrWq7Zo7r3mn39JosLjG1GDk+g8pHbdh26223k8AyqvzWm4UXeRIT5CyJZ
tSZNA/oPar/o/yoV9dkI9/W8fPtVYL6RgxjU/ZmeYZ/NFhk5bIb674ycuEvr
EiOHs1D/V1hKxL9dauSgDA0fsLOWIcIPPXwBtcqi+Q==
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{{3.558963332418755*^9, 3.558963348200001*^9}, 
   3.561393288852768*^9, 3.5641637799397717`*^9, 3.5641659959659443`*^9, 
   3.564166790943315*^9, 3.564166983651999*^9, 3.564167269845582*^9, 
   3.564167492704575*^9, 3.564167734846733*^9, 3.5641680729183073`*^9, 
   3.5641683086007853`*^9, 3.564420613201067*^9, 3.5644214262745523`*^9, 
   3.5644215883400927`*^9}]
}, Open  ]],

Cell[TextData[{
 "Boring! The head always moves right and turns the cell black, so it just \
creates a growing black triangle (at least for this ",
 ButtonBox["initial condition",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/nksonline/page-710"], None},
  ButtonNote->"http://www.wolframscience.com/nksonline/page-710"],
 ")."
}], "Text",
 CellChangeTimes->{{3.5569039918061543`*^9, 3.556904025072082*^9}, {
   3.556904092373909*^9, 3.556904229793429*^9}, {3.5569042735990543`*^9, 
   3.556904284399638*^9}, {3.5599092524005947`*^9, 3.559909253430456*^9}, {
   3.5614719553586197`*^9, 3.5614719594849167`*^9}, 3.5638999320305147`*^9, 
   3.564831594547309*^9, {3.564915183005262*^9, 3.5649151862187147`*^9}, {
   3.5650049361220703`*^9, 3.5650049465004473`*^9}}],

Cell["\<\
So now you might be wondering, what happens when the head goes all the way to \
the right edge of the tape? Does it stop or keep going? Well, it kind of \
depends on who you ask. At the summer school, we use the convention that the \
head just wraps around and keeps going from the left:\
\>", "Text",
 CellChangeTimes->{{3.5613931436774197`*^9, 3.561393252352695*^9}, {
  3.561393505519164*^9, 3.5613935227535667`*^9}, {3.5648315981317673`*^9, 
  3.564831604209761*^9}, {3.5648326632211576`*^9, 3.5648326800661726`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", "=", "18"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"PadRight", "[", 
      RowBox[{
       RowBox[{"e2", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", "t"}], ",", "1"}], "]"}], "]"}], ",", "t", ",", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "21", "}"}]}], "]"}], "}"}]}], "]"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmhead", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1", "+", "0.5"}], ",", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "0.5"}], ")"}], "-", 
                RowBox[{"#2", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "3", ",", "0.15"}], "]"}], 
           "&"}], ",", 
          RowBox[{"e2", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "t"}], "]"}], "]"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "445"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.558961995277556*^9, 3.5589620514557447`*^9, {3.558962088277604*^9, 
   3.558962102612935*^9}, {3.5589633252866707`*^9, 3.558963347852647*^9}, {
   3.561393289903606*^9, 3.561393303534009*^9}}],

Cell[BoxData[
 GraphicsBox[{RasterBox[CompressedData["
1:eJyNyLENgEAMxdBvRkBigFuJEbIA+3ekoLnIBZbcvFXPXUeSs7/yRZcRgggi
iCB/EUEEEUQQQQQRnIYZZphtvUbNArE=
    "], {{0, 0}, {21, 18}}, {0, 1}], {
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 18}, {21, 18}}, {{0, 17}, {21, 17}}, {{0, 16}, {21, 
       16}}, {{0, 15}, {21, 15}}, {{0, 14}, {21, 14}}, {{0, 13}, {21, 13}}, {{
       0, 12}, {21, 12}}, {{0, 11}, {21, 11}}, {{0, 10}, {21, 10}}, {{0, 9}, {
       21, 9}}, {{0, 8}, {21, 8}}, {{0, 7}, {21, 7}}, {{0, 6}, {21, 6}}, {{0, 
       5}, {21, 5}}, {{0, 4}, {21, 4}}, {{0, 3}, {21, 3}}, {{0, 2}, {21, 
       2}}, {{0, 1}, {21, 1}}, {{0, 0}, {21, 0}}}],
      Antialiasing->False]}, 
    {GrayLevel[
      NCache[-1 + GoldenRatio, 0.6180339887498949]], 
     StyleBox[
      LineBox[{{{0, 0}, {0, 18}}, {{1, 0}, {1, 18}}, {{2, 0}, {2, 18}}, {{3, 
       0}, {3, 18}}, {{4, 0}, {4, 18}}, {{5, 0}, {5, 18}}, {{6, 0}, {6, 
       18}}, {{7, 0}, {7, 18}}, {{8, 0}, {8, 18}}, {{9, 0}, {9, 18}}, {{10, 
       0}, {10, 18}}, {{11, 0}, {11, 18}}, {{12, 0}, {12, 18}}, {{13, 0}, {13,
        18}}, {{14, 0}, {14, 18}}, {{15, 0}, {15, 18}}, {{16, 0}, {16, 
       18}}, {{17, 0}, {17, 18}}, {{18, 0}, {18, 18}}, {{19, 0}, {19, 18}}, {{
       20, 0}, {20, 18}}, {{21, 0}, {21, 18}}}],
      Antialiasing->False]}}},
  Epilog->{
    RGBColor[1, 0, 0], {{
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQHKDsYg8NkQQm9WcgALNxg68Peed1TdouTQ6Htc
/1+loUP6oYvlX7cpOSz3dLVVKjF00M8Nlpy0W8mhenG9+MQ8Q4cXOioi9w4q
OSQs+3U1N9PQ4Toj1/aNJ5UcXjO03r6RYuhw0Ofr6tuXlBxKxIS43icYOnxz
+6+ndFfJYfq2lTwnYw0d/CZ3Vbm8UHIwefhid1W0oQPj7L74P5+VHDqOPV8g
FGXoAHPvrJlAEGno8D+lcAEzjzJcflNOaetucWW4fq6dDBfvKinDzbffzBWi
oqsMt1/z31cPPzNluPskLt9+rWinDHf/xUlrnuW6KMP9N9NWr4PLUxnu/49F
BvtueSvDw+fsGSDwUYaHH3r4AgDm6o72
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveyV875yCxWHNBBwM3DIANFqqg4Ff7bO3xdn4HCg
yvZjiIGqw7VNahEaSQYORjUJl4QsVR1Uwzfq+qUZONzK03uf4aDqwFX595do
toEDg9F1Dk03VYewPzvmJhYA1Xvcu6/nperw51b3Fv4yA4cpu2ZIJPqoOvQE
NBX+qTZw+HaM9fZGIP+P4P5qpiag/fuEtOS9VR22PHh263e7gUPIf+UPm9xV
HSRqKp8d6jVwkGOfcqDJSdXBGAQmA+VnbfJfb63qkLB3XoXWDAOHbYFzlyQb
A9XbGWR2zjFweMPLynVFU9Uhx3x6uckCoHr2viM28qoO/2dkt4gsNnDg8nox
7YEwUL3K+3zxpQYOL+J+y7BzqDp4xfr0GCwzcOC408jx+7eKQ9XjprcRQP4M
OyMvjg8qDibxnFP7geovsPMaVz1RcVj5X7DiJtC8WTOB4KaKQz+zV4LjQgMH
9PAFAO3ulK4=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuLrDGRDo0XNIAwE1dQcZ9ikHmpz0HQx+
fDrTKq3uEPRf+cMmd32HjINnt37nV3dI2yekJe+t7/BDue47C4u6w5djrLc3
+ug7SC5kefzju5rDhF0zJBKB/B9bxTPl36g56Hncu6/npe+w5keh9eEHag5/
DK9zaLrpO4h++vVV+5qaw7U8vfcZDvoOXuuSouecAaqvSbgkZAlUn+q7IeCI
msO+KtuPIQb6Dg9/ZNvX7lVzSAG7EyjPcIffdwdQPdid+g4zHN9efbBFzSEN
7E59B27LXyp+m9UcvoHdqe+Q55r+fB6QLwF2p57Due2KChe3AuXB7tRzYDyn
8f3aTjWHVWB36jmoTbwoMH2/moMI2J1A9c3zdd8eU3PwALtTz8Gh9RDf6vNA
9WB36jnMmgkEN9UcHoDdqeeAHr4AzvCoaQ==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQGaDmkg8EzXwRgENms4QMR1Hfh7zzuqbtFwYJzd
F//ns45D+qGL5V+3aTj4Te6qcnmh46CfGyw5abeGwze3/3pKd3UcXuioiNw7
qOFw0Ofr6tuXdByuM3Jt33hSA0rrQMU1oOp0oPo0oOboQM3VgNqjA7VXA+oO
HQeYeyHu1HH4n1K4gJlHEy6/Kae0dbe4Jlw/106Gi3eVNOHm22/mClHR1YTb
r/nvq4efmSbcfRKXb79WtNOEu//ipDXPcl004f6baavXweWpCff/xyKDfbe8
NeHhc/YMEPhowsMPPXwBdUGSqA==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQveyV875yCy2Hs2eAoEfLISMNCNS0HR79yLav3avl
cKDK9mOIgbbDmlTfDQFHtByMahIuCVlqO3itS4qec0bL4Vae3vsMB20HsU+/
vmpf03JgMLrOoekGVP+j0PrwA6B6j3v39by0HX5sFc+Uf6PlMGXXDIlEH20H
qYUsj39813L4coz19kYg/4dy3XcWFm2HjH1CWvLeQPrg2a3f+bUdQv4rf9jk
ru1g9OPTmVZpbQcF9ikHmpy0HdKg7gyZtcl/vbU23J07AucuSTbWhrvzDS8r
1xVNbbg7Q9j7jtjIazv8N4S4k8PrxbQHwtpwd76I+y3DzqHtMAnqTo47jRy/
f2s5fIW6c4adkRfHBy24Oy+w8xpXPdGCu3PWTCC4qeUgD3UnevgCABzimzY=

       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHS26x7HjuK7DuTNA0KPhkAYCaroOcuxTDjQ5aToY
/Ph0plVa1yHkv/KHTe6aDhkHz279zq/rkLFPSEveW9Phh3LddxYWXYdvx1hv
b/TRdJBcyPL4x3cdh0m7ZkgkAvk/topnyr/RcTDwuHdfz0vTYc2PQuvDD3Qc
/hle59B003QQ/fTrq/Y1HYcbeXrvMxw0HbzWJUXPOQNUX5NwScgSqD7Vd0PA
ER2HA1W2H0MMNB0e/si2r92rA3UnUJ7hDr/vDh2oOzUdZji+vfpgiw7UnZoO
3Ja/VPw260DdqemQ55r+fB6QLwV2p4bDue2KChe36kDdqeHAeE7j+7WdOlB3
ajioTbwoMH2/joMY2J0aDhea5+u+PaYDdaeGg0PrIb7V53Wg7tRwmDUTCG7q
ODwCu1PDAT18AfTQqJk=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQH6Dmkg8EzdwRgENus5QMTVHfh7zzuqbtFzYJzd
F//ns5pD+qGL5V+36Tn4Te6qcnmh5qCfGyw5abeewze3/3pKd9UcXuioiNw7
qOdw0Ofr6tuX1ByuM3Jt33hSD0qrQcX1oOrUoPr0oOaoQc3Vg9qjBrVXD+oO
NQeYeyHuVHP4n1K4gJlHHy6/Kae0dbe4Plw/106Gi3eV9OHm22/mClHR1Yfb
r/nvq4efmT7cfRKXb79WtNOHu//ipDXPcl304f6baavXweWpD/f/xyKDfbe8
9eHhc/YMEPjow8MPPXwBeZGSqA==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHfxV8b61jIHD2TNA0KPiYAwCkw0cHv/Itq/dq+KQ
sHdehdYMA4e1qb4bAo6oOEjYGWR2zjFw8F6XFD3njIpDrvn0cpMFBg6in359
1b6m4sAwM7tFZDFQ/Y9C68MPVBwkVd7niy81cPi+VTxT/o2Kg1esT4/BMgMH
yYUsj398V3Goetz0NgLI/6lc952FRdXBJJ5zaj9QfebBs1u/86s6rPovWHET
aJ7hj09nWqVVHSYweyU4LjRwSE8DAjVVBy3fm8uvzzVw2F9l+zHEQNXh9gq/
SxtnAtXXJFwSslR1+NbGxPpqioHDzTy99xkOQPOY3ZPm9Rs4MBhd59B0U3Vg
US3x/tBp4GDsce++npeqQ8n62j7mFgOHybtmSCT6AOXfObT8rTVw+HaM9fZG
IN9HXlKVpQJo/z4hLXlvVYcXzW2StkUGDsH/lT9scleFhGOOgYMc+5QDTU6q
DujhCwCrgZtD
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvY7rnsKRx4YO584AQY+Sg4kxEEw2dJBjn3KgyUnZ
QaKm8tmhXkOHoP/KHza5KztsefDs1u92Q4e0fUJa8t7KDn8F91czNRk6fDvG
enujj7JDb0BT4Z9qQ4dJu2ZIJAL5f291b+EvM3Qw8rh3X89L2SH8z465iQWG
DgxG1zk03ZQduCv//hLNNnS4kaf3PsNB2UEtfKOuX5qhg0FNwiUhS2WHa5vU
IjSSDB0OVNl+DDFQdij8s3X+vjig/SCgBjSP4V27WgzQ/B+fzrRKKzucWfAt
qyDK0CHj4Nmt3/mVHdpkaoWWRxo6/FCu+87CouywfdHm4vNAvsRClsc/vis5
vLgtMOEFUP2PreKZ8m+UHBjTp1S/Bpq35keh9eEHSg5TTmR0nI43dBD59Our
9jWg+oPnp5UlGzp4rUuKnnNGyWGBU2L71XSg+lTfDQFHlCDhmGPo8OhHtn3t
XiUH9PAFAHiupmI=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYNRg5pIPBM0WHWTCCINHKASCg6dBx7vkAoysiB
cXZf/J/PCg4mD1/sroo2cvCb3FXl8kLBYfq2lTwnY40cvrn911O6q+BQIibE
9T7ByOGgz9fVty8pOLxmaL19I8XI4Toj1/aNJxUcEpb9upqbaeTwQkdF5N5B
BYfqxfXiE/OMHPRzgyUn7VZwWO7paqtUYuSQfuhi+ddtCg6Nvsf1/1UaOfD3
nndU3aLgAHOvMQhsVnCo32RxgbENIR+5bdehu90I/a0xDS/yJiLMXxDJqjVp
GsJ+0f9VKuqzEe7refn2q8B8hPszPcM+my1C+O+MnLhL6xKE/yssJeLfLkWE
DzgclyHCDz18ASVAk+0=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHfRV8b61jLHDrJlAICnrYAwCk40djny8XverStYh
Ye+8Cq0Zxg4Rp2clLOyQdZCwM8jsnGPsMC3m6DaLmbIOuebTy00WGDuoPfn6
OnyNrAPDzOwWkcVA9R8fl7UdlHWQVHmfL77U2OFNtv4luxuyDl6xPj0Gy4wd
DJw4j318L+tQ9bjpbQSQ/8b9zztODjkHk3jOqf1A9WeaZme/l5dzWPVfsOIm
0LyED09ncpvLOUxg9kpwXAiUBwEfOQct35vLr881dqj5WvVoZYKcw+0Vfpc2
zgSq/3FgiWqRnMO3NibWV1OMHTbcjbl3sQFoHrN70rx+Y4c/yesEg3rkHFhU
S7w/dALVT9izP3aKnEPJ+to+5hZjB5VSQ8NDM4Dy7xxa/tYaO7zq5d6WPFPO
wUdeUpWlwtjhXI1qiN00OYcXzW2StkXGDkv+uT9I7ZdzOAtyV46xgwWfRiNr
q5wDevgCAIitn5w=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvY7rnsKRxyYOM2YCgaSkg4kxEEw2cbDh02hkbZVy
kKipfHao18RhxT/3B6n9Ug5bHzy79bvdxOFMjWqI3TQphz+C+6uZmkwc3vRy
b0ueKeXQG9BU+KfaxEGj1NDw0Awph7+3urfwl5k4pEzYsz92ipRD+J8dcxML
TBwYUtYJBvVIOXBX/v0lmm3isOFuzL2LDVIOauEbdf3STBwSfhxYolok5XBt
k1qERpKJQ8PXqkcrE6QcCv9snb8vDmg/CPgAzWN4164WAzT/w9OZ3OZSDmcW
fMsqiDJxuNA0O/u9vJRDm0yt0PJIE4cP7n/ecXJIOWxftLn4PJBv4MR57ON7
SYcXtwUmvACqf5Otf8nuhqQDY/qU6tdA82I+Pi5rOyjpMOVERsfpeBMHnSdf
X4evkXR4efD8tLJkE4cpMUe3WcyUdFjglNh+NR2o/vSshIUdkg7nQO7KMXE4
8vF63a8qSQf08AUA4tapxw==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEP7M+eAQFxhzQwuGYPERdzeLLwo+WKlmv2TGay
+388F3V45mPxa929a/Zz1US/dlwQdXiwNFfLuei6/evef7Euu0QdGOa2thyy
vmHfOPNV+Palog53rBwempndtF/HLJKXPFnUQXzGyrrS6Fv2FyI9NPY0izps
vvfivuuS2/Zxt5YZqZSLOpzNDArs57hrf65l8ftXuaIOKgmXP3bX37OXk5rf
7JUBNB/qXog7RR3e+YuxWx14AJeXPB0WvqP6IVz/sgncAnd1H8HN/2K82sH1
0iO4/ZMexfc/SXkMd1+94d69co8ew90voHsy657bE7j/em4+blox4Qnc/3z6
7I9X730CDx9IOD6Bhx96+AIAGrGkdQ==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQrREq/2nv4Y/2s2YCgaSgg4kxCPy0P/zxet2vKkEH
lmuvO5c3/bQPPz0rYWGHoEPLQ+bJ0078tJ8Sc3SbxUxBhzNlxZXuzL/stZ98
fR2+RtDhT/9ONw/DX/aRHx+XtR0UdOhw/PSvLPCX/Yds/Ut2NwQdZlw5eoQj
+Ze9kRPnsY/vBR1WmOvd6EsFyrv/ecfJIeTg8HlqwM+IX/YXm2Znv5cXcpjz
S75xuu0v+6QPT2dymws5/LBYwCIm8sv+7Bkg8BFyWHJpSm3V3Z/2DV+rHq1M
EHLY0vtKRXb2T/uEHweWqBYJOUTkawQs8Ptpv+luzL2LDUDzrApUnv38Yf8v
eZ1gUA/QvgCn7Szzf9gnTdizP3aKkIPN91vPLRx+2KuVGhoemiHk4PKAz+XG
/e/2r3q5tyXPFHLY82VioFPDd/vzNaohdtOEHGrsMmZcVP5uv+yf+4PUfiGH
CyB3nflmb8On0cjaKuSAHr4A+pu3Ug==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQnRv6gU1Rjt3ByBgEuBxmzQQBFodKmQAmbi5eh0MP
ThuL57E4+PztP3BajtdhEav59Xv2LA7zfnqtqNHhdbjX/+OusACLwxVp8Zzj
RrwOKS1CPY/vMzt4vUpKajHkdXhwPW5J7QZmhyMKlfW7NXgdNj06/panmdnh
z/EY5SUSvA6hJ15fXx/B7JC6e+eexYy8Dho7u3ILjZgdDnxo9PR+wuOwfprp
QSdBZgeG11+PBB/kcWh7vP7vl69MUHfyOGxhKrA3ecgEdSePQxLb1vDmy0xQ
d/I4aD95MdniLBPUnTwO20Tnzq0+xwR1J7eDzf22BpfrTFB3cjuwWCy+E/2c
CepObodZLm7OMf+YoO7kdnDgr9u2RZoZ6k5uh38iXNZr7Jgd1oHdye2QBgbM
UHdyOaCHLwAGNZnm
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQE8DrNmggC7w9kzIMDlABFncbA1sWOfeoHLgTXH
qu7jeWaHuZzu96/e5nKw8tV6JbiQ2WHPFt9Uj3dcDtek/+7uKGF2WLB5QkAF
O7cDs/HV9XnezA7R7Bp3jqlxO8SAaWaoODdUHTNUHzfUHCaoudxQe5gcWMD2
ckPdweQAcy/EnUwOvycfbeQz4IHLH9t0VfRdHA9cv9YTJpfybh64+X/PaAVM
3MIDt3/Jj+vKljd5oO5kdkjwyV/f/oMH7n4X702ztgvywv2X/G2HgpYKL9z/
h08f/JGlzwt1J7ODMRjwwsMPPXwBbMeI3A==
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQ7XW1veZ9gYBDGhh8sT97Bgh8hBx4jsf/fvn6q33D
16pHKxOEHOJ0s5talb7ZJ/44sES1SMjBr0j09qOUb/ab7sbcu9gg5LBmwvX1
8Ru/2f9LXicY1CPkkHa0/7Yk23f7pAl79sdOEXI4tH6vx++E7/ZqpYaGh2YI
ORzjUJU4vv+7/ate7m3JM4Uc9sl/3K2u8MP+fI1qiN00IQc37rx1e+t/2C//
5/4gtV/Ioe3g9HS9Oz/sbfk0GllbhRyMjEHgp/1Kk9T5ceVCDizXXncub/pp
n7PYyvN4mpBD00PmydNO/LS/Ks0lsiJYyOFMWXGlO/Mv++V8Mp2VdkIOv/p3
unkY/rIXmHJB96C6kEOH46d/ZYG/7M/t/WbJJyDkMO3K0SMcyUD5HcyC374L
Oqww17vRl/rLXr82ZYrAA0EHh89TA35G/LKfxy+V9uWEoMOsX/KN021/2YOd
tVnQ4ZvFAhYxkV/26OELACenq2w=
       "]]}, {
      RGBColor[1, 0.7777777777777778, 
       NCache[
        Rational[5, 9], 0.5555555555555556]], 
      EdgeForm[
       RGBColor[
        NCache[
         Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQvV2rolmgX9xhwUwQuGh/7gwQ+Ig5vCh04NTReGKf
9OHpTG5zMQeLr/ZM+tVP7C81zc5+Ly/m0PBMe+GnjU/sP7j/ecfJIeYQkB+z
Qfb0E3sjJ85jH9+LOmis7O4UPPbE/mO2/iW7G6IOAs1P/r5d9MQ+6uPjsraD
og4/5It7JyQ9sdd58vV1+BpRhxlvn33qY3tiPyXm6DaLmaIOHIfZ1XQnPraP
OD0rYWEHkL/murA/62P7Ix+v1/2qEnXISAOBR/ZRjDvkZxUA5Zv1z8fseGhv
1Hxr9cFMUYcJYndiqv8/sBcr+uI5J03UocL+Ubm/wwP7213nztmmizooKE9J
kPl/z35+vrPDomxRB4b935TeNt+1Z5oT+G5tMVC/qH1eusQdez+lxYp69aIO
C5zi9tcdvWW/gN0++lavqIPDydCc7sk37Ru4WmXD5os6FGxdwynWdcPexBgI
Nos6GMjUv12+/ro9evgCAF+Lqsg=
       "]]}}},
  Frame->False,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->445]], "Output",
 CellChangeTimes->{{3.561393297444422*^9, 3.5613933043099318`*^9}, 
   3.564163780026162*^9, 3.564165996195059*^9, 3.5641667910293303`*^9, 
   3.564166983737357*^9, 3.56416726993079*^9, 3.5641674927943687`*^9, 
   3.564167734928917*^9, 3.564168073076836*^9, 3.564168308690544*^9, 
   3.564420616868394*^9, 3.564421426443234*^9, 3.564421588416704*^9}]
}, Open  ]],

Cell["\<\
We call this a \[OpenCurlyDoubleQuote]periodic boundary\
\[CloseCurlyDoubleQuote]. The other convention you could choose is called the \
\[OpenCurlyDoubleQuote]halting\[CloseCurlyDoubleQuote] condition, where the \
head just stops at the right edge of the tape and the game is over.\
\>", "Text",
 CellChangeTimes->{{3.5613933823848677`*^9, 3.561393399540534*^9}, {
  3.561393435339814*^9, 3.561393470834538*^9}, {3.5613935464965277`*^9, 
  3.561393647711679*^9}, {3.5613936863363543`*^9, 3.56139369805199*^9}, {
  3.561393803723037*^9, 3.56139387968498*^9}, {3.561469788965951*^9, 
  3.561469794260543*^9}, {3.5648316069682355`*^9, 3.564831609757879*^9}, {
  3.564832688867347*^9, 3.564832691141633*^9}}],

Cell["\<\
Side note: this seemingly trivial detail has actually gotten a LOT of \
attention. It turns out that there are Turing machines (like the one Turing \
constructed in his famous 1936 paper) where it is impossible to predict (\
\[OpenCurlyDoubleQuote]undecidable\[CloseCurlyDoubleQuote]) whether or not \
the head will reach the right edge and halt. This is called the \"halting \
problem\". And there are even so-called \"busy beaver\" competitions where \
people try to find Turing machines that will run the longest before \
eventually halting.\
\>", "Text",
 CellChangeTimes->{{3.5613933823848677`*^9, 3.561393399540534*^9}, {
  3.561393435339814*^9, 3.561393470834538*^9}, {3.5613935464965277`*^9, 
  3.561393647711679*^9}, {3.5613936863363543`*^9, 3.56139369805199*^9}, {
  3.561393803723037*^9, 3.561393889942718*^9}, {3.5614704099560337`*^9, 
  3.561470445122458*^9}, {3.563900033563202*^9, 3.563900050702175*^9}, {
  3.564831613654029*^9, 3.564831621165806*^9}, {3.5648327226077785`*^9, 
  3.5648327505378776`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Enumerate All Point-changes to the Rule\
\>", "Section",
 CellChangeTimes->{{3.561477264775741*^9, 3.561477284717094*^9}, {
  3.565003359386262*^9, 3.565003377267749*^9}}],

Cell[TextData[{
 "So is it even possible to get something more interesting by changing one of \
the cases in the rule table? How about a pattern that grows more slowly? Or \
one that never repeats? Well, it\[CloseCurlyQuote]s kind of hard to tell just \
by thinking about it, isn\[CloseCurlyQuote]t it? I mean, you have to \
basically run the rule in your head to figure it out. This happens so often \
with Turing machines that they gave it a name: ",
 StyleBox[ButtonBox["computational irreducibility",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/nksonline/page-737-text"], None},
  ButtonNote->"http://www.wolframscience.com/nksonline/page-737-text"],
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.556908327371057*^9, 3.55690844803231*^9}, {
   3.556908486965328*^9, 3.556908487952211*^9}, {3.556908528765802*^9, 
   3.5569086104351063`*^9}, {3.556908643745961*^9, 3.5569086462578077`*^9}, {
   3.556908709607778*^9, 3.556908838991887*^9}, {3.556908944407257*^9, 
   3.556909053886216*^9}, {3.556909090284524*^9, 3.556909118802786*^9}, {
   3.5569091491031647`*^9, 3.5569091563781767`*^9}, {3.557096924114133*^9, 
   3.557096937043398*^9}, 3.5589660059029913`*^9, {3.559909265142355*^9, 
   3.559909265639461*^9}, 3.561394149499795*^9, {3.561471374760722*^9, 
   3.561471377446787*^9}, {3.5648316246567564`*^9, 3.5648316359241123`*^9}, {
   3.5648327661619096`*^9, 3.5648327750253935`*^9}, 3.564842984028132*^9, {
   3.564843166723405*^9, 3.564843192072942*^9}, 3.564844550749299*^9, {
   3.5649152285466127`*^9, 3.5649152379926567`*^9}}],

Cell[TextData[{
 "But that doesn't mean we're stuck, because we have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "! Let's just enumerate all the possible point changes to the rule and show \
them all in a table like so (see the attached notebook for the code):"
}], "Text",
 CellChangeTimes->{{3.556908327371057*^9, 3.55690844803231*^9}, {
   3.556908486965328*^9, 3.556908487952211*^9}, {3.556908528765802*^9, 
   3.5569086104351063`*^9}, {3.556908643745961*^9, 3.5569086462578077`*^9}, {
   3.556908709607778*^9, 3.556908838991887*^9}, {3.556908944407257*^9, 
   3.556909053886216*^9}, {3.556909090284524*^9, 3.556909118802786*^9}, {
   3.5569091491031647`*^9, 3.5569091563781767`*^9}, {3.557096924114133*^9, 
   3.557096937043398*^9}, 3.5589660059029913`*^9, {3.5614714216451406`*^9, 
   3.56147142824509*^9}, 3.564831639599552*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"perturbstate", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"statechoices", "=", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"rule", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "2", ",", "1"}], "]"}], "]"}], "}"}]}], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ReplacePart", "[", 
           RowBox[{"rule", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n", ",", "2", ",", "1"}], "}"}], "\[Rule]", 
             RowBox[{"statechoices", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ",", 
          RowBox[{"ReplacePart", "[", 
           RowBox[{"rule", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n", ",", "2", ",", "1"}], "}"}], "\[Rule]", 
             RowBox[{"statechoices", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], "}"}]}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "6", ",", "1"}], "}"}]}], "]"}], ",", 
    "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.556905309149219*^9, 3.556905421823455*^9}, {
   3.556905464239736*^9, 3.556905513040057*^9}, {3.556905559081118*^9, 
   3.556905575836585*^9}, 3.5569056714835663`*^9, {3.556905966241806*^9, 
   3.556905969609448*^9}, {3.5569060176159353`*^9, 3.556906021732709*^9}, {
   3.558963392420567*^9, 3.5589633978189077`*^9}, {3.5589656991493797`*^9, 
   3.558965702673274*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.556905527972336*^9, {3.556905559692092*^9, 3.556905576363051*^9}, 
   3.55690567304978*^9, 3.556905979571351*^9, 3.556906023457546*^9, 
   3.558963399073451*^9, 3.5641659962277184`*^9, 3.5641667910657797`*^9, 
   3.564166983770131*^9, 3.564167269968926*^9, 3.564167492839054*^9, 
   3.5641677350201607`*^9, 3.564168073104848*^9, 3.5641683087341833`*^9, 
   3.56442062291481*^9, 3.564421426457481*^9, 3.564421588445207*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"perturbcolor", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"othercolor", "=", 
        RowBox[{"1", "-", 
         RowBox[{"rule", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"ReplacePart", "[", 
       RowBox[{"rule", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", "2", ",", "2"}], "}"}], "\[Rule]", 
         "othercolor"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "6", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.55690562635798*^9, 3.556905690310589*^9}, {
   3.556905842178606*^9, 3.5569058582306356`*^9}, 3.55690597350307*^9, {
   3.556906024444241*^9, 3.556906026603208*^9}, {3.558963402088716*^9, 
   3.558963403921204*^9}, {3.558965704300865*^9, 3.558965705282514*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.556905679033062*^9, 3.556905691241647*^9}, 
   3.55690585909636*^9, 3.556905989736669*^9, 3.556906027139409*^9, 
   3.558963404243106*^9, 3.5641659962605047`*^9, 3.564166791125059*^9, 
   3.564166983820602*^9, 3.5641672700043373`*^9, 3.5641674928781357`*^9, 
   3.564167735050871*^9, 3.564168073142061*^9, 3.564168308786448*^9, 
   3.56442062304038*^9, 3.564421426498438*^9, 3.564421588477708*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"perturbdir", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"otherdir", "=", 
        RowBox[{"-", 
         RowBox[{"rule", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2", ",", "3"}], "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"ReplacePart", "[", 
       RowBox[{"rule", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", "2", ",", "3"}], "}"}], "\[Rule]", "otherdir"}]}],
        "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "6", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.55690562635798*^9, 3.556905690310589*^9}, {
  3.556905842178606*^9, 3.5569058582306356`*^9}, {3.556905898408684*^9, 
  3.5569059278321867`*^9}, {3.556906005790326*^9, 3.556906030331283*^9}, {
  3.558963407803502*^9, 3.558963409521263*^9}, {3.558965706588009*^9, 
  3.55896570760165*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.556905929466649*^9, {3.556906006292918*^9, 3.5569060307838087`*^9}, 
   3.558963410143499*^9, 3.564165996306397*^9, 3.564166791169662*^9, 
   3.564166983859178*^9, 3.5641672701448317`*^9, 3.564167492972143*^9, 
   3.564167735097039*^9, 3.5641680731874123`*^9, 3.5641683088332767`*^9, 
   3.564420623086182*^9, 3.56442142654312*^9, 3.56442158850956*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"perturbrules", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"perturbstate", ",", "perturbcolor", ",", "perturbdir"}], "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.556906032491156*^9, 3.5569060483464727`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a", "=", 
           RowBox[{
            RowBox[{"TuringMachine", "[", 
             RowBox[{"rule", ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "50"}],
              "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"ArrayPlot", "[", 
          RowBox[{
           RowBox[{"PadRight", "[", 
            RowBox[{"a", ",", 
             RowBox[{"{", 
              RowBox[{"51", ",", "50"}], "}"}], ",", "0", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"Round", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"50", "-", 
                   RowBox[{"Length", "@", 
                    RowBox[{"a", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "/", "2"}], 
                "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"PixelConstrained", "\[Rule]", "2"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"rule", ",", "perturbrules"}], "}"}]}], "]"}], ",", "4", ",", 
     "4", ",", "1", ",", 
     RowBox[{"{", "}"}]}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "LightGray"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.556907452832616*^9, 3.556907480802825*^9}, {
  3.5569075310524893`*^9, 3.556907534002008*^9}, {3.556907645367412*^9, 
  3.556907673968492*^9}, {3.556907711648546*^9, 3.5569077161250887`*^9}, {
  3.556907799989629*^9, 3.556907847633732*^9}, {3.556907910018263*^9, 
  3.556907942983123*^9}, {3.556908005502738*^9, 3.556908019374241*^9}, {
  3.556908059653059*^9, 3.556908069596043*^9}, {3.556908139550517*^9, 
  3.556908160369349*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[RasterBox[CompressedData["
1:eJy90sEJwCAMheG8btIV2k06ggt0/1uF0iJ6MH+EPPDmB/HFvdxX2czsrOeo
R32sy3BhJuZAGAiDNSEufMFDJb9cXAS6Stggb9cHhMGCcBbVCnfwUJkv937D
RgS6Stggb9cNhEFU+Iv6BQkeKu3l4Bt+ItBVwgZ5uwQIg5BARYWEuGALfwEX
FMzyANXHCl4=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJyt0dsNgCAQBdHFTmxBO7EEGrD/PzU+UcLeAYn8mJxkcunjPMXOzMb1DusN
ybHtz/crnH9EoMK4wFVlkK+iogz+EOWhMsKZNidwlQsyVVS4oFm4Q72FP+1H
4CoFvKuoUECbUIZKhDRtKnCVCJIqKkTQIMShbqFO+xC4Sgd3FRU6qBX6UIcA
054CVyHAHu8SCFQJNFSVCFywB98BFxQIZwFX4goo
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy9z7ENgDAMRNHAJqwAmzBCFmD/jogCEMSHf2JhkYLiSf+mvK15TCkt5c3l
DdeVH/HVTokqCBVGlBJ1QGcrYYE4YUfR2aKKCgGChIyis60qKjSIEF9RdHa1
iopP0C0cUXT2u4oKD+gTvig6+1FFhRN0CHcUnX2vosIPWgWJorPPKioQaBIw
is4+BAR0RIv4I8p7O7SkCfw=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 
       1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJiYGAwBmIjIGakLiDdPNKdQIYOUjWQDkY9TryOUY/TUAepGkgH
ox4nXseox2mog1QNpINRjxOvY9TjNNRBqgYCAAAMnwvI
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True]},
    {
     GraphicsBox[RasterBox[CompressedData["
1:eJy107ENgDAMRNF/bMIKsAkjsAD7d0CfFP+kBKVCT9hnvN/PdW/A+d3juxke
/mf2ciywIlbgha4K3bkXRbrxophHvMCLLBdYESvwQleF7tyLIt14UcwjXhQb
leUCK2IFXuiq0J17UaQbL4p5xItioxxohC1Kr2DTuK5q/UKlSVf/JD7d4hPT
8wLL8AtF
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJyd1sENwjAQBMBbOqEF6IQS0gD9/wgCLCOicBMn/nmk83kd5bzcb8upqq7r
vKwzv6Oe7+dpjSoX5SIuykVclIu4KBdxsRmJfdEDc1Uq2mTqrgkoa0qJCNr6
lPa+wPbyAR4Q+l34Mn3gArsbvOVvQSkJ3vIhIO2juS76gNeHawrvO9zb8PmF
MzLurQndeXF3tahs/0v8EUi4qAOCo/syClwo2BsPN1ILBQ==
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy9yzsRgEAQwNALTrAATpCAAfx3UHP7mVCQmZRvPa/jXMYY+/M2fgkNrMAK
rMAKrMAKrMAKrMAKrMAKrMAKrHiDVkygEzNoRABqEYFShKASMShEAnKRgVSk
IBM5SEQBYlGBUJQgEjUIRANm0YFJtOAteoAGaIAGaIAGaIAGaIAGaIAGaIAG
aPChG84XBwk=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy9yzsRgEAQwNALTrAATpCAAfx3UHP7mVCQmZRvPa/jXMYY+/M2fgkNrMAK
rMAKrMAKrMAKrMAKrMAKrMAKrHiDVkygEzNoRABqEYFShKASMShEAnKRgVSk
IBM5SEQBYlGBUJQgEjUIRANm0YFJtOAteoAGaIAGaIAGaIAGaIAGaIAGaIAG
aPChG84XBwk=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True]},
    {
     GraphicsBox[RasterBox[CompressedData["
1:eJydz8ENgCAUBFHGTmxBO7EEGrD/m5z5JjBLwo0Xds7+Pv1ord3jXuMynVbO
/KKIYlai/qLBhpjNepUXQTlWzL9osCWwAi+CcqzAi6AcvcqLoBy9yougHL3K
i6AcvcqLoBy9yougHL3Ki6AcvcqLoBy9yougHL3Ki6AcvcqLoBy9youg3IKf
8wF5oQo5
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJyd0MkRAjEQQ1GLTEgBMiGESYD8b0yxzGIf3I+u8s2/9KXr8nwsl9bafX23
9aW71l3GL1NiAozE9HpijrBU+gAm2KoQMVgpUUFYKucAJtiqFNFZKVFDWCrH
ACbYqhhxslKiirBU9gAm2KocEaydY3Mk6lLRpTaCrSAiutTeHAmRii71JdiK
IqJL/ZojYVLRpd4EW2GEBuTTHAmVii6Vv4ooML8XbqwKOQ==
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJyd08ENAjEMRNEMndACdEIJ2wD939gTcgQCP2eV0/rLM/bkejwfx2WtdT/v
7bz5OKt+X/7/IToA14c1VaLbpHRAom+kdCBChlU6AGELKR3ahC69dBjEpEmw
qrDzzXtflBOUki0nQkDat7wb0X6127tVogtwfVhT2Hd4tiUlQqB1zWE465ks
hFWFnYenG97ge4dISBIHo+L6sKaw7/BsMzHCqsLOBy1+nBeY/QsV
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy9kbENgDAQA/1swgqwCSNkAfbvCASo0pwLW/rqddJZXtt5tEXS3m/rV7Oo
NDL9zgMJcYJbBXr8ACEKW1FCnOBWgR7GHp8WsaKEOMGtAj2MPV4tZEUJcYJb
BXoYewwtRBQlxAluFehh7PFoMaIoIU5wq0APY49bCxJFCXGCWwV6GHsYUvNc
XHMLFQ==
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True]},
    {
     GraphicsBox[RasterBox[CompressedData["
1:eJy90MENgDAMQ9GYTVgBNmGELsD+N3pukWI7lEi99an53dt9tS0izn6OfjBM
zDNeyQR+EPpWGXjZarlIuz8QRkcKpq2WC6K7LIwOAkAGNUF1F4XRQQHIoCLI
7pIwOkgAGfiC7i4Io4MGkIErhG5bGB0CgAwgA0tIH2UJ6AK6UMuNJ9J5ANd1
CfE=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJiYGAwBmIjIGbEArAKDgJAurvo4BMyHEWyFjJ0kKqBTmA0ConX
QaoGOoHRKCReB6ka6ARGo5B4HaRqoBMYjULidZCqgU5gAKMQAGF7C9k=
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJydk8ENgDAMAxs2YQXYhBG6APv/qJBKk/YRH0HlgXTETuq93lfdSilnO0c7
NlWx9q2/3ieriVh/mRIpsKiihFKBkBBPaE0cIcpygighWw/rZgRWZdi54eka
3qBsI6qihIiE6TJCtcECOxMawAIbCblQYD0BmqDADgIZQYHtBBsuC+wgqHM9
sJ5gG2Q2WGAdQRAU2I9ANlhgHQEArAmuohMQofuD17Y3oQRWBS/VvxZpPTkK
Cuc=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy1z7sNgEAMg+E7NmEF2IQRbgH276BAIFAedhJ+yeVXeB77NqbW2npuOdfv
mlkXokGt6LyQqxQKKBTKbUuolQkdVAn9tiqsaoQJSoR5WxZOBcIDeeHdFoRf
VgAgKYDbXwGVEhjICOz2S6DFBQzCAr79CKKgYEBMMLcvwRURJAgI8vavHWYr
CRE=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True]},
    {
     GraphicsBox[RasterBox[CompressedData["
1:eJy90bENwCAMRFE7m2SFZJOMwALs3wUpHRS+jyMj6HjS6e5s/WmHmd3jXeP5
dGy6649QRGARIUgLIVS9ELr9QcSAzjcLBeSEFqpYaN1mhQTofI7HSAk5VKWQ
u00JFdD5HI+xL0ioMkG63RcA0Pkcj7EpYKgaAbutEXTxjxQICsLzApHyCxI=

       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJzt1MEJgDAQRNEZO7EF7cQS0oD93wxBRVDC/oMHcSfsbR8EwmQs61IGSXOd
qY7v0eXEkiLFG8JciAtzIS7MhbgwF+LCXDz+NH0RBXg/xfcFrFMDXKA67Zfi
AtTpEPE6nYIAvP9nAZ+vAS4o6GYDFeULKg==
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy90dEJgDAMhOGcm7iCbuIIXcD93ywUEelD8yeQQJ/KB8fd3u6rbWZ29nf0
p+nsd/P/QniAMEgKnEpUqEDwVCV7+IAwSAmcytntJ7z7ZQRPVbKHFwiDhMCp
3N2+wr9fXPBUJXv4gTAIC5wKdDsE2S8qeKqSPQgQBiGBigoJccEGH4ALChb3
AGyBCnE=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy9yzsRgEAQwNALTrAATpCAAfx3UHP7mVCQmZRvPa/jXMYY+/M2fgkNrMAK
rMAKrMAKrMAKrMAKrMAKrMAKrHiDVkygEzNoRABqEYFShKASMShEAnKRgVSk
IBM5SEQBYlGBUJQgEjUIRANm0YFJtOAteoAGaIAGaIAGaIAGaIAGaIAGaIAG
aPChG84XBwk=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True]},
    {
     GraphicsBox[RasterBox[CompressedData["
1:eJy9z7ERgDAMQ1GZTVgBNmGELMD+HS65ECdIhZxz4bu84u/tvtoG4Mw9cuM1
eVWvGF6U/2tRmxoYhNBRmRkwCKFjbObAIISOkVkBgxA6vmYNDELo6M0fYBBC
R/ACBiF0BC9gEEJH8AIGIXQEL2AQQkfwAgYhdAQvwAsWdPMAymMKjQ==
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy10rENhEAQQ9HxdXItQCdXAg3Qf3YEQLTJG2ksbQRfa6/9Pc7f8amq/Trb
dbJQPVp9XKriRJQoJ9jVcwkRYVdOzCef7yNO8ErCS3xtEWENvq9FRCN5nAi7
cmI++XwfcYJXEl7ibQsJa/B+LSQayeOEqVfgfPL5PuIEr6TVCHYe/r8Ro7cs
v0SJRva1/s8BCvo=
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJiYGAwBmIjIGYkAhCnCkUHqRpIB6S7adQXtAKjvqCVFaSDUV/Q
ygrSwagvaGUF6WDUF7SygnQw6gtaWUEkAAA0QgvR
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True], 
     GraphicsBox[RasterBox[CompressedData["
1:eJy1lcsNgCAQRGfsxBa0E0ugAfu/iR8SD2h4m+wiN16cWQaYy76VSdJa51Kn
O6XnO8dYnctFCVNCnMCqAkS+D1HCnMCq3sw4wAmWxFsUJ8wJccKc6B/RX2Ic
wOuNNRn7Nu6t8f4ZZ8S8WYHtwKoCRMAH7W57DxjBUiLTJAZCAoPbnEMiOYft
XUsn8n3QewHn8EIwgWOCUxL5xXcdkf0LOg==
       
       "], {{0, 0}, Offset[{100, 102}, {0, 0}]}, {0, 1}],
      Frame->False,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}},
      ImageSize->{100, 102},
      PlotRange->{{0, 100}, {0, 102}},
      PlotRangeClipping->True]}
   },
   AutoDelete->False,
   FrameStyle->GrayLevel[0.85],
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.5589634737234917`*^9, 3.564165996815529*^9, 
  3.564166791655301*^9, 3.564166984415695*^9, 3.5641672706348457`*^9, 
  3.564167495576222*^9, 3.564167735574531*^9, 3.564168074031869*^9, 
  3.564168310763129*^9, 3.56442062361195*^9, 3.5644214269948063`*^9, 
  3.5644215890337257`*^9}]
}, Open  ]],

Cell["\<\
Each one of these is a different Turing machine with a rule table that \
differs by just a single change from the original rule (there are 24 similar \
rules in all, in a 6x4 grid). While there is quite a variety, they are all \
pretty predictable. Nothing earth-shattering.\
\>", "Text",
 CellChangeTimes->{{3.55690926682546*^9, 3.556909331475575*^9}, {
  3.556909401246059*^9, 3.55690946471084*^9}, {3.55690951314172*^9, 
  3.5569096299537086`*^9}, {3.55709696744664*^9, 3.557096997985242*^9}, {
  3.5648316430258102`*^9, 3.564831646794694*^9}, {3.564832878474242*^9, 
  3.5648328809977655`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Number of Turing Machine Rules", "Section",
 CellChangeTimes->{{3.564162589978003*^9, 3.5641626242711153`*^9}, {
  3.565003398512672*^9, 3.565003405057767*^9}}],

Cell[TextData[{
 "But these 24 rules are just a small sample of all the possible Turing \
machine rules with three states and two colors. Just think about it: for each \
of the six cases in the rule table, there is a choice of what the new color \
should be, which state the head will be in, and which direction it will go. \
If you do the ",
 ButtonBox["math",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/summerschool/resources/EnumLecture-mz-\
nks-ss07.cdf"], None},
  ButtonNote->
   "http://www.wolframscience.com/summerschool/resources/EnumLecture-mz-nks-\
ss07.cdf"],
 ", it turns out that there are over ",
 ButtonBox["2 billion of them",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/nksonline/page-888c-text"], None},
  ButtonNote->"http://www.wolframscience.com/nksonline/page-888c-text"],
 ":"
}], "Text",
 CellChangeTimes->{{3.5570989263726673`*^9, 3.557099124006122*^9}, {
   3.557099176821025*^9, 3.5570991866520357`*^9}, {3.5570992303434687`*^9, 
   3.5570992306345053`*^9}, {3.561472272127881*^9, 3.5614722754758883`*^9}, 
   3.561472353711158*^9, {3.5648316496758657`*^9, 3.5648316531332717`*^9}, {
   3.5648329904341774`*^9, 3.564833015553651*^9}, {3.5648444945981607`*^9, 
   3.564844496192284*^9}, {3.5649152803062687`*^9, 3.564915304237603*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numtmrules", "[", 
   RowBox[{"numstates_Integer", ",", "numcolors_Integer"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"numstates", "*", "numcolors"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"2", "*", "numstates", "*", "numcolors"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.557099129345593*^9, 3.557099168447517*^9}, {
  3.557099245448983*^9, 3.557099288139668*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numtmrules", "[", 
  RowBox[{"3", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.557099297339716*^9, 3.557099304426243*^9}}],

Cell[BoxData["2176782336"], "Output",
 CellChangeTimes->{3.5570993049879313`*^9, 3.5641659968793983`*^9, 
  3.564166791828671*^9, 3.564166984584394*^9, 3.564167270720292*^9, 
  3.564167495708143*^9, 3.564167735635981*^9, 3.564168074215764*^9, 
  3.564168311012167*^9, 3.564420650952482*^9, 3.564421427045191*^9, 
  3.564421589170783*^9}]
}, Open  ]],

Cell["\<\
And if you think that\[CloseCurlyQuote]s bad, the faculty at the Wolfram \
Science Summer School decided to be really diabolical and make the students \
choose their favorite 4-state, 4-color Turing machine. And just how many \
rules is that to choose from?:\
\>", "Text",
 CellChangeTimes->{{3.557099444119013*^9, 3.557099586431563*^9}, {
   3.5570996316132793`*^9, 3.5570996593800097`*^9}, {3.558963622887931*^9, 
   3.5589636229736767`*^9}, 3.564831658708728*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numtmrules", "[", 
  RowBox[{"4", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.5570995928372097`*^9, 3.557099596944076*^9}}],

Cell[BoxData["340282366920938463463374607431768211456"], "Output",
 CellChangeTimes->{{3.557098585490649*^9, 3.557098666224533*^9}, 
   3.55709873061931*^9, {3.5570988493430767`*^9, 3.557098871933312*^9}, 
   3.5570995973789997`*^9, 3.56416599690864*^9, 3.564166791881937*^9, 
   3.56416698463694*^9, 3.5641672707512074`*^9, 3.56416749573884*^9, 
   3.564167735668942*^9, 3.564168074277237*^9, 3.5641683110673847`*^9, 
   3.5644206509876738`*^9, 3.564421427071465*^9, 3.564421589214609*^9}]
}, Open  ]],

Cell["Mwahahhaaha!!!!", "Text",
 CellChangeTimes->{{3.557099603489406*^9, 3.557099607821651*^9}}],

Cell["\<\
Needless to say, an exhaustive search was pretty much out of the question. :)\
\
\>", "Text",
 CellChangeTimes->{{3.5570996805832033`*^9, 3.557099698642614*^9}, {
   3.5570998464714003`*^9, 3.557099849486287*^9}, {3.557254607183577*^9, 
   3.5572546341024837`*^9}, 3.558966080764127*^9, {3.5648316636923757`*^9, 
   3.5648316640194273`*^9}, {3.564833030887126*^9, 3.564833038273373*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Student Homeworks", "Section",
 CellChangeTimes->{{3.55709778064751*^9, 3.557097784596464*^9}, {
  3.565003422148189*^9, 3.565003425076099*^9}}],

Cell["\<\
So the students had to figure out some tricks for searching for Turing \
machines with the kinds of features they were interested in. And with so many \
rules to sort through, it was definitely a needle-in-a-haystack situation.\
\>", "Text",
 CellChangeTimes->{{3.5570996805832033`*^9, 3.557099698642614*^9}, {
   3.5570998464714003`*^9, 3.557099849486287*^9}, {3.557254607183577*^9, 
   3.5572546341024837`*^9}, {3.558966080764127*^9, 3.5589661077555237`*^9}, {
   3.558966171505018*^9, 3.5589661758039722`*^9}, 3.564831667040764*^9, {
   3.564833050225381*^9, 3.5648330504123745`*^9}}],

Cell[TextData[{
 "But the students were up to the challenge, and they got really creative. \
They ran searches using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " looking for things like:"
}], "Text",
 CellChangeTimes->{{3.557100439079948*^9, 3.5571004846029167`*^9}, {
   3.5571005188118067`*^9, 3.557100696396886*^9}, {3.5571007288427763`*^9, 
   3.557100789632626*^9}, {3.557100939626054*^9, 3.557100947724197*^9}, {
   3.55725459875432*^9, 3.5572545989164*^9}, {3.557254665062388*^9, 
   3.5572546660776157`*^9}, {3.5589661862535067`*^9, 
   3.5589661906996937`*^9}, {3.558966251062985*^9, 3.558966272699583*^9}, {
   3.5599095077858343`*^9, 3.559909528797624*^9}, {3.561394279129333*^9, 
   3.561394339402021*^9}, {3.561394506225092*^9, 3.561394513066721*^9}, {
   3.561394564885427*^9, 3.561394572179175*^9}, {3.56139822620399*^9, 
   3.5613982298285418`*^9}, {3.5613982742945423`*^9, 3.561398281133263*^9}, {
   3.561398334540217*^9, 3.5613983385387297`*^9}, {3.561398421411598*^9, 
   3.5613984355889273`*^9}, {3.561398497790513*^9, 3.561398499006649*^9}, 
   3.5648316706850567`*^9}],

Cell[CellGroupData[{

Cell["Slowest Growth", "Subsection",
 CellChangeTimes->{{3.563900201851614*^9, 3.563900203917017*^9}, {
  3.56500347676795*^9, 3.5650034798876667`*^9}}],

Cell[TextData[{
 "the ",
 ButtonBox["slowest possible growth of the tape:",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/2012/alumni/goldfarb.html"], 
    None},
  ButtonNote->
   "http://wolframscience.com/summerschool/2012/alumni/goldfarb.html"]
}], "Text",
 CellChangeTimes->{{3.557100439079948*^9, 3.5571004846029167`*^9}, {
   3.5571005188118067`*^9, 3.557100696396886*^9}, {3.5571007288427763`*^9, 
   3.557100789632626*^9}, {3.557100939626054*^9, 3.557100947724197*^9}, {
   3.55725459875432*^9, 3.5572545989164*^9}, {3.557254665062388*^9, 
   3.5572546660776157`*^9}, {3.5589661862535067`*^9, 
   3.5589661906996937`*^9}, {3.558966251062985*^9, 3.558966272699583*^9}, {
   3.5599095077858343`*^9, 3.559909528797624*^9}, {3.561394279129333*^9, 
   3.561394339402021*^9}, {3.561394506225092*^9, 3.561394513066721*^9}, {
   3.561394564885427*^9, 3.561394572179175*^9}, {3.56139822620399*^9, 
   3.5613982298285418`*^9}, {3.5613982742945423`*^9, 3.561398281133263*^9}, {
   3.561398334540217*^9, 3.5613983385387297`*^9}, {3.561398421411598*^9, 
   3.5613984411624804`*^9}, {3.561398493926351*^9, 3.561398494038396*^9}, 
   3.5613989534576597`*^9, 3.5648330919249535`*^9, {3.564929038600865*^9, 
   3.564929059447998*^9}, {3.564938450414806*^9, 3.56493845070138*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"TuringMachine", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"195516390533805345796937", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "3000"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563900228005419*^9, 3.563900235518388*^9}, 
   3.563900267058216*^9, {3.563900493957591*^9, 3.563900494730587*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TMColors", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "\[Rule]", "White"}], ",", 
     RowBox[{"1", "\[Rule]", 
      RowBox[{
       RowBox[{"ColorData", "[", "\"\<WebSafe\>\"", "]"}], "[", 
       "\"\<#ffff99\>\"", "]"}]}], ",", 
     RowBox[{"2", "\[Rule]", 
      RowBox[{
       RowBox[{"ColorData", "[", "\"\<WebSafe\>\"", "]"}], "[", 
       "\"\<#ff9900\>\"", "]"}]}], ",", 
     RowBox[{"3", "\[Rule]", 
      RowBox[{
       RowBox[{"ColorData", "[", "\"\<WebSafe\>\"", "]"}], "[", 
       "\"\<#FF0000\>\"", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563900329323913*^9, 3.563900331815607*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ArrayPlot", "[", 
     RowBox[{"#", ",", 
      RowBox[{"ColorRules", "->", "$TMColors"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "25"}]}], "]"}], "&"}], "/@", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "200"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.563900270981656*^9, 3.5639002917847147`*^9}, {
  3.563900360889529*^9, 3.5639003642873983`*^9}, {3.563900409277801*^9, 
  3.563900471514374*^9}, {3.56390050346623*^9, 3.563900534331818*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    RasterBox[CompressedData["
1:eJzt19GN0DAQhGFLvNEFNVDA9UAJSDzTJn3QwJXAAQ+IJLPKOvZ51/tbOu0x
iqL5citZfPr6/cu3D621H28/H99+fv/+97y+qPn5z/n50v47r4d//8tHPW+/
Z97E+6RnfO/YnqPeg3fUrLbPePHixTv2u+HN7l0138d1PPm9tkvl8b19LpXH
8fb19+ar5qj+3hzv7Fltn/E+6e/N43h3vY9UH7x3+ntz9nn2xGvnfS6V4509
+f+g3TO719sTb997Vs1q+4zX7rmrd9f7SPXBa+e2S+Xs8+yJty+3XSrHO3vi
HZtn96r+2b12z3OexWv3uZ/jvfMe9nn2xHun5znP7t31PhrVH6/9/KpZbZ/x
9vXHaz+/anq9o75PNK/qmd1r9znneO3cfj/7PHvitXvu6t31PlJ98Pbl6v2r
ZrV9xosXL168dp7d2y5Pfq9yqTyL1+tSeTSvt783xzujP/usJt4+l8qzeHe9
j/p6np/vew/e2bPaPuO90/PsUjne9/Udp9fr/Q5ZvH39vc/HuY/6+nufxzt7
VttnvE/6e5+P4931PvL2xNv3nlWz2j7jxYsXb9/3ie9tlye/V7lUnsXrdakc
r52vmtX2Ga/tUnl27673kbe/93m8K3x19xkv3sreUTnePbzR5ljX8az3PfXa
LpXHmWNdKo82vf29ebTp7e/N48xq+4z3iUvlcWa1+0j1xHvHpfI4s9o+47Vz
26XyOBNvX57dq/pn99o9zzneO++JM6vtM167/67eXe8j1ROvnav3RJvV9hkv
Xrx47e8QZ476O2b3KpfKs3i9LpXjXelhn+/1PLtUjjeG7zir3Ud9/b3PR5ve
/t7n48xq+4wXb2Vv3/eJM0f9HbN4lUvleO082qy2z3hrene9j9rlwbuLt9o+
4+3rn93bLk9+r+1SOd4s3mr7jLemd9f7qF0evLt4q+0zXrw7eUf1z+71zr29
x1PPy1wzfwFK+jv8
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztltFNHTEQRVfiL11QAwW8HlJCJL7TZvqgAUoAwhfxm8F3drzx2Gelp4uu
rNlzViOZx1+/fz4/HMfx5/334/338ffn83qz8unv83I7vjx2f9x9svvR2b4X
3zP8aj8ud9tnfP0+xq/2+Gal6nvNd7je1+Kp7qvy4Bub4/fsc1bi6/Os6rvq
fWS9F1+/9/nVnn3OSnxjfczL6vHNSnxze9/L6ufxtTir+6qcVXxjPG2P75n5
7HNW4hvjrO676n2UxY+vf97v2eesxDfGj2+Pl9XP45v1ffz+el+Lp7qvyoOv
36vzR+du+4yvz7Oq76r3kfVefGO972X17HNW4pvb+15Wj29W4pvb+15WX9c3
9h3m97X4q/v6nG1fxdfn6e9n81X51R7fnjnsc1bi28PT31fxXfU+yuXMmoNv
Vu62z/ie4Wx7fHvmzOOr8lfxzeKfzdd/73l+fHveyz5nJb65/FV8V72PVE58
Y3Os86Nzt33GN9Zb/Pj650cnvtf0VXwtzuq+Pk/bV/H139vf4+v3/nz2OSvx
7eFp++q+q95HKr96Hl9/zujcbZ/xjXHiG5szOlXOrH42X4unuq//3rbHN9b7
72WfsxJfn2dV31XvI+u9+Ob21ntH5277jC+++OKLL749fXXf4+5T39fysvoq
vqqX1c/mq/Kr/f/yzeJXe3wVXva5N/GN8av9bL6r3kcxnva82uN7hp99thLf
Hp5+L6vHN8fnu1R9s77DbL4xzvZ8bM7191GMM2sOvlm52z7je4azPR+bw32U
m/08+Ppz1Pmjc7d9xjfWW15Wj+8Yv38T39y+um+MXz1/va/FGeNXz1///4ba
43vmPPuclfj6nDF+9Tz3UW6O5lfP45uVu+0zviP41fP4ZqXqe833mef/jeq+
Fo/KiW9szujcbZ/xjXFW9131PlJ58O3h758/OnfbZ3zxxRdffGN9Fd/j7lPf
1/Ky+iq+qpfVz+ar8qs9vn4/OnfbZ3xjXlZfxXfV+0jltM6rc/DN9GGfz/G0
XlaPb898fLNS5VG/QxVflV89P9t9pPKr5/HN9Nlnn98ApoONXA==
     "], {{0, 0}, {10, 
     200}}, {0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztltFtGzEQRA/IX7pwDSnAPaSEAP5Om+kjDaSE2MlPotNSO8vh3VF8Aowx
BsTyPWEB6uXb969vn7Zt+/H+9/n97+P/v59fr1F++fP5+br999H77e5H79vz
+/Msr6g/y9fFr/ajfUfzqz2+/55nn9XE18uv9rxHbf5aqvfm+dUe33u87HM2
8c3cm+dXe3zb/GqqvqO/h6v93pjd18uTn1Obj6+aq+0zvj08+/Nqz3uk+eQy
fy++7Tlqzz5rPo8S31qvekU9vprPo8TX20deUX813xrn/nxtzjhfL6drzrjf
G15O1xx81Vxtn/Edwemaw3tUy35+fNvna3PYZzXxrfHj2z5fm3O8r+v7ifqz
fFWeWXxdPPh657tytX3Gt8Yzu++zvkfqvfhmOPfz1Xtdudo+4+vtI6+ox7fP
7zbx9faRV9TP7qt+D7P41vjV88f7Rpw1fvX8ON+IR+2v5qvyqz2+PefZZzXx
bfOo/Sy+z/oeuThdc/DN8LPPUeJb46zxq+fxVVP19fKr54//vTG7b3TvMfzq
eXzVXG2f8T2SXz3Pe1TL/L349vCr59lnNfGt9TV+9Ty+auJ7TD+Lr8o5i2/E
o3JezTe6V+3xzfDn57hytX3Gt82jcs7i+6zvUe3e/Hl8e+5ln9XE18uJb22O
K1VOV381X5VnFt/oXpUH3wx/fr4rV9tnfGs8s/uO7s/yVe/Ft9ar97pytX3G
F1988cUX355+Ft/t7md+38gr6mfxVb2i/mq+Kr/an+Xr4ld7fNu9K1fbZ3xr
/Gp/Nd9nfY9Unui82uObuZd9VhPfzL15r6jHN3Pv8b6u7+FqvipndF6dc9Z7
pHK65uCb4Wefo8S3xhmdV+fwHvX53U8Xz36Odz6+aq62z/j28Oy9oh7fzHx8
1XT5qt/DLL4qv3r+LN+IU+VXz4/2jXjUHt/aefZZ83mU+LY5VX71PO9Rn9/9
HMevnse34sM+992b51fP49vnd5v4evtZfL2crjnj3iMvp2sOvmquts/4juB0
zeE9qmU/D77e+a5cbZ/xxRdffPH19vg+h+/oPNfr9jO/b9sr6q/vW/OK+uv4
1vjV/nhfL7/aj87R/GqPrytX22d8R/CrfT1/A1asPc4=
     "], {{0, 0}, {10, 200}}, {0,
      1}], Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztltGNFDEQRFfijyyIgQA2B0JA4ps0yYMELgQO+GPolqtdO+P2vJVOhUpW
+71RS+bT1+9fvn14PB4/3v8+vv/9/vff39szz39/b8/Pf34/n7N9NL/Wz6fL
C98Zr6jHV018vX3NK+rxVfPVvt7vsI5vxNndV+Xs4lvjOfar+dbuHe/xnZnP
PquJ7wzPse/iu+t79GpOfGtzXHm3fcbXy4lvbY4rVV+Vv4uvi381X/VefL3n
8559VhNfL38X313fI5UT39qc6Hzes89q4lvrI058R7yiHl81Xb6u75P35/tG
PN19VZ4uvrV7jz2+eV+7l31WE98aT3ffXd8jlV89j28+J+/ZZzXxrXHiW5uT
9+f7uvrcK+rP//9Gd1/1XnxrvXqvK++2z/jm9+7qu+t7FM3H19vnXlHPPquJ
7zl97hX1+KqJ7zl97hX1+Kp5lW/tO6zvG/F39805j30X35xnvF/NV+VX+6t8
Xfxqj+/IHPZZTXxr/Gq/mu+u75GXZ7zHd2QO+6wmvjM84z2+I3PO93V9h9V8
vZyuOa97j7ycrjn4qnm3fcb3FZyuObxHtRznwXeEc3x+Pod9VhPfWp9zHnt8
R+bgq6bLV+Xv4uviX803v3ee/yrffP54j6/3vCvvts/4jtw7z7+a767v0VX8
+ObnXXm3fcb3HH588/OuVH2v+j6udHF28c3nj3PiW5uT87DPauJb4+zuu+t7
pPLgW+Nnn/PzrsTX20f8+ObnXYmvt4/4d/V1fZ/VfCPO7r45z7Hv4pvfO96v
5qvyqz2+eZ/PZ5/VxHfk3vG+i++u75HKmfOMz8F3ZD77rCa+MzzHHt+Z+ef7
qpxdfFV+9fxq75HKr57Hd4SHfVYT3xq/en41313fo1dz4lub48q77TO+Xk58
a3Ncie+1/Wq+EU933/zeY9/FN58/3uNb6/N72Wc18R2599h39931PVL51fP4
1ua78m77jG+NB1/vfFe6OLv7Rvd2983nH3t8vX3Owz6riW9+766+V/Wv9o3m
43tOH/G48m77jC+++OKLL774qt+hr+/jv7/+vpFX1M/6/gJB+saV
     "], {{0, 0}, {10, 
     200}}, {0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl9FtFEEQRFfijyyIgQCcAyEg8U2a5EECDgEbPjjuroeu2erZmd23klV2
aVRdb9W68X36+v3Ltw/btv14+/n49vP++5/n9SXSz7+fny/bP8/r3d9//ei8
y1fnqgrvsX41r5oPr9dX+6h6tX2GF1544YUXXnhd72d+3u3psz5vxBX5q/Cq
XJE/G6/aX/WP4nX1V/1q3ur+qg9v21f1avsMr7e/6nMfZfrs/7yCt6+/6rPP
mT7wRgpvJj/fX/Vn461+D0fxqn2i86p/1H2k9lFz1Hx4b3PY50jh7esTnVd9
7qPM3P2fV/Bm5j7mqD77nJkLb6Tw7pmb54p8eDNzx/O63sNsvGrP6LyaU83r
6unKcfGqfdSerhx4b3PY50jh9fZ05XAfPefJ6f7+8LbPqzns83Oe/ym8ff3h
bZ9Xc47idb2fyD+K19vnMcebX/d9Ad5Mn+p89jlSeCv6POZ487mP2rp/Lrzt
fNdcVa+2z/B6/Ygr8uHN5MMbKbxj/NV51f7q+aN4o55qf/V8NW/UR/Vn41X7
qz68fefZ59sceCOFt6+n2l89X/15BW/7vCuHfc7kwBspvH091f7q+aN4Xf3V
89W81f3V8y7eaG51f/U8vLc57HOk8I7pr56v5u2bm++vnq/+vILX2987l32O
FN49c/P91fPw5vjuFd4x/iq83p6unLr/J709XTl13we9PV058EZ6tX2Gt93H
29OVw33U1vxcb09XDryRXm2f4R3Z05UDb6RqvsufjdfVZzbeaK6rD7zefFWv
ts/wevuswlvtH8Xrmgtvpuf+uapebZ/hhRdeeOGFt8KH9xy8Lp2T6/5Zn7fN
Ffnz8/ZxRf48vH39VX88r7e/6tfxjumv+i6t7uny4VX1avsM78j+qs991KeP
+fBW9Fd99llVeNu+t7/qw6sq3wfbc1fnVefCu6e/6rPPqsLbnntW3rPeR1E+
vG2/r7/qs8+qwtvn9/VXfXhVhdfr93FF/njeqM/qvGqfVXhdfeD15rv0avsM
b1+f1XnPeh+5+sOb6a/67LOq8Pb1hzfTX/XH87reT58//v+N1XnVufC2fTW/
7bPPqsLbnntW3rPeR1H+qry/APmudok=
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl91tFEEQhE/ijSyIgQCcAyEg8Uya5EEChMDfC/iu1lM9NbMzt99JVlml
VnV9q5b3/OHz109f3t1ut2+/ft7/+vn9+9/PjxelH/98vr/c/vto//bw48+7
/nG+q/394T2ed/0U79XuGd5af3iP513/LN7U83H90bzu3l14U3vhreW7e129
2j3DW9u7O++zvo/cfHhb+tznuz73/JjnLYU367tcyof3Mc9bCm/Wd7mUvwtv
6jmsxlvreT9fyxnHm+2Zyhn3/0K2Zyqn//tkyod3RA73rBTeWp9az1QO76Nj
PatnKgdepVe7Z3hn9kzlwKvU5XX778Kb6r8ab3Zv/3wtB16lV7tneLP9d+F9
1veRmw9vT8/7+VoO96wU3ppf63k/X8uBVym8c3zFpfyzeN0+u/Cm+qzG6+51
+8CbzXf1avcMb7bPLrzP+j6q5bfPw3ucU+vDPSuFt9YT3lqOm++q2zPlKy7l
j+Z19+7Cm9oLb0vP/r2uXu2e4a3t3Z13tK+4lD/67xW8WV/tdfu4erV7hneO
r7iUD28b32uFd46vuJQPbxvfaz2L130Ou/DW+rvz83lVz1p/d34cr+rj+qvx
uv1d/yzeVH/Xh7dnnntWCm+tv+uvxvus76NUH9eHt2eee1YKb62P68PbMz+O
N/UcVuNN9UzljH4fpXqmcuD9d557Vgpvtmcqh/fRY542bc+H9zin1t+d556V
wlvzVc9af3ceXqXwZv1af3d+HO+c/u78uO+Tc/q78/3fN1wf3pnz3LNSeI/3
zunvzvM+OtbV+rvz8Cq92j3Du0J/dx5epS7vms9n3PeN3XlVvrsX3p7+7jz3
rBTe2t7deVN+rb87P+7/BXhH9HfnuWel8Gb9Wn93Hl6l8Gb9Wn93fh3eOc9n
Pq/bcxde1cftuRqv2uv6q/G6/V0f3pb+7TmuXu2e4T3e6/q78D7r+6iWfz/v
5sDb04d7VgpvrY/bE95ajqtun1TP1Xhre9vnz+JV+bW97fPw9uzlnpXC27O3
fX413tE9V/t7BW+2J/dcy3EV3jk94a3luArvuf5qvG6fXXjVXrfParwq3/Xh
rfluvqtXu2d4j/e6fXbhTfVZjbeW3z4Pbzbf1avdM7zZPvBm811N9dyd1927
C6/Kd/fCW/Pdva4+2z3/BEFXU60=
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztlsFtFUEQRFfiRhaOgQCcAyEg+Uya5EECDgEbDiws3XTNdO/M/Hlfssou
tarrrVr7/fTl6+eXD8dxfHv7+fj28/77r8/rs6Wffn6+Px9/fF7/+vv/vpWj
5rf1UdXKifvwtvWv5t3tnuGN5Md7rsKb1XM23qy98ObmWPOq7nbP8Ob2hLct
x5pXVe2Z5Vv9R/GqfVbh9XPifeBt6889+/OqwtvWZ3Xeat/qP+p9BW+ur+61
5lXd7Z7hvce3+sPrz6sK7z2+1R9ef17VUbxZz2c2Xqvn6rx+n6u/Cq+/N+7P
xqv2V/1RvFn9VR9e3/fzuWdL4W3rr/qz8T7q95Hax98b9+Ht2cs9Wwpvz964
D2/P3jrerOcwG6/a0+8Tzxn1faT2zMqBN5LPPVsKb1tPv088h++jSH7/+wre
nj7V+dyzpfBW9Ln68Pbkw2tpFq/acxVetb86P4rXz4/3V+eref2cuA9v2zz3
HOkDr6Xw5vZX50e9r+C9Z5579nNUhTe3vzoPr5+jqrq3+vmM4q3uOYrXz6nr
CW9bjqq73TO89/ScjTfLt3rO9r6CN7cn99yWoyq8ub7VE962HFXhzfWtno/K
W/3cRvFafVbn9fde/VV4/fy4Pxuv2l/14W3z/b3cs6XwRvLj/iq8j/p9pPb0
98Zz4O3Zyz1bCm/P3qsPb8XeOl61zyq8an91fhSvnxPvr87D25av6m73DG9b
f3V+Nt6sPrPxZvXMyoHXz1d1t3uGN7cPvLn5qsI7pz+K19q7Oq+ff/VX4fVz
4j68ub7fh3u2FN5I/tVfnVfduwqv2l+dh7fNt/aquts9w9u2F95c39qranXP
VXit/NV5/ZyrD+89vt+Te7YUXj//UXln87N4rRx4x/pWT1Vn44IXXnjhhXdO
Lnjh3YHXfw7r8h7//KzPa3FZ/iq8Kpflz8ar9lf9UbxZ/VW/mre6v+pn8Vb3
zPLhPc9zz5bCe09/1ef76Dzf/76CN7e/6nPP53l4LYU3kt/fX/VH8Y56DqP+
31idN3dvPCd3L7yW7nbP8PbsjfdXfb6PzvP97yt4I3vj/VWfez7Pw2spvG2+
2l/14T3P389b/RxG8bb1uc6rfjVvbp94Tlt+//8buX2q8+G1dLd7hreiTzyn
Lf+3/gCjr1hV
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl8Ft3UAMRAXkli5cQwpwDykhgM9pM32kgZQQOzkFyhAkl6tdSu8DH2MM
FsN5AvFXfvn2/evbp+M4frx/P79/P/7++/n1qvTLn8/P1+OfT9w//vvRflVO
Tv194M31XMX7tH2GN+dHe8Kby4kqvLW+6tmFt6r/brzRuV14c/lnH97a87bP
PiuFNze3O+9d76NV/eG1z9s++6wU3mv6w2uft/15vKuej+3Pe9/ozhvNhzfX
n322z9s+vErhrfVVz91+r+DN+dF8dd722Wel8Nb6qie8Hi7lw6sU3rW+zaX8
63lVn+680T5deHNzz/5uvLl8vw+v7efmss9K4R2Ze/a78N71Por2jPaBtzY/
qk/bZ3hr+8Bbmx/VaJ9ozy680f7R87vdR9H+0fPw5vpE9Wn7DG+uf/T8brx3
vY9m94Q3l2P77LNSeGt7wpvLsX14lVbxzn5utj+PV83tzhud24U3l3/24c35
uT7ss1J4c3O78971Por2j56HN5dv++yzUnhzfeCtzbf9ebyzfZtL+fPeN7rz
RvPhrfWjfaL6tH2G186/K+8q3+ZS/rz/F+Ct9W0u5bPPSuFd69tcyodXKbxr
fZtL+fAqhXdPvzuv6t+d1+559rvw2n38/m680f5RfxVvVf+oP5u3qmeVD68n
h31WCm9t/6jPfeTJGf+9gjfXP+qzz54ceJXCOzJ33N+Nd/Zz2O19ozvvNX1m
58Or9Gn7DO+MPn6f+8iTM/57Be9IH7/PPnty4FUKb863+/h9eD051/NWPYfd
eGt7VuXMe5+s7VmVM/6+cU3Pqhx4lT5tn+G9smdVDveRreNz4fX0rMphn5XC
m5sLr6dnVc483qrno/xVvNE+XXir+sBbm2/nsM9K4c316c571/soOhfekZ7+
uXYO+6wU3lrf7nn24fXkwKsU3mt81b8Lb1X/3XjtueP9V/Ha+X5/N95o/6gP
b+35qD5tn+H15Pv9Lrx3vY9q547nwOuZyz4rhXdk7nh/eD1z5/HO7r+Kd1X/
VffRqv7wenqyz0p36w+vfT6qT7uPonPhre3PPtvnowpvzq/qD699PqrwXuOr
/rvxRntezfsbo8gwmg==
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl9Ft3DAQRA/wX7pwDS7APaSEAP5Om+7DDaSE2MlflCG0yyHFpZ6AwxgD
YXYesTien3/8/P729Hg83j8/3z4/X3//fX69tvXfR/svf56P19735+Qc1TXX
29OVAy+8K/R05Zz/voJ3Zk9XDvsM7wo9XTnwwnutvxqvq89qvGquq89VvCo/
6sPb07M/X+nd9hne9lxXn9V4R/dZ7fsKXm8f9tmbrxTeOX3g9eYrdfWszuua
uxqvynfNhfdMz/65Su+2z/B651bhvcofzevKh7enZ38fpXfbZ3jhhRdeeOGF
d/S5wbtaTxdXdd7Hf5/6vG0u5a/Pm+NS/jq8uf5Rfz6vt3/UH8c7p3/U7+ed
09PlR/Wqni4fXqV322d4Z/Z0+dxHbT3mwDuip8tnn5XC2/bn9I/68Crl/8F2
fnXeaD68PT1dPvusFN52/q68u95HKgfetu/tH/XZZ6Xw5nxv/6gPr1J4vX6u
f9Qfx6vmVueNzq3C65oLrze/7bPPSuHNza3Ou+t9pHLg9b7v9dlnpfDm+sPb
0z/qj+N1nY/XH/d7ozpvNB/etp/rH/XZZ6XwtvN35d31PlI58Ob8XP+ozz4r
hdfr5/pHfXiVwuv1c/2j/jq8c85hPq/qU5032qcKr6vParzeuUcf3hFz2Wel
8Hr7VOHd9T4a3RPeXE7bZ5+VwuvtCW8up+2P4432r8Lr6r8abzQfXu/7OZ99
Vgqvt38V3l3vo2hPeHM57f5Rn31WCm/OV33gPdM/6sOr1MXrOp+cP45Xza3O
G51bhdc1F96275ob1bvtM7y5udV5d72Pov2j78N7pn/UZ5+VwpvrCW8uJ+eP
43X5OS7lj/u9UZ03mg9vzo/Obfvss1J42/m78u56H6kceL1+u3/UZ5+VwjvH
z3EpH16l8M7xc1zKh1fpVbzec1iHV/WszhvtWYU31+for8abm3vev4o3l9/v
w9uTzz4rhbdn7nl/Nd5d76M5fUbnw6v0bvsM74g+Rx/envxxvK6eq/GO7rna
fTS6J7y5nKjebZ/hndNzFO9vnD2qAQ==
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztmNFt3EAMRA/IX7pIDSnAPaSEAPlOm+kjDbiEOMnP2gIPHO5Qu4LeAYZs
ghi+tyYky1++//z249Pj8fj19vX57evv9/8/ry/R9eu/z++Xx7vP64ef19cj
zuf8+NZy5vnVustXzXfxq3V8M5zsM76ZnHl+tY5vhnPed9U5dPuqc1V+td79
PFLnqjmuufiOOewzvrW5Kr9a53mU4Zl/X8C3xq/W2ecMD774zuTn+dU6vhme
Pt/uc1jlq/JE/Wq929fFo+ao+apvN093Pr5jDvuMr5dHzVHzeR6NOfPvg65+
tY5vZi77jG+NH9/n/Wp9la/rfNR6t6937jFHrbt8z5mbz/fOxfdu+4xvx9xj
jlrv9nXVVa+o3n2/wndm7jFfrbPPmbn44uutq15RHd/MXHy7fV3nsJuvyhn1
qzndvi5OV47LV+VROV05qq8618XpysF3zGGf8a3xqJyuHJ5HY878+76L05WD
75jDPuN7DqcrB98xh/fBbv7dfF1zXf1qDr5jDvuMr5f/Kr61/Dxn1K/muO5X
+Nb4d/O92z7jO5Of54z61Rx8xxx8Xb6u84nqq3y9PMccb/7835Nenu78+fdB
L093Pr5322d8z+Tpzud5pOZ7eY453nx877bP+NY48a3lePN5H+z+Pe7m2z0X
33PmRte77TO+3rlX8e2uR15Rvft+ha+3Hs118UTXu+0zvufUI6+ojm8mH198
z6lHXlH96r7qOVzFV+VX+1f5Rpwqv9rf7RvxqPXdfFV+tb7K18Wv1vGt9bPP
Yw6++NZ41Ppu9yt8n/erdfa51o/vmIMvvjP5R06VX+13+bo4XTku325OVw6+
mRz2GV8vpyun27eWf+RU+dV+1/0K3xqnmu/lYZ/xnck/cqr8aj++Yw6+Ll8X
v9rf7dvNr/a7fKO53fxqv+ob5at1fM/pZ5/HHHzxXcuv9rvuV/ju2c8+jzn4
4ruWX+3v9t3tfFy+3rn5HO/c+fcFfL383rnsM74dc/M53rk8j1z5+NbyXTzR
9W77jK+3rvKr/fi+9/t4xddbV/nV/t18u89nla+X05XT9/8cL6crZ/59Qa3v
5qvyq3V8M5yuHPYZ3+dz1fpVfF3nsJuvmh/1ezldOfjebZ/xrfF4OV05+Ko5
53C6cub/3ri6b5SvzvVy1nP+AKZwmIo=
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl8FtHEEMBBfQz1koBgWgHByCAb2dpvJQAg7Bsv0548TFNIecIW/rAIFG
o9HsWhMn7fOPn9/fno7jeP/8+fb58+ff/z6/Xq358vfz8Xr899H148vPbv88
r7V3TX/VP85r5at6NV61v6rDu9LPPcN7nq/qXXgf9fdR1N41/VU/vFe7Z3h9
e9f0V/3wqrx7+6v++b83evnn3xfgreznnnv1V/3wWn5VX9Nf9c+/L8C7sr/q
557h9elr+qt+eOFdo/v6q/689/3uvFa+urcar5Wj6vBm9Ff93DO85/nq3i68
UXur8WbvhXfNXmte7Z7hjd0L70x/1c/7YPb/YzVeK0fNhzejv+rnnuH15Xfn
zdZ9/VX//PsCvD7d11/1c8/wrtF9/VU/vPCu0X39VT+8u3jXPJ/1vGrPLrxW
H7VnNV5rr6pX41X7q/ou3qj+qg7vua7mWPNq9wyvr7+qV+N91N9Hvpx7v6rD
69vLPd/64YXXt1fVu/BGPYdqvL78e7+ak80b1TMqB96ZPtwzvDP59341Zxdv
VB+1567vK3h9fbLzuedbP7zwxvZRe8Lry7FmFG9Uz2q8vr3j/l28Vr5v77g/
m9fKUXV4fX7ueWYvvPBm7B337/q+gneNn3ue2QsvvBl7x/3VeLN77uLd1TOb
18rZ1RNeX441q/WE15djzWo9d/FG6WrPXd9X8K7pyT37cqwJb6yu9oTXl2NN
eGN1tWd33l3PLZtX7dOF19qr9qnGa+WrejVetb+qw+vT1XxrXu2e4T3PV/Uu
vFHPoRqvL+fer+bA69vLPd/64YXXt1ft04U3qk81Xl/+uH8Xr5Xjyx/3wxub
b82r3TO8M/nj/mq82X2qfV/BG9uHe47Ntya8a/rAG5tvTXhr6rt41b1deK18
dW81XitH1eGN1dW91rzaPcN7nq/u7cIbtbcary9n3A+vT/f15J7hjd0L75q9
1szu2YVXze/Ca+Wo+fDG6mofa17tnuH15XfnraZH8ao58K7R1Z7WrMYFL7zw
wgtvTS544b0Cr+/51Oc9vvz057W4LL0Lr8pl6dV41f6qvos3qr+qZ/Nm91f1
KN7snlE6vOe6NR/tnn8D1IqUCQ==
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl9Ft3DAQRA/wX7pwDS7gekgJAfydNtNHGnAJcZIf+YSVtbNDkTTfAQaN
wWL43mFhWc8/fn5/fbrdbr/ef769//z9/f/n7X58Pn7e7i//Pr/vrfLo3mx+
3L8/W3vhq3lFOb7beXzxvSbPekU5vtv5cXxd38Novhrnfl7raefr5XT11H2z
PBqnq+e8b/ZeL6er5/z7Qusc3xY97DO+2r1eTlcPz6PWPK378d3Os8/4enk0
TlcPvlnfazhdPfX/N2b3HZPT1YPvavuM7wicrh6eR9kefFtwunrYZ3y13Mvp
6sEXX2+uce7ntZ66r4t/NF/vvfV5raf+PqjdW5/XevBdbZ/xbXFvfV7r4XnU
ix/f43mth33G9xp+fI/ntR7eB12cs/i6+vGtcNZ5onO1fcZX65/d15VrnPt5
raf+voCvxs8+H89rPfji6801zv281oMvvn3zyCvKe/lmeWbxdfGM5pu9N8vT
yzfb7+LB19sfnavtM77avVme0Xy/6vNI66nz4Ovtj87V9hnfa3jw9fZHZ5Yn
yzmLr9Z/fr6Xr7f//Dy+LXjYZ3wr/efnR/N1cY7m25oTX60n2x+dq+0zvl5O
fLWebH904ts3j7yivLVv9t5ZfF33juab7c/ei+8Zzvq90bnaPuPrvXcW3yzP
LL5az/l5fLV+jZN9xlfjwdfbn703Ol2cs/tm+2fxdfXjq+UunuhcbZ/x1fpn
9+2VR15R7vp7he81ecST5YzO1fYZ37555BXl+H70ezzx7ZtHXlGO70e/xxPf
MfPZfTX+7Pz1vhGnxp+db+cb8WTz0Xyz/Nm8l6+LP5u39nVxunJ8K/PsM75e
/mzO86gyf/7vFb4afzZnnyvz+OKr3evKR/Nt/T308nXxZPNezyMXT+t+fLfz
7DO+Xp5szvOoMl9/X8D3uCebs8+VeXzx1fKIJ5vjW5lv5+v6HkbzdXG6ely+
rTldPVnfLI+L09WD73aefcb3Gk5XD8+j7Xz9fdA1f829+K62z/i2uHc/7+rB
dzvP+6CrfxZfFw++3n5tnn3GV+uf3deVR5waf3a+/r6Ar8ap8Wfn2Wd8vXnE
qfFn5/HF15tHnBp/dv56Xy//5/N/AIVl99c=
     "], {{0, 0}, {10, 200}}, {0, 1}], 
    Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl9utFDEQRFfijyyIgQBuDoSAxDdpkgcJEAKvH4uhLXe7euwen5VWviqV
qutYrZ07Hz5//fTl3ev1+vbr+/7X9/fffz8/3vrnvx9b//jn8/1tVFflePOt
M7unKgfefr51wntPn1W8q/rAq823ztP2Gd57+sCrzbdOeO/p81TeVfeZzWvN
rc7bz7/qVXj7OeP6brze/l4dXq3e78M+wzuSM65X4VXdw2683p79/PEceGN6
vw/7DO9M/lWHV6v3+/A+qOrv9a/i7fvH+3v98Mb0fn/2Gd5Yf69/N17V3N14
VT1VOfDG5lrnafsMr3YuvPfMtU54a+nZvFZ+dd5+zlWvwtv3j+vw3qP3e7LP
8I7kXPXqvN78Krze/l4/vFrd6mOdp+0zvLF8eO/RrT7WuarnbrxWTnXevv+q
w7tW7/dnn+Ht5zyVt4ru5bX8u3HB2+9vnbv1hxdeeOGFd8/+8MIL7zm8/Xuo
y/v676c+r8Vl6VV4vVyWvhuvt79XX8Wr6u/Vs3mz+3t1FW92T5Xu5V3VU6XD
2/rZZ3jv6anSeR61/vHfK3i1PVU6+9z64YV3JCevv1fP5t3tHrL/36jOq80f
z1Hp8LZ+9hnemfz5/l6d51Hrn39fgFfb36uzz60fXnhjuqq/V4e39efxrrqH
bN7Y3PH+Xl3Fq507nqOdO/8+GJs7nx+bC+9p+wxvxtzxHO1cnkexnHm/Soe3
9bPP8Mb6wxvr79WzeVX3o9JVvN78KryqfHhj+ao+1nnaPsMby6/O+9TnkTcH
3pG54/29Ovvc+uGFV6t7+3t1eFs/vNm82fewijfW5+r36tm82j7jObH8+fcF
bZ/s/Pn3fW2f7Hx4T9tneO/sk53P8yi7J7yxnFg++wyvtie8sZxY/jyvt38V
XlX/3Xi1+fN+bR94T9tneLX9q/A+9XnkzYF3ps/V79XZ59YPL7wxPdbn6vfq
8Lb+PF7V/Xj1bF7v3Cq8qrm78WbPhfeeudZ52j7Dq51bhfepz6NYzrgf3n6O
V2efWz+88MZ6PpVXpXu5LF3F682vwqvKh3ekz/hcbx/rPG2f4Y3lV+fN1r1c
lq76varK+xOh0hrS
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl8GJHEEMRQd8cxaOwQFMDg7B4LPTdB5OYEPwrn3bRkK/JLWqvG9gqeUj
vt4bim7my/ef3358ejwev17/Pr/+vf3/7/Py9M/3n5fn17+f38/3uTqv5lU8
1tnNg29tvzVvnfjW8pzu251b/N2+6t5TfP35+F5813J1r8/PfcZ3be/pvlO5
xd/9vML3nlzlseat86PdZ3xnc4sfX3/eOvGdzS1+fP1568T3rPwUX4vzdF+f
55qf4uvvjee7+ar8aj7lW8Wv5t2+VZxVOb5+7vdzn/Gt5Vdz3kcZnvjzCt81
fjXnPmd48MU305/Pd/Pt/h6mfFUef288n3ofqTxqj9qPb6Sf+4zvGo+/N57z
Psrszf9ewDeyN55znzN78cW3Y288xzezt8+36nvYzVfl9HniPd2+VZxVPVW+
Ko/KWdWDb6Sf+4xvLWdVD++jSH/+92DVvNqDb6Sf+4zvWj++EZ54z5RvLc81
n/K9h6e7P/97Ad8MT3c/9xnfO3m6+3kfVe3FN8KT3+v3c5/xrc19nmuOb6Yf
X3zvyS3OU3xVfnV+ytfvj/Or892+fk88381X5VdzfNfmuc8RHnzxzfTH+dX5
7ucVvpH+fA/3OcODL76Z/ji/Oj/lW8Wvznf7dvOr81W+/nwfvzqPb4Sf+4zv
PfzqfLdv1d7dfLv34nvPXuv8aPcZ39q9+K7N4+v3WGeVb/f3M+XbzTnl6/f0
cXb7+vPxHN81Tu5zhhNffGc5p55X+N7DyX1e67HO3TjxXeuxzt04d/Otyi3O
Kd8qnt18/fk8D761/T4/9xnfWp5TfLtzi3PqeYVvbV611+qxzo92n/G9J7c4
8V3rsU5878ktTnzXeqxzyrf7e5vytXhO9/X3XvNTfP3+eL6br8qv5lO+Vfxq
ju9a7u/lPuO7xq/mu/n+r+8jlcfvj+f4ruX+Xu4zvpn+eI5vBw+/B9We032r
OKt68M3s5T7ju8bp7433TPnW7r3muz2v8M3szfdznyN78cW3Y+81x7djb5+v
ynOKr8qvzk/5+j1xfnW+29efj+f4rs1znzOc+OJby6/OTz2v8L1nnvu81m+d
+Nbyq/P4rvVbZ9Xe032rOKt6qnz9+TxnVU+0/w/tcYqS
     "], {{0, 0}, {10, 200}}, {0,
      1}], Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 25],GraphicsBox[
    RasterBox[CompressedData["
1:eJztl8GNFEEMRUfiRhYbAwFsDoSAtGfSJA8SIAR24YQGW3bVd5Wr+420KvRV
+n6vsaY1L9++f3379Hg8frz/fX7/+/j338+vV+v88ufz8/XxzyefP/770eVj
c/FV+VY/h12+Wp54Xu27hqe63zp38VT343u3fcZ3JU91P+8jVT++EZ54zj5H
evDFd6z/qr6q55PNq32zc0/xVc3Fd6w/O9fvYZ/xHZt7uu9V30fZfnxneOI5
+xzpwRdfbe7zxHN8Iz34VvuqnkM3Xy2nqmfedw2nqmf+98IaTlXP/O/9NZyq
Hnzvts/4jvFoOVU9vI96cqp68L3bPuPbgVPVg2/WNzv3FF/V3G6+1XPxXTPX
Ou+2z/hq557ie9X3UbYf3wpOVQ/7jO9YruVU9eCL75rc53zOd/lmeU7xVfF0
883OzfLgq+33e9hnfLU8p/he9X2k6sd3hnOexzrvts/4jvXjO8MZ7/d7+D1Y
/f/YzVc1F98Zzvhcv4d9xnds7um+1bnP+ZxXf1/hq819zjiP38M+47sm9zmf
c3wjPfjiuyb3OZ/z032z/Kf4qvi7+fpz5/l3+fr98bybb5Y/m+/yzXKqcny1
963zbvuM7xh/Nu/me9X3kbY/nuNbwcM+4zvTH8/x1d63zqyv6jl089XOne+p
fh9p58734BuZyz7jWzF3vof3UWTu/O8FfCNz5/nZ58hcfPEdy/258/z4RubW
+Vbz7/LdxV/t6/es51f5+vfjOb5771vn3fYZ30jPen7eR/59/+zPj69/3zrv
ts/49uTH179vnVnfU56PdarmnuLr34/PxVfLzz77960T37G5p/uqchV/9fcV
vmO5ip999u9bJ77aXMWPr3/fOvHV5ir+U3x3PR/r3MV5iq/fH+fs5uv3xPNu
vln+bI6vn2d7fB72Gd9ITzw/xfeq7yNtf7wH3woe9hnfmf44J75jPT4Pvwer
53bz9e/Pz8VX2+Pzs8/4auee4lvN2e37Cl8tJ/s81mPdt05813DiO9Zj3bdO
fPfmFv8u3yzPKb5+T5ynm69/P57jO5Zn+31O9hnfSE+c5xRfFU83X1V/F9/f
ct0/6w==
     "], {{0, 0}, {10, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 25]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.5639002789528522`*^9, 3.5639002925308027`*^9}, {
   3.5639003656471367`*^9, 3.56390040966394*^9}, 3.563900455750266*^9, {
   3.56390049764965*^9, 3.56390053485951*^9}, 3.5641659976507072`*^9, 
   3.5641667925638514`*^9, 3.5641669851186743`*^9, 3.564167271195128*^9, 
   3.5641674963839083`*^9, 3.5641677362447443`*^9, 3.5641680750033417`*^9, 
   3.564168311582755*^9, 3.5644206995798388`*^9, 3.564421427805523*^9, 
   3.564421589767063*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["High Entropy", "Subsection",
 CellChangeTimes->{{3.563900563057027*^9, 3.563900564523651*^9}, {
  3.56500348961419*^9, 3.565003492056458*^9}}],

Cell[TextData[{
 ButtonBox["patterns on the tape with high entropy",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/2012/alumni/palasek.html"], 
    None},
  ButtonNote->
   "http://wolframscience.com/summerschool/2012/alumni/palasek.html"],
 ":"
}], "Text",
 CellChangeTimes->{{3.557100439079948*^9, 3.5571004846029167`*^9}, {
   3.5571005188118067`*^9, 3.557100696396886*^9}, {3.5571007288427763`*^9, 
   3.557100789632626*^9}, {3.557100939626054*^9, 3.557100947724197*^9}, {
   3.55725459875432*^9, 3.5572545989164*^9}, {3.557254665062388*^9, 
   3.5572546660776157`*^9}, {3.5589661862535067`*^9, 
   3.5589661906996937`*^9}, {3.558966251062985*^9, 3.558966272699583*^9}, {
   3.5599095077858343`*^9, 3.559909528797624*^9}, {3.561394279129333*^9, 
   3.561394339402021*^9}, {3.561394506225092*^9, 3.561394513066721*^9}, {
   3.561394564885427*^9, 3.561394572179175*^9}, {3.56139822620399*^9, 
   3.5613982298285418`*^9}, {3.5613982742945423`*^9, 3.561398281133263*^9}, {
   3.561398334540217*^9, 3.5613983385387297`*^9}, {3.561398421411598*^9, 
   3.5613984479865513`*^9}, {3.5613984910062733`*^9, 3.561398491134158*^9}, 
   3.561398950145567*^9, 3.564833095571329*^9, {3.564915427411152*^9, 
   3.5649154323850803`*^9}, {3.56493845338091*^9, 3.5649384774677773`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"TuringMachine", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"169850843303314304904918", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "1000"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563900228005419*^9, 3.563900235518388*^9}, 
   3.563900267058216*^9, {3.563900493957591*^9, 3.563900494730587*^9}, 
   3.563900677417593*^9, {3.563900784356688*^9, 3.563900784673606*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ArrayPlot", "[", 
     RowBox[{"#", ",", 
      RowBox[{"ColorRules", "->", "$TMColors"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "80"}]}], "]"}], "&"}], "/@", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "200"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.563900270981656*^9, 3.5639002917847147`*^9}, {
  3.563900360889529*^9, 3.5639003642873983`*^9}, {3.563900409277801*^9, 
  3.563900471514374*^9}, {3.56390050346623*^9, 3.563900534331818*^9}, {
  3.563900791693438*^9, 3.563900814183288*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    RasterBox[CompressedData["
1:eJzt3MGNG0cQhlECisR33RSAc3AIBnR2ms5DCSgEy/Zpp1nkNNm9U9X9BhCe
NPgxSwvoD8vdlX/7868/vn+53W5///r19devf3////Xz92d+++/6cfL+8aq/
/7g7Pid6/vvPuXZPnnP3Pry2b+/rA1dUHx7tI9vn6ANXVB8e7fWBe6sPr+zb
+/rAFdWHMXt94Irqw8j9vO+b6AP1ofr+/H19YAX1YeReH7iW+jByP6oPs3tC
nlMfRu71gWupDyP3V/Whf0/qw759IPUh2z7P+wtSH7Lt9YFrqQ8j93m+v0nq
Q7a9PnAt9WHk/nwH9IEV1IeR+1Hfd2g/rj5QH6rvx31fsu858esk9SHLfl4f
Xn2dpD5k2V/VB3KO+jByrw9cS30YuZ/39clnH5fUh+z7UV9X7P+4pD5k3+sD
11If5u71gZXVh4z73ueQc9SHK/eRo55Dvqc+XLnXB+ZWHzLue59DzlEfKu31
gZ+rPlTak5+rPmTcx88h9WH9/cc/H/fxc0h9WG3f3tcHVlAfxux7z7s+sIL6
8Mq+va8PXFF9uL+ffd71gRXUh/v39YHcpw/Zzrs+sIJr9qG9n+286wMrWLUP
2c6vPnBFa/ShvZ/t/OoDVzRLH7Kdx2x7cp8+tPezncdse3KlPmQ7X9X3ZN0+
tPezna/qezJzH7Kdl932ZJ4+HK9852W3PZnH45XvvOy2JzPp/UWuPZnJ++87
vB+5ak9msq8PPt/QB+6kPuTak5mc2wc90QdWVh9y7clM5uqDnpCZ1IdcezKT
tfuwXk/ITOpDrj2Zyb36kL8nZCb1QR/ISH3I1RMyk/qgD2SkPuTqCZlJfdAH
MlIfrt2TmdUHfSAj9WHk/njpA2urD/pARurDyPPeuydzqw/6QEbu1YfjdfWe
zK0+6AMZWbsPx6vansytPugDGZmrD8dr9T2ZW33QBzJybh+Ol/3HPZlbfdAH
MrKvD8fr6vNVfU/m9t0+9O5rnd/ZezK3c/vg/Yg+sLL6oA9kZK4+7NYTMrf6
oA9kZO0+VO8JmVt90Acycq8+ZOsJmVt90AcyUh+u7AmZW33QBzJSH67dk5nV
h7l7srL6MHIf//2QFdUHfSAj9aHvvOsDd1If9IGM3KsP7evXB1IfotevD+Sq
fWhfT7Y9WVl90AcyMlcf2udX35OV1Qd9ICPn9qHdZzu/+kDm6UPvPtt51wfu
ZK4+rPd+hKysPugDGVm7D/l7QlZWH/SBjNyrD/59FqkP+kDqQ7Z9/N9LVlQf
9IGM1Iexe3Il9UEfyEh9eLRvX78+cCf1QR/IyL360L4efSD1IXo9+kCu2of2
+fpA6kP0fH0gV+1Du9cHUh9G7fWB1Ifovj6Q+hDd1wdSH6L7z87v3J6Qa6kP
+kBG6sPYPbmS+tC3J3dSH/reX5A7qQ/6QEbu1Yf2+fpA6kP0fH0gV+1Du9cH
Uh9G7fWB1Ifovj6Q+hDd1wdSH6L7j/tA7q0+6AMZuVcf2r0+kPrwbE9y3z74
PIHUh+i+PpD79OHxeW+fow/kqn1o7+sDuU8fxp733j3JPH1o7+sDmc9Zfbj2
vPfuSc7rQ3tfH8j6nu1DrfPeuyd5vg/H6+rzO3tP8rzH6+rzO3tP8h1rnffe
Pcnxnch63nv3JOf1ofrXM0l+Zh8e3z9e+kCu4Jg+ZPt8g6Q+6AO5Xh/8+26y
gvpAMrJGH/z/5Uh9OL8nqQ+3u9f1f2/kDuoDychr+nC89IHMqD6QjJzVAX0g
6/vZX2e43b30gczoNX3w9Umygln68Pj+8br+743cwRp9IKkP+kBm8po+HC99
IDM6tw/HSx/ISuoDych3v4+gD+S6vtuH1/a9zyG5Xh8iRz2HpD6QXK8P0b73
OST36YOfjyIrmK0PJPOY7f0FyTzO6sPHPx/38XNI5nFMH9r7+kDW92wfes+7
PpD1Pft5gj6QvN299IFkrD6QfOas9yMk6zvr65kk69v7c9G9P0dBsq5j+kBy
RfWBZOS7P3dNcjePlz6QfK4+kCQ5338AMjyWuw==
     "], {{0, 0}, {44, 200}}, {0, 
     1}], Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt182NJEUUhdGRsIQ9OwzAB0xAYo2b+IEDmMAMbCBCr7qzqMr3Eyck9EHr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     "], {{0, 0}, {44, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt2cGNHDcQQFEBjsR33xyAcnAIBnx2ms7DCTgESxaMnWZrRt0cNruq+ApY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     "], {{0, 0}, {44, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt112qZFUMQOECR+K7bw6g5+AQBJ+dpvNwAg7BP4Rb6du7zvGkTlayV6CJ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     "], {{0, 0}, {44, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt18GNJEUQBdCVsIQ7NwxYHzABiTNu4gcOYAILCKknamajczK7KqLyfQkF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     "], {{0, 0}, {
     44, 200}}, {0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.563900792737526*^9, 3.563900815099862*^9}, 
   3.5641659982865877`*^9, 3.564166793188271*^9, 3.564166985503696*^9, 
   3.5641672716193447`*^9, 3.564167496963179*^9, 3.564167736683309*^9, 
   3.564168075729659*^9, 3.564168312022512*^9, 3.564420700005035*^9, 
   3.564421428235911*^9, 3.564421590118075*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Too Complex to be Compressed", "Subsection",
 CellChangeTimes->{{3.56390086973315*^9, 3.56390087344562*^9}, {
  3.565003499370936*^9, 3.5650035064767933`*^9}}],

Cell[TextData[{
 ButtonBox["patterns too complex to be digitally compressed",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/2012/alumni/guidetti.html"], 
    None},
  ButtonNote->
   "http://wolframscience.com/summerschool/2012/alumni/guidetti.html"],
 ":"
}], "Text",
 CellChangeTimes->{{3.557100439079948*^9, 3.5571004846029167`*^9}, {
   3.5571005188118067`*^9, 3.557100696396886*^9}, {3.5571007288427763`*^9, 
   3.557100789632626*^9}, {3.557100939626054*^9, 3.557100947724197*^9}, {
   3.55725459875432*^9, 3.5572545989164*^9}, {3.557254665062388*^9, 
   3.5572546660776157`*^9}, {3.5589661862535067`*^9, 
   3.5589661906996937`*^9}, {3.558966251062985*^9, 3.558966272699583*^9}, {
   3.5599095077858343`*^9, 3.559909528797624*^9}, {3.561394279129333*^9, 
   3.561394339402021*^9}, {3.561394506225092*^9, 3.561394513066721*^9}, {
   3.561394564885427*^9, 3.561394572179175*^9}, {3.56139822620399*^9, 
   3.5613982298285418`*^9}, {3.5613982742945423`*^9, 3.561398281133263*^9}, {
   3.561398334540217*^9, 3.5613983385387297`*^9}, {3.561398421411598*^9, 
   3.56139845524152*^9}, {3.561398488495092*^9, 3.5613984888393*^9}, {
   3.5613985890055723`*^9, 3.561398592387628*^9}, 3.561398946082036*^9, 
   3.5648330995137773`*^9, {3.5649154434760027`*^9, 3.56491545841877*^9}, {
   3.56493846744438*^9, 3.564938470572023*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"TuringMachine", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"644848724890336249172854", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "10000"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563900228005419*^9, 3.563900235518388*^9}, 
   3.563900267058216*^9, {3.563900493957591*^9, 3.563900494730587*^9}, 
   3.563900677417593*^9, {3.563900784356688*^9, 3.563900784673606*^9}, 
   3.563900908465106*^9, {3.563900946911586*^9, 3.5639009472997503`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rightcompress", "[", "e", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"ColorRules", "->", "$TMColors"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.563900925197348*^9, 3.563900966774185*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzt3FHOxbiRnuEGspKsYRbgPWQJAXKdveYq99nALCHj8UWPj1tHKvEjizp6
DmC8Rpk/62WRkkii3f/9f/7v//G//tsff/zxf/7jP//3P/7z9//+j9+//+3f
/vP3//72xz/9/v1vf/2/n8eP+Nn+KO/seNWnq/1Z/IhX+9mtbruth7P4EVPz
/r3d/XGlfGZ7VuNPWVepOqTy8ufPnz9//vz58+fPnz//N/t//urn/apPLU+9
nql41aer/Vn8iKPrp6sOu62Hs/gRU/P+vd39caV8ZntW409ZV6k6pPLy58+f
P3/+/Pnz58+fP/93+19lyqeWp17PVLzq09X+LH7E0fXTVYfd1sNZ/Iipef/e
7v64Uj6zPavxp6yrVB1Sefnz58+fP3/+/Pnz58+f/2/7p7jKZ7SeqXjVp6v9
WfyIo+u/qw67rYez+BFT8/693f1xpXxme1bjT1lXqTqk8vLnz58/f/78+fPn
z58//9/yn8VUPWt56vVMxas+Xe3P4kccXf9dddhtPZzFj5ia9+/t/rWfq+3T
dRiNd8/j6nGl6pDKy58/f/78+fPnz58/f/78d/b//OXuA6tMjbeWpz5fqXjV
p6v9WfyIo+uzqw67rYez+BFT8/693b/2c7V9ug6j8e55XD2uVB1Sefnz58+f
P3/+/Pnz58+f/97+uzA13lqe+nyl4lWfrvZn8SOOrs+uOuy2Hs7iR0zN+/d2
/9rP1fbpOozGu+dx9bhSdUjl5c+fP3/+/Pnz58+fP3/+vf5P4arxjs5XKl71
6Wp/Fj/i6PPVVYfd1sNZ/Iipef/e7l/7udo+XYfRePc8rh5Xqg6pvPz58+fP
nz9//vz58+fPf63/U5mar1qe+nyl4lWfrvZn8SOOPl9dddhtPZzFj5ia9yqr
/rvMy9P9Zz8vqX748+fPnz9//vz58+fPn/8M/89f3/3ebKbqWctTXw+peNWn
q/1Z/Iij67+rDruth7P4EVPzXmXVf5d5ebr/7Ocl1Q9//vz58+fPnz9//vz5
85/j/xam6lnLU18PqXjVp6v9WfyIo+u/qw67rYez+BFT815l1X+XeXm6/+zn
JdUPf/78+fPnz58/f/78+fO/54//4Kp6jq6HVLzq09X+LH7E0ee3qw67rYez
+BFT815l1X+XeXm6/+znJdUPf/78+fPnz58/f/78+fO/5o9/zdR6qOWpr4dU
vOrT1f4sfsTR57erDqvm/bvfuX9qXNX+U3ln+7zNvzquVB1Sefnz58+fP3/+
/Pnz58//t/0/f/33cE9lar5qeerrLRWv+nS1P4sfcfT56qrDqnn/7nfunxpX
tf9U3tk+b/OvjitVh1Re/vz58+fPnz9//vz58/91f8wwNV+1PPX1lopXfbra
n8WPOPp8ddVh1bx/9zv3T42r2n8q72yft/lXx5WqQyovf/78+fPnz58/f/78
+T/dH9dw1XyNrrdUvOrT1f4sfsTR90NXHVbN+3e/c//UuKr9p/LO9nmbf3Vc
qTqk8vLnz58/f/78+fPnz5//0/yxh6n1VstTX2+peNWnq/1Z/Iij74euOqTn
d5f6zK5DNe9sn7f5p9Z/aryp+vDnz58/f/78+fPnz5//Gv/PX/89Gf41U+uh
lqe+nlPxqk9X+7P4EUef3646pOd3l/rMrkM172yft/mn1n9qvKn68OfPnz9/
/vz58+fPn/8qf3wGU+uhlqe+nlPxqk9X+7P4EUef3646pOd3l/rMrkM172yf
t/mn1n9qvKn68OfPnz9//vz58+fPn3/KH3+Dq9bD6HpOxas+Xe3P4kccff90
1SE9v7vUZ3Ydqnln+7zNP7X+U+NN1Yc/f/78+fPnz58/f/787/rjbzK1nmt5
6us5Fa/6dLU/ix9x9P3TVYe7PlfrkBpvV/+pvLN93uZfHVeqDqm8/Pnz58+f
P3/+/Pnz5/+9n89f/z0W9jC13mp56s9LKl716Wp/Fj/i6Puhqw53fa7WITXe
rv5TeWf7vM2/Oq5UHVJ5+fPnz58/f/78+fPnz/+sH8TkeqvlqT8vqXjVp6v9
WfyIo++Hrjrc9blah9R4u/pP5Z3t8zb/6rhSdUjl5c+fP3/+/Pnz58+fP3/E
K1y13kafl1S86tPV/ix+xNH3W1cd7vpcrUNqvF39p/LO9nmbf3VcqTqk8vLn
z58/f/78+fPnz/99/oh3mHpeannqz0sqXvXpan8WP+Lo+62rDmf9XB1vqs6p
+qT6T6+fWT5v80+t/9R4U/Xhz58/f/78+fPnz5//U/w/f/33TPibTK3nWp76
85iKV3262p/Fjzj6/umqw1k/V8c7+/3c1X96/czyeZt/av2nxpuqD3/+/Pnz
58+fP3/+/J/jj7iCqfVcy1N/HlPxqk9X+7P4EUffP111uPs+XP1+7uo/vX5m
+bzNP7X+U+NN1Yc/f/78+fPnz58/f/77+CPuwFXrefR5TMWrPl3tz+JHHH1/
dtXhrJ+r403VOVWfVP/p9TPL523+qfWfGm+qPvz58+fPnz9//vz58+/zR9yR
qeexlqf+PKbiVZ+u9mfxI46+P7vrcHVcqbypeZndfyrvbJ+3+VfHlapDKi9/
/vz58+fPnz9//vxn+3/++u+BEO8w9bzU8tSf91S86tPV/ix+xNH3W3cdro4r
lTc1L7P7T+Wd7fM2/+q4UnVI5eXPnz9//vz58+fPn/98f8RfYOp5qeWpP++p
eNWnq/1Z/Iij77fuOlwdVypval5m95/KO9vnbf7VcaXqkMrLnz9//vz58+fP
nz//cX/EN3DV8zL6vKfiVZ+u9mfxI46+n7vrcHVcqbypeZndfyrvbJ+3+VfH
lapDKi9//vz58+fPnz9//vzr/ohvZOp5r+WpP++peNWnq/1Z/Iij7+fu9+0u
dU7VJ93/937v16crfuRZjT9lXLPXT6o+/Pnz58+fP3/+/Pm/x//z139Pg7gj
U89jLU/9fZKKV3262p/Fjzj6/lw1rqv+u31fuvv/3u/9+nTFjzyr8aeMa/b6
SdWHP3/+/Pnz58+fP/83+SPiOVPPYy1P/X2Sild9utqfxY84+v5cNa6r/rt9
X7r7/97v/fp0xY88q/GnjGv2+knVhz9//vz58+fPnz//X/JHxHGueh5H3yep
eNWnq/1Z/Iij7/9V47rq31XnVH3S/X/v9359uuJHntX4U8Y1e/2k6sOfP3/+
/Pnz58+f/5P9ETHP1Puklqf+PknFqz5d7c/iRxx9/3e/z3epc6o+dz2v1md2
HWbHq3V++rhSdUjl5c+fP3/+/Pnz589/f//PX/89CuIbmXrea3nq76tUvOrT
1f4sfsTR9/OqcV313+37Nbv/an1m12F2vFrnp48rVYdUXv78+fPnz58/f/78
n+CPiP1MPe+1PPX3VSpe9elqfxY/4uj7edW4rvrv9v2a3X+1PrPrMDterfPT
x5WqQyovf/78+fPnz58/f/47+CPi/lz1vI++r1Lxqk9X+7P4EUe/L6vGddW/
q86p+tz1vFqf2XWYHa/W+enjStUhlZc/f/78+fPnz58//w5/RHweU++rWp76
+yoVr/p0tT+LH3H0+9L9vdilzqn6zK5Dqj6z49fGua9/9/My67ngz58/f/78
+fPnz3/c//PXf8+BiHmm3ie1PM8/13e9t884+v5fNa6r/rt9H5/yvKT6ScWv
jXNf/+7nZdZzwZ8/f/78+fPnz59/wh8Rf5+p90ktz/PP9V3v7TOOvv9Xjeuq
/27fx6c8L6l+UvFr49zXv/t5mfVc8OfPnz9//vz58+d/xR8RcdX7ZPR9mIpX
fbran8WPOPr9WjWuq/5ddU7VZ3YdUvWZHb82zn39u5+XWc8Ff/78+fPnz58/
f/5/5Y+I+MnU+7CW5/nn+q7vzhlHv1/d36Nd6pyqz+w6pOqTilfHVfWs9tMV
nz0vs+vGnz9//vz58+fP/5f8P3/99xCI+Dym3le1PPX3bSpe9elqfxY/4uj3
ZdW4rvrv9v19yvOS6udu3qvjqnpW++mKz56X2XXjz58/f/78+fPn/1v+iIij
TL2vannq79tUvOrT1f4sfsTR78uqcV313+37+5TnJdXP3bxXx1X1rPbTFZ89
L7Prxp8/f/78+fPnz/9Z/oiIs7nqfTX6vk3Fqz5d7c/iRxz9Pq4a11X/rjqn
6jO7Dqn6pOLVcVU9q/10xWfPy+y68efPnz9//vz589/bHxFxNVPv21qe3H1F
13u767t2xtHvY/f3bpc6p+ozuw6p+tzt/6n+s+NV/6P2qX748+fPnz9//vz5
7+z/+eu/J0BE/GTqfVjL8/xzfdd354yj369V47rqv9v3/SnPS6qfs/6f6j87
XvU/ap/qhz9//vz58+fPn//e/oiIuzP1Pqzlef65vuu7c8bR79eqcV313+37
/pTnJdXPWf9P9Z8dr/oftU/1w58/f/78+fPnz7/XHxHx6Vz1Phx9n6fiVZ+u
9mfxI45+f1eN66p/V51T9Zldh1R97vb/VP/Z8ar/UftUP/z58+fPnz9//vzX
+iMi/hpT7/Nanuef67u+m2cc/f52f093qXOqPrPrkKrPWT+jntX6pOu8Or5q
XnapP3/+/Pnz58+f/2/7f/76z/GIiKuZet/W8tS/F6l41aer/Vn8iKPfx1Xj
uuq/2/7hKc9Lup9Rz2p90nVeHV81L7vUnz9//vz58+fP/9f9ERHfztT7tpan
/r1Ixas+Xe3P4kcc/T6uGtdV/932D095XtL9jHpW65Ou8+r4qnnZpf78+fPn
z58/f/5P90dExO9c9b4d/V6k4lWfrvZn8SOOft9Xjeuqf1edU/WZXYdUfc76
GfWs1idd59XxVfOyS/358+fPnz9//vyf5o+IiDWmvhe1PPXvRSpe9elqfxY/
4uj3vft7vUudU/WZXYd0fUZ9uvx3i1f9j9qn+uHPnz9//vz58/9t/89f/zkb
EfHXmHqf1/I8/1zf9d084+j3d9W4rvrvtj95yvNytz6jPl3+u8Wr/kftU/3w
58+fP3/+/Pn/uj8iIs5l6n1ey/P8c33Xd/OMo9/fVeO66r/b/uQpz8vd+oz6
dPnvFq/6H7VP9cOfP3/+/Pnz5/90f0RE7OWq9/no9ygVr/p0tT+LH3F0/7Bq
XFf9u+qcqs/sOqTrM+rT5b9bvOp/1D7VD3/+/Pnz58+f/9P8ERFxL6a+R7U8
zz/Xd333zzi6f+jeD+xS51R9ZtfhV+tfZfd6nlU3/vz58+fPnz//3/D//PWf
gxERscbU96KWp/69S8WrPl3tz+JHHP2+rxrXVf/d9j9PeV5m5021v+v5/e/v
12f2+qm258+fP3/+/Pnz/xV/RER8NlPfi1qe+vcuFa/6dLU/ix9x9Pu+alxX
/Xfb/zzleZmdN9X+ruf3v79fn9nrp9qeP3/+/Pnz58//Kf6IiPjbXPW9GP3e
peJVn672Z/Ejju5PVo3rqn9XnVP1mV2HX61/ld3reVbd+PPnz58/f/78d/VH
RMR3MfW9q+Wpf+9S8apPV/uz+BFH9yfd+41d6pyqz+w67Fb/Kneb32p7/vz5
8+fPnz//3/D//PWfUxERcS+mvke1PPXvaSpe9elqfxY/4uj+YdW4rvrvtr96
yvMyO+/d/r///Xn/s+e32p4/f/78+fPnz/9X/BEREb8x9T2q5al/T1Pxqk9X
+7P4EUf3D6vGddV/t/3VU56X2Xnv9v/978/7nz2/1fb8+fPnz58/f/5P8UdE
RBzhqu/R6Pc0Fa/6dLU/ix9xdP+zalxX/bvqnKrP7DrsVv8qd5vfanv+/Pnz
58+fP/9d/REREZNMfU9reerf01S86tPV/ix+xNH9T/d+Zpc6n/Xz/e/zeVPz
lcpb7T/lM9t/1frhz58/f/78+fOv9fP56z9HIiLiu5j63tXy5O5Jur77XfuK
M47uT1aN66r/nvu3ec/R7HWeylvtP+Uz23/V+uHPnz9//vz586/2g4iI2MnU
966WJ3dP0vXd79pXnHF0f7JqXFf9n7J/m503NV+pvNX+Uz6z/VetH/78+fPn
z58//6M4IiLijlz1vRv9XqfiVZ+u9mfxI47ur1aN66p/V53P+vn+9/m8qflK
5a32n/KZ7b9q/fDnz58/f/78+SMiIj6Jqe91LU/unqTru9+1Lzrj6P6qe7/0
ljpf6/f+eFPzOztv1/zOrjN//vz58+fP/23+n7/+cx4iImKSqe9pLc/8+4fZ
+4qufcsZR/c/q8Z11f9X63yt3/vjTc3v7Lxd8zu7zvz58+fPnz//9/kjIiL+
MlPf01qe+fcPs/cVXfuWM47uf1aN66r/r9b5Wr/3x5ua39l5u+Z3dp358+fP
nz9//r/nj4iI+Gau+p6O7gdS8apPV/uz+BFH92+rxnXV/1frfK3f++NNze/s
vF3zO7vO/Pnz58+fP//n+yMiIuKfTO0Hannm3z/M3ld07bvOOLp/696P/Vqd
V/Xz/e//rMNuz1GqH/78+fPnz58//+/9fP76z2GIiIhPYup7Xcsz/35j9r6l
a190xtH91apxXfV/ep1X9fP97/+sw27PUaof/vz58+fPnz//s34QERHxPlPf
61qe+fcbs/ctXfuiM47ur1aN66r/0+u8qp/vf/9nHXZ7jlL98OfPnz9//vz5
IyIi4jyu+l6P7jdS8apPV/uz+BFH94erxnXV/+l1XtXP97//sw67PUepfvjz
58+fP3/+7/NHRETEdUztN2p55t9vzN63dO3rzji6P+ze783qP1X/VfN41b9r
Haby8ufPnz9//vz5//GXv/5zEiIiIv7J1H6glsf94Vn7s/gRR/dvq8Z11T/V
/5p9r/vDanv+/Pnz58+fP39ERETcn6n9QC2P+8Oz9mfxI47u31aN66p/qv9V
+97UPF7171qHqbz8+fPnz58///f4IyIi4nO5aj8wup9Jxas+Xe3P4kcc3X+u
GtdV/1T/qfqvmser/l3rMJWXP3/+/Pnz5/+7/oiIiPg7TO1nanncH561P4sf
cXT/2b2fnNX/qvqP5k15pvLy58+fP3/+/Pn/8Ze//nMMIiIirmNqv1HL4/7w
rP1Z/Iij+8NV47rqn+p/Vf1H86Y8U3n58+fPnz9//vwRERERU/uNWh73h2ft
z+JHHN0frhrXVf9U/6vqP5o35ZnKy58/f/78+fN/jz8iIiLiEVftN0b3S6l4
1aer/Vn8iKP721Xjuuqf6r9rX921TlJ5+fPnz58/f/6/64+IiIh4lan9Ui2P
+8Oz9mfxI47ub7v3q6v3w+l5Ga1/tX3XOuTPnz9//vz57+b/+es/ZyAiIuLv
MLWfqeVxf3jW/ix+xNH956pxXfVP9//976/3PxpP1blrHfLnz58/f/789/NH
REREnMXUfqaWx/3hWfuz+BFH95+rxnXVP93/97+/3v9oPFXnrnXInz9//vz5
899vH4iIiIg4i6v2M6P7sVS86tPV/ix+xNH986pxXfVP9//976/3PxpP1blr
HfLnz58/f/78+/ZLiIiIiKuZ2o/V8rg/PGt/Fj9iav/8/e//bD97P5+u2yyf
rnWY6oc/f/78+fPnP9v/89d/DkBERES8ytR+qZbH/eFZ+7P4EVP78+9//2f7
2fvtdN1m+XStw1Q//Pnz58+fP//5/oiIiIhPZWq/VMvj/vCs/Vn8iLP2t6k6
V33SdZvl07UOU/3w58+fP3/+/Ofv0xARERGfylX7pdH9Xipe9elqfxY/Ymp/
/v3v/2w/+7yQrtssn651mOqHP3/+/Pnz51/3R0RERHwLU/u9Wp733R9eq8v1
fmbt26ued+s/q//d1kmqH/78+fPnz5//bP/PX/8+HREREXEXpvZjtTzPvxe6
W7fv7a73M2tfXfW8W/9Z/e+2TlL98OfPnz9//vzn+yMiIiLiXzO1H6vlef69
0N26fW93vZ9Z++qq5936z+p/t3WS6oc/f/78+fPnP3+/ioiIiIh/zVX7sdH9
ZCpe9Um1v1aX6/2s3len6z+r/93WSaof/vz58+fPn//4vgsRERER7zG1n6zl
ef69UGof27WfT3me5b3W337x1HpYta748+fPnz//3/f//PXvoxERERHfwtR+
r5bH/eFoP7P27VXPs7zX+tsvnloPq9YVf/78+fPn/wZ/REREROxhar9Xy+P+
cLSfWfv2qufdfX7VZ3U8tR5WrSv+/Pnz58//F/wRERERcU+u2u+N7ldT8apP
qv21ulzvZ/W+/W6dr/W3Xzy1HlatK/78+fPnz/+J/oiIiIj4DKb2q7U87g9H
+5l17rjree3v+ua9+3w0a73x58+fP3/++/h//vr3uYiIiIiYYWo/Wcvz/Huh
u3X73u56P7POBXc9r/3dfveEq+Z91nrjz58/f/78d/JHRERExN9kaj9Zy/P8
e6G7dfve7no/s84Fdz2v/d1+94Sr5n3WeuPPnz9//vxX+iMiIiLiO7lqPzm6
H07Fqz6p9tfqcr2f1eeCs/6v/d1+94Sr5n3WeuPPnz9//vxn+iMiIiIi/p2p
/XAtz/PvhVL78K7zSNWzNo68z+p4aj2sWlf8+fPnz5//eT+fv/59KCIiIiI+
g6n9ai2P+8PRfmadO+5yts/qeGo9rFpX/Pnz58+f/5V+EBERERHvMLVfreVx
fzjaz6xzx13O9lkdT62HVeuKP3/+/Pnzv/K9RkRERES8w1X71dH9dipe9Um1
v1aX6/3sdu6Y7bM6nloPq9YVf/78+fN/pz8iIiIi4gqm9tu1PO4PR/sZPUfs
dj7aLV71P2qf6oc/f/78+b/B//PXv09ERERERPw7U/vhWp7n3wvdrdv3dtf7
qdZ/NO/sOu8Wr/oftU/1w58/f/783+GPiIiIiLgjU/vhWp7n3wvdrdv3dtf7
qdZ/NO/sOu8Wr/oftU/1w58/f/78f8MfEREREfGJXLUfHt3Pp+JVn1T7a3W5
3s/oeWS389du8ar/UftUP/z58+fP/5n+iIiIiIi/wNR+vpbn+fdCs88R6XmZ
dS6b3U9XPLUeVq0r/vz58+e/wv/z17+PQ0RERERcwdR+u5bH/eEZ0/My69w3
u5+ueGo9rFpX/Pnz589/jT8iIiIi4huZ2m/X8rg/PGN6Xmad+2b30xVPrYdV
64o/f/78+Wf8ERERERHxX7lqvz16XkjFqz6p9lWm52XWuW92P13x1HpYta74
8+fPn/89f0REREREPGfqvFDLs9/94d36VNuvPmfNPpft5t9Vh6P2qX748+fP
n/+Vfj5//fssRERERMRfYGo/X8uz373Q3fpU268+x80+9+3m31WHo/apfvjz
58+f/7V+EBERERExz9R+vpZnv3uhu/Wptl99jpt97tvNv6sOR+1T/fDnz58/
/3+OIyIiIiLiOq7az4+eR1Lxqv9ZP9X2q89xs899u/l31eGofaof/vz583+r
PyIiIiIi9jN1Hqnl2e9e6C5Xn9eqeWd77ubfVYfUOuyqP3/+/Pmv8f/89e+D
EBERERHxnKnzQi2P+8N0+1S86/y7Wzw1X13zzp8/f/67+iMiIiIi4vOYOi/U
8rg/TLdPxbvOv7vFU/PVNe/8+fPn3+WPiIiIiIi/x1XnhdHzTip+1//quKrj
TbVPxbvOv7vFU/PVNe/8+fPnv8ofERERERHfy9nnoNnx1LjSPqvPibM9d/Pf
bb5S/fDnz5//Gv/PX/9+BBERERER9+Xsc8rseGpcaZ/V59DZnrv57zZfqX74
8+fPf5U/IiIiIiLiVc4+p8yOp8aV9ll9Dp3tuZv/bvOV6oc/f/78U/6IiIiI
iIgpzj5nzY6nxpX2WX0One25m/9u85Xqhz9//vzv+iMiIiIiIs7i7HNWKl4b
R92z2k+q/9k+s/N2+XfV4e663aX+/Pnzf4r/569/v4CIiIiIiO/l7HNQKl4b
R92z2k+q/9k+s/N2+XfV4e663aX+/Pnzf44/IiIiIiLiLpx9DkrFa+Ooe1b7
SfU/22d23i7/rjrcXbe71J8/f/77+CMiIiIiIj6Fs89xqXhtHHXPaj+p/mf7
zM7b5d9Vh7vrdpf68+fPv88fERERERHxqZx9jrt7XrvmO/882HXeTPnsdr7e
LV71P2qf6oc/f/5P8f/89X/PERERERERZ3H2OevuefCa7373XdX+Z/vsdn7f
LV71P2qf6oc/f/7P8UdERERERHwLZ5+z7p4Hr/nud99V7X+2z27n993iVf+j
9ql++PPnv48/IiIiIiIi/oOzz4l3z4PXfPe776r2P9tnt/P7bvGq/1H7VD/8
+fPv80dERERERMS/5uxz4ln/17z6zrOz+5/t8/R67laHu+t8l/rz5/8e/89f
//cWERERERHxqZx9jjvr/5rXc+67us7RXXXo8u+qw911vkv9+fN/kz8iIiIi
IiJmOPscd/d8t8t5eXb/s32eXs/d6nB3ne9Sf/78f8kfERERERER13D2OfSs
/2tez7nv6j5Hr65Dl39XHe6u813qz5//k/0RERERERGxh6vOodfy73ee7Tov
p3yeXs/d6nDUPtUPf/7v8f/89X8PERERERER8a+56px7Lf9+5+Wu83jK5+n1
3K0OR+1T/fDn/yZ/REREREREfAa7z4m7n5e7zuMpn6fXc7c6HLVP9cOf/y/5
IyIiIiIi4m9w1Tn3Wv79zstd5/GUz9PruVsdjtqn+uHP/8n+iIiIiIiI+JtM
nXNrefb752G6zumzfVLtq/7VcXX5d807f/77+3/++r9XiIiIiIiI2MPUObSW
Z7/7rq57gNk+qfZV/+q49rw/efr9D3/+Y/0gIiIiIiIi/p2pc2gtz373XV33
ALN9Uu2r/tVx7Xp/Mmve+fPfwR8RERERERHxCledQ2edu1OeXfcAs31S7av+
1XF1+XfNO3/+Hf6IiIiIiIiId5g6R9fy7Hff1XUPMNunmrfb5+n3M/z5r/P/
/PV/TxAREREREfE3mTrn1vK4P1zlU83b7fOu+x/+/Mf6QURERERERFzB1Dm3
lsf94Sqfat5un7fd//Dnn3xOEREREREREWdw1Tl31rk+5dl1zzDbp5q32+fX
7n/486/4IyIiIiIiIu7I1Dm9lsf94ZlP1TNdn1+9n+HPf53/56//fY+IiIiI
iIh4h6lzdC2P+8Mzn6pnuj7uf/jzH/dHRERERERE/AWmztG1PO4Pz3yqnun6
uP/hz3/8vYeIiIiIiIj4C1x1jp51b5Dy7LrHqDKddzT+9Psf/vwr/oiIiIiI
iIhvZOoeoJZnv/vDan1S9xiz4yl/90v8f8//89f/PkZERERERETckalzei2P
+8NV8ZT/nvc/T7+/4t/tj4iIiIiIiIjnTJ3Ta3ncH66Kp/x3vf8ZHS//3/ZH
RERERERExHGuOqfPupdIe16tT+qeZHY85d81X6m8/N/hj4iIiIiIiIh5pu4Z
annm3w903bdU+58dT/mn6tZ9v8T/Sf6fv/73JSIiIiIiIuIbmb53upbH/eGq
eMo/Vbdn3V/x7/ZHRERERERExH6m752u5XF/uCqe8k/V7Wn3V/zn+iMiIiIi
IiLi/lx1D5C6f5g1rnQdRu9tUvGUf6puu91f8V/rj4iIiIiIiIi/w1X3G6N5
u9qn7mFmx1P+q+6XVs8X/5F+Pn/97y1EREREREREXMdV9yejebvap+55ZsdT
/nveXz39/u35/oiIiIiIiIj4XnbdP8y+J5l9n5OqWyqe8t/1/mp0vPyvxRER
ERERERERP7nq/mQ0b1f71D3P7HjKv+v+avZ88f/nOCIiIiIiIiLiVabvwa7l
OY7vdn8y+14uFT8a71vvx97l//nrf68gIiIiIiIi4u8wdb9Ry3McX3U/M1qf
3eJH43X/9g5/RERERERERMRZTN1v1PIcx1fdz4zWZ7f40Xjdv/2GPyIiIiIi
IiJiF1fdb6y+57nrebU+u8WPxuv+7Zn+iIiIiIiIiIi7MHU/U8tT7+fMc3Rc
6Tqsjj/tfuxd/p+//uceEREREREREfEq0/dm1/LU+znzHB1Xug6r4799//Z8
f0RERERERETEpzJ9b3YtT72f6v1M1z1SV/zX799290dERERERERE/FW6P5xT
B/eHv+2PiIiIiIiIiPgWPuX+MNX/7HuqrnhqvKl+nuX/+et/LhERERERERER
d6H7w3vtd4unxpvq52n+iIiIiIiIiIj413R/eK/9bvHUeFP97OaPiIiIiIiI
iIj36P7wXvvd4qnxpvrp9kdERERERERExLmcfa/YdY9X9az6u9+b4f/5638+
EBERERERERHfTveH9/z3vH97+v0hIiIiIiIiIiLuRveH9/x3vX/b/f4QERER
ERERERGfRfeH9/zdH17zR0RERERERETEZ7PrnytL3xOOjuut93u1fj5//esX
ERERERERERHn0v1htg6/fX+IiIiIiIiIiIhvo/vDbB2efn+IiIiIiIiIiIj4
X+n+MFuHp90fIiIiIiIiIiIifuNT7g9r/R3Hn3a/V+vn89e/vhARERERERER
8dl0f3iv/Z73h4iIiIiIiIiIiFm6P7zXvuv+EBERERERERERcSXdH95rv+r+
EBERERERERERsZO73R/W/q7/fq/Wz+evf/4RERERERERERG/0f1htg53x4WI
iIiIiIiIiLgj3R/21gEREREREREREXFnuj8cqwMiIiIiIiIiIuIvc9d/7q7n
/1/8+eufH0RERERERERExE66P5zjj4iIiIiIiIiI+At82/0hIiIiIiIiIiIi
Xueu93L+/YSIiIiIiIiIiIj9XHN/+Pk77se/nxAREREREREREXEfPuv+EBER
EREREREREVdyt/tDRERERERERERE3Ie7/vsPERERERERERER8Xn07ydERERE
RERERETEI/r3EyIiIiIiIiIiIu7L/w89Y59u
   "], {{0, 0}, {216, 210}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{{3.56390094313741*^9, 3.563900967376375*^9}, 
   3.564165999621043*^9, 3.564166794272573*^9, 3.564166987483466*^9, 
   3.564167272381674*^9, 3.5641674981032333`*^9, 3.564167737397079*^9, 
   3.564168077028699*^9, 3.564168313087844*^9, 3.56442070087609*^9, 
   3.564421428902236*^9, 3.564421590901018*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quasi-periodic", "Subsection",
 CellChangeTimes->{{3.563901020021421*^9, 3.563901022241702*^9}, {
  3.565003516083166*^9, 3.5650035163777313`*^9}}],

Cell[TextData[{
 ButtonBox["quasi-periodicity",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/2012/alumni/feinberg.html"], 
    None},
  ButtonNote->
   "http://wolframscience.com/summerschool/2012/alumni/feinberg.html"],
 ":"
}], "Text",
 CellChangeTimes->{{3.557100439079948*^9, 3.5571004846029167`*^9}, {
   3.5571005188118067`*^9, 3.557100696396886*^9}, {3.5571007288427763`*^9, 
   3.557100789632626*^9}, {3.557100939626054*^9, 3.557100947724197*^9}, {
   3.55725459875432*^9, 3.5572545989164*^9}, {3.557254665062388*^9, 
   3.5572546660776157`*^9}, {3.5589661862535067`*^9, 
   3.5589661906996937`*^9}, {3.558966251062985*^9, 3.558966272699583*^9}, {
   3.5599095077858343`*^9, 3.559909528797624*^9}, {3.561394279129333*^9, 
   3.561394339402021*^9}, {3.561394506225092*^9, 3.561394513066721*^9}, {
   3.561394564885427*^9, 3.561394572179175*^9}, {3.56139822620399*^9, 
   3.5613982298285418`*^9}, {3.5613982742945423`*^9, 3.561398281133263*^9}, {
   3.561398334540217*^9, 3.5613983385387297`*^9}, {3.561398421411598*^9, 
   3.561398481561248*^9}, 3.561398938120727*^9, 3.5648331031757355`*^9, {
   3.564915487050275*^9, 3.564915510526635*^9}, {3.564938481115801*^9, 
   3.564938481923588*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"TuringMachine", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"578870483740283859310689", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "1000"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563900228005419*^9, 3.563900235518388*^9}, 
   3.563900267058216*^9, {3.563900493957591*^9, 3.563900494730587*^9}, 
   3.563900677417593*^9, {3.563900784356688*^9, 3.563900784673606*^9}, 
   3.563900908465106*^9, {3.563900946911586*^9, 3.5639009472997503`*^9}, {
   3.5639011041642437`*^9, 3.5639011086962347`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ArrayPlot", "[", 
     RowBox[{"#", ",", 
      RowBox[{"ColorRules", "->", "$TMColors"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "80"}]}], "]"}], "&"}], "/@", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "200"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.56390112200939*^9, 3.563901122011058*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    RasterBox[CompressedData["
1:eJzt3eGJHDcYgOEFVxJwBy4gPaSEgH+nzfThBlxCnITjWM1oV5qRZvRJj8A8
Qeg0mmVebnO32L/9+dcf3788Ho+/f/35+uvPv//9//j5+6p++2/8SObT8W4+
t0+r+drzjHZOrqq+rjgPV1VfLc+T34drqq+W59EXn9VXy+vqi8/q68h16++L
a6qvI9fVEcvUV8vrks/qq+V1yWf11XZ/Ul9n/z8rv57Ul754jWv1VTuvL55T
Xy3PQz6rr5bnIZ/V16t5ffGcq/T1vO/Z+8qvJ2fuK9eRvqiv8vPUdqQv6ktf
nMux+iq/rr4YwRh9bdfrixHU15H7yq8n7+/r/P76YgTH6qt8H30xgqP31aoj
fVFf23l9MbL6OnJf+fXkdX3V7rOd1xcje09f139OQ1/U13a9vhjZXu/rXs/r
i2vYt69xPserL+pru4++GFnvD9uck+zRV+/nVl+MbK/nPLdP7+vqiyOprzbn
JLemQ19Hz0mW93X+c+y1++fW64txTYe+jp6T1Je+OIb6qjsnWd/Vx9BX6XpS
X+3PSepLX7zX0Z5bfXFG0+dKX2XrSX21PyepL31xDPefq/LuHrtDX6S+9MW+
tumrdv906Itz2ruvfdOhL86pvva+Tl9sY9++0qEvruU9fb07x+d6fTGy+tr7
On2xjfra+zp9sY2lfb2b3zcd+uJatukrHfoi+/d19Byf++iLkdVX3/vi2l79
PrDsHJ/76IuRbfV9KrfPsXN87q8vRlZfx+6XPN5XOvR19L64tq2+T+mL1Ffd
feXXk+37ys3ri9RX7fnz68n3pkNfpevJ4335+fy79aS+0nO2u19SX+k5290v
eUZ9vV5PtnzOH7tDX6S+9MUx1FfZerJ9X6Vfpy+yZV+9rqsvzqS+ytaT7Z53
fbW6T/KO501fXMm65y03ry+yX1+5eX1xbfv2tZ3XF1dSX6/Xk/oqPY++eK1X
95W7rr44o/p6vZ7U1/HrvltPztBXbl5fjKy+Xq8n9XX2uvn15Mx95eb1xQjq
6/V6Ul/b/XPqi/rq19e++XOS+truX2f+nKS+tvvvW39OUl/b/ffNn4fUl74Y
S32R+qqd3zd/HlJfpfP15yH1dbYv8lr1RerL+0BGdM6+an/uQfZRX+TqfbXb
n9TX+e9T+uIIztoXOYKx+8rvT46gvshV+mq3PzmCMfryOQ3GVF/kbH3VzuuL
MR2rL5/j5Vzqi1ylr9y8vhjTq/t6vl7pPvpiTHv1letIX1zJs33VdqQvrmTp
c9uqI31xJfVF9jId+iL791X+9+Xqi9QXqa/y87xbT46svsjeXX0MfZH6uv/1
I/VF3qO+yKs70xepr/tfN1Jf5L3uP8/9unvsDn1xTvVF6iu3nhzZ0r5y8/oi
9UXqS1+cy7N95eb1ReqLnK+v2vOk4/7XjYzY177puP91I/VF3utYfaVDX4xt
jL7ImOqL1BcZ0V59vZvfNx33vz5kvL7SoS/O6Vh9kXOpLzJqX+nQF9fyru9T
dT/3IGOqL3L0vtKhL7J/X61+L0bG1PtAMmpfuXlyDfVFjtJXOvRF9u/L5zRI
fZHX2vf3Wfn15Ar2/X1Wfh9yBfVFjtJXbl5fpL7IK02Hvsj+ffn5PKkvcmTT
oS/yCvVF9u7qY+iL1Bc5tvoi7+qr9Ov0Rbbsa9903H9/pL7IOT3WVzr0Rfbv
i6S+yGvUF3l1Z/oi+/eVDn2R/fsiqS9yBNOhL7J/X/69IVJf5MimQ1/kFeqL
JM/5D7hjtAM=
     "], {{0, 0}, {36, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt2utpbDcUhmFDKgmkgxSQHlJCIL/TZvpIAykhJwlmODOjbV2WtHV5BOY1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     "], {{0, 0}, {36, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJztmO2N3TYQRRdIJQHcQQpwDykhQH6nzfSRBlxCnCwMWe9p+DG8lGbII2Bx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     "], {{0, 0}, {36, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJztme2tJUUSREfCEiQ8wAB8wAQkfuMmfuAAJvAldDXTN7ozu7I6M947I6Gz
W4qpjOxbR7va/f6X337+9bsvX778/vc/P/z9zz//+r8/f/5UzR///fPH4vm3
f67Od9+/+/zY8+t/f/8eRXV/7dxjPju3q+dU4ldNT/zq7TmV+FXTE796e04l
ft05xy/8ivGz+1X1u+NXb8+p/Cx+7f7d8au351R+NL+6fnf86u05la5+Tfvd
8au351TiF345feer/DTO8it+z7TfHb96e06lh1/x94xfK3OP+Wnf+So/jfiF
X/j10fzKnuMXfsXy0zjLr/jcab87fvX2nEr8wi/8+ix+qXP8wq9Yfhqf9mv3
e8avlbnH/LTvfJWfxl1+db1n/FqZe8xP+85X+WnEL/zCryl+qb2O5/h17x5F
/Irlp7HGr/X3v/t+/IrMPeanfeer/DTiF37h19N+qf56L/zCL/xa9Sv+n3f4
de8eRfyK5acRv/ALv6b4pffCL/zCL/x6uk/2HkX8iuVnUfXMnuMXfvX2nMm6
vfALv/ALv57uk71HEb9i+Vms2wu/8Au/4sSvmj7ZexTxK5afzq73v/t+/IrM
Peanfeer/HTiV22f7D2K+BXLTyd+1fbJ3qOIX7H8dJ5/h+jfw6+79yjiVyw/
nXf9it6DX+f3KOJXLD+d+FXbJ3uPIn7F8i6M/u6xv//6Dvh1fo8ifsXyLlzd
C7/u3aOIX7G8C3N7Hc/x6949ivgVy7sQv2r6ZO9RxK9Y3oX4VdMne48ifsXy
Llz1S92DX+f3KOJXLO9C/OrZSxG/YnkX9vgV7zPtd8ev3p5unObX+b2ve/Br
Ze4xP+07X+VdiF+Ve8Xvqdr33txjftp3vsq7cJdfV+f3+r3m4tfK3GN+2ne+
yruwxy99z/nff+Xxa2XuMT/tO1/lXTjLr+P5tN8dv3p7uhG/cnvhV29PN+JX
bi/86u3pxul+qXvwa2XuMY9fe4hfNXOz9yjiVyzvQvyqmZu9RxG/YnkXuvql
zvErMveYx689xK/cXPzq7elG/MrNxa/enm78aH6pc/w6z+PXHuJXbi5+9fZ0
I36dE7/wC7/q/Xrm/eBXtqcb8es98av2vKqnGz+LX1fn57lXH/zq7elG/Ho/
F79qz6t6uhG/3s/Fr9rzqp5uxK/3c/Gr9ryqpxvxKzcXv3p7uhG/cnPxq7en
G/ErN/f8/WS/M35le7oRv3Jz7/oVJX7F8i7Er9xc/Ort6Ub8qp27SvyK5V2I
X0/shV9VPd2IX717nd/7yuPX13kX4lfnXsdz/IrlXYhfnXsdz/ErlnchfnXu
dTzHr1jehfjVuVd8Ln59nXchfnXuFZ+LX1/nXYhfnXvF556/2/XfF7/2EL86
94rPvevXex7n4tce4lfnXvG5+BXZax7xq3Ov+Nx7fsXn4tce4lfnXvG5tX5d
vYNXHr/WiF+de8Xn4td5/6nEr8694nPx67z/VOJX5151+76nvv/83lcev9aI
X517dc3Fr6eIX5177Z579x287sGvNeJX51675+JXN/Grc6/s3Pw9UeLXHuJX
517ZufmeUeLXHuJX517ZufmeUeLXHuJX515V5/g1lfjVuVf2vOr/F8Ovp4hf
nXtlz/HLjfjVuVfVOX5NJX517nU8r32f+NVN/OrZ65n3iV/dxK+9e/W+T/zq
Jn7t3Qu/VvrrvAvx687ceH/8Wumv8y7Erztz43n8Wumv8y7Erztz43n8Wumv
8y7Erzt94j3xa6W/zrsQv/b2wa+V/jrvQvza2we/VvrrvAvx606feE/8Wumv
8y7Er/dzq94Jfq3013kX4tf7ufg1ob/Ou/Bz+RWfi18T+uu8C/HrfR6/JvTX
eRfi1/s8fk3or/Mu/Jh+rd+PXxP667wLXd//vfvj9+DXhP4678JZ73/3/evv
f/f9+BXLu3DW+3/+fvyq7YlfK3upc/xSffBrpb/Ou3D6+6+953iOX7U98Wtl
L3U+za94Hr9qe+LXyl7qHL/UXPxa6a/zLvTwq6rPMY9ftT3xa2Uvdd7l1/pc
/KrtiV8re6lz/FJz8Wulv8670NuvbJ9jHr9qe+LXyl7qfJ9fu38v/KrtiV8r
e6nz+f89rWsufq3013kX4hd+4ZerX/F78Kt2bpb4tYc9fq2/w6o++FXbE79W
9lLn+FW1F37F8i6s8St7jl/4Femv8y7c61f8f/fAr9q5WeLXHuIXfuGXq1/q
HL/wK9Jf51246lfXO8zen+2PXxP667wLXd9h9n6XvfArlneh6zvM3u+yF37F
8h5U/Y/n095h9n6XvfArlveg7v/0+8ev2rlZ4tcO6v74hV/9/XXeg7o/fuFX
f3+ddyd+4Vd/f513Zdf3xK/auVni1zPEr9698CuWdyV+9e6FX7G8K/Grdy/8
iuXd+fT7x6/auVni17PEL/zq76/z7sQv/Orvr/PuVL9X9P18efsHv56amyV+
PUv8wq/+/jrvzhq/4vfjV+3cLPHrWe726/ze1z34dW9ulvj1LPELv/r767w7
o35dnd+b9/8f/Lo7N0v8epY1fn37B7+empslfj3LvX4dz/Grdm6W+PUs8Qu/
+vvrvDvxC7/6++u8O5/2S92DX/fmZolfzxK/8Ku/v86708OvbP/jXPyq7Ylf
Mbr79Z7HufhV2xO/YsQv/Orvr/Pu9PYrPhe/anviV4wf06/1d1XVH78i/XXe
nfiFX/39dd6d+IVf/f113p1T/Lo6f099//m9rzx+Teiv8+708Ct///m9rzx+
Teiv8+709mvfu8r2x6+V/jrvTvzCr/7+Ou/OWX7l74kSv2p74leMHn49/66y
ffBrpb/OuxO/8Ku/v867s8ev7Dl+qblZ4teznOVXvs+9PV9z8WtCf513J37h
V39/nXfnLL/UOX6puVni17N82i+Xd5Xtg18r/XXenbv8cn9X2T74tdJf592J
X/jV31/n3bnqkTp3f1fZPvi10l/n3Vnj1/p7y96/tmd9H/xa6a/z7sQv/Orv
r/PuzO2rzvELv1b667w7s/uq3xe/8Au/8GtXH/xa6a/z7sztq87xC79W+uu8
O/ELv/r767w31V7Zc/zCr5X+Ou9NvVf2O+AXfuEXfu3qg18r/XXem3ov/Nq7
r8t3wK89xK+9+7p8B/yqZdd7y95ftRd+Teiv8x+N+PXMvi7fwdWvvwC+0Gn5

     "], {{0, 0}, {36, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJztmOHNJLcRRA9wJAKUgQNQDgrBgH47TefhBByCJOvHYLVTs91kDad7+Q44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     "], {{0, 0}, {36, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.563901129148765*^9, 3.564166000108487*^9, 
  3.564166794864348*^9, 3.564166988038838*^9, 3.564167272745826*^9, 
  3.5641674986439133`*^9, 3.564167737698588*^9, 3.564168077659607*^9, 
  3.564168313484496*^9, 3.564420701263883*^9, 3.564421429207589*^9, 
  3.5644215911747913`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interesting When Sonified", "Subsection",
 CellChangeTimes->{{3.563901167464336*^9, 3.563901170989717*^9}, {
  3.5650035298104343`*^9, 3.565003534667375*^9}}],

Cell[TextData[{
 "and ",
 ButtonBox["rules that sound interesting when their features are sonified",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/2012/alumni/belli.html"], 
    None},
  ButtonNote->"http://wolframscience.com/summerschool/2012/alumni/belli.html"],
 " (check out ",
 ButtonBox["Wolfram",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://tones.wolfram.com"], None},
  ButtonNote->"http://tones.wolfram.com"],
 StyleBox[ButtonBox["Tones",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://tones.wolfram.com"], None},
  ButtonNote->"http://tones.wolfram.com"],
  FontSlant->"Italic"],
 "):"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ/b7vUdHChleOEt6TK0B00K+bNSDaazPPZBDN9kNq
OoiutNsyD0Qv4ijZCKLn65RvAtEpyjd2vAHSasF3wbTof8WDIPpKtROY3iXj
UWrQ8srxSfI1MP2TOakWRP9JEmsA0X2qlQJ/W185KrdJCoPoeuUnPJc6XjlG
380RAdFfjN01QfQUJSUtEJ0dOscARJ/d3WoIosXa3X5dBtJZzbvA9JMcT4Yr
QHqjswojiC71vMgOot1sAzlA9AXttUIgOj5+kyyI1njWqA+ipb5BaIlFd/1B
dETm0SAQvSq3/45M3yvHEqP7j0C02Y0fqon9rxzDghjVQLTMlgYtEP14bSeY
nlPNkN8JpO8821kEogFtsLmw
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"TuringMachine", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"794017016576815858547405", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "1000"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.563901208273363*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ArrayPlot", "[", 
     RowBox[{"#", ",", 
      RowBox[{"ColorRules", "->", "$TMColors"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "80"}]}], "]"}], "&"}], "/@", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "200"}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    RasterBox[CompressedData["
1:eJzt3OFtHMkRgFECjsQxOIDLwSEY8G9n4dichxNwCD7d4kBxNF3TXayd7pl5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     "], {{0, 0}, {134, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt2eGt5shxBdABHIljcADKwSEY0G9l4dichxJQCJYtCNo3TRa7i9UkmzwL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     "], {{0, 0}, {134, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt2e2t5FpuBdAGHIljmAAmhwnBgH9PFhOb83ACDmE+LozXGpYoqUDWKUqr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     "], {{0, 0}, {134, 200}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt2eGN49pyReEBHIljcAAvB4dgwL+dhWNzHk7AIfjZxgWsLrFEsqt0WOTX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     "], {{0, 0}, {134, 200}}, {0, 1}], Frame -> 
    Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80],GraphicsBox[
    RasterBox[CompressedData["
1:eJzt19GN5FhyBdAGZIlsWAPWB5kgQN/yYm2TH3JAJmilwXywIxlJciLqMchT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     "], {{0, 0}, {134, 
     200}}, {0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
    FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 80]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.5639012198407803`*^9, 3.564166001014001*^9, 
  3.5641667958764563`*^9, 3.564166989541462*^9, 3.564167273596064*^9, 
  3.564167499992729*^9, 3.564167738577908*^9, 3.5641680790063133`*^9, 
  3.564168314470344*^9, 3.564420702121373*^9, 3.564421429967486*^9, 
  3.564421592191975*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"headPos", "[", 
      RowBox[{"rule_", ",", 
       RowBox[{"steps_:", "100"}]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"TM", "[", 
       RowBox[{"rule", ",", "steps"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1", ",", "3"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TM", "[", 
      RowBox[{"rule_", ",", 
       RowBox[{"steps_:", "100"}]}], "]"}], ":=", 
     RowBox[{"TuringMachine", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"rule", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "steps"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"printTM", "[", 
      RowBox[{"rule_", ",", 
       RowBox[{"steps_:", "100"}]}], "]"}], ":=", 
     RowBox[{"ArrayPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"TM", "[", 
         RowBox[{"rule", ",", "steps"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"PixelConstrained", "\[Rule]", "6"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"200", ",", "Automatic"}], "}"}]}], ",", 
       RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"ColorRules", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Yellow"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}], ",", 
          RowBox[{"3", "\[Rule]", " ", "Red"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"printSmallTM", "[", 
      RowBox[{"rule_", ",", 
       RowBox[{"steps_:", "100"}]}], "]"}], ":=", 
     RowBox[{"ArrayPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"TM", "[", 
         RowBox[{"rule", ",", "steps"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"PixelConstrained", "\[Rule]", "4"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"50", ",", "Automatic"}], "}"}]}], ",", 
       RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"ColorRules", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Yellow"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}], ",", 
          RowBox[{"3", "\[Rule]", " ", "Red"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"printHead", "[", 
      RowBox[{"rule_", ",", "steps_"}], "]"}], ":=", 
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"headPos", "[", 
        RowBox[{"rule", ",", "steps"}], "]"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"400", ",", "Automatic"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"histo", "[", 
      RowBox[{"test_", ",", "steps_"}], "]"}], ":=", 
     RowBox[{"Histogram", "[", 
      RowBox[{
       RowBox[{"Flatten", "@", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{"Function", "[", 
           RowBox[{"int", ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Cases", "[", 
                 RowBox[{"#", ",", "int"}], "]"}], "&"}], "/@", 
               RowBox[{
                RowBox[{"TM", "[", 
                 RowBox[{"test", ",", "steps"}], "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ",", "2"}], 
             "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "\"\<Rainbow\>\""}]}], " ", 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"even", "[", "rule_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"TM", "[", "rule", "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "#"}], "]"}], "]"}], "&"}], "/@", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"(", 
            RowBox[{"Round", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{
                 RowBox[{"TM", "[", "rule", "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}], "/", "2"}], "]"}], ")"}], 
           "]"}], "-", "1"}], ")"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sumCompress", "[", "rule_", "]"}], ":=", 
    RowBox[{"Plus", "@@", 
     RowBox[{"StringLength", "/@", 
      RowBox[{"Compress", "/@", 
       RowBox[{"even", "[", "rule", "]"}]}]}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"countColor", "[", "rule_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"Count", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"TM", "[", "rule", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "#", ",", "2"}], 
        "]"}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"totalNoColor", "[", "rule_", "]"}], ":=", 
     RowBox[{"Plus", "@@", 
      RowBox[{"countColor", "[", "rule", "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"percColor", "[", "rule_", "]"}], ":=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"totalNoColor", "[", "rule", "]"}], "\[NotEqual]", "0"}], ",", 
       RowBox[{"N", "@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"countColor", "[", "rule", "]"}], "/", 
          RowBox[{"totalNoColor", "[", "rule", "]"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testCompress", "[", "rule_", "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"sumCompress", "[", "rule", "]"}], ">", "600"}], ",", "True", 
      ",", "False"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testColor", "[", "rule_", "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Max", "@", 
         RowBox[{"percColor", "[", "rule", "]"}]}], "<", "0.60"}], "&&", 
       RowBox[{
        RowBox[{"Min", "@", 
         RowBox[{"percColor", "[", "rule", "]"}]}], ">", "0.15"}]}], ",", 
      "True", ",", "False"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"testMax", "[", "rule_", "]"}], ":=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Max", "@", 
         RowBox[{"Abs", "@", 
          RowBox[{"headPos", "[", "rule", "]"}]}]}], "<", "95"}], ",", "True",
        ",", "False"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tm", "=", "794017016576815858547405"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5498452673399982`*^9, 3.549845293020124*^9}, {
   3.549845509055315*^9, 3.549845587083173*^9}, {3.5498456598168707`*^9, 
   3.54984582853242*^9}, {3.5498458617906218`*^9, 3.549845870345813*^9}, {
   3.5498459306122637`*^9, 3.549845962018786*^9}, {3.549846073694366*^9, 
   3.5498461243940372`*^9}, {3.549846288311372*^9, 3.549846311739914*^9}, {
   3.549846351477461*^9, 3.5498463517463408`*^9}, {3.5498464999850883`*^9, 
   3.5498465007509317`*^9}, {3.5498465468943872`*^9, 
   3.5498465778858967`*^9}, {3.5498467634296722`*^9, 3.549846785252717*^9}, {
   3.549885042389056*^9, 3.54988510182404*^9}, {3.54988515095918*^9, 
   3.549885155824705*^9}, 3.5498852874348383`*^9, {3.549885318158041*^9, 
   3.549885341005093*^9}, {3.5498854236346083`*^9, 3.549885424332004*^9}, {
   3.549886187297763*^9, 3.5498861981511593`*^9}, {3.550071312196287*^9, 
   3.5500713244793262`*^9}, {3.5500713633040943`*^9, 3.55007136352695*^9}, 
   3.5500714380522957`*^9, {3.5500724005245733`*^9, 3.550072445464513*^9}, {
   3.550072513152652*^9, 3.550072730080867*^9}, {3.550072911931128*^9, 
   3.550072928390414*^9}, {3.550072959974724*^9, 3.5500730031254*^9}, {
   3.550073041555895*^9, 3.550073107157791*^9}, {3.550073205362533*^9, 
   3.5500732532092047`*^9}, {3.550073344428052*^9, 3.5500734283367453`*^9}, {
   3.5500736690533648`*^9, 3.550073758975428*^9}, 3.5500921241063137`*^9, {
   3.55014549785358*^9, 3.5501455506010427`*^9}, 3.5501502023559217`*^9, {
   3.550150343854548*^9, 3.550150345383892*^9}, {3.550150470363344*^9, 
   3.5501504872763863`*^9}, {3.550175965448146*^9, 3.550175976992635*^9}, {
   3.550176017345025*^9, 3.550176017902623*^9}, {3.550178704338459*^9, 
   3.550178704661138*^9}, {3.550178814195537*^9, 3.550178817711177*^9}, {
   3.550178934795638*^9, 3.550178938866076*^9}, {3.550179209222856*^9, 
   3.55017921296603*^9}, {3.550180865187512*^9, 3.550180882020625*^9}, {
   3.55018414832421*^9, 3.550184157078884*^9}, {3.550197471333797*^9, 
   3.550197478142655*^9}, {3.5502030713824244`*^9, 3.550203093934511*^9}, {
   3.55020312395539*^9, 3.550203143006518*^9}, {3.550203173127083*^9, 
   3.5502032380258417`*^9}, {3.550204936847908*^9, 3.5502049568298473`*^9}, {
   3.550205677473402*^9, 3.550205677790756*^9}, {3.550207988136382*^9, 
   3.5502079926997957`*^9}, {3.550208057215699*^9, 3.5502080641375017`*^9}, {
   3.550208333309778*^9, 3.550208333572052*^9}, {3.550208436230406*^9, 
   3.550208503509804*^9}, 3.550208536764874*^9, {3.550209065509343*^9, 
   3.550209071829815*^9}, {3.550209570183106*^9, 3.550209603397098*^9}, 
   3.550209644691188*^9, 3.550210878315905*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tuneTheTuring", "[", "rule_", "]"}], ":=", 
   RowBox[{"Sound", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sound", "[", 
       RowBox[{
        RowBox[{"play1", "[", "rule", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "70.33"}], "}"}]}], "]"}], ",", 
      RowBox[{"Sound", "[", 
       RowBox[{
        RowBox[{"play2", "[", "rule", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "64"}], "}"}]}], "]"}], ",", 
      RowBox[{"Sound", "[", 
       RowBox[{
        RowBox[{"play3", "[", "rule", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "64"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"play1", "[", "rule_", "]"}], ":=", 
   RowBox[{"Sound", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"SoundNote", "[", 
          RowBox[{"#", ",", 
           RowBox[{"1", "/", "6"}], ",", "\"\<Piano\>\""}], "]"}], "&"}], "/@", 
        RowBox[{"Pick", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"dim", "[", "rule", "]"}], "]"}], "-", "1"}], ",", "#", 
          ",", "1"}], "]"}]}], "&"}], "/@", 
      RowBox[{
       RowBox[{"TM", "[", "rule", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"play2", "[", "rule_", "]"}], ":=", 
   RowBox[{"Sound", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"SoundNote", "[", 
          RowBox[{"#", ",", 
           RowBox[{"1", "/", "6"}], ",", "\"\<Harp\>\""}], "]"}], "&"}], "/@", 
        RowBox[{"Pick", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"dim", "[", "rule", "]"}], "]"}], "-", "1"}], ",", "#", 
          ",", "2"}], "]"}]}], "&"}], "/@", 
      RowBox[{
       RowBox[{"TM", "[", "rule", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"play3", "[", "rule_", "]"}], ":=", 
   RowBox[{"Sound", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"SoundNote", "[", 
          RowBox[{"#", ",", 
           RowBox[{"1", "/", "6"}], ",", "\"\<Xylophone\>\""}], "]"}], "&"}], 
        "/@", 
        RowBox[{"Pick", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"dim", "[", "rule", "]"}], "]"}], "-", "1"}], ",", "#", 
          ",", "2"}], "]"}]}], "&"}], "/@", 
      RowBox[{
       RowBox[{"TM", "[", "rule", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim", "[", "rule_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Dimensions", "[", 
    RowBox[{
     RowBox[{"TM", "[", "rule", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5502020903320704`*^9, 3.550202231616604*^9}, {
  3.5502023173965673`*^9, 3.550202346606868*^9}, {3.550202379581662*^9, 
  3.5502023832994747`*^9}, {3.5502024711231813`*^9, 3.550202478092107*^9}, {
  3.550202561077176*^9, 3.550202561460384*^9}, {3.550205952258108*^9, 
  3.550205961615349*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tuneTheTuring", "[", "tm", "]"}]], "Input",
 CellChangeTimes->{{3.5639025231447697`*^9, 3.5639025322475433`*^9}, {
   3.5639025954584293`*^9, 3.563902605189815*^9}, 3.563902635501376*^9}],

Cell[BoxData[
 InterpretationBox[
  GraphicsBox[{
    {GrayLevel[0.9], RectangleBox[{0, 0}, {360, -164}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[0.5, 0, 0.5], 
         StyleBox[{
           RectangleBox[{42.66463209936827, 0.45579648983751037`}, \
{42.82296060060426, 0.4677012517422721}], 
           RectangleBox[{44.66454054383984, 0.45579648983751037`}, \
{44.822869045075834`, 0.4677012517422721}], 
           RectangleBox[{46.66444898831141, 0.45579648983751037`}, \
{46.822777489547406`, 0.4677012517422721}], 
           RectangleBox[{48.664357432782985`, 0.45579648983751037`}, \
{48.82265694143498, 0.4677012517422721}], 
           RectangleBox[{40.83138523514511, 0.4677012517422721}, \
{40.98971373638111, 0.4796060136470343}], 
           RectangleBox[{42.831293679616685`, 0.4677012517422721}, \
{42.989622180852685`, 0.4796060136470343}], 
           RectangleBox[{44.83120212408826, 0.4677012517422721}, \
{44.98953062532426, 0.4796060136470343}], 
           RectangleBox[{46.83111056855983, 0.4677012517422721}, \
{46.98943906979583, 0.4796060136470343}], 
           RectangleBox[{48.830988494521925`, 0.4677012517422721}, \
{48.989316995757925`, 0.4796060136470343}], 
           RectangleBox[{50.66423535874508, 0.4677012517422721}, \
{50.822563859981074`, 0.4796060136470343}], 
           RectangleBox[{52.49748222296823, 0.4677012517422721}, \
{52.65581072420423, 0.4796060136470343}], 
           RectangleBox[{54.33072908719138, 0.4677012517422721}, \
{54.48905758842738, 0.4796060136470343}], 
           RectangleBox[{9.499526963103122, 0.4796060136470343}, \
{9.657855464339121, 0.49151077555179606`}], 
           RectangleBox[{11.166112247077853`, 0.4796060136470343}, \
{11.324440748313851`, 0.49151077555179606`}], 
           RectangleBox[{12.832697531052583`, 0.4796060136470343}, \
{12.991026032288582`, 0.49151077555179606`}], 
           RectangleBox[{14.499282815027314`, 0.4796060136470343}, \
{14.657611316263313`, 0.49151077555179606`}], 
           RectangleBox[{39.16479995117039, 0.4796060136470343}, \
{39.32312845240638, 0.49151077555179606`}], 
           
           RectangleBox[{40.998046815393536`, 0.4796060136470343}, \
{41.156375316629536`, 0.49151077555179606`}], 
           RectangleBox[{42.99795525986511, 0.4796060136470343}, \
{43.15628376110111, 0.49151077555179606`}], 
           RectangleBox[{44.99786370433668, 0.4796060136470343}, \
{45.15619220557268, 0.49151077555179606`}], 
           RectangleBox[{46.99777214880825, 0.4796060136470343}, \
{47.15607165746025, 0.49151077555179606`}], 
           RectangleBox[{48.99765007477035, 0.4796060136470343}, \
{49.15597857600635, 0.49151077555179606`}], 
           RectangleBox[{50.8308969389935, 0.4796060136470343}, \
{50.9892254402295, 0.49151077555179606`}], 
           RectangleBox[{52.66414380321665, 0.4796060136470343}, \
{52.822472304452646`, 0.49151077555179606`}], 
           RectangleBox[{54.4973906674398, 0.4796060136470343}, \
{54.6557191686758, 0.49151077555179606`}], 
           RectangleBox[{56.163975951414535`, 0.4796060136470343}, \
{56.32230445265053, 0.49151077555179606`}], 
           RectangleBox[{7.999603259376812, 0.49151077555179606`}, \
{8.157931760612811, 0.5034155374565581}], 
           RectangleBox[{9.666188543351543, 0.49151077555179606`}, \
{9.824517044587541, 0.5034155374565581}], 
           RectangleBox[{11.332773827326273`, 0.49151077555179606`}, \
{11.491102328562272`, 0.5034155374565581}], 
           RectangleBox[{12.999359111301004`, 0.49151077555179606`}, \
{13.157687612537003`, 0.5034155374565581}], 
           RectangleBox[{14.665944395275735`, 0.49151077555179606`}, \
{14.824272896511733`, 0.5034155374565581}], 
           RectangleBox[{16.16589861751152, 0.49151077555179606`}, \
{16.32419812616352, 0.5034155374565581}], 
           RectangleBox[{17.66582232123783, 0.49151077555179606`}, \
{17.824150822473833`, 0.5034155374565581}], 
           RectangleBox[{19.16574602496414, 0.49151077555179606`}, \
{19.324074526200143`, 0.5034155374565581}], 
           RectangleBox[{37.66487624744408, 0.49151077555179606`}, \
{37.82320474868007, 0.5034155374565581}], 
           RectangleBox[{39.3314615314188, 0.49151077555179606`}, \
{39.4897900326548, 0.5034155374565581}], 
           RectangleBox[{41.16470839564196, 0.49151077555179606`}, \
{41.32303689687795, 0.5034155374565581}], 
           RectangleBox[{43.16461684011353, 0.49151077555179606`}, \
{43.322945341349524`, 0.5034155374565581}], 
           RectangleBox[{45.1645252845851, 0.49151077555179606`}, \
{45.322824793237096`, 0.5034155374565581}], 
           RectangleBox[{47.1644032105472, 0.49151077555179606`}, \
{47.32273171178319, 0.5034155374565581}], 
           RectangleBox[{49.16431165501877, 0.49151077555179606`}, \
{49.322640156254764`, 0.5034155374565581}], 
           RectangleBox[{50.99755851924192, 0.49151077555179606`}, \
{51.15588702047792, 0.5034155374565581}], 
           RectangleBox[{52.83080538346507, 0.49151077555179606`}, \
{52.98913388470107, 0.5034155374565581}], 
           RectangleBox[{54.664052247688225`, 0.49151077555179606`}, \
{54.82238074892422, 0.5034155374565581}], 
           RectangleBox[{56.33063753166295, 0.49151077555179606`}, \
{56.48896603289895, 0.5034155374565581}], 
           RectangleBox[{57.83059175389874, 0.49151077555179606`}, \
{57.98889126255074, 0.5034155374565581}], 
           RectangleBox[{0.6666158024842067, 0.5034155374565581}, \
{0.8249443037202062, 0.5153202993613198}], 
           RectangleBox[{0.8332773827326273, 0.5034155374565581}, \
{0.9916058839686269, 0.5153202993613198}], 
           RectangleBox[{0.999938962981048, 0.5034155374565581}, \
{1.1582674642170476`, 0.5153202993613198}], 
           RectangleBox[{1.1666005432294686`, 0.5034155374565581}, \
{1.3249290444654684`, 0.5153202993613198}], 
           RectangleBox[{6.666341135898922, 0.5034155374565581}, \
{6.824669637134923, 0.5153202993613198}], 
           RectangleBox[{8.166264839625233, 0.5034155374565581}, \
{8.324593340861231, 0.5153202993613198}], 
           RectangleBox[{9.832850123599963, 0.5034155374565581}, \
{9.991178624835962, 0.5153202993613198}], 
           RectangleBox[{11.499435407574694`, 0.5034155374565581}, \
{11.657763908810693`, 0.5153202993613198}], 
           RectangleBox[{13.166020691549425`, 0.5034155374565581}, \
{13.324349192785423`, 0.5153202993613198}], 
           RectangleBox[{14.832605975524155`, 0.5034155374565581}, \
{14.990934476760154`, 0.5153202993613198}], 
           RectangleBox[{16.332529679250467`, 0.5034155374565581}, \
{16.490858180486466`, 0.5153202993613198}], 
           RectangleBox[{17.832483901486253`, 0.5034155374565581}, \
{17.990812402722252`, 0.5153202993613198}], 
           RectangleBox[{19.332407605212563`, 0.5034155374565581}, \
{19.490736106448562`, 0.5153202993613198}], 
           RectangleBox[{20.66566972869045, 0.5034155374565581}, \
{20.823998229926453`, 0.5153202993613198}], 
           RectangleBox[{0., 0.5153202993613198}, \
{0.15829950865199743`, 0.5272250612660818}], 
           RectangleBox[{0.16663106173894468`, 0.5153202993613198}, \
{0.3249595629749443, 0.5272250612660818}], 
           RectangleBox[{0.33329264198736536`, 0.5153202993613198}, \
{0.491621143223365, 0.5272250612660818}], 
           RectangleBox[{0.499954222235786, 0.5153202993613198}, \
{0.6582827234717856, 0.5272250612660818}], 
           RectangleBox[{5.499710074159978, 0.5153202993613198}, \
{5.658038575395977, 0.5272250612660818}], 
           RectangleBox[{6.833002716147344, 0.5153202993613198}, \
{6.991331217383343, 0.5272250612660818}], 
           RectangleBox[{8.332926419873653, 0.5153202993613198}, \
{8.491254921109652, 0.5272250612660818}], 
           RectangleBox[{9.999511703848384, 0.5153202993613198}, \
{10.157840205084383`, 0.5272250612660818}], 
           RectangleBox[{11.666096987823115`, 0.5153202993613198}, \
{11.824425489059113`, 0.5272250612660818}], 
           RectangleBox[{13.332682271797845`, 0.5153202993613198}, \
{13.491010773033844`, 0.5272250612660818}], 
           RectangleBox[{14.999267555772576`, 0.5153202993613198}, \
{15.157596057008575`, 0.5272250612660818}], 
           RectangleBox[{16.499191259498886`, 0.5153202993613198}, \
{16.657519760734885`, 0.5272250612660818}], 
           RectangleBox[{17.999145481734672`, 0.5153202993613198}, \
{18.15744499038667, 0.5272250612660818}], 
           RectangleBox[{19.499069185460982`, 0.5153202993613198}, \
{19.65739768669698, 0.5272250612660818}], 
           RectangleBox[{20.832331308938873`, 0.5153202993613198}, \
{20.990659810174872`, 0.5272250612660818}], 
           RectangleBox[{21.99893185216834, 0.5153202993613198}, \
{22.15726035340434, 0.5272250612660818}], 
           RectangleBox[{34.99832148197882, 0.5153202993613198}, \
{35.15664998321482, 0.5272250612660818}], 
           RectangleBox[{36.33158360545671, 0.5153202993613198}, \
{36.48991210669271, 0.5272250612660818}], 
           RectangleBox[{37.83153782769249, 0.5153202993613198}, \
{37.98983733634449, 0.5272250612660818}], 
           RectangleBox[{39.498123111667226`, 0.5153202993613198}, \
{39.656451612903226`, 0.5272250612660818}], 
           RectangleBox[{41.331369975890375`, 0.5153202993613198}, \
{41.489698477126375`, 0.5272250612660818}], 
           RectangleBox[{43.33127842036195, 0.5153202993613198}, \
{43.48957792901395, 0.5272250612660818}], 
           RectangleBox[{45.33115634632404, 0.5153202993613198}, \
{45.48948484756004, 0.5272250612660818}], 
           RectangleBox[{47.331064790795615`, 0.5153202993613198}, \
{47.489393292031615`, 0.5272250612660818}], 
           RectangleBox[{49.33097323526719, 0.5153202993613198}, \
{49.48930173650319, 0.5272250612660818}], 
           RectangleBox[{51.16422009949034, 0.5153202993613198}, \
{51.322548600726336`, 0.5272250612660818}], 
           RectangleBox[{52.99746696371349, 0.5153202993613198}, \
{53.15579546494949, 0.5272250612660818}], 
           RectangleBox[{54.83071382793664, 0.5153202993613198}, \
{54.98904232917264, 0.5272250612660818}], 
           RectangleBox[{56.497299111911374`, 0.5153202993613198}, \
{56.655627613147374`, 0.5272250612660818}], 
           RectangleBox[{57.997222815637684`, 0.5153202993613198}, \
{58.155551316873684`, 0.5272250612660818}], 
           RectangleBox[{59.33051545762505, 0.5153202993613198}, \
{59.48884395886105, 0.5272250612660818}], 
           RectangleBox[{60.66377758110294, 0.5153202993613198}, \
{60.822106082338934`, 0.5272250612660818}], 
           RectangleBox[{4.49977111117893, 0.5272250612660818}, \
{4.658099612414929, 0.5391298231708438}], 
           RectangleBox[{5.666371654408398, 0.5272250612660818}, \
{5.824700155644399, 0.5391298231708438}], 
           RectangleBox[{6.999664296395764, 0.5272250612660818}, \
{7.157992797631763, 0.5391298231708438}], 
           RectangleBox[{8.499588000122074, 0.5272250612660818}, \
{8.657916501358073, 0.5391298231708438}], 
           RectangleBox[{10.166173284096805`, 0.5272250612660818}, \
{10.324501785332803`, 0.5391298231708438}], 
           RectangleBox[{11.832758568071535`, 0.5272250612660818}, \
{11.991087069307534`, 0.5391298231708438}], 
           RectangleBox[{13.499343852046266`, 0.5272250612660818}, \
{13.657672353282265`, 0.5391298231708438}], 
           RectangleBox[{15.165929136020997`, 0.5272250612660818}, \
{15.324257637256995`, 0.5391298231708438}], 
           RectangleBox[{16.665852839747306`, 0.5272250612660818}, \
{16.82418134098331, 0.5391298231708438}], 
           RectangleBox[{18.165776543473616`, 0.5272250612660818}, \
{18.32410504470962, 0.5391298231708438}], 
           RectangleBox[{19.6657307657094, 0.5272250612660818}, \
{19.824059266945405`, 0.5391298231708438}], 
           RectangleBox[{20.998992889187292`, 0.5272250612660818}, \
{21.15732139042329, 0.5391298231708438}], 
           RectangleBox[{22.16559343241676, 0.5272250612660818}, \
{22.323921933652763`, 0.5391298231708438}], 
           RectangleBox[{23.165562913907284`, 0.5272250612660818}, \
{23.323891415143287`, 0.5391298231708438}], 
           RectangleBox[{3.666463209936827, 0.5391298231708438}, \
{3.8247917111728262`, 0.5510345850756055}], 
           RectangleBox[{4.66643269142735, 0.5391298231708438}, \
{4.824761192663351, 0.5510345850756055}], 
           RectangleBox[{5.83303323465682, 0.5391298231708438}, \
{5.991361735892819, 0.5510345850756055}], 
           RectangleBox[{7.166325876644184, 0.5391298231708438}, \
{7.324625385296183, 0.5510345850756055}], 
           RectangleBox[{8.666249580370495, 0.5391298231708438}, \
{8.824578081606493, 0.5510345850756055}], 
           RectangleBox[{10.332834864345225`, 0.5391298231708438}, \
{10.491163365581224`, 0.5510345850756055}], 
           RectangleBox[{11.999420148319956`, 0.5391298231708438}, \
{12.157748649555955`, 0.5510345850756055}], 
           RectangleBox[{13.666005432294687`, 0.5391298231708438}, \
{13.824333933530685`, 0.5510345850756055}], 
           RectangleBox[{15.332590716269417`, 0.5391298231708438}, \
{15.490919217505416`, 0.5510345850756055}], 
           RectangleBox[{16.83251441999573, 0.5391298231708438}, \
{16.990842921231728`, 0.5510345850756055}], 
           RectangleBox[{18.33243812372204, 0.5391298231708438}, \
{18.490766624958038`, 0.5510345850756055}], 
           RectangleBox[{19.832392345957825`, 0.5391298231708438}, \
{19.99069185460982, 0.5510345850756055}], 
           RectangleBox[{21.16565446943571, 0.5391298231708438}, \
{21.323982970671715`, 0.5510345850756055}], 
           RectangleBox[{22.332255012665183`, 0.5391298231708438}, \
{22.490583513901182`, 0.5510345850756055}], 
           RectangleBox[{23.332224494155707`, 0.5391298231708438}, \
{23.490552995391706`, 0.5510345850756055}], 
           RectangleBox[{24.16550187688833, 0.5391298231708438}, \
{24.323830378124335`, 0.5510345850756055}], 
           RectangleBox[{32.66508987701041, 0.5391298231708438}, \
{32.8234183782464, 0.5510345850756055}], 
           RectangleBox[{33.83172093874935, 0.5391298231708438}, \
{33.99004943998535, 0.5510345850756055}], 
           RectangleBox[{35.16498306222724, 0.5391298231708438}, \
{35.323311563463236`, 0.5510345850756055}], 
           RectangleBox[{36.49824518570513, 0.5391298231708438}, \
{36.65657368694113, 0.5510345850756055}], 
           RectangleBox[{37.99816888943144, 0.5391298231708438}, \
{38.15649739066744, 0.5510345850756055}], 
           RectangleBox[{39.66478469191565, 0.5391298231708438}, \
{39.82308420056764, 0.5510345850756055}], 
           RectangleBox[{41.4980315561388, 0.5391298231708438}, \
{41.6563310647908, 0.5510345850756055}], 
           RectangleBox[{43.497909482100894`, 0.5391298231708438}, \
{43.656237983336894`, 0.5510345850756055}], 
           RectangleBox[{45.497817926572466`, 0.5391298231708438}, \
{45.656146427808466`, 0.5510345850756055}], 
           RectangleBox[{47.49772637104404, 0.5391298231708438}, \
{47.65605487228004, 0.5510345850756055}], 
           RectangleBox[{49.49763481551561, 0.5391298231708438}, \
{49.65596331675161, 0.5510345850756055}], 
           RectangleBox[{51.33088167973876, 0.5391298231708438}, \
{51.48921018097476, 0.5510345850756055}], 
           RectangleBox[{53.164128543961915`, 0.5391298231708438}, \
{53.32245704519791, 0.5510345850756055}], 
           RectangleBox[{54.997375408185064`, 0.5391298231708438}, \
{55.155703909421064`, 0.5510345850756055}], 
           RectangleBox[{56.6639606921598, 0.5391298231708438}, \
{56.82228919339579, 0.5510345850756055}], 
           RectangleBox[{58.16388439588611, 0.5391298231708438}, \
{58.3222128971221, 0.5510345850756055}], 
           RectangleBox[{59.49717703787347, 0.5391298231708438}, \
{59.65550553910947, 0.5510345850756055}], 
           RectangleBox[{60.83043916135136, 0.5391298231708438}, \
{60.98876766258736, 0.5510345850756055}], 
           RectangleBox[{61.99703970458083, 0.5391298231708438}, \
{62.15536820581683, 0.5510345850756055}], 
           RectangleBox[{63.163670766319775`, 0.5391298231708438}, \
{63.32199926755577, 0.5510345850756055}], 
           RectangleBox[{1.3332621234778894`, 0.5510345850756055}, \
{1.491590624713889, 0.5629393469803675}], 
           RectangleBox[{1.49992370372631, 0.5510345850756055}, \
{1.6582522049623096`, 0.5629393469803675}], 
           RectangleBox[{1.6665852839747306`, 0.5510345850756055}, \
{1.8248847926267282`, 0.5629393469803675}], 
           RectangleBox[{1.8332163457136754`, 0.5510345850756055}, \
{1.991544846949675, 0.5629393469803675}], 
           RectangleBox[{2.99984740745262, 0.5510345850756055}, \
{3.15817590868862, 0.5629393469803675}], 
           RectangleBox[{3.833124790185247, 0.5510345850756055}, \
{3.991453291421247, 0.5629393469803675}], 
           RectangleBox[{4.833094271675772, 0.5510345850756055}, \
{4.991422772911771, 0.5629393469803675}], 
           RectangleBox[{5.99969481490524, 0.5510345850756055}, \
{6.158023316141239, 0.5629393469803675}], 
           
           RectangleBox[{7.33295693838313, 0.5510345850756055}, \
{7.491285439619129, 0.5629393469803675}], 
           RectangleBox[{8.832911160618915, 0.5510345850756055}, \
{8.991210669270913, 0.5629393469803675}], 
           RectangleBox[{10.499496444593646`, 0.5510345850756055}, \
{10.657824945829645`, 0.5629393469803675}], 
           RectangleBox[{12.166081728568377`, 0.5510345850756055}, \
{12.324410229804375`, 0.5629393469803675}], 
           RectangleBox[{13.832667012543107`, 0.5510345850756055}, \
{13.990995513779106`, 0.5629393469803675}], 
           RectangleBox[{15.499252296517838`, 0.5510345850756055}, \
{15.657580797753837`, 0.5629393469803675}], 
           RectangleBox[{16.999176000244148`, 0.5510345850756055}, \
{17.157504501480147`, 0.5629393469803675}], 
           RectangleBox[{18.499099703970458`, 0.5510345850756055}, \
{18.657428205206458`, 0.5629393469803675}], 
           RectangleBox[{19.999023407696768`, 0.5510345850756055}, \
{20.157351908932768`, 0.5629393469803675}], 
           RectangleBox[{21.332316049684135`, 0.5510345850756055}, \
{21.490644550920134`, 0.5629393469803675}], 
           RectangleBox[{22.498916592913602`, 0.5510345850756055}, \
{22.6572450941496, 0.5629393469803675}], 
           RectangleBox[{23.498886074404126`, 0.5510345850756055}, \
{23.657185583056123`, 0.5629393469803675}], 
           RectangleBox[{24.332163457136755`, 0.5510345850756055}, \
{24.490491958372754`, 0.5629393469803675}], 
           RectangleBox[{24.998809778130436`, 0.5510345850756055}, \
{25.157138279366436`, 0.5629393469803675}], 
           RectangleBox[{2.499862666707358, 0.5629393469803675}, \
{2.658191167943358, 0.5748441088851295}], 
           RectangleBox[{3.166508987701041, 0.5629393469803675}, \
{3.3248374889370402`, 0.5748441088851295}], 
           RectangleBox[{3.999786370433668, 0.5629393469803675}, \
{4.158114871669667, 0.5748441088851295}], 
           RectangleBox[{4.999755851924192, 0.5629393469803675}, \
{5.158084353160191, 0.5748441088851295}], 
           RectangleBox[{6.16635639515366, 0.5629393469803675}, \
{6.324684896389661, 0.5748441088851295}], 
           
           RectangleBox[{7.49961851863155, 0.5629393469803675}, \
{7.657947019867549, 0.5748441088851295}], 
           RectangleBox[{8.99954222235786, 0.5629393469803675}, \
{9.15787072359386, 0.5748441088851295}], 
           RectangleBox[{10.666158024842067`, 0.5629393469803675}, \
{10.824486526078065`, 0.5748441088851295}], 
           RectangleBox[{12.332743308816797`, 0.5629393469803675}, \
{12.491071810052796`, 0.5748441088851295}], 
           RectangleBox[{13.999328592791528`, 0.5629393469803675}, \
{14.157657094027527`, 0.5748441088851295}], 
           RectangleBox[{15.66591387676626, 0.5629393469803675}, \
{15.824242378002257`, 0.5748441088851295}], 
           RectangleBox[{17.165837580492568`, 0.5629393469803675}, \
{17.32416608172857, 0.5748441088851295}], 
           RectangleBox[{18.665761284218878`, 0.5629393469803675}, \
{18.82408978545488, 0.5748441088851295}], 
           RectangleBox[{20.165684987945188`, 0.5629393469803675}, \
{20.32401348918119, 0.5748441088851295}], 
           RectangleBox[{21.498977629932554`, 0.5629393469803675}, \
{21.657306131168554`, 0.5748441088851295}], 
           RectangleBox[{22.66557817316202, 0.5629393469803675}, \
{22.823906674398025`, 0.5748441088851295}], 
           RectangleBox[{23.66551713614307, 0.5629393469803675}, \
{23.823845637379073`, 0.5748441088851295}], 
           RectangleBox[{24.498825037385174`, 0.5629393469803675}, \
{24.657153538621174`, 0.5748441088851295}], 
           RectangleBox[{25.165471358378856`, 0.5629393469803675}, \
{25.32379985961486, 0.5748441088851295}], 
           RectangleBox[{25.66542558061464, 0.5629393469803675}, \
{25.823754081850645`, 0.5748441088851295}], 
           RectangleBox[{30.66521195104831, 0.5629393469803675}, \
{30.82351145970031, 0.5748441088851295}], 
           RectangleBox[{31.665150914029358`, 0.5629393469803675}, \
{31.82347941526536, 0.5748441088851295}], 
           RectangleBox[{32.831751457258825`, 0.5629393469803675}, \
{32.990079958494825`, 0.5748441088851295}], 
           RectangleBox[{33.99838251899777, 0.5629393469803675}, \
{34.15671102023377, 0.5748441088851295}], 
           
           RectangleBox[{35.33164464247566, 0.5629393469803675}, \
{35.48997314371166, 0.5748441088851295}], 
           RectangleBox[{36.66490676595355, 0.5629393469803675}, \
{36.823235267189546`, 0.5748441088851295}], 
           RectangleBox[{38.16483046967986, 0.5629393469803675}, \
{38.323158970915856`, 0.5748441088851295}], 
           RectangleBox[{39.83141575365459, 0.5629393469803675}, \
{39.98974425489059, 0.5748441088851295}], 
           RectangleBox[{41.664662617877745`, 0.5629393469803675}, \
{41.82299111911374, 0.5748441088851295}], 
           RectangleBox[{43.66457106234932, 0.5629393469803675}, \
{43.82289956358531, 0.5748441088851295}], 
           RectangleBox[{45.66447950682089, 0.5629393469803675}, \
{45.82280800805688, 0.5748441088851295}], 
           RectangleBox[{47.66438795129246, 0.5629393469803675}, \
{47.822716452528454`, 0.5748441088851295}], 
           RectangleBox[{49.66429639576403, 0.5629393469803675}, \
{49.822624897000026`, 0.5748441088851295}], 
           RectangleBox[{51.49754325998718, 0.5629393469803675}, \
{51.65587176122318, 0.5748441088851295}], 
           RectangleBox[{53.33079012421033, 0.5629393469803675}, \
{53.48911862544633, 0.5748441088851295}], 
           RectangleBox[{55.16403698843349, 0.5629393469803675}, \
{55.32236548966948, 0.5748441088851295}], 
           RectangleBox[{56.83062227240821, 0.5629393469803675}, \
{56.98895077364421, 0.5748441088851295}], 
           RectangleBox[{58.33054597613452, 0.5629393469803675}, \
{58.48887447737052, 0.5748441088851295}], 
           RectangleBox[{59.66383861812189, 0.5629393469803675}, \
{59.822138126773886`, 0.5748441088851295}], 
           RectangleBox[{60.99710074159978, 0.5629393469803675}, \
{61.15542924283578, 0.5748441088851295}], 
           RectangleBox[{62.16370128482925, 0.5629393469803675}, \
{62.322029786065244`, 0.5748441088851295}], 
           RectangleBox[{63.33033234656819, 0.5629393469803675}, \
{63.48863185522019, 0.5748441088851295}], 
           RectangleBox[{64.33027130954925, 0.5629393469803675}, \
{64.48859981078525, 0.5748441088851295}], 
           RectangleBox[{65.3302102725303, 0.5629393469803675}, 
            {65.4885387737663, 0.5748441088851295}], 
           RectangleBox[{2.166539506210517, 0.5748441088851295}, \
{2.3248680074465162`, 0.5867488707898912}], 
           RectangleBox[{2.666524246955779, 0.5748441088851295}, \
{2.8248527481917782`, 0.5867488707898912}], 
           RectangleBox[{3.333170567949461, 0.5748441088851295}, \
{3.491499069185461, 0.5867488707898912}], 
           RectangleBox[{4.166447950682088, 0.5748441088851295}, \
{4.324776451918089, 0.5867488707898912}], 
           RectangleBox[{5.166417432172612, 0.5748441088851295}, \
{5.324745933408613, 0.5867488707898912}], 
           RectangleBox[{6.333017975402082, 0.5748441088851295}, \
{6.491346476638081, 0.5867488707898912}], 
           RectangleBox[{7.66628009887997, 0.5748441088851295}, \
{7.824608600115971, 0.5867488707898912}], 
           RectangleBox[{9.166203802606281, 0.5748441088851295}, \
{9.324532303842279, 0.5867488707898912}], 
           RectangleBox[{10.832819605090487`, 0.5748441088851295}, \
{10.991119113742485`, 0.5867488707898912}], 
           RectangleBox[{12.499404889065218`, 0.5748441088851295}, \
{12.657733390301217`, 0.5867488707898912}], 
           RectangleBox[{14.16599017303995, 0.5748441088851295}, \
{14.324318674275947`, 0.5867488707898912}], 
           RectangleBox[{15.832575457014679`, 0.5748441088851295}, \
{15.990903958250678`, 0.5867488707898912}], 
           RectangleBox[{17.33249916074099, 0.5748441088851295}, \
{17.49082766197699, 0.5867488707898912}], 
           RectangleBox[{18.8324228644673, 0.5748441088851295}, \
{18.9907513657033, 0.5867488707898912}], 
           RectangleBox[{20.33234656819361, 0.5748441088851295}, \
{20.49067506942961, 0.5867488707898912}], 
           RectangleBox[{21.665639210180974`, 0.5748441088851295}, \
{21.823938718832974`, 0.5867488707898912}], 
           RectangleBox[{22.832239753410445`, 0.5748441088851295}, \
{22.990568254646444`, 0.5867488707898912}], 
           RectangleBox[{23.832178716391493`, 0.5748441088851295}, \
{23.990507217627492`, 0.5867488707898912}], 
           RectangleBox[{24.665486617633594`, 0.5748441088851295}, \
{24.823815118869597`, 0.5867488707898912}], 
           RectangleBox[{25.33213293862728, 0.5748441088851295}, \
{25.490432447279275`, 0.5867488707898912}], 
           RectangleBox[{25.832087160863065`, 0.5748441088851295}, \
{25.990415662099064`, 0.5867488707898912}], 
           RectangleBox[{26.165410321359904`, 0.5748441088851295}, \
{26.323738822595907`, 0.5867488707898912}], 
           RectangleBox[{1.999877925962096, 0.5867488707898912}, \
{2.158206427198096, 0.5986536326946532}], 
           RectangleBox[{2.333201086458937, 0.5867488707898912}, \
{2.491529587694937, 0.5986536326946532}], 
           RectangleBox[{2.833185827204199, 0.5867488707898912}, \
{2.991514328440199, 0.5986536326946532}], 
           RectangleBox[{3.499832148197882, 0.5867488707898912}, \
{3.6581316568498794`, 0.5986536326946532}], 
           RectangleBox[{4.33310953093051, 0.5867488707898912}, \
{4.491438032166509, 0.5986536326946532}], 
           RectangleBox[{5.333079012421034, 0.5867488707898912}, \
{5.491378521073031, 0.5986536326946532}], 
           RectangleBox[{6.499679555650502, 0.5867488707898912}, \
{6.658008056886501, 0.5986536326946532}], 
           RectangleBox[{7.832941679128392, 0.5867488707898912}, \
{7.991270180364391, 0.5986536326946532}], 
           RectangleBox[{9.3328653828547, 0.5867488707898912}, \
{9.4911938840907, 0.5986536326946532}], 
           RectangleBox[{10.999450666829432`, 0.5867488707898912}, \
{11.157779168065431`, 0.5986536326946532}], 
           RectangleBox[{12.66606646931364, 0.5867488707898912}, \
{12.824365977965636`, 0.5986536326946532}], 
           RectangleBox[{14.332651753288369`, 0.5867488707898912}, \
{14.490951261940367`, 0.5986536326946532}], 
           RectangleBox[{15.9992370372631, 0.5867488707898912}, \
{16.1575655384991, 0.5986536326946532}], 
           RectangleBox[{17.49916074098941, 0.5867488707898912}, \
{17.65748924222541, 0.5986536326946532}], 
           RectangleBox[{18.99908444471572, 0.5867488707898912}, \
{19.15741294595172, 0.5986536326946532}], 
           RectangleBox[{20.49900814844203, 0.5867488707898912}, \
{20.65733664967803, 0.5986536326946532}], 
           
           RectangleBox[{21.83227027191992, 0.5867488707898912}, \
{21.99059877315592, 0.5986536326946532}], 
           RectangleBox[{22.998901333658864`, 0.5867488707898912}, \
{23.157229834894864`, 0.5986536326946532}], 
           RectangleBox[{23.998840296639912`, 0.5867488707898912}, \
{24.15716879787591, 0.5986536326946532}], 
           RectangleBox[{24.832148197882017`, 0.5867488707898912}, \
{24.990476699118016`, 0.5986536326946532}], 
           RectangleBox[{25.498764000366222`, 0.5867488707898912}, \
{25.65709250160222, 0.5986536326946532}], 
           RectangleBox[{25.998748741111484`, 0.5867488707898912}, \
{26.157077242347484`, 0.5986536326946532}], 
           RectangleBox[{26.332071901608327`, 0.5867488707898912}, \
{26.490400402844326`, 0.5986536326946532}], 
           RectangleBox[{26.498733481856746`, 0.5867488707898912}, \
{26.657061983092746`, 0.5986536326946532}], 
           RectangleBox[{28.998596148564104`, 0.5867488707898912}, \
{29.156924649800104`, 0.5986536326946532}], 
           RectangleBox[{29.83190404980621, 0.5867488707898912}, \
{29.990232551042208`, 0.5986536326946532}], 
           RectangleBox[{30.831843012787257`, 0.5867488707898912}, \
{30.990171514023256`, 0.5986536326946532}], 
           RectangleBox[{31.83181249427778, 0.5867488707898912}, \
{31.99014099551378, 0.5986536326946532}], 
           RectangleBox[{32.99841303750725, 0.5867488707898912}, \
{33.15674153874325, 0.5986536326946532}], 
           RectangleBox[{34.165044099246195`, 0.5867488707898912}, \
{34.32334360789819, 0.5986536326946532}], 
           RectangleBox[{35.49830622272408, 0.5867488707898912}, \
{35.65663472396008, 0.5986536326946532}], 
           RectangleBox[{36.83156834620197, 0.5867488707898912}, \
{36.98989684743797, 0.5986536326946532}], 
           RectangleBox[{38.33149204992828, 0.5867488707898912}, \
{38.48982055116428, 0.5986536326946532}], 
           RectangleBox[{39.99807733390301, 0.5867488707898912}, \
{40.15640583513901, 0.5986536326946532}], 
           RectangleBox[{41.83132419812616, 0.5867488707898912}, \
{41.98965269936216, 0.5986536326946532}], 
           
           RectangleBox[{43.83123264259773, 0.5867488707898912}, \
{43.98956114383373, 0.5986536326946532}], 
           RectangleBox[{45.831141087069305`, 0.5867488707898912}, \
{45.989469588305305`, 0.5986536326946532}], 
           RectangleBox[{47.83104953154088, 0.5867488707898912}, \
{47.98937803277688, 0.5986536326946532}], 
           RectangleBox[{49.83095797601245, 0.5867488707898912}, \
{49.98928647724845, 0.5986536326946532}], 
           RectangleBox[{51.664204840235605`, 0.5867488707898912}, \
{51.8225333414716, 0.5986536326946532}], 
           RectangleBox[{53.497451704458754`, 0.5867488707898912}, \
{53.655780205694754`, 0.5986536326946532}], 
           RectangleBox[{55.3306985686819, 0.5867488707898912}, \
{55.4890270699179, 0.5986536326946532}], 
           RectangleBox[{56.997283852656636`, 0.5867488707898912}, \
{57.155612353892636`, 0.5986536326946532}], 
           RectangleBox[{58.497207556382946`, 0.5867488707898912}, \
{58.655536057618946`, 0.5986536326946532}], 
           RectangleBox[{59.83046967986083, 0.5867488707898912}, \
{59.98879818109683, 0.5986536326946532}], 
           RectangleBox[{61.1637623218482, 0.5867488707898912}, \
{61.322090823084196`, 0.5986536326946532}], 
           RectangleBox[{62.33036286507767, 0.5867488707898912}, \
{62.48869136631367, 0.5986536326946532}], 
           RectangleBox[{63.49696340830714, 0.5867488707898912}, \
{63.65529190954314, 0.5986536326946532}], 
           RectangleBox[{64.49693288979766, 0.5867488707898912}, \
{64.65526139103366, 0.5986536326946532}], 
           RectangleBox[{65.49687185277871, 0.5867488707898912}, \
{65.65520035401471, 0.5986536326946532}], 
           RectangleBox[{66.33017975402082, 0.5867488707898912}, \
{66.48850825525682, 0.5986536326946532}], 
           RectangleBox[{67.16345713675344, 0.5867488707898912}, \
{67.32178563798945, 0.5986536326946532}], 
           RectangleBox[{26.665395062105166`, 0.5986536326946532}, \
{26.82372356334117, 0.610558394599415}], 
           RectangleBox[{26.83205664235359, 0.5986536326946532}, \
{26.990385143589588`, 0.610558394599415}], 
           RectangleBox[{26.998718222602008`, 0.5986536326946532}, 
            {27.157017731254005`, 0.610558394599415}], 
           RectangleBox[{27.16534928434095, 0.5986536326946532}, \
{27.323677785576955`, 0.610558394599415}], 
           RectangleBox[{28.3319803460799, 0.5986536326946532}, \
{28.490308847315898`, 0.610558394599415}], 
           RectangleBox[{29.165257728812524`, 0.5986536326946532}, \
{29.323586230048527`, 0.610558394599415}], 
           RectangleBox[{29.998565630054628`, 0.5986536326946532}, \
{30.156894131290628`, 0.610558394599415}], 
           RectangleBox[{30.998504593035676`, 0.5986536326946532}, \
{31.156833094271676`, 0.610558394599415}], 
           RectangleBox[{31.9984740745262, 0.5986536326946532}, \
{32.1568025757622, 0.610558394599415}], 
           RectangleBox[{33.16507461775567, 0.5986536326946532}, \
{33.32340311899166, 0.610558394599415}], 
           RectangleBox[{34.331675160985135`, 0.5986536326946532}, \
{34.490003662221135`, 0.610558394599415}], 
           RectangleBox[{35.664967802972505`, 0.5986536326946532}, \
{35.8232963042085, 0.610558394599415}], 
           RectangleBox[{36.99822992645039, 0.5986536326946532}, \
{37.15655842768639, 0.610558394599415}], 
           RectangleBox[{38.4981536301767, 0.5986536326946532}, \
{38.6564821314127, 0.610558394599415}], 
           RectangleBox[{40.164738914151435`, 0.5986536326946532}, \
{40.32306741538743, 0.610558394599415}], 
           RectangleBox[{41.997985778374584`, 0.5986536326946532}, \
{42.156314279610584`, 0.610558394599415}], 
           RectangleBox[{43.997894222846156`, 0.5986536326946532}, \
{44.156222724082156`, 0.610558394599415}], 
           RectangleBox[{45.99780266731773, 0.5986536326946532}, \
{46.15613116855373, 0.610558394599415}], 
           RectangleBox[{47.9977111117893, 0.5986536326946532}, \
{48.1560396130253, 0.610558394599415}], 
           RectangleBox[{49.99761955626087, 0.5986536326946532}, \
{50.15594805749687, 0.610558394599415}], 
           RectangleBox[{51.83086642048402, 0.5986536326946532}, \
{51.98919492172002, 0.610558394599415}], 
           RectangleBox[{53.66411328470718, 0.5986536326946532}, \
{53.82244178594317, 0.610558394599415}], 
           
           RectangleBox[{55.497360148930326`, 0.5986536326946532}, \
{55.655688650166326`, 0.610558394599415}], 
           RectangleBox[{57.16394543290506, 0.5986536326946532}, \
{57.32227393414105, 0.610558394599415}], 
           RectangleBox[{58.66386913663137, 0.5986536326946532}, \
{58.82219763786736, 0.610558394599415}], 
           RectangleBox[{59.997131260109256`, 0.5986536326946532}, \
{60.155459761345256`, 0.610558394599415}], 
           RectangleBox[{61.33042390209662, 0.5986536326946532}, \
{61.48872341074862, 0.610558394599415}], 
           RectangleBox[{62.49702444532609, 0.5986536326946532}, \
{62.65535294656209, 0.610558394599415}], 
           RectangleBox[{63.66362498855556, 0.5986536326946532}, \
{63.821953489791554`, 0.610558394599415}], 
           RectangleBox[{64.66359447004608, 0.5986536326946532}, \
{64.82192297128209, 0.610558394599415}], 
           RectangleBox[{65.66353343302713, 0.5986536326946532}, \
{65.82186193426314, 0.610558394599415}], 
           RectangleBox[{66.49684133426923, 0.5986536326946532}, \
{66.65516983550523, 0.610558394599415}], 
           RectangleBox[{67.33011871700187, 0.5986536326946532}, \
{67.48844721823787, 0.610558394599415}], 
           RectangleBox[{67.99676503799554, 0.5986536326946532}, \
{68.15509353923154, 0.610558394599415}], 
           RectangleBox[{27.831995605334637`, 0.610558394599415}, \
{27.990324106570636`, 0.6224631565041769}], 
           RectangleBox[{28.498641926328318`, 0.610558394599415}, \
{28.656970427564318`, 0.6224631565041769}], 
           RectangleBox[{29.331919309060947`, 0.610558394599415}, \
{29.490247810296946`, 0.6224631565041769}], 
           RectangleBox[{30.165227210303048`, 0.610558394599415}, \
{30.32355571153905, 0.6224631565041769}], 
           RectangleBox[{31.165166173284096`, 0.610558394599415}, \
{31.3234946745201, 0.6224631565041769}], 
           RectangleBox[{32.16513565477462, 0.610558394599415}, \
{32.323464156010616`, 0.6224631565041769}], 
           RectangleBox[{33.33173619800409, 0.610558394599415}, \
{33.49006469924009, 0.6224631565041769}], 
           RectangleBox[{34.49833674123356, 0.610558394599415}, 
            {34.65666524246956, 0.6224631565041769}], 
           RectangleBox[{35.83162938322092, 0.610558394599415}, \
{35.98995788445692, 0.6224631565041769}], 
           RectangleBox[{37.164891506698815`, 0.610558394599415}, \
{37.32322000793481, 0.6224631565041769}], 
           RectangleBox[{38.664815210425125`, 0.610558394599415}, \
{38.82314371166112, 0.6224631565041769}], 
           RectangleBox[{40.33140049439985, 0.610558394599415}, \
{40.48972899563585, 0.6224631565041769}], 
           RectangleBox[{42.16464735862301, 0.610558394599415}, \
{42.322975859859, 0.6224631565041769}], 
           RectangleBox[{44.16455580309458, 0.610558394599415}, \
{44.32288430433057, 0.6224631565041769}], 
           RectangleBox[{46.16446424756615, 0.610558394599415}, \
{46.322792748802144`, 0.6224631565041769}], 
           RectangleBox[{48.16437269203772, 0.610558394599415}, \
{48.322701193273716`, 0.6224631565041769}], 
           RectangleBox[{50.164281136509295`, 0.610558394599415}, \
{50.32260963774529, 0.6224631565041769}], 
           RectangleBox[{51.997528000732444`, 0.610558394599415}, \
{52.155856501968444`, 0.6224631565041769}], 
           RectangleBox[{53.83077486495559, 0.610558394599415}, \
{53.98910336619159, 0.6224631565041769}], 
           RectangleBox[{55.66402172917875, 0.610558394599415}, \
{55.82235023041474, 0.6224631565041769}], 
           RectangleBox[{57.330607013153475`, 0.610558394599415}, \
{57.488935514389475`, 0.6224631565041769}], 
           RectangleBox[{58.830530716879785`, 0.610558394599415}, \
{58.988859218115785`, 0.6224631565041769}], 
           RectangleBox[{60.16379284035768, 0.610558394599415}, \
{60.32212134159367, 0.6224631565041769}], 
           RectangleBox[{61.497054963835566`, 0.610558394599415}, \
{61.655383465071566`, 0.6224631565041769}], 
           RectangleBox[{62.66368602557451, 0.610558394599415}, \
{62.822014526810506`, 0.6224631565041769}], 
           RectangleBox[{63.83028656880398, 0.610558394599415}, \
{63.98861507003998, 0.6224631565041769}], 
           RectangleBox[{64.83025605029451, 0.610558394599415}, \
{64.98858455153051, 0.6224631565041769}], 
           
           RectangleBox[{65.83019501327556, 0.610558394599415}, \
{65.98852351451156, 0.6224631565041769}], 
           RectangleBox[{66.66350291451765, 0.610558394599415}, \
{66.82183141575366, 0.6224631565041769}], 
           RectangleBox[{67.49678029725028, 0.610558394599415}, \
{67.65510879848628, 0.6224631565041769}], 
           RectangleBox[{68.16342661824396, 0.610558394599415}, \
{68.32175511947997, 0.6224631565041769}], 
           RectangleBox[{68.66341135898922, 0.610558394599415}, \
{68.82171086764123, 0.6224631565041769}], 
           RectangleBox[{27.498672444837794`, 0.6224631565041769}, \
{27.657000946073794`, 0.6343679184089389}], 
           RectangleBox[{27.998657185583056`, 0.6224631565041769}, \
{28.156985686819056`, 0.6343679184089389}], 
           RectangleBox[{28.665303506576738`, 0.6224631565041769}, \
{28.82363200781274, 0.6343679184089389}], 
           RectangleBox[{29.498580889309366`, 0.6224631565041769}, \
{29.656909390545366`, 0.6343679184089389}], 
           RectangleBox[{30.33188879055147, 0.6224631565041769}, \
{30.49021729178747, 0.6343679184089389}], 
           RectangleBox[{31.33182775353252, 0.6224631565041769}, \
{31.490156254768518`, 0.6343679184089389}], 
           RectangleBox[{32.33179723502304, 0.6224631565041769}, \
{32.49012573625904, 0.6343679184089389}], 
           RectangleBox[{33.49839777825251, 0.6224631565041769}, \
{33.65672627948851, 0.6343679184089389}], 
           RectangleBox[{34.66499832148198, 0.6224631565041769}, \
{34.82332682271797, 0.6343679184089389}], 
           RectangleBox[{35.998290963469344`, 0.6224631565041769}, \
{36.156619464705344`, 0.6343679184089389}], 
           RectangleBox[{37.33155308694723, 0.6224631565041769}, \
{37.48988158818323, 0.6343679184089389}], 
           RectangleBox[{38.83147679067354, 0.6224631565041769}, \
{38.98980529190954, 0.6343679184089389}], 
           RectangleBox[{40.498062074648274`, 0.6224631565041769}, \
{40.656390575884274`, 0.6343679184089389}], 
           RectangleBox[{42.33130893887142, 0.6224631565041769}, \
{42.48963744010742, 0.6343679184089389}], 
           RectangleBox[{44.331217383342995`, 0.6224631565041769}, 
            {44.489545884578995`, 0.6343679184089389}], 
           RectangleBox[{46.33112582781457, 0.6224631565041769}, \
{46.48945432905057, 0.6343679184089389}], 
           RectangleBox[{48.33103427228614, 0.6224631565041769}, \
{48.48936277352214, 0.6343679184089389}], 
           RectangleBox[{50.33094271675771, 0.6224631565041769}, \
{50.48927121799371, 0.6343679184089389}], 
           RectangleBox[{52.16418958098087, 0.6224631565041769}, \
{52.32251808221686, 0.6343679184089389}], 
           RectangleBox[{53.997436445204016`, 0.6224631565041769}, \
{54.155764946440016`, 0.6343679184089389}], 
           RectangleBox[{55.830683309427165`, 0.6224631565041769}, \
{55.989011810663165`, 0.6343679184089389}], 
           RectangleBox[{57.4972685934019, 0.6224631565041769}, \
{57.6555970946379, 0.6343679184089389}], 
           RectangleBox[{58.99719229712821, 0.6224631565041769}, \
{59.15552079836421, 0.6343679184089389}], 
           RectangleBox[{60.330454420606095`, 0.6224631565041769}, \
{60.488782921842095`, 0.6343679184089389}], 
           RectangleBox[{61.66371654408399, 0.6224631565041769}, \
{61.82204504531998, 0.6343679184089389}], 
           RectangleBox[{62.83034760582293, 0.6224631565041769}, \
{62.98867610705893, 0.6343679184089389}], 
           RectangleBox[{63.9969481490524, 0.6224631565041769}, \
{64.1552766502884, 0.6343679184089389}], 
           RectangleBox[{64.99691763054292, 0.6224631565041769}, \
{65.15521713919492, 0.6343679184089389}], 
           RectangleBox[{65.99685659352397, 0.6224631565041769}, \
{66.15518509475997, 0.6343679184089389}], 
           RectangleBox[{66.83016449476608, 0.6224631565041769}, \
{66.98846400341807, 0.6343679184089389}], 
           RectangleBox[{67.6634418774987, 0.6224631565041769}, \
{67.82177037873471, 0.6343679184089389}], 
           RectangleBox[{68.33008819849239, 0.6224631565041769}, \
{68.48841669972839, 0.6343679184089389}], 
           RectangleBox[{68.83004242072818, 0.6224631565041769}, \
{68.98837092196418, 0.6343679184089389}], 
           RectangleBox[{69.16336558122501, 0.6224631565041769}, \
{69.32169408246102, 0.6343679184089389}], 
           
           RectangleBox[{27.332010864589375`, 0.6343679184089389}, \
{27.490339365825374`, 0.646272680313701}], 
           RectangleBox[{27.665334025086214`, 0.6343679184089389}, \
{27.823662526322217`, 0.646272680313701}], 
           RectangleBox[{28.165318765831476`, 0.6343679184089389}, \
{28.32364726706748, 0.646272680313701}], 
           RectangleBox[{28.83196508682516, 0.6343679184089389}, \
{28.990264595477157`, 0.646272680313701}], 
           RectangleBox[{29.665242469557786`, 0.6343679184089389}, \
{29.82357097079379, 0.646272680313701}], 
           RectangleBox[{30.49855037079989, 0.6343679184089389}, \
{30.65687887203589, 0.646272680313701}], 
           RectangleBox[{31.498489333780938`, 0.6343679184089389}, \
{31.656817835016938`, 0.646272680313701}], 
           RectangleBox[{32.49845881527146, 0.6343679184089389}, \
{32.65675832392346, 0.646272680313701}], 
           RectangleBox[{33.66505935850093, 0.6343679184089389}, \
{33.823387859736926`, 0.646272680313701}], 
           RectangleBox[{34.8316599017304, 0.6343679184089389}, \
{34.9899884029664, 0.646272680313701}], 
           RectangleBox[{36.16495254371777, 0.6343679184089389}, \
{36.32325205236976, 0.646272680313701}], 
           RectangleBox[{37.498214667195654`, 0.6343679184089389}, \
{37.656543168431654`, 0.646272680313701}], 
           RectangleBox[{38.998138370921964`, 0.6343679184089389}, \
{39.156466872157964`, 0.646272680313701}], 
           RectangleBox[{40.6647236548967, 0.6343679184089389}, \
{40.82305215613269, 0.646272680313701}], 
           RectangleBox[{42.497970519119846`, 0.6343679184089389}, \
{42.656299020355846`, 0.646272680313701}], 
           RectangleBox[{44.49787896359142, 0.6343679184089389}, \
{44.65620746482742, 0.646272680313701}], 
           RectangleBox[{46.49778740806299, 0.6343679184089389}, \
{46.65611590929899, 0.646272680313701}], 
           RectangleBox[{48.49769585253456, 0.6343679184089389}, \
{48.65602435377056, 0.646272680313701}], 
           RectangleBox[{50.497604297006134`, 0.6343679184089389}, \
{50.655903805658134`, 0.646272680313701}], 
           RectangleBox[{52.33085116122928, 0.6343679184089389}, 
            {52.48915066988128, 0.646272680313701}], 
           RectangleBox[{54.16409802545244, 0.6343679184089389}, \
{54.32239753410443, 0.646272680313701}], 
           RectangleBox[{55.99734488967559, 0.6343679184089389}, \
{56.15564439832759, 0.646272680313701}], 
           RectangleBox[{57.66393017365032, 0.6343679184089389}, \
{57.822258674886314`, 0.646272680313701}], 
           RectangleBox[{59.16385387737663, 0.6343679184089389}, \
{59.322182378612624`, 0.646272680313701}], 
           RectangleBox[{60.49711600085452, 0.6343679184089389}, \
{60.65544450209052, 0.646272680313701}], 
           RectangleBox[{61.830378124332405`, 0.6343679184089389}, \
{61.988706625568405`, 0.646272680313701}], 
           RectangleBox[{62.99700918607135, 0.6343679184089389}, \
{63.15533768730735, 0.646272680313701}], 
           RectangleBox[{64.16360972930082, 0.6343679184089389}, \
{64.32193823053683, 0.646272680313701}], 
           RectangleBox[{65.16354869228186, 0.6343679184089389}, \
{65.32187719351788, 0.646272680313701}], 
           RectangleBox[{66.16351817377239, 0.6343679184089389}, \
{66.3218466750084, 0.646272680313701}], 
           RectangleBox[{66.99679555650502, 0.6343679184089389}, \
{67.15512405774102, 0.646272680313701}], 
           RectangleBox[{67.83010345774713, 0.6343679184089389}, \
{67.98843195898313, 0.646272680313701}], 
           RectangleBox[{68.4967497787408, 0.6343679184089389}, \
{68.6550782799768, 0.646272680313701}], 
           RectangleBox[{68.99670400097659, 0.6343679184089389}, \
{69.15503250221259, 0.646272680313701}], 
           RectangleBox[{69.33002716147344, 0.6343679184089389}, \
{69.48835566270944, 0.646272680313701}], 
           RectangleBox[{69.49668874172185, 0.6343679184089389}, \
{69.65501724295785, 0.646272680313701}], 
           RectangleBox[{69.66335032197027, 0.646272680313701}, \
{69.82167882320628, 0.658177442218463}], 
           RectangleBox[{69.8300119022187, 0.646272680313701}, \
{69.9883404034547, 0.658177442218463}], 
           RectangleBox[{69.99667348246712, 0.646272680313701}, \
{70.15500198370312, 0.658177442218463}], 
           RectangleBox[{70.16333506271553, 0.646272680313701}, 
            {70.32166356395155, 0.658177442218463}]},
          Antialiasing->True]}, 
        {Hue[0.11294451710184394`, 0.9, 0.7], 
         StyleBox[{
           RectangleBox[{43., 0.43198696602798653`}, \
{43.158328501236, 0.4438917279327484}], 
           RectangleBox[{43.16666158024842, 0.43198696602798653`}, \
{43.324990081484415`, 0.4438917279327484}], 
           RectangleBox[{43.33332316049684, 0.43198696602798653`}, \
{43.49165166173284, 0.4438917279327484}], 
           RectangleBox[{43.49998474074526, 0.43198696602798653`}, \
{43.65831324198126, 0.4438917279327484}], 
           RectangleBox[{43.8333079012421, 0.43198696602798653`}, \
{43.99166539506211, 0.4438917279327484}], 
           RectangleBox[{44.33332316049684, 0.43198696602798653`}, \
{44.49165166173284, 0.4438917279327484}], 
           RectangleBox[{44.8333079012421, 0.43198696602798653`}, \
{44.99166539506211, 0.4438917279327484}], 
           RectangleBox[{45.33332316049684, 0.43198696602798653`}, \
{45.49165166173284, 0.4438917279327484}], 
           RectangleBox[{45.8333079012421, 0.43198696602798653`}, \
{45.99166539506211, 0.4438917279327484}], 
           RectangleBox[{46.49998474074526, 0.43198696602798653`}, \
{46.65831324198126, 0.4438917279327484}], 
           RectangleBox[{47.16666158024842, 0.43198696602798653`}, \
{47.324990081484415`, 0.4438917279327484}], 
           RectangleBox[{48., 0.43198696602798653`}, \
{48.158328501236, 0.4438917279327484}], 
           RectangleBox[{48.8333079012421, 0.43198696602798653`}, \
{48.99166539506211, 0.4438917279327484}], 
           RectangleBox[{49.8333079012421, 0.43198696602798653`}, \
{49.99166539506211, 0.4438917279327484}], 
           RectangleBox[{50.8333079012421, 0.43198696602798653`}, \
{50.99166539506211, 0.4438917279327484}], 
           RectangleBox[{52., 0.43198696602798653`}, \
{52.158328501236, 0.4438917279327484}], 
           RectangleBox[{53.16666158024842, 0.43198696602798653`}, \
{53.324990081484415`, 0.4438917279327484}], 
           RectangleBox[{54.33332316049684, 0.43198696602798653`}, \
{54.49165166173284, 0.4438917279327484}], 
           
           RectangleBox[{55.49998474074526, 0.43198696602798653`}, \
{55.65831324198126, 0.4438917279327484}], 
           RectangleBox[{56.666646320993685`, 0.43198696602798653`}, \
{56.82497482222968, 0.4438917279327484}], 
           RectangleBox[{57.8333079012421, 0.43198696602798653`}, \
{57.99166539506211, 0.4438917279327484}], 
           RectangleBox[{59., 0.43198696602798653`}, \
{59.158328501236, 0.4438917279327484}], 
           RectangleBox[{60.33332316049684, 0.43198696602798653`}, \
{60.49165166173284, 0.4438917279327484}], 
           RectangleBox[{61.666646320993685`, 0.43198696602798653`}, \
{61.82497482222968, 0.4438917279327484}], 
           RectangleBox[{62.8333079012421, 0.43198696602798653`}, \
{62.99166539506211, 0.4438917279327484}], 
           RectangleBox[{43.666646320993685`, 0.4438917279327484}, \
{43.82497482222968, 0.45579648983751037`}], 
           RectangleBox[{44., 0.4438917279327484}, \
{44.158328501236, 0.45579648983751037`}], 
           RectangleBox[{44.49998474074526, 0.4438917279327484}, \
{44.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{45., 0.4438917279327484}, \
{45.158328501236, 0.45579648983751037`}], 
           RectangleBox[{45.49998474074526, 0.4438917279327484}, \
{45.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{46., 0.4438917279327484}, \
{46.158328501236, 0.45579648983751037`}], 
           RectangleBox[{46.666646320993685`, 0.4438917279327484}, \
{46.82497482222968, 0.45579648983751037`}], 
           RectangleBox[{47.33332316049684, 0.4438917279327484}, \
{47.49165166173284, 0.45579648983751037`}], 
           RectangleBox[{48.16666158024842, 0.4438917279327484}, \
{48.324990081484415`, 0.45579648983751037`}], 
           RectangleBox[{49., 0.4438917279327484}, \
{49.158328501236, 0.45579648983751037`}], 
           RectangleBox[{50., 0.4438917279327484}, \
{50.158328501236, 0.45579648983751037`}], 
           RectangleBox[{51., 0.4438917279327484}, \
{51.158328501236, 0.45579648983751037`}], 
           RectangleBox[{52.16666158024842, 0.4438917279327484}, \
{52.324990081484415`, 0.45579648983751037`}], 
           
           RectangleBox[{53.33332316049684, 0.4438917279327484}, \
{53.49165166173284, 0.45579648983751037`}], 
           RectangleBox[{54.49998474074526, 0.4438917279327484}, \
{54.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{55.666646320993685`, 0.4438917279327484}, \
{55.82497482222968, 0.45579648983751037`}], 
           RectangleBox[{56.8333079012421, 0.4438917279327484}, \
{56.99166539506211, 0.45579648983751037`}], 
           RectangleBox[{58., 0.4438917279327484}, \
{58.158328501236, 0.45579648983751037`}], 
           RectangleBox[{59.16666158024842, 0.4438917279327484}, \
{59.324990081484415`, 0.45579648983751037`}], 
           RectangleBox[{60.49998474074526, 0.4438917279327484}, \
{60.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{61.8333079012421, 0.4438917279327484}, \
{61.99166539506211, 0.45579648983751037`}], 
           RectangleBox[{63., 0.4438917279327484}, \
{63.158328501236, 0.45579648983751037`}], 
           RectangleBox[{22., 0.45579648983751037`}, \
{22.158328501236, 0.4677012517422721}], 
           RectangleBox[{22.16666158024842, 0.45579648983751037`}, \
{22.324990081484422`, 0.4677012517422721}], 
           RectangleBox[{22.333323160496843`, 0.45579648983751037`}, \
{22.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{22.499984740745262`, 0.45579648983751037`}, \
{22.65831324198126, 0.4677012517422721}], 
           RectangleBox[{22.833307901242105`, 0.45579648983751037`}, \
{22.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{23.333323160496843`, 0.45579648983751037`}, \
{23.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{23.833307901242105`, 0.45579648983751037`}, \
{23.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{24.333323160496843`, 0.45579648983751037`}, \
{24.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{24.833307901242105`, 0.45579648983751037`}, \
{24.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{25.333323160496843`, 0.45579648983751037`}, \
{25.491651661732842`, 0.4677012517422721}], 
           
           RectangleBox[{25.833307901242105`, 0.45579648983751037`}, \
{25.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{26.333323160496843`, 0.45579648983751037`}, \
{26.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{26.833307901242105`, 0.45579648983751037`}, \
{26.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{27.333323160496843`, 0.45579648983751037`}, \
{27.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{27.833307901242105`, 0.45579648983751037`}, \
{27.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{28.333323160496843`, 0.45579648983751037`}, \
{28.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{29., 0.45579648983751037`}, \
{29.158328501236, 0.4677012517422721}], 
           RectangleBox[{29.66664632099368, 0.45579648983751037`}, \
{29.824974822229684`, 0.4677012517422721}], 
           RectangleBox[{30.16666158024842, 0.45579648983751037`}, \
{30.324990081484422`, 0.4677012517422721}], 
           RectangleBox[{30.66664632099368, 0.45579648983751037`}, \
{30.824974822229684`, 0.4677012517422721}], 
           RectangleBox[{31.333323160496843`, 0.45579648983751037`}, \
{31.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{32.16666158024842, 0.45579648983751037`}, \
{32.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{33.16666158024842, 0.45579648983751037`}, \
{33.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{34.33332316049684, 0.45579648983751037`}, \
{34.49165166173284, 0.4677012517422721}], 
           RectangleBox[{35.49998474074526, 0.45579648983751037`}, \
{35.65831324198126, 0.4677012517422721}], 
           RectangleBox[{36.49998474074526, 0.45579648983751037`}, \
{36.65831324198126, 0.4677012517422721}], 
           RectangleBox[{37.33332316049684, 0.45579648983751037`}, \
{37.49165166173284, 0.4677012517422721}], 
           RectangleBox[{38., 0.45579648983751037`}, \
{38.158328501236, 0.4677012517422721}], 
           RectangleBox[{38.49998474074526, 0.45579648983751037`}, \
{38.65831324198126, 0.4677012517422721}], 
           
           RectangleBox[{39., 0.45579648983751037`}, \
{39.158328501236, 0.4677012517422721}], 
           RectangleBox[{39.49998474074526, 0.45579648983751037`}, \
{39.65831324198126, 0.4677012517422721}], 
           RectangleBox[{40., 0.45579648983751037`}, \
{40.158328501236, 0.4677012517422721}], 
           RectangleBox[{40.49998474074526, 0.45579648983751037`}, \
{40.65831324198126, 0.4677012517422721}], 
           RectangleBox[{41., 0.45579648983751037`}, \
{41.158328501236, 0.4677012517422721}], 
           RectangleBox[{41.49998474074526, 0.45579648983751037`}, \
{41.65831324198126, 0.4677012517422721}], 
           RectangleBox[{42., 0.45579648983751037`}, \
{42.158328501236, 0.4677012517422721}], 
           RectangleBox[{42.49998474074526, 0.45579648983751037`}, \
{42.65831324198126, 0.4677012517422721}], 
           RectangleBox[{42.8333079012421, 0.45579648983751037`}, \
{42.99166539506211, 0.4677012517422721}], 
           RectangleBox[{44.16666158024842, 0.45579648983751037`}, \
{44.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{44.666646320993685`, 0.45579648983751037`}, \
{44.82497482222968, 0.4677012517422721}], 
           RectangleBox[{45.16666158024842, 0.45579648983751037`}, \
{45.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{45.666646320993685`, 0.45579648983751037`}, \
{45.82497482222968, 0.4677012517422721}], 
           RectangleBox[{46.16666158024842, 0.45579648983751037`}, \
{46.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{46.8333079012421, 0.45579648983751037`}, \
{46.99166539506211, 0.4677012517422721}], 
           RectangleBox[{47.49998474074526, 0.45579648983751037`}, \
{47.65831324198126, 0.4677012517422721}], 
           RectangleBox[{48.33332316049684, 0.45579648983751037`}, \
{48.49165166173284, 0.4677012517422721}], 
           RectangleBox[{49.16666158024842, 0.45579648983751037`}, \
{49.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{50.16666158024842, 0.45579648983751037`}, \
{50.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{51.16666158024842, 0.45579648983751037`}, \
{51.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{52.33332316049684, 0.45579648983751037`}, \
{52.49165166173284, 0.4677012517422721}], 
           RectangleBox[{53.49998474074526, 0.45579648983751037`}, \
{53.65831324198126, 0.4677012517422721}], 
           RectangleBox[{54.666646320993685`, 0.45579648983751037`}, \
{54.82497482222968, 0.4677012517422721}], 
           RectangleBox[{55.8333079012421, 0.45579648983751037`}, \
{55.99166539506211, 0.4677012517422721}], 
           RectangleBox[{57., 0.45579648983751037`}, \
{57.158328501236, 0.4677012517422721}], 
           RectangleBox[{58.16666158024842, 0.45579648983751037`}, \
{58.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{59.33332316049684, 0.45579648983751037`}, \
{59.49165166173284, 0.4677012517422721}], 
           RectangleBox[{60.666646320993685`, 0.45579648983751037`}, \
{60.82497482222968, 0.4677012517422721}], 
           RectangleBox[{62., 0.45579648983751037`}, \
{62.158328501236, 0.4677012517422721}], 
           RectangleBox[{63.16666158024842, 0.45579648983751037`}, \
{63.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{22.66664632099368, 0.4677012517422721}, \
{22.824974822229684`, 0.4796060136470343}], 
           RectangleBox[{23., 0.4677012517422721}, \
{23.158328501236, 0.4796060136470343}], 
           RectangleBox[{23.499984740745262`, 0.4677012517422721}, \
{23.65831324198126, 0.4796060136470343}], 
           RectangleBox[{24., 0.4677012517422721}, \
{24.158328501236, 0.4796060136470343}], 
           RectangleBox[{24.499984740745262`, 0.4677012517422721}, \
{24.65831324198126, 0.4796060136470343}], 
           RectangleBox[{25., 0.4677012517422721}, \
{25.158328501236, 0.4796060136470343}], 
           RectangleBox[{25.499984740745262`, 0.4677012517422721}, \
{25.65831324198126, 0.4796060136470343}], 
           RectangleBox[{26., 0.4677012517422721}, \
{26.158328501236, 0.4796060136470343}], 
           RectangleBox[{26.499984740745262`, 0.4677012517422721}, \
{26.65831324198126, 0.4796060136470343}], 
           RectangleBox[{27., 0.4677012517422721}, \
{27.158328501236, 0.4796060136470343}], 
           RectangleBox[{27.499984740745262`, 0.4677012517422721}, \
{27.65831324198126, 0.4796060136470343}], 
           RectangleBox[{28., 0.4677012517422721}, \
{28.158328501236, 0.4796060136470343}], 
           RectangleBox[{28.499984740745262`, 0.4677012517422721}, \
{28.65831324198126, 0.4796060136470343}], 
           RectangleBox[{29.16666158024842, 0.4677012517422721}, \
{29.324990081484422`, 0.4796060136470343}], 
           RectangleBox[{29.833307901242105`, 0.4677012517422721}, \
{29.991665395062107`, 0.4796060136470343}], 
           RectangleBox[{30.333323160496843`, 0.4677012517422721}, \
{30.491651661732842`, 0.4796060136470343}], 
           RectangleBox[{30.833307901242105`, 0.4677012517422721}, \
{30.991665395062107`, 0.4796060136470343}], 
           RectangleBox[{31.499984740745262`, 0.4677012517422721}, \
{31.65831324198126, 0.4796060136470343}], 
           RectangleBox[{32.33332316049684, 0.4677012517422721}, \
{32.49165166173284, 0.4796060136470343}], 
           RectangleBox[{33.33332316049684, 0.4677012517422721}, \
{33.49165166173284, 0.4796060136470343}], 
           RectangleBox[{34.49998474074526, 0.4677012517422721}, \
{34.65831324198126, 0.4796060136470343}], 
           RectangleBox[{35.666646320993685`, 0.4677012517422721}, \
{35.82497482222968, 0.4796060136470343}], 
           RectangleBox[{36.666646320993685`, 0.4677012517422721}, \
{36.82497482222968, 0.4796060136470343}], 
           RectangleBox[{37.49998474074526, 0.4677012517422721}, \
{37.65831324198126, 0.4796060136470343}], 
           RectangleBox[{38.16666158024842, 0.4677012517422721}, \
{38.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{38.666646320993685`, 0.4677012517422721}, \
{38.82497482222968, 0.4796060136470343}], 
           RectangleBox[{39.16666158024842, 0.4677012517422721}, \
{39.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{39.666646320993685`, 0.4677012517422721}, \
{39.82497482222968, 0.4796060136470343}], 
           RectangleBox[{40.16666158024842, 0.4677012517422721}, \
{40.324990081484415`, 0.4796060136470343}], 
           
           RectangleBox[{40.666646320993685`, 0.4677012517422721}, \
{40.82497482222968, 0.4796060136470343}], 
           RectangleBox[{41.16666158024842, 0.4677012517422721}, \
{41.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{41.666646320993685`, 0.4677012517422721}, \
{41.82497482222968, 0.4796060136470343}], 
           RectangleBox[{42.16666158024842, 0.4677012517422721}, \
{42.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{42.666646320993685`, 0.4677012517422721}, \
{42.82497482222968, 0.4796060136470343}], 
           RectangleBox[{0.33332316049684135`, 0.4796060136470343}, \
{0.49165166173284097`, 0.49151077555179606`}], 
           RectangleBox[{0.499984740745262, 0.4796060136470343}, \
{0.6583132419812616, 0.49151077555179606`}], 
           RectangleBox[{0.6666463209936827, 0.4796060136470343}, \
{0.8249748222296822, 0.49151077555179606`}], 
           RectangleBox[{0.8333079012421033, 0.4796060136470343}, \
{0.9916653950621052, 0.49151077555179606`}], 
           RectangleBox[{1.1666615802484206`, 0.4796060136470343}, \
{1.3249900814844204`, 0.49151077555179606`}], 
           RectangleBox[{1.6666463209936826`, 0.4796060136470343}, \
{1.8249748222296824`, 0.49151077555179606`}], 
           RectangleBox[{2.333323160496841, 0.4796060136470343}, \
{2.491651661732841, 0.49151077555179606`}], 
           RectangleBox[{3.166661580248421, 0.4796060136470343}, \
{3.32499008148442, 0.49151077555179606`}], 
           RectangleBox[{4.16666158024842, 0.4796060136470343}, \
{4.324990081484421, 0.49151077555179606`}], 
           RectangleBox[{5.16666158024842, 0.4796060136470343}, \
{5.324990081484421, 0.49151077555179606`}], 
           RectangleBox[{6.333323160496842, 0.4796060136470343}, \
{6.491651661732841, 0.49151077555179606`}], 
           RectangleBox[{7.499984740745262, 0.4796060136470343}, \
{7.658313241981261, 0.49151077555179606`}], 
           RectangleBox[{8.499984740745262, 0.4796060136470343}, \
{8.658313241981261, 0.49151077555179606`}], 
           RectangleBox[{9.499984740745262, 0.4796060136470343}, \
{9.658313241981261, 0.49151077555179606`}], 
           
           RectangleBox[{10.499984740745262`, 0.4796060136470343}, \
{10.658313241981261`, 0.49151077555179606`}], 
           RectangleBox[{11.666646320993683`, 0.4796060136470343}, \
{11.82497482222968, 0.49151077555179606`}], 
           RectangleBox[{13., 0.4796060136470343}, \
{13.158328501236, 0.49151077555179606`}], 
           RectangleBox[{14.499984740745262`, 0.4796060136470343}, \
{14.658313241981261`, 0.49151077555179606`}], 
           RectangleBox[{16., 0.4796060136470343}, \
{16.158328501236, 0.49151077555179606`}], 
           RectangleBox[{17.333323160496843`, 0.4796060136470343}, \
{17.491651661732842`, 0.49151077555179606`}], 
           RectangleBox[{18.499984740745262`, 0.4796060136470343}, \
{18.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{19.499984740745262`, 0.4796060136470343}, \
{19.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{20.333323160496843`, 0.4796060136470343}, \
{20.491651661732842`, 0.49151077555179606`}], 
           RectangleBox[{21., 0.4796060136470343}, \
{21.158328501236, 0.49151077555179606`}], 
           RectangleBox[{21.499984740745262`, 0.4796060136470343}, \
{21.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{21.833307901242105`, 0.4796060136470343}, \
{21.991665395062107`, 0.49151077555179606`}], 
           RectangleBox[{23.16666158024842, 0.4796060136470343}, \
{23.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{23.66664632099368, 0.4796060136470343}, \
{23.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{24.16666158024842, 0.4796060136470343}, \
{24.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{24.66664632099368, 0.4796060136470343}, \
{24.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{25.16666158024842, 0.4796060136470343}, \
{25.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{25.66664632099368, 0.4796060136470343}, \
{25.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{26.16666158024842, 0.4796060136470343}, \
{26.324990081484422`, 0.49151077555179606`}], 
           
           RectangleBox[{26.66664632099368, 0.4796060136470343}, \
{26.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{27.16666158024842, 0.4796060136470343}, \
{27.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{27.66664632099368, 0.4796060136470343}, \
{27.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{28.16666158024842, 0.4796060136470343}, \
{28.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{28.66664632099368, 0.4796060136470343}, \
{28.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{29.333323160496843`, 0.4796060136470343}, \
{29.491651661732842`, 0.49151077555179606`}], 
           RectangleBox[{30., 0.4796060136470343}, \
{30.158328501236, 0.49151077555179606`}], 
           RectangleBox[{30.499984740745262`, 0.4796060136470343}, \
{30.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{31., 0.4796060136470343}, \
{31.158328501236, 0.49151077555179606`}], 
           RectangleBox[{31.66664632099368, 0.4796060136470343}, \
{31.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{32.49998474074526, 0.4796060136470343}, \
{32.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{33.49998474074526, 0.4796060136470343}, \
{33.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{34.666646320993685`, 0.4796060136470343}, \
{34.82497482222968, 0.49151077555179606`}], 
           RectangleBox[{35.8333079012421, 0.4796060136470343}, \
{35.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{36.8333079012421, 0.4796060136470343}, \
{36.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{37.666646320993685`, 0.4796060136470343}, \
{37.82497482222968, 0.49151077555179606`}], 
           RectangleBox[{38.33332316049684, 0.4796060136470343}, \
{38.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{38.8333079012421, 0.4796060136470343}, \
{38.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{39.33332316049684, 0.4796060136470343}, \
{39.49165166173284, 0.49151077555179606`}], 
           
           RectangleBox[{39.8333079012421, 0.4796060136470343}, \
{39.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{40.33332316049684, 0.4796060136470343}, \
{40.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{40.8333079012421, 0.4796060136470343}, \
{40.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{41.33332316049684, 0.4796060136470343}, \
{41.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{41.8333079012421, 0.4796060136470343}, \
{41.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{42.33332316049684, 0.4796060136470343}, \
{42.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{1., 0.49151077555179606`}, \
{1.1583285012359996`, 0.5034155374565581}], 
           RectangleBox[{1.3333231604968414`, 0.49151077555179606`}, \
{1.491651661732841, 0.5034155374565581}], 
           RectangleBox[{1.8333079012421034`, 0.49151077555179606`}, \
{1.9916653950621053`, 0.5034155374565581}], 
           RectangleBox[{2.499984740745262, 0.49151077555179606`}, \
{2.658313241981262, 0.5034155374565581}], 
           RectangleBox[{3.333323160496841, 0.49151077555179606`}, \
{3.491651661732841, 0.5034155374565581}], 
           RectangleBox[{4.333323160496842, 0.49151077555179606`}, \
{4.491651661732841, 0.5034155374565581}], 
           RectangleBox[{5.333323160496842, 0.49151077555179606`}, \
{5.491651661732841, 0.5034155374565581}], 
           RectangleBox[{6.499984740745262, 0.49151077555179606`}, \
{6.658313241981261, 0.5034155374565581}], 
           RectangleBox[{7.666646320993682, 0.49151077555179606`}, \
{7.824974822229683, 0.5034155374565581}], 
           RectangleBox[{8.666646320993683, 0.49151077555179606`}, \
{8.82497482222968, 0.5034155374565581}], 
           RectangleBox[{9.666646320993683, 0.49151077555179606`}, \
{9.82497482222968, 0.5034155374565581}], 
           RectangleBox[{10.666646320993683`, 0.49151077555179606`}, \
{10.82497482222968, 0.5034155374565581}], 
           RectangleBox[{11.833307901242103`, 0.49151077555179606`}, \
{11.991665395062105`, 0.5034155374565581}], 
           
           RectangleBox[{13.166661580248421`, 0.49151077555179606`}, \
{13.324990081484419`, 0.5034155374565581}], 
           RectangleBox[{14.666646320993683`, 0.49151077555179606`}, \
{14.82497482222968, 0.5034155374565581}], 
           RectangleBox[{16.16666158024842, 0.49151077555179606`}, \
{16.324990081484422`, 0.5034155374565581}], 
           RectangleBox[{17.499984740745262`, 0.49151077555179606`}, \
{17.65831324198126, 0.5034155374565581}], 
           RectangleBox[{18.66664632099368, 0.49151077555179606`}, \
{18.824974822229684`, 0.5034155374565581}], 
           RectangleBox[{19.66664632099368, 0.49151077555179606`}, \
{19.824974822229684`, 0.5034155374565581}], 
           RectangleBox[{20.499984740745262`, 0.49151077555179606`}, \
{20.65831324198126, 0.5034155374565581}], 
           RectangleBox[{21.16666158024842, 0.49151077555179606`}, \
{21.324990081484422`, 0.5034155374565581}], 
           RectangleBox[{21.66664632099368, 0.49151077555179606`}, \
{21.824974822229684`, 0.5034155374565581}], 
           RectangleBox[{1.499984740745262, 0.5034155374565581}, \
{1.6583132419812616`, 0.5153202993613198}], 
           RectangleBox[{2., 0.5034155374565581}, \
{2.158328501236, 0.5153202993613198}], 
           RectangleBox[{2.666646320993683, 0.5034155374565581}, \
{2.824974822229682, 0.5153202993613198}], 
           RectangleBox[{3.499984740745262, 0.5034155374565581}, \
{3.658313241981262, 0.5153202993613198}], 
           RectangleBox[{4.499984740745262, 0.5034155374565581}, \
{4.658313241981261, 0.5153202993613198}], 
           RectangleBox[{5.499984740745262, 0.5034155374565581}, \
{5.658313241981261, 0.5153202993613198}], 
           RectangleBox[{6.666646320993682, 0.5034155374565581}, \
{6.824974822229683, 0.5153202993613198}], 
           RectangleBox[{7.833307901242104, 0.5034155374565581}, \
{7.991665395062105, 0.5153202993613198}], 
           RectangleBox[{8.833307901242103, 0.5034155374565581}, \
{8.991665395062105, 0.5153202993613198}], 
           RectangleBox[{9.833307901242103, 0.5034155374565581}, \
{9.991665395062105, 0.5153202993613198}], 
           RectangleBox[{10.833307901242103`, 0.5034155374565581}, 
            {10.991665395062105`, 0.5153202993613198}], 
           RectangleBox[{12., 0.5034155374565581}, \
{12.158328501236, 0.5153202993613198}], 
           RectangleBox[{13.33332316049684, 0.5034155374565581}, \
{13.49165166173284, 0.5153202993613198}], 
           RectangleBox[{14.833307901242103`, 0.5034155374565581}, \
{14.991665395062105`, 0.5153202993613198}], 
           RectangleBox[{16.333323160496843`, 0.5034155374565581}, \
{16.491651661732842`, 0.5153202993613198}], 
           RectangleBox[{17.66664632099368, 0.5034155374565581}, \
{17.824974822229684`, 0.5153202993613198}], 
           RectangleBox[{18.833307901242105`, 0.5034155374565581}, \
{18.991665395062107`, 0.5153202993613198}], 
           RectangleBox[{19.833307901242105`, 0.5034155374565581}, \
{19.991665395062107`, 0.5153202993613198}], 
           RectangleBox[{20.66664632099368, 0.5034155374565581}, \
{20.824974822229684`, 0.5153202993613198}], 
           RectangleBox[{21.333323160496843`, 0.5034155374565581}, \
{21.491651661732842`, 0.5153202993613198}], 
           RectangleBox[{46.33332316049684, 0.5034155374565581}, \
{46.49165166173284, 0.5153202993613198}], 
           RectangleBox[{47., 0.5034155374565581}, \
{47.158328501236, 0.5153202993613198}], 
           RectangleBox[{47.666646320993685`, 0.5034155374565581}, \
{47.82497482222968, 0.5153202993613198}], 
           RectangleBox[{48.49998474074526, 0.5034155374565581}, \
{48.65831324198126, 0.5153202993613198}], 
           RectangleBox[{49.33332316049684, 0.5034155374565581}, \
{49.49165166173284, 0.5153202993613198}], 
           RectangleBox[{50.33332316049684, 0.5034155374565581}, \
{50.49165166173284, 0.5153202993613198}], 
           RectangleBox[{51.33332316049684, 0.5034155374565581}, \
{51.49165166173284, 0.5153202993613198}], 
           RectangleBox[{52.49998474074526, 0.5034155374565581}, \
{52.65831324198126, 0.5153202993613198}], 
           RectangleBox[{53.666646320993685`, 0.5034155374565581}, \
{53.82497482222968, 0.5153202993613198}], 
           RectangleBox[{54.8333079012421, 0.5034155374565581}, \
{54.99166539506211, 0.5153202993613198}], 
           
           RectangleBox[{56., 0.5034155374565581}, \
{56.158328501236, 0.5153202993613198}], 
           RectangleBox[{57.16666158024842, 0.5034155374565581}, \
{57.324990081484415`, 0.5153202993613198}], 
           RectangleBox[{58.33332316049684, 0.5034155374565581}, \
{58.49165166173284, 0.5153202993613198}], 
           RectangleBox[{59.49998474074526, 0.5034155374565581}, \
{59.65831324198126, 0.5153202993613198}], 
           RectangleBox[{60.8333079012421, 0.5034155374565581}, \
{60.99166539506211, 0.5153202993613198}], 
           RectangleBox[{62.16666158024842, 0.5034155374565581}, \
{62.324990081484415`, 0.5153202993613198}], 
           RectangleBox[{63.33332316049684, 0.5034155374565581}, \
{63.49165166173284, 0.5153202993613198}], 
           RectangleBox[{2.166661580248421, 0.5153202993613198}, \
{2.32499008148442, 0.5272250612660818}], 
           RectangleBox[{2.833307901242103, 0.5153202993613198}, \
{2.991665395062105, 0.5272250612660818}], 
           RectangleBox[{3.666646320993683, 0.5153202993613198}, \
{3.824974822229682, 0.5272250612660818}], 
           RectangleBox[{4.666646320993682, 0.5153202993613198}, \
{4.824974822229683, 0.5272250612660818}], 
           RectangleBox[{5.666646320993682, 0.5153202993613198}, \
{5.824974822229683, 0.5272250612660818}], 
           RectangleBox[{6.833307901242104, 0.5153202993613198}, \
{6.991665395062105, 0.5272250612660818}], 
           RectangleBox[{8., 0.5153202993613198}, \
{8.158328501236, 0.5272250612660818}], 
           RectangleBox[{9., 0.5153202993613198}, \
{9.158328501236, 0.5272250612660818}], 
           RectangleBox[{10., 0.5153202993613198}, \
{10.158328501236, 0.5272250612660818}], 
           RectangleBox[{11., 0.5153202993613198}, \
{11.158328501236, 0.5272250612660818}], 
           RectangleBox[{12.166661580248421`, 0.5153202993613198}, \
{12.324990081484419`, 0.5272250612660818}], 
           RectangleBox[{13.499984740745262`, 0.5153202993613198}, \
{13.658313241981261`, 0.5272250612660818}], 
           RectangleBox[{15., 0.5153202993613198}, \
{15.158328501236, 0.5272250612660818}], 
           RectangleBox[{16.499984740745262`, 0.5153202993613198}, 
            {16.65831324198126, 0.5272250612660818}], 
           RectangleBox[{17.833307901242105`, 0.5153202993613198}, \
{17.991665395062107`, 0.5272250612660818}], 
           RectangleBox[{19., 0.5153202993613198}, \
{19.158328501236, 0.5272250612660818}], 
           RectangleBox[{20., 0.5153202993613198}, \
{20.158328501236, 0.5272250612660818}], 
           RectangleBox[{20.833307901242105`, 0.5153202993613198}, \
{20.991665395062107`, 0.5272250612660818}], 
           RectangleBox[{0., 0.5272250612660818}, \
{0.15832850123599965`, 0.5391298231708438}], 
           RectangleBox[{0.16666158024842068`, 0.5272250612660818}, \
{0.3249900814844203, 0.5391298231708438}], 
           RectangleBox[{3., 0.5272250612660818}, \
{3.158328501236, 0.5391298231708438}], 
           RectangleBox[{3.833307901242103, 0.5272250612660818}, \
{3.991665395062105, 0.5391298231708438}], 
           RectangleBox[{4.833307901242104, 0.5272250612660818}, \
{4.991665395062105, 0.5391298231708438}], 
           RectangleBox[{5.833307901242104, 0.5272250612660818}, \
{5.991665395062105, 0.5391298231708438}], 
           RectangleBox[{7., 0.5272250612660818}, \
{7.158328501235999, 0.5391298231708438}], 
           RectangleBox[{8.166661580248421, 0.5272250612660818}, \
{8.324990081484419, 0.5391298231708438}], 
           RectangleBox[{9.166661580248421, 0.5272250612660818}, \
{9.324990081484419, 0.5391298231708438}], 
           RectangleBox[{10.166661580248421`, 0.5272250612660818}, \
{10.324990081484419`, 0.5391298231708438}], 
           RectangleBox[{11.166661580248421`, 0.5272250612660818}, \
{11.324990081484419`, 0.5391298231708438}], 
           RectangleBox[{12.33332316049684, 0.5272250612660818}, \
{12.49165166173284, 0.5391298231708438}], 
           RectangleBox[{13.666646320993683`, 0.5272250612660818}, \
{13.82497482222968, 0.5391298231708438}], 
           RectangleBox[{15.166661580248421`, 0.5272250612660818}, \
{15.324990081484419`, 0.5391298231708438}], 
           RectangleBox[{16.66664632099368, 0.5272250612660818}, \
{16.824974822229684`, 0.5391298231708438}], 
           RectangleBox[{18., 0.5272250612660818}, \
{18.158328501236, 0.5391298231708438}], 
           RectangleBox[{19.16666158024842, 0.5272250612660818}, \
{19.324990081484422`, 0.5391298231708438}], 
           RectangleBox[{20.16666158024842, 0.5272250612660818}, \
{20.324990081484422`, 0.5391298231708438}], 
           RectangleBox[{47.8333079012421, 0.5272250612660818}, \
{47.99166539506211, 0.5391298231708438}], 
           RectangleBox[{48.666646320993685`, 0.5272250612660818}, \
{48.82497482222968, 0.5391298231708438}], 
           RectangleBox[{49.49998474074526, 0.5272250612660818}, \
{49.65831324198126, 0.5391298231708438}], 
           RectangleBox[{50.49998474074526, 0.5272250612660818}, \
{50.65831324198126, 0.5391298231708438}], 
           RectangleBox[{51.49998474074526, 0.5272250612660818}, \
{51.65831324198126, 0.5391298231708438}], 
           RectangleBox[{52.666646320993685`, 0.5272250612660818}, \
{52.82497482222968, 0.5391298231708438}], 
           RectangleBox[{53.8333079012421, 0.5272250612660818}, \
{53.99166539506211, 0.5391298231708438}], 
           RectangleBox[{55., 0.5272250612660818}, \
{55.158328501236, 0.5391298231708438}], 
           RectangleBox[{56.16666158024842, 0.5272250612660818}, \
{56.324990081484415`, 0.5391298231708438}], 
           RectangleBox[{57.33332316049684, 0.5272250612660818}, \
{57.49165166173284, 0.5391298231708438}], 
           RectangleBox[{58.49998474074526, 0.5272250612660818}, \
{58.65831324198126, 0.5391298231708438}], 
           RectangleBox[{59.666646320993685`, 0.5272250612660818}, \
{59.82497482222968, 0.5391298231708438}], 
           RectangleBox[{61., 0.5272250612660818}, \
{61.158328501236, 0.5391298231708438}], 
           RectangleBox[{62.33332316049684, 0.5272250612660818}, \
{62.49165166173284, 0.5391298231708438}], 
           RectangleBox[{63.49998474074526, 0.5272250612660818}, \
{63.65831324198126, 0.5391298231708438}], 
           RectangleBox[{4., 0.5391298231708438}, \
{4.158328501235999, 0.5510345850756055}], 
           RectangleBox[{5., 0.5391298231708438}, \
{5.158328501235999, 0.5510345850756055}], 
           RectangleBox[{6., 0.5391298231708438}, \
{6.158328501235999, 0.5510345850756055}], 
           RectangleBox[{7.16666158024842, 0.5391298231708438}, \
{7.324990081484421, 0.5510345850756055}], 
           RectangleBox[{8.33332316049684, 0.5391298231708438}, \
{8.49165166173284, 0.5510345850756055}], 
           RectangleBox[{9.33332316049684, 0.5391298231708438}, \
{9.49165166173284, 0.5510345850756055}], 
           RectangleBox[{10.33332316049684, 0.5391298231708438}, \
{10.49165166173284, 0.5510345850756055}], 
           RectangleBox[{11.33332316049684, 0.5391298231708438}, \
{11.49165166173284, 0.5510345850756055}], 
           RectangleBox[{12.499984740745262`, 0.5391298231708438}, \
{12.658313241981261`, 0.5510345850756055}], 
           RectangleBox[{13.833307901242103`, 0.5391298231708438}, \
{13.991665395062105`, 0.5510345850756055}], 
           RectangleBox[{15.33332316049684, 0.5391298231708438}, \
{15.49165166173284, 0.5510345850756055}], 
           RectangleBox[{16.833307901242105`, 0.5391298231708438}, \
{16.991665395062107`, 0.5510345850756055}], 
           RectangleBox[{18.16666158024842, 0.5391298231708438}, \
{18.324990081484422`, 0.5510345850756055}], 
           RectangleBox[{19.333323160496843`, 0.5391298231708438}, \
{19.491651661732842`, 0.5510345850756055}], 
           RectangleBox[{11.499984740745262`, 0.5510345850756055}, \
{11.658313241981261`, 0.5629393469803675}], 
           RectangleBox[{12.666646320993683`, 0.5510345850756055}, \
{12.82497482222968, 0.5629393469803675}], 
           RectangleBox[{14., 0.5510345850756055}, \
{14.158328501236, 0.5629393469803675}], 
           RectangleBox[{15.499984740745262`, 0.5510345850756055}, \
{15.658313241981261`, 0.5629393469803675}], 
           RectangleBox[{17., 0.5510345850756055}, \
{17.158328501236, 0.5629393469803675}], 
           RectangleBox[{18.333323160496843`, 0.5510345850756055}, \
{18.491651661732842`, 0.5629393469803675}], 
           RectangleBox[{49.666646320993685`, 0.5510345850756055}, \
{49.82497482222968, 0.5629393469803675}], 
           RectangleBox[{50.666646320993685`, 0.5510345850756055}, \
{50.82497482222968, 0.5629393469803675}], 
           
           RectangleBox[{51.666646320993685`, 0.5510345850756055}, \
{51.82497482222968, 0.5629393469803675}], 
           RectangleBox[{52.8333079012421, 0.5510345850756055}, \
{52.99166539506211, 0.5629393469803675}], 
           RectangleBox[{54., 0.5510345850756055}, \
{54.158328501236, 0.5629393469803675}], 
           RectangleBox[{55.16666158024842, 0.5510345850756055}, \
{55.324990081484415`, 0.5629393469803675}], 
           RectangleBox[{56.33332316049684, 0.5510345850756055}, \
{56.49165166173284, 0.5629393469803675}], 
           RectangleBox[{57.49998474074526, 0.5510345850756055}, \
{57.65831324198126, 0.5629393469803675}], 
           RectangleBox[{58.666646320993685`, 0.5510345850756055}, \
{58.82497482222968, 0.5629393469803675}], 
           RectangleBox[{59.8333079012421, 0.5510345850756055}, \
{59.99166539506211, 0.5629393469803675}], 
           RectangleBox[{61.16666158024842, 0.5510345850756055}, \
{61.324990081484415`, 0.5629393469803675}], 
           RectangleBox[{62.49998474074526, 0.5510345850756055}, \
{62.65831324198126, 0.5629393469803675}], 
           RectangleBox[{63.666646320993685`, 0.5510345850756055}, \
{63.82497482222968, 0.5629393469803675}], 
           RectangleBox[{6.16666158024842, 0.5629393469803675}, \
{6.324990081484421, 0.5748441088851295}], 
           RectangleBox[{7.333323160496842, 0.5629393469803675}, \
{7.491651661732841, 0.5748441088851295}], 
           RectangleBox[{12.833307901242103`, 0.5629393469803675}, \
{12.991665395062105`, 0.5748441088851295}], 
           RectangleBox[{14.166661580248421`, 0.5629393469803675}, \
{14.324990081484419`, 0.5748441088851295}], 
           RectangleBox[{15.666646320993683`, 0.5629393469803675}, \
{15.82497482222968, 0.5748441088851295}], 
           RectangleBox[{17.16666158024842, 0.5629393469803675}, \
{17.324990081484422`, 0.5748441088851295}], 
           RectangleBox[{14.33332316049684, 0.5748441088851295}, \
{14.49165166173284, 0.5867488707898912}], 
           RectangleBox[{15.833307901242103`, 0.5748441088851295}, \
{15.991665395062105`, 0.5867488707898912}], 
           RectangleBox[{51.8333079012421, 0.5748441088851295}, 
            {51.99166539506211, 0.5867488707898912}], 
           RectangleBox[{53., 0.5748441088851295}, \
{53.158328501236, 0.5867488707898912}], 
           RectangleBox[{54.16666158024842, 0.5748441088851295}, \
{54.324990081484415`, 0.5867488707898912}], 
           RectangleBox[{55.33332316049684, 0.5748441088851295}, \
{55.49165166173284, 0.5867488707898912}], 
           RectangleBox[{56.49998474074526, 0.5748441088851295}, \
{56.65831324198126, 0.5867488707898912}], 
           RectangleBox[{57.666646320993685`, 0.5748441088851295}, \
{57.82497482222968, 0.5867488707898912}], 
           RectangleBox[{58.8333079012421, 0.5748441088851295}, \
{58.99166539506211, 0.5867488707898912}], 
           RectangleBox[{60., 0.5748441088851295}, \
{60.158328501236, 0.5867488707898912}], 
           RectangleBox[{61.33332316049684, 0.5748441088851295}, \
{61.49165166173284, 0.5867488707898912}], 
           RectangleBox[{62.666646320993685`, 0.5748441088851295}, \
{62.82497482222968, 0.5867488707898912}], 
           RectangleBox[{63.8333079012421, 0.5748441088851295}, \
{63.99166539506211, 0.5867488707898912}], 
           RectangleBox[{31.16666158024842, 0.5867488707898912}, \
{31.324990081484422`, 0.5986536326946532}], 
           RectangleBox[{31.833307901242105`, 0.5867488707898912}, \
{31.991665395062107`, 0.5986536326946532}], 
           RectangleBox[{32.666646320993685`, 0.5867488707898912}, \
{32.82497482222968, 0.5986536326946532}], 
           RectangleBox[{33.666646320993685`, 0.5867488707898912}, \
{33.82497482222968, 0.5986536326946532}], 
           RectangleBox[{34.8333079012421, 0.5867488707898912}, \
{34.99166539506211, 0.5986536326946532}], 
           RectangleBox[{36., 0.5867488707898912}, \
{36.158328501236, 0.5986536326946532}], 
           RectangleBox[{37., 0.5867488707898912}, \
{37.158328501236, 0.5986536326946532}], 
           RectangleBox[{37.8333079012421, 0.5867488707898912}, \
{37.99166539506211, 0.5986536326946532}], 
           RectangleBox[{32., 0.5986536326946532}, \
{32.158328501236, 0.610558394599415}], 
           RectangleBox[{32.8333079012421, 0.5986536326946532}, \
{32.99166539506211, 0.610558394599415}], 
           RectangleBox[{33.8333079012421, 0.5986536326946532}, \
{33.99166539506211, 0.610558394599415}], 
           RectangleBox[{35., 0.5986536326946532}, \
{35.158328501236, 0.610558394599415}], 
           RectangleBox[{36.16666158024842, 0.5986536326946532}, \
{36.324990081484415`, 0.610558394599415}], 
           RectangleBox[{37.16666158024842, 0.5986536326946532}, \
{37.324990081484415`, 0.610558394599415}], 
           RectangleBox[{28.833307901242105`, 0.610558394599415}, \
{28.991665395062107`, 0.6224631565041769}], 
           RectangleBox[{29.499984740745262`, 0.610558394599415}, \
{29.65831324198126, 0.6224631565041769}], 
           RectangleBox[{33., 0.610558394599415}, \
{33.158328501236, 0.6224631565041769}], 
           RectangleBox[{34., 0.610558394599415}, \
{34.158328501236, 0.6224631565041769}], 
           RectangleBox[{35.16666158024842, 0.610558394599415}, \
{35.324990081484415`, 0.6224631565041769}], 
           RectangleBox[{36.33332316049684, 0.610558394599415}, \
{36.49165166173284, 0.6224631565041769}], 
           RectangleBox[{34.16666158024842, 0.6224631565041769}, \
{34.324990081484415`, 0.6343679184089389}], 
           RectangleBox[{35.33332316049684, 0.6224631565041769}, \
{35.49165166173284, 0.6343679184089389}], 
           RectangleBox[{60.16666158024842, 0.658177442218463}, \
{60.324990081484415`, 0.6700822041232247}], 
           RectangleBox[{61.49998474074526, 0.658177442218463}, \
{61.65831324198126, 0.6700822041232247}]},
          Antialiasing->True]}, 
        {Hue[0.26606693913191143`, 0.9, 0.7], 
         StyleBox[{
           RectangleBox[{43., 0.43198696602798653`}, \
{43.158328501236, 0.4438917279327484}], 
           RectangleBox[{43.16666158024842, 0.43198696602798653`}, \
{43.324990081484415`, 0.4438917279327484}], 
           RectangleBox[{43.33332316049684, 0.43198696602798653`}, \
{43.49165166173284, 0.4438917279327484}], 
           RectangleBox[{43.49998474074526, 0.43198696602798653`}, \
{43.65831324198126, 0.4438917279327484}], 
           RectangleBox[{43.8333079012421, 0.43198696602798653`}, \
{43.99166539506211, 0.4438917279327484}], 
           RectangleBox[{44.33332316049684, 0.43198696602798653`}, \
{44.49165166173284, 0.4438917279327484}], 
           RectangleBox[{44.8333079012421, 0.43198696602798653`}, \
{44.99166539506211, 0.4438917279327484}], 
           RectangleBox[{45.33332316049684, 0.43198696602798653`}, \
{45.49165166173284, 0.4438917279327484}], 
           RectangleBox[{45.8333079012421, 0.43198696602798653`}, \
{45.99166539506211, 0.4438917279327484}], 
           RectangleBox[{46.49998474074526, 0.43198696602798653`}, \
{46.65831324198126, 0.4438917279327484}], 
           RectangleBox[{47.16666158024842, 0.43198696602798653`}, \
{47.324990081484415`, 0.4438917279327484}], 
           RectangleBox[{48., 0.43198696602798653`}, \
{48.158328501236, 0.4438917279327484}], 
           RectangleBox[{48.8333079012421, 0.43198696602798653`}, \
{48.99166539506211, 0.4438917279327484}], 
           RectangleBox[{49.8333079012421, 0.43198696602798653`}, \
{49.99166539506211, 0.4438917279327484}], 
           RectangleBox[{50.8333079012421, 0.43198696602798653`}, \
{50.99166539506211, 0.4438917279327484}], 
           RectangleBox[{52., 0.43198696602798653`}, \
{52.158328501236, 0.4438917279327484}], 
           RectangleBox[{53.16666158024842, 0.43198696602798653`}, \
{53.324990081484415`, 0.4438917279327484}], 
           RectangleBox[{54.33332316049684, 0.43198696602798653`}, \
{54.49165166173284, 0.4438917279327484}], 
           RectangleBox[{55.49998474074526, 0.43198696602798653`}, \
{55.65831324198126, 0.4438917279327484}], 
           RectangleBox[{56.666646320993685`, 0.43198696602798653`}, \
{56.82497482222968, 0.4438917279327484}], 
           RectangleBox[{57.8333079012421, 0.43198696602798653`}, \
{57.99166539506211, 0.4438917279327484}], 
           RectangleBox[{59., 0.43198696602798653`}, \
{59.158328501236, 0.4438917279327484}], 
           RectangleBox[{60.33332316049684, 0.43198696602798653`}, \
{60.49165166173284, 0.4438917279327484}], 
           RectangleBox[{61.666646320993685`, 0.43198696602798653`}, \
{61.82497482222968, 0.4438917279327484}], 
           RectangleBox[{62.8333079012421, 0.43198696602798653`}, 
            {62.99166539506211, 0.4438917279327484}], 
           RectangleBox[{43.666646320993685`, 0.4438917279327484}, \
{43.82497482222968, 0.45579648983751037`}], 
           RectangleBox[{44., 0.4438917279327484}, \
{44.158328501236, 0.45579648983751037`}], 
           RectangleBox[{44.49998474074526, 0.4438917279327484}, \
{44.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{45., 0.4438917279327484}, \
{45.158328501236, 0.45579648983751037`}], 
           RectangleBox[{45.49998474074526, 0.4438917279327484}, \
{45.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{46., 0.4438917279327484}, \
{46.158328501236, 0.45579648983751037`}], 
           RectangleBox[{46.666646320993685`, 0.4438917279327484}, \
{46.82497482222968, 0.45579648983751037`}], 
           RectangleBox[{47.33332316049684, 0.4438917279327484}, \
{47.49165166173284, 0.45579648983751037`}], 
           RectangleBox[{48.16666158024842, 0.4438917279327484}, \
{48.324990081484415`, 0.45579648983751037`}], 
           RectangleBox[{49., 0.4438917279327484}, \
{49.158328501236, 0.45579648983751037`}], 
           RectangleBox[{50., 0.4438917279327484}, \
{50.158328501236, 0.45579648983751037`}], 
           RectangleBox[{51., 0.4438917279327484}, \
{51.158328501236, 0.45579648983751037`}], 
           RectangleBox[{52.16666158024842, 0.4438917279327484}, \
{52.324990081484415`, 0.45579648983751037`}], 
           RectangleBox[{53.33332316049684, 0.4438917279327484}, \
{53.49165166173284, 0.45579648983751037`}], 
           RectangleBox[{54.49998474074526, 0.4438917279327484}, \
{54.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{55.666646320993685`, 0.4438917279327484}, \
{55.82497482222968, 0.45579648983751037`}], 
           RectangleBox[{56.8333079012421, 0.4438917279327484}, \
{56.99166539506211, 0.45579648983751037`}], 
           RectangleBox[{58., 0.4438917279327484}, \
{58.158328501236, 0.45579648983751037`}], 
           RectangleBox[{59.16666158024842, 0.4438917279327484}, \
{59.324990081484415`, 0.45579648983751037`}], 
           RectangleBox[{60.49998474074526, 0.4438917279327484}, \
{60.65831324198126, 0.45579648983751037`}], 
           RectangleBox[{61.8333079012421, 0.4438917279327484}, \
{61.99166539506211, 0.45579648983751037`}], 
           RectangleBox[{63., 0.4438917279327484}, \
{63.158328501236, 0.45579648983751037`}], 
           RectangleBox[{22., 0.45579648983751037`}, \
{22.158328501236, 0.4677012517422721}], 
           RectangleBox[{22.16666158024842, 0.45579648983751037`}, \
{22.324990081484422`, 0.4677012517422721}], 
           RectangleBox[{22.333323160496843`, 0.45579648983751037`}, \
{22.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{22.499984740745262`, 0.45579648983751037`}, \
{22.65831324198126, 0.4677012517422721}], 
           RectangleBox[{22.833307901242105`, 0.45579648983751037`}, \
{22.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{23.333323160496843`, 0.45579648983751037`}, \
{23.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{23.833307901242105`, 0.45579648983751037`}, \
{23.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{24.333323160496843`, 0.45579648983751037`}, \
{24.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{24.833307901242105`, 0.45579648983751037`}, \
{24.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{25.333323160496843`, 0.45579648983751037`}, \
{25.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{25.833307901242105`, 0.45579648983751037`}, \
{25.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{26.333323160496843`, 0.45579648983751037`}, \
{26.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{26.833307901242105`, 0.45579648983751037`}, \
{26.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{27.333323160496843`, 0.45579648983751037`}, \
{27.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{27.833307901242105`, 0.45579648983751037`}, \
{27.991665395062107`, 0.4677012517422721}], 
           RectangleBox[{28.333323160496843`, 0.45579648983751037`}, \
{28.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{29., 0.45579648983751037`}, \
{29.158328501236, 0.4677012517422721}], 
           RectangleBox[{29.66664632099368, 0.45579648983751037`}, \
{29.824974822229684`, 0.4677012517422721}], 
           RectangleBox[{30.16666158024842, 0.45579648983751037`}, \
{30.324990081484422`, 0.4677012517422721}], 
           RectangleBox[{30.66664632099368, 0.45579648983751037`}, \
{30.824974822229684`, 0.4677012517422721}], 
           RectangleBox[{31.333323160496843`, 0.45579648983751037`}, \
{31.491651661732842`, 0.4677012517422721}], 
           RectangleBox[{32.16666158024842, 0.45579648983751037`}, \
{32.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{33.16666158024842, 0.45579648983751037`}, \
{33.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{34.33332316049684, 0.45579648983751037`}, \
{34.49165166173284, 0.4677012517422721}], 
           RectangleBox[{35.49998474074526, 0.45579648983751037`}, \
{35.65831324198126, 0.4677012517422721}], 
           RectangleBox[{36.49998474074526, 0.45579648983751037`}, \
{36.65831324198126, 0.4677012517422721}], 
           RectangleBox[{37.33332316049684, 0.45579648983751037`}, \
{37.49165166173284, 0.4677012517422721}], 
           RectangleBox[{38., 0.45579648983751037`}, \
{38.158328501236, 0.4677012517422721}], 
           RectangleBox[{38.49998474074526, 0.45579648983751037`}, \
{38.65831324198126, 0.4677012517422721}], 
           RectangleBox[{39., 0.45579648983751037`}, \
{39.158328501236, 0.4677012517422721}], 
           RectangleBox[{39.49998474074526, 0.45579648983751037`}, \
{39.65831324198126, 0.4677012517422721}], 
           RectangleBox[{40., 0.45579648983751037`}, \
{40.158328501236, 0.4677012517422721}], 
           RectangleBox[{40.49998474074526, 0.45579648983751037`}, \
{40.65831324198126, 0.4677012517422721}], 
           RectangleBox[{41., 0.45579648983751037`}, \
{41.158328501236, 0.4677012517422721}], 
           RectangleBox[{41.49998474074526, 0.45579648983751037`}, \
{41.65831324198126, 0.4677012517422721}], 
           RectangleBox[{42., 0.45579648983751037`}, \
{42.158328501236, 0.4677012517422721}], 
           RectangleBox[{42.49998474074526, 0.45579648983751037`}, 
            {42.65831324198126, 0.4677012517422721}], 
           RectangleBox[{42.8333079012421, 0.45579648983751037`}, \
{42.99166539506211, 0.4677012517422721}], 
           RectangleBox[{44.16666158024842, 0.45579648983751037`}, \
{44.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{44.666646320993685`, 0.45579648983751037`}, \
{44.82497482222968, 0.4677012517422721}], 
           RectangleBox[{45.16666158024842, 0.45579648983751037`}, \
{45.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{45.666646320993685`, 0.45579648983751037`}, \
{45.82497482222968, 0.4677012517422721}], 
           RectangleBox[{46.16666158024842, 0.45579648983751037`}, \
{46.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{46.8333079012421, 0.45579648983751037`}, \
{46.99166539506211, 0.4677012517422721}], 
           RectangleBox[{47.49998474074526, 0.45579648983751037`}, \
{47.65831324198126, 0.4677012517422721}], 
           RectangleBox[{48.33332316049684, 0.45579648983751037`}, \
{48.49165166173284, 0.4677012517422721}], 
           RectangleBox[{49.16666158024842, 0.45579648983751037`}, \
{49.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{50.16666158024842, 0.45579648983751037`}, \
{50.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{51.16666158024842, 0.45579648983751037`}, \
{51.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{52.33332316049684, 0.45579648983751037`}, \
{52.49165166173284, 0.4677012517422721}], 
           RectangleBox[{53.49998474074526, 0.45579648983751037`}, \
{53.65831324198126, 0.4677012517422721}], 
           RectangleBox[{54.666646320993685`, 0.45579648983751037`}, \
{54.82497482222968, 0.4677012517422721}], 
           RectangleBox[{55.8333079012421, 0.45579648983751037`}, \
{55.99166539506211, 0.4677012517422721}], 
           RectangleBox[{57., 0.45579648983751037`}, \
{57.158328501236, 0.4677012517422721}], 
           RectangleBox[{58.16666158024842, 0.45579648983751037`}, \
{58.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{59.33332316049684, 0.45579648983751037`}, \
{59.49165166173284, 0.4677012517422721}], 
           RectangleBox[{60.666646320993685`, 0.45579648983751037`}, \
{60.82497482222968, 0.4677012517422721}], 
           RectangleBox[{62., 0.45579648983751037`}, \
{62.158328501236, 0.4677012517422721}], 
           RectangleBox[{63.16666158024842, 0.45579648983751037`}, \
{63.324990081484415`, 0.4677012517422721}], 
           RectangleBox[{22.66664632099368, 0.4677012517422721}, \
{22.824974822229684`, 0.4796060136470343}], 
           RectangleBox[{23., 0.4677012517422721}, \
{23.158328501236, 0.4796060136470343}], 
           RectangleBox[{23.499984740745262`, 0.4677012517422721}, \
{23.65831324198126, 0.4796060136470343}], 
           RectangleBox[{24., 0.4677012517422721}, \
{24.158328501236, 0.4796060136470343}], 
           RectangleBox[{24.499984740745262`, 0.4677012517422721}, \
{24.65831324198126, 0.4796060136470343}], 
           RectangleBox[{25., 0.4677012517422721}, \
{25.158328501236, 0.4796060136470343}], 
           RectangleBox[{25.499984740745262`, 0.4677012517422721}, \
{25.65831324198126, 0.4796060136470343}], 
           RectangleBox[{26., 0.4677012517422721}, \
{26.158328501236, 0.4796060136470343}], 
           RectangleBox[{26.499984740745262`, 0.4677012517422721}, \
{26.65831324198126, 0.4796060136470343}], 
           RectangleBox[{27., 0.4677012517422721}, \
{27.158328501236, 0.4796060136470343}], 
           RectangleBox[{27.499984740745262`, 0.4677012517422721}, \
{27.65831324198126, 0.4796060136470343}], 
           RectangleBox[{28., 0.4677012517422721}, \
{28.158328501236, 0.4796060136470343}], 
           RectangleBox[{28.499984740745262`, 0.4677012517422721}, \
{28.65831324198126, 0.4796060136470343}], 
           RectangleBox[{29.16666158024842, 0.4677012517422721}, \
{29.324990081484422`, 0.4796060136470343}], 
           RectangleBox[{29.833307901242105`, 0.4677012517422721}, \
{29.991665395062107`, 0.4796060136470343}], 
           RectangleBox[{30.333323160496843`, 0.4677012517422721}, \
{30.491651661732842`, 0.4796060136470343}], 
           RectangleBox[{30.833307901242105`, 0.4677012517422721}, \
{30.991665395062107`, 0.4796060136470343}], 
           
           RectangleBox[{31.499984740745262`, 0.4677012517422721}, \
{31.65831324198126, 0.4796060136470343}], 
           RectangleBox[{32.33332316049684, 0.4677012517422721}, \
{32.49165166173284, 0.4796060136470343}], 
           RectangleBox[{33.33332316049684, 0.4677012517422721}, \
{33.49165166173284, 0.4796060136470343}], 
           RectangleBox[{34.49998474074526, 0.4677012517422721}, \
{34.65831324198126, 0.4796060136470343}], 
           RectangleBox[{35.666646320993685`, 0.4677012517422721}, \
{35.82497482222968, 0.4796060136470343}], 
           RectangleBox[{36.666646320993685`, 0.4677012517422721}, \
{36.82497482222968, 0.4796060136470343}], 
           RectangleBox[{37.49998474074526, 0.4677012517422721}, \
{37.65831324198126, 0.4796060136470343}], 
           RectangleBox[{38.16666158024842, 0.4677012517422721}, \
{38.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{38.666646320993685`, 0.4677012517422721}, \
{38.82497482222968, 0.4796060136470343}], 
           RectangleBox[{39.16666158024842, 0.4677012517422721}, \
{39.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{39.666646320993685`, 0.4677012517422721}, \
{39.82497482222968, 0.4796060136470343}], 
           RectangleBox[{40.16666158024842, 0.4677012517422721}, \
{40.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{40.666646320993685`, 0.4677012517422721}, \
{40.82497482222968, 0.4796060136470343}], 
           RectangleBox[{41.16666158024842, 0.4677012517422721}, \
{41.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{41.666646320993685`, 0.4677012517422721}, \
{41.82497482222968, 0.4796060136470343}], 
           RectangleBox[{42.16666158024842, 0.4677012517422721}, \
{42.324990081484415`, 0.4796060136470343}], 
           RectangleBox[{42.666646320993685`, 0.4677012517422721}, \
{42.82497482222968, 0.4796060136470343}], 
           RectangleBox[{0.33332316049684135`, 0.4796060136470343}, \
{0.49165166173284097`, 0.49151077555179606`}], 
           RectangleBox[{0.499984740745262, 0.4796060136470343}, \
{0.6583132419812616, 0.49151077555179606`}], 
           
           RectangleBox[{0.6666463209936827, 0.4796060136470343}, \
{0.8249748222296822, 0.49151077555179606`}], 
           RectangleBox[{0.8333079012421033, 0.4796060136470343}, \
{0.9916653950621052, 0.49151077555179606`}], 
           RectangleBox[{1.1666615802484206`, 0.4796060136470343}, \
{1.3249900814844204`, 0.49151077555179606`}], 
           RectangleBox[{1.6666463209936826`, 0.4796060136470343}, \
{1.8249748222296824`, 0.49151077555179606`}], 
           RectangleBox[{2.333323160496841, 0.4796060136470343}, \
{2.491651661732841, 0.49151077555179606`}], 
           RectangleBox[{3.166661580248421, 0.4796060136470343}, \
{3.32499008148442, 0.49151077555179606`}], 
           RectangleBox[{4.16666158024842, 0.4796060136470343}, \
{4.324990081484421, 0.49151077555179606`}], 
           RectangleBox[{5.16666158024842, 0.4796060136470343}, \
{5.324990081484421, 0.49151077555179606`}], 
           RectangleBox[{6.333323160496842, 0.4796060136470343}, \
{6.491651661732841, 0.49151077555179606`}], 
           RectangleBox[{7.499984740745262, 0.4796060136470343}, \
{7.658313241981261, 0.49151077555179606`}], 
           RectangleBox[{8.499984740745262, 0.4796060136470343}, \
{8.658313241981261, 0.49151077555179606`}], 
           RectangleBox[{9.499984740745262, 0.4796060136470343}, \
{9.658313241981261, 0.49151077555179606`}], 
           RectangleBox[{10.499984740745262`, 0.4796060136470343}, \
{10.658313241981261`, 0.49151077555179606`}], 
           RectangleBox[{11.666646320993683`, 0.4796060136470343}, \
{11.82497482222968, 0.49151077555179606`}], 
           RectangleBox[{13., 0.4796060136470343}, \
{13.158328501236, 0.49151077555179606`}], 
           RectangleBox[{14.499984740745262`, 0.4796060136470343}, \
{14.658313241981261`, 0.49151077555179606`}], 
           RectangleBox[{16., 0.4796060136470343}, \
{16.158328501236, 0.49151077555179606`}], 
           RectangleBox[{17.333323160496843`, 0.4796060136470343}, \
{17.491651661732842`, 0.49151077555179606`}], 
           RectangleBox[{18.499984740745262`, 0.4796060136470343}, \
{18.65831324198126, 0.49151077555179606`}], 
           
           RectangleBox[{19.499984740745262`, 0.4796060136470343}, \
{19.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{20.333323160496843`, 0.4796060136470343}, \
{20.491651661732842`, 0.49151077555179606`}], 
           RectangleBox[{21., 0.4796060136470343}, \
{21.158328501236, 0.49151077555179606`}], 
           RectangleBox[{21.499984740745262`, 0.4796060136470343}, \
{21.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{21.833307901242105`, 0.4796060136470343}, \
{21.991665395062107`, 0.49151077555179606`}], 
           RectangleBox[{23.16666158024842, 0.4796060136470343}, \
{23.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{23.66664632099368, 0.4796060136470343}, \
{23.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{24.16666158024842, 0.4796060136470343}, \
{24.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{24.66664632099368, 0.4796060136470343}, \
{24.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{25.16666158024842, 0.4796060136470343}, \
{25.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{25.66664632099368, 0.4796060136470343}, \
{25.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{26.16666158024842, 0.4796060136470343}, \
{26.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{26.66664632099368, 0.4796060136470343}, \
{26.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{27.16666158024842, 0.4796060136470343}, \
{27.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{27.66664632099368, 0.4796060136470343}, \
{27.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{28.16666158024842, 0.4796060136470343}, \
{28.324990081484422`, 0.49151077555179606`}], 
           RectangleBox[{28.66664632099368, 0.4796060136470343}, \
{28.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{29.333323160496843`, 0.4796060136470343}, \
{29.491651661732842`, 0.49151077555179606`}], 
           RectangleBox[{30., 0.4796060136470343}, \
{30.158328501236, 0.49151077555179606`}], 
           
           RectangleBox[{30.499984740745262`, 0.4796060136470343}, \
{30.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{31., 0.4796060136470343}, \
{31.158328501236, 0.49151077555179606`}], 
           RectangleBox[{31.66664632099368, 0.4796060136470343}, \
{31.824974822229684`, 0.49151077555179606`}], 
           RectangleBox[{32.49998474074526, 0.4796060136470343}, \
{32.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{33.49998474074526, 0.4796060136470343}, \
{33.65831324198126, 0.49151077555179606`}], 
           RectangleBox[{34.666646320993685`, 0.4796060136470343}, \
{34.82497482222968, 0.49151077555179606`}], 
           RectangleBox[{35.8333079012421, 0.4796060136470343}, \
{35.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{36.8333079012421, 0.4796060136470343}, \
{36.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{37.666646320993685`, 0.4796060136470343}, \
{37.82497482222968, 0.49151077555179606`}], 
           RectangleBox[{38.33332316049684, 0.4796060136470343}, \
{38.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{38.8333079012421, 0.4796060136470343}, \
{38.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{39.33332316049684, 0.4796060136470343}, \
{39.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{39.8333079012421, 0.4796060136470343}, \
{39.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{40.33332316049684, 0.4796060136470343}, \
{40.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{40.8333079012421, 0.4796060136470343}, \
{40.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{41.33332316049684, 0.4796060136470343}, \
{41.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{41.8333079012421, 0.4796060136470343}, \
{41.99166539506211, 0.49151077555179606`}], 
           RectangleBox[{42.33332316049684, 0.4796060136470343}, \
{42.49165166173284, 0.49151077555179606`}], 
           RectangleBox[{1., 0.49151077555179606`}, \
{1.1583285012359996`, 0.5034155374565581}], 
           RectangleBox[{1.3333231604968414`, 0.49151077555179606`}, 
            {1.491651661732841, 0.5034155374565581}], 
           RectangleBox[{1.8333079012421034`, 0.49151077555179606`}, \
{1.9916653950621053`, 0.5034155374565581}], 
           RectangleBox[{2.499984740745262, 0.49151077555179606`}, \
{2.658313241981262, 0.5034155374565581}], 
           RectangleBox[{3.333323160496841, 0.49151077555179606`}, \
{3.491651661732841, 0.5034155374565581}], 
           RectangleBox[{4.333323160496842, 0.49151077555179606`}, \
{4.491651661732841, 0.5034155374565581}], 
           RectangleBox[{5.333323160496842, 0.49151077555179606`}, \
{5.491651661732841, 0.5034155374565581}], 
           RectangleBox[{6.499984740745262, 0.49151077555179606`}, \
{6.658313241981261, 0.5034155374565581}], 
           RectangleBox[{7.666646320993682, 0.49151077555179606`}, \
{7.824974822229683, 0.5034155374565581}], 
           RectangleBox[{8.666646320993683, 0.49151077555179606`}, \
{8.82497482222968, 0.5034155374565581}], 
           RectangleBox[{9.666646320993683, 0.49151077555179606`}, \
{9.82497482222968, 0.5034155374565581}], 
           RectangleBox[{10.666646320993683`, 0.49151077555179606`}, \
{10.82497482222968, 0.5034155374565581}], 
           RectangleBox[{11.833307901242103`, 0.49151077555179606`}, \
{11.991665395062105`, 0.5034155374565581}], 
           RectangleBox[{13.166661580248421`, 0.49151077555179606`}, \
{13.324990081484419`, 0.5034155374565581}], 
           RectangleBox[{14.666646320993683`, 0.49151077555179606`}, \
{14.82497482222968, 0.5034155374565581}], 
           RectangleBox[{16.16666158024842, 0.49151077555179606`}, \
{16.324990081484422`, 0.5034155374565581}], 
           RectangleBox[{17.499984740745262`, 0.49151077555179606`}, \
{17.65831324198126, 0.5034155374565581}], 
           RectangleBox[{18.66664632099368, 0.49151077555179606`}, \
{18.824974822229684`, 0.5034155374565581}], 
           RectangleBox[{19.66664632099368, 0.49151077555179606`}, \
{19.824974822229684`, 0.5034155374565581}], 
           RectangleBox[{20.499984740745262`, 0.49151077555179606`}, \
{20.65831324198126, 0.5034155374565581}], 
           RectangleBox[{21.16666158024842, 0.49151077555179606`}, 
            {21.324990081484422`, 0.5034155374565581}], 
           RectangleBox[{21.66664632099368, 0.49151077555179606`}, \
{21.824974822229684`, 0.5034155374565581}], 
           RectangleBox[{1.499984740745262, 0.5034155374565581}, \
{1.6583132419812616`, 0.5153202993613198}], 
           RectangleBox[{2., 0.5034155374565581}, \
{2.158328501236, 0.5153202993613198}], 
           RectangleBox[{2.666646320993683, 0.5034155374565581}, \
{2.824974822229682, 0.5153202993613198}], 
           RectangleBox[{3.499984740745262, 0.5034155374565581}, \
{3.658313241981262, 0.5153202993613198}], 
           RectangleBox[{4.499984740745262, 0.5034155374565581}, \
{4.658313241981261, 0.5153202993613198}], 
           RectangleBox[{5.499984740745262, 0.5034155374565581}, \
{5.658313241981261, 0.5153202993613198}], 
           RectangleBox[{6.666646320993682, 0.5034155374565581}, \
{6.824974822229683, 0.5153202993613198}], 
           RectangleBox[{7.833307901242104, 0.5034155374565581}, \
{7.991665395062105, 0.5153202993613198}], 
           RectangleBox[{8.833307901242103, 0.5034155374565581}, \
{8.991665395062105, 0.5153202993613198}], 
           RectangleBox[{9.833307901242103, 0.5034155374565581}, \
{9.991665395062105, 0.5153202993613198}], 
           RectangleBox[{10.833307901242103`, 0.5034155374565581}, \
{10.991665395062105`, 0.5153202993613198}], 
           RectangleBox[{12., 0.5034155374565581}, \
{12.158328501236, 0.5153202993613198}], 
           RectangleBox[{13.33332316049684, 0.5034155374565581}, \
{13.49165166173284, 0.5153202993613198}], 
           RectangleBox[{14.833307901242103`, 0.5034155374565581}, \
{14.991665395062105`, 0.5153202993613198}], 
           RectangleBox[{16.333323160496843`, 0.5034155374565581}, \
{16.491651661732842`, 0.5153202993613198}], 
           RectangleBox[{17.66664632099368, 0.5034155374565581}, \
{17.824974822229684`, 0.5153202993613198}], 
           RectangleBox[{18.833307901242105`, 0.5034155374565581}, \
{18.991665395062107`, 0.5153202993613198}], 
           RectangleBox[{19.833307901242105`, 0.5034155374565581}, \
{19.991665395062107`, 0.5153202993613198}], 
           
           RectangleBox[{20.66664632099368, 0.5034155374565581}, \
{20.824974822229684`, 0.5153202993613198}], 
           RectangleBox[{21.333323160496843`, 0.5034155374565581}, \
{21.491651661732842`, 0.5153202993613198}], 
           RectangleBox[{46.33332316049684, 0.5034155374565581}, \
{46.49165166173284, 0.5153202993613198}], 
           RectangleBox[{47., 0.5034155374565581}, \
{47.158328501236, 0.5153202993613198}], 
           RectangleBox[{47.666646320993685`, 0.5034155374565581}, \
{47.82497482222968, 0.5153202993613198}], 
           RectangleBox[{48.49998474074526, 0.5034155374565581}, \
{48.65831324198126, 0.5153202993613198}], 
           RectangleBox[{49.33332316049684, 0.5034155374565581}, \
{49.49165166173284, 0.5153202993613198}], 
           RectangleBox[{50.33332316049684, 0.5034155374565581}, \
{50.49165166173284, 0.5153202993613198}], 
           RectangleBox[{51.33332316049684, 0.5034155374565581}, \
{51.49165166173284, 0.5153202993613198}], 
           RectangleBox[{52.49998474074526, 0.5034155374565581}, \
{52.65831324198126, 0.5153202993613198}], 
           RectangleBox[{53.666646320993685`, 0.5034155374565581}, \
{53.82497482222968, 0.5153202993613198}], 
           RectangleBox[{54.8333079012421, 0.5034155374565581}, \
{54.99166539506211, 0.5153202993613198}], 
           RectangleBox[{56., 0.5034155374565581}, \
{56.158328501236, 0.5153202993613198}], 
           RectangleBox[{57.16666158024842, 0.5034155374565581}, \
{57.324990081484415`, 0.5153202993613198}], 
           RectangleBox[{58.33332316049684, 0.5034155374565581}, \
{58.49165166173284, 0.5153202993613198}], 
           RectangleBox[{59.49998474074526, 0.5034155374565581}, \
{59.65831324198126, 0.5153202993613198}], 
           RectangleBox[{60.8333079012421, 0.5034155374565581}, \
{60.99166539506211, 0.5153202993613198}], 
           RectangleBox[{62.16666158024842, 0.5034155374565581}, \
{62.324990081484415`, 0.5153202993613198}], 
           RectangleBox[{63.33332316049684, 0.5034155374565581}, \
{63.49165166173284, 0.5153202993613198}], 
           RectangleBox[{2.166661580248421, 0.5153202993613198}, \
{2.32499008148442, 0.5272250612660818}], 
           RectangleBox[{2.833307901242103, 0.5153202993613198}, \
{2.991665395062105, 0.5272250612660818}], 
           RectangleBox[{3.666646320993683, 0.5153202993613198}, \
{3.824974822229682, 0.5272250612660818}], 
           RectangleBox[{4.666646320993682, 0.5153202993613198}, \
{4.824974822229683, 0.5272250612660818}], 
           RectangleBox[{5.666646320993682, 0.5153202993613198}, \
{5.824974822229683, 0.5272250612660818}], 
           RectangleBox[{6.833307901242104, 0.5153202993613198}, \
{6.991665395062105, 0.5272250612660818}], 
           RectangleBox[{8., 0.5153202993613198}, \
{8.158328501236, 0.5272250612660818}], 
           RectangleBox[{9., 0.5153202993613198}, \
{9.158328501236, 0.5272250612660818}], 
           RectangleBox[{10., 0.5153202993613198}, \
{10.158328501236, 0.5272250612660818}], 
           RectangleBox[{11., 0.5153202993613198}, \
{11.158328501236, 0.5272250612660818}], 
           RectangleBox[{12.166661580248421`, 0.5153202993613198}, \
{12.324990081484419`, 0.5272250612660818}], 
           RectangleBox[{13.499984740745262`, 0.5153202993613198}, \
{13.658313241981261`, 0.5272250612660818}], 
           RectangleBox[{15., 0.5153202993613198}, \
{15.158328501236, 0.5272250612660818}], 
           RectangleBox[{16.499984740745262`, 0.5153202993613198}, \
{16.65831324198126, 0.5272250612660818}], 
           RectangleBox[{17.833307901242105`, 0.5153202993613198}, \
{17.991665395062107`, 0.5272250612660818}], 
           RectangleBox[{19., 0.5153202993613198}, \
{19.158328501236, 0.5272250612660818}], 
           RectangleBox[{20., 0.5153202993613198}, \
{20.158328501236, 0.5272250612660818}], 
           RectangleBox[{20.833307901242105`, 0.5153202993613198}, \
{20.991665395062107`, 0.5272250612660818}], 
           RectangleBox[{0., 0.5272250612660818}, \
{0.15832850123599965`, 0.5391298231708438}], 
           RectangleBox[{0.16666158024842068`, 0.5272250612660818}, \
{0.3249900814844203, 0.5391298231708438}], 
           RectangleBox[{3., 0.5272250612660818}, \
{3.158328501236, 0.5391298231708438}], 
           RectangleBox[{3.833307901242103, 0.5272250612660818}, 
            {3.991665395062105, 0.5391298231708438}], 
           RectangleBox[{4.833307901242104, 0.5272250612660818}, \
{4.991665395062105, 0.5391298231708438}], 
           RectangleBox[{5.833307901242104, 0.5272250612660818}, \
{5.991665395062105, 0.5391298231708438}], 
           RectangleBox[{7., 0.5272250612660818}, \
{7.158328501235999, 0.5391298231708438}], 
           RectangleBox[{8.166661580248421, 0.5272250612660818}, \
{8.324990081484419, 0.5391298231708438}], 
           RectangleBox[{9.166661580248421, 0.5272250612660818}, \
{9.324990081484419, 0.5391298231708438}], 
           RectangleBox[{10.166661580248421`, 0.5272250612660818}, \
{10.324990081484419`, 0.5391298231708438}], 
           RectangleBox[{11.166661580248421`, 0.5272250612660818}, \
{11.324990081484419`, 0.5391298231708438}], 
           RectangleBox[{12.33332316049684, 0.5272250612660818}, \
{12.49165166173284, 0.5391298231708438}], 
           RectangleBox[{13.666646320993683`, 0.5272250612660818}, \
{13.82497482222968, 0.5391298231708438}], 
           RectangleBox[{15.166661580248421`, 0.5272250612660818}, \
{15.324990081484419`, 0.5391298231708438}], 
           RectangleBox[{16.66664632099368, 0.5272250612660818}, \
{16.824974822229684`, 0.5391298231708438}], 
           RectangleBox[{18., 0.5272250612660818}, \
{18.158328501236, 0.5391298231708438}], 
           RectangleBox[{19.16666158024842, 0.5272250612660818}, \
{19.324990081484422`, 0.5391298231708438}], 
           RectangleBox[{20.16666158024842, 0.5272250612660818}, \
{20.324990081484422`, 0.5391298231708438}], 
           RectangleBox[{47.8333079012421, 0.5272250612660818}, \
{47.99166539506211, 0.5391298231708438}], 
           RectangleBox[{48.666646320993685`, 0.5272250612660818}, \
{48.82497482222968, 0.5391298231708438}], 
           RectangleBox[{49.49998474074526, 0.5272250612660818}, \
{49.65831324198126, 0.5391298231708438}], 
           RectangleBox[{50.49998474074526, 0.5272250612660818}, \
{50.65831324198126, 0.5391298231708438}], 
           RectangleBox[{51.49998474074526, 0.5272250612660818}, \
{51.65831324198126, 0.5391298231708438}], 
           
           RectangleBox[{52.666646320993685`, 0.5272250612660818}, \
{52.82497482222968, 0.5391298231708438}], 
           RectangleBox[{53.8333079012421, 0.5272250612660818}, \
{53.99166539506211, 0.5391298231708438}], 
           RectangleBox[{55., 0.5272250612660818}, \
{55.158328501236, 0.5391298231708438}], 
           RectangleBox[{56.16666158024842, 0.5272250612660818}, \
{56.324990081484415`, 0.5391298231708438}], 
           RectangleBox[{57.33332316049684, 0.5272250612660818}, \
{57.49165166173284, 0.5391298231708438}], 
           RectangleBox[{58.49998474074526, 0.5272250612660818}, \
{58.65831324198126, 0.5391298231708438}], 
           RectangleBox[{59.666646320993685`, 0.5272250612660818}, \
{59.82497482222968, 0.5391298231708438}], 
           RectangleBox[{61., 0.5272250612660818}, \
{61.158328501236, 0.5391298231708438}], 
           RectangleBox[{62.33332316049684, 0.5272250612660818}, \
{62.49165166173284, 0.5391298231708438}], 
           RectangleBox[{63.49998474074526, 0.5272250612660818}, \
{63.65831324198126, 0.5391298231708438}], 
           RectangleBox[{4., 0.5391298231708438}, \
{4.158328501235999, 0.5510345850756055}], 
           RectangleBox[{5., 0.5391298231708438}, \
{5.158328501235999, 0.5510345850756055}], 
           RectangleBox[{6., 0.5391298231708438}, \
{6.158328501235999, 0.5510345850756055}], 
           RectangleBox[{7.16666158024842, 0.5391298231708438}, \
{7.324990081484421, 0.5510345850756055}], 
           RectangleBox[{8.33332316049684, 0.5391298231708438}, \
{8.49165166173284, 0.5510345850756055}], 
           RectangleBox[{9.33332316049684, 0.5391298231708438}, \
{9.49165166173284, 0.5510345850756055}], 
           RectangleBox[{10.33332316049684, 0.5391298231708438}, \
{10.49165166173284, 0.5510345850756055}], 
           RectangleBox[{11.33332316049684, 0.5391298231708438}, \
{11.49165166173284, 0.5510345850756055}], 
           RectangleBox[{12.499984740745262`, 0.5391298231708438}, \
{12.658313241981261`, 0.5510345850756055}], 
           RectangleBox[{13.833307901242103`, 0.5391298231708438}, \
{13.991665395062105`, 0.5510345850756055}], 
           
           RectangleBox[{15.33332316049684, 0.5391298231708438}, \
{15.49165166173284, 0.5510345850756055}], 
           RectangleBox[{16.833307901242105`, 0.5391298231708438}, \
{16.991665395062107`, 0.5510345850756055}], 
           RectangleBox[{18.16666158024842, 0.5391298231708438}, \
{18.324990081484422`, 0.5510345850756055}], 
           RectangleBox[{19.333323160496843`, 0.5391298231708438}, \
{19.491651661732842`, 0.5510345850756055}], 
           RectangleBox[{11.499984740745262`, 0.5510345850756055}, \
{11.658313241981261`, 0.5629393469803675}], 
           RectangleBox[{12.666646320993683`, 0.5510345850756055}, \
{12.82497482222968, 0.5629393469803675}], 
           RectangleBox[{14., 0.5510345850756055}, \
{14.158328501236, 0.5629393469803675}], 
           RectangleBox[{15.499984740745262`, 0.5510345850756055}, \
{15.658313241981261`, 0.5629393469803675}], 
           RectangleBox[{17., 0.5510345850756055}, \
{17.158328501236, 0.5629393469803675}], 
           RectangleBox[{18.333323160496843`, 0.5510345850756055}, \
{18.491651661732842`, 0.5629393469803675}], 
           RectangleBox[{49.666646320993685`, 0.5510345850756055}, \
{49.82497482222968, 0.5629393469803675}], 
           RectangleBox[{50.666646320993685`, 0.5510345850756055}, \
{50.82497482222968, 0.5629393469803675}], 
           RectangleBox[{51.666646320993685`, 0.5510345850756055}, \
{51.82497482222968, 0.5629393469803675}], 
           RectangleBox[{52.8333079012421, 0.5510345850756055}, \
{52.99166539506211, 0.5629393469803675}], 
           RectangleBox[{54., 0.5510345850756055}, \
{54.158328501236, 0.5629393469803675}], 
           RectangleBox[{55.16666158024842, 0.5510345850756055}, \
{55.324990081484415`, 0.5629393469803675}], 
           RectangleBox[{56.33332316049684, 0.5510345850756055}, \
{56.49165166173284, 0.5629393469803675}], 
           RectangleBox[{57.49998474074526, 0.5510345850756055}, \
{57.65831324198126, 0.5629393469803675}], 
           RectangleBox[{58.666646320993685`, 0.5510345850756055}, \
{58.82497482222968, 0.5629393469803675}], 
           RectangleBox[{59.8333079012421, 0.5510345850756055}, \
{59.99166539506211, 0.5629393469803675}], 
           RectangleBox[{61.16666158024842, 0.5510345850756055}, \
{61.324990081484415`, 0.5629393469803675}], 
           RectangleBox[{62.49998474074526, 0.5510345850756055}, \
{62.65831324198126, 0.5629393469803675}], 
           RectangleBox[{63.666646320993685`, 0.5510345850756055}, \
{63.82497482222968, 0.5629393469803675}], 
           RectangleBox[{6.16666158024842, 0.5629393469803675}, \
{6.324990081484421, 0.5748441088851295}], 
           RectangleBox[{7.333323160496842, 0.5629393469803675}, \
{7.491651661732841, 0.5748441088851295}], 
           RectangleBox[{12.833307901242103`, 0.5629393469803675}, \
{12.991665395062105`, 0.5748441088851295}], 
           RectangleBox[{14.166661580248421`, 0.5629393469803675}, \
{14.324990081484419`, 0.5748441088851295}], 
           RectangleBox[{15.666646320993683`, 0.5629393469803675}, \
{15.82497482222968, 0.5748441088851295}], 
           RectangleBox[{17.16666158024842, 0.5629393469803675}, \
{17.324990081484422`, 0.5748441088851295}], 
           RectangleBox[{14.33332316049684, 0.5748441088851295}, \
{14.49165166173284, 0.5867488707898912}], 
           RectangleBox[{15.833307901242103`, 0.5748441088851295}, \
{15.991665395062105`, 0.5867488707898912}], 
           RectangleBox[{51.8333079012421, 0.5748441088851295}, \
{51.99166539506211, 0.5867488707898912}], 
           RectangleBox[{53., 0.5748441088851295}, \
{53.158328501236, 0.5867488707898912}], 
           RectangleBox[{54.16666158024842, 0.5748441088851295}, \
{54.324990081484415`, 0.5867488707898912}], 
           RectangleBox[{55.33332316049684, 0.5748441088851295}, \
{55.49165166173284, 0.5867488707898912}], 
           RectangleBox[{56.49998474074526, 0.5748441088851295}, \
{56.65831324198126, 0.5867488707898912}], 
           RectangleBox[{57.666646320993685`, 0.5748441088851295}, \
{57.82497482222968, 0.5867488707898912}], 
           RectangleBox[{58.8333079012421, 0.5748441088851295}, \
{58.99166539506211, 0.5867488707898912}], 
           RectangleBox[{60., 0.5748441088851295}, \
{60.158328501236, 0.5867488707898912}], 
           RectangleBox[{61.33332316049684, 0.5748441088851295}, 
            {61.49165166173284, 0.5867488707898912}], 
           RectangleBox[{62.666646320993685`, 0.5748441088851295}, \
{62.82497482222968, 0.5867488707898912}], 
           RectangleBox[{63.8333079012421, 0.5748441088851295}, \
{63.99166539506211, 0.5867488707898912}], 
           RectangleBox[{31.16666158024842, 0.5867488707898912}, \
{31.324990081484422`, 0.5986536326946532}], 
           RectangleBox[{31.833307901242105`, 0.5867488707898912}, \
{31.991665395062107`, 0.5986536326946532}], 
           RectangleBox[{32.666646320993685`, 0.5867488707898912}, \
{32.82497482222968, 0.5986536326946532}], 
           RectangleBox[{33.666646320993685`, 0.5867488707898912}, \
{33.82497482222968, 0.5986536326946532}], 
           RectangleBox[{34.8333079012421, 0.5867488707898912}, \
{34.99166539506211, 0.5986536326946532}], 
           RectangleBox[{36., 0.5867488707898912}, \
{36.158328501236, 0.5986536326946532}], 
           RectangleBox[{37., 0.5867488707898912}, \
{37.158328501236, 0.5986536326946532}], 
           RectangleBox[{37.8333079012421, 0.5867488707898912}, \
{37.99166539506211, 0.5986536326946532}], 
           RectangleBox[{32., 0.5986536326946532}, \
{32.158328501236, 0.610558394599415}], 
           RectangleBox[{32.8333079012421, 0.5986536326946532}, \
{32.99166539506211, 0.610558394599415}], 
           RectangleBox[{33.8333079012421, 0.5986536326946532}, \
{33.99166539506211, 0.610558394599415}], 
           RectangleBox[{35., 0.5986536326946532}, \
{35.158328501236, 0.610558394599415}], 
           RectangleBox[{36.16666158024842, 0.5986536326946532}, \
{36.324990081484415`, 0.610558394599415}], 
           RectangleBox[{37.16666158024842, 0.5986536326946532}, \
{37.324990081484415`, 0.610558394599415}], 
           RectangleBox[{28.833307901242105`, 0.610558394599415}, \
{28.991665395062107`, 0.6224631565041769}], 
           RectangleBox[{29.499984740745262`, 0.610558394599415}, \
{29.65831324198126, 0.6224631565041769}], 
           RectangleBox[{33., 0.610558394599415}, \
{33.158328501236, 0.6224631565041769}], 
           RectangleBox[{34., 0.610558394599415}, \
{34.158328501236, 0.6224631565041769}], 
           
           RectangleBox[{35.16666158024842, 0.610558394599415}, \
{35.324990081484415`, 0.6224631565041769}], 
           RectangleBox[{36.33332316049684, 0.610558394599415}, \
{36.49165166173284, 0.6224631565041769}], 
           RectangleBox[{34.16666158024842, 0.6224631565041769}, \
{34.324990081484415`, 0.6343679184089389}], 
           RectangleBox[{35.33332316049684, 0.6224631565041769}, \
{35.49165166173284, 0.6343679184089389}], 
           RectangleBox[{60.16666158024842, 0.658177442218463}, \
{60.324990081484415`, 0.6700822041232247}], 
           RectangleBox[{61.49998474074526, 0.658177442218463}, \
{61.65831324198126, 0.6700822041232247}]},
          Antialiasing->True]}},
       AspectRatio->NCache[
         Rational[6, 35], 0.17142857142857143`],
       Background->GrayLevel[1],
       Frame->True,
       FrameStyle->GrayLevel[0.75],
       FrameTicks->False,
       ImagePadding->None,
       PlotRange->All,
       PlotRangePadding->{Automatic, 0.05}], {180, -35}, 
      ImageScaled[{0.5, 0.5}], {350, 60},
      Background->GrayLevel[0.9]], InsetBox[
      GraphicsBox[
       {GrayLevel[0.6], RectangleBox[{0, 0}]},
       AspectRatio->NCache[
         Rational[6, 35], 0.17142857142857143`],
       Background->GrayLevel[1],
       Frame->True,
       FrameStyle->GrayLevel[0.75],
       FrameTicks->False,
       ImagePadding->None], {180, -100}, ImageScaled[{0.5, 0.5}], {350, 60},
      Background->GrayLevel[0.9]]}, InsetBox[
     StyleBox[
      TemplateBox[{
       StyleBox[
        "\" | \"", FontSize -> 14, FontColor -> GrayLevel[0.75], StripOnInput -> 
         False],TemplateBox[{"\"70.33\"", "\" s\""}, "RowDefault"]},
       "RowWithSeparator"], "DialogStyle",
      StripOnInput->False], {355, -159}, Scaled[{1, 0}]], 
    TagBox[
     TooltipBox[
      TagBox[{
        {GrayLevel[0.9], RectangleBox[{5, -158}, {29, -135}]}, 
        {GrayLevel[0.3], 
         PolygonBox[
          NCache[{{13, -153}, {13, -140}, {21, Rational[-293, 2]}, {
            13, -153}}, {{13, -153}, {13, -140}, {21, -146.5}, {13, -153}}]]}, 
        {GrayLevel[0.5], 
         StyleBox[
          LineBox[{{5, -158}, {5, -135}, {29, -135}, {29, -158}, {5, -158}}],
          Antialiasing->False]}},
       EventHandlerTag[{"MouseClicked" :> (Sound`EmitMIDI[
            Sound`MIDISequence[{
              Sound`MIDITrack[{
                Sound`MIDIEvent[0, "SetTempo", "Tempo" -> 1000000], 
                Sound`MIDIEvent[
                0, "ProgramCommand", "Channel" -> 0, "Value" -> 0], 
                Sound`MIDIEvent[
                0, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 127], 
                Sound`MIDIEvent[
                5460, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                5460, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                10921, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                10921, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                16382, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                16382, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                21843, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                21843, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                27304, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                27304, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                32765, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                32765, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                38226, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                38226, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                43687, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                43687, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                49148, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                49148, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                54609, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                54609, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                60069, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                60069, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                65530, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                65530, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                70991, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                70991, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                76452, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                76452, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                81913, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                81913, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                87374, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                87374, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                92835, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                92835, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                98296, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                98296, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                103757, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                103757, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                109218, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                109218, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                114679, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                114679, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                120139, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                120139, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                125600, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                125600, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                131061, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                131061, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                136522, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                136522, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                141983, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                141983, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                147444, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                147444, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                152905, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                152905, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                158366, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                158366, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                163827, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                163827, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                169288, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                169288, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                174749, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                174749, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                180209, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                180209, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                185670, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                185670, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                191131, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                191131, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                196592, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                196592, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                202053, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                202053, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                207514, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                207514, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                212975, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                212975, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                218436, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                218436, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                223897, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                223897, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                229358, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                229358, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                234819, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                234819, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                240279, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                240279, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                245740, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                245740, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                251201, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                251201, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                256662, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                256662, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                262123, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                262123, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                267584, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                267584, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                273045, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                273045, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                278506, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                278506, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                283967, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                283967, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                289428, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                289428, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                294888, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                294888, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                300349, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                300349, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                305810, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                305810, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                311271, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                311271, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                316732, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                316732, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                322193, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                322193, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                327654, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                327654, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                333115, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                333115, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                338576, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                338576, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                344037, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                344037, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                349498, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                349498, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                354959, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                354959, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                360419, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                360419, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                365880, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                365880, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                371341, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                371341, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                376802, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                376802, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                382263, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                382263, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                387724, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                387724, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                393185, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                393185, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                398646, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                398646, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                404107, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                404107, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                409568, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                409568, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                415029, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                415029, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                420489, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                420489, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                425950, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                425950, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                431411, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                431411, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                436872, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                436872, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                442333, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                442333, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                447794, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                447794, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                453255, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                453255, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                458716, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                458716, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                464177, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                464177, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                469638, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                469638, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                475098, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                475098, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                480559, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                480559, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                486020, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                486020, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                491481, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                491481, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                496942, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                496942, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                502403, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                502403, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                507864, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                507864, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                513325, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                513325, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                518786, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                518786, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                524247, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                524247, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                529708, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                529708, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                535168, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                535168, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                540629, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                540629, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                546090, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                546090, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                551551, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                551551, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                557012, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                557012, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                562473, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                562473, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                567934, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                567934, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                573395, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                573395, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                578856, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                578856, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                584317, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                584317, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                589778, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                589778, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                595238, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                595238, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                600699, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                600699, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                606160, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                606160, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                611621, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                611621, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                617082, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                617082, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                622543, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                622543, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                628004, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                628004, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                633465, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                633465, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                638926, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                638926, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                644387, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                644387, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                649848, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                649848, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                655308, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                655308, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                660769, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                660769, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                666230, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                666230, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                671691, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                671691, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                677152, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                677152, "NoteOn", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                682613, "NoteOff", "Note" -> 66, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                682613, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                688074, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                688074, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                693535, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                693535, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                698996, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                698996, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                704457, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                704457, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                709918, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                709918, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                715378, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                715378, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                720839, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                720839, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                726300, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                726300, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                731761, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                731761, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                737222, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                737222, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                742683, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                742683, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                748144, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                748144, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                753605, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                753605, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                759066, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                759066, "NoteOn", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                764527, "NoteOff", "Note" -> 68, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                764527, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                769988, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                769988, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                775448, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                775448, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                780909, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                780909, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                786370, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                786370, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                791831, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                791831, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                797292, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                797292, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                802753, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                802753, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                808214, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                808214, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                813675, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                813675, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                819136, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                819136, "NoteOn", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                824597, "NoteOff", "Note" -> 70, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                824597, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                830058, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                830058, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                835518, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                835518, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                840979, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                840979, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                846440, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                846440, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                851901, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                851901, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                857362, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                857362, "NoteOn", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                862823, "NoteOff", "Note" -> 72, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                862823, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                868284, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                868284, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                873745, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                873745, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                879206, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                879206, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                884667, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                884667, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                890127, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                890127, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                895588, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                895588, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                901049, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                901049, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                906510, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                906510, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                911971, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                911971, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                917432, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                917432, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                922893, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                922893, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                928354, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                928354, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                933815, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                933815, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                939276, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                939276, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                944737, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                944737, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                950197, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                950197, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                955658, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                955658, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                961119, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                961119, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                966580, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                966580, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                972041, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                972041, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                977502, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                977502, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                982963, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                982963, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                988424, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                988424, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                993885, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                993885, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                999346, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                999346, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1004807, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1004807, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1010267, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1010267, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1015728, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1015728, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1021189, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1021189, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1026650, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1026650, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1032111, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1032111, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1037572, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1037572, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1043033, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1043033, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1048494, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1048494, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1053955, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1053955, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1059416, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1059416, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1064877, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1064877, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1070337, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1070337, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1075798, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1075798, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1081259, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1081259, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1086720, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1086720, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1092181, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1092181, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1097642, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1097642, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1103103, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1103103, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1108564, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1108564, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1114025, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1114025, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1119486, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1119486, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1124946, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1124946, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1130407, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1130407, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1135868, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1135868, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1141329, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1141329, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1146790, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1146790, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1152251, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1152251, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1157712, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1157712, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1163173, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1163173, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1168634, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1168634, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1174095, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1174095, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1179556, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1179556, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1185017, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1185017, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1190477, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1190477, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1195938, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1195938, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1201399, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1201399, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1206860, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1206860, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1212321, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1212321, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1217782, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1217782, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1223243, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1223243, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1228704, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1228704, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1234165, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1234165, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1239626, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1239626, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1245086, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1245086, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1250547, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1250547, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1256008, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1256008, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1261469, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1261469, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1266930, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1266930, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1272391, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1272391, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1277852, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1277852, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1283313, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1283313, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1288774, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1288774, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1294235, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1294235, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1299696, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1299696, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1305156, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1305156, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1310617, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1310617, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1316078, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1316078, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1321539, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1321539, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1327000, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1327000, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1332461, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1332461, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1337922, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1337922, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1343383, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1343383, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1348844, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1348844, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1354305, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1354305, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1359766, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1359766, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1365226, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1365226, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1370687, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1370687, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1376148, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1376148, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1381609, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1381609, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1387070, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1387070, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1392531, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1392531, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1397992, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1397992, "NoteOn", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1403453, "NoteOff", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1403453, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1408914, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1408914, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1414375, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1414375, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1419836, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1419836, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1425296, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1425296, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1430757, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1430757, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1436218, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1436218, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1441679, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1441679, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1447140, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1447140, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1452601, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1452601, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1458062, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1458062, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1463523, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1463523, "NoteOn", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1468984, "NoteOff", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1468984, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1474445, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1474445, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1479906, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1479906, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1485366, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1485366, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1490827, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1490827, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1496288, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1496288, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1501749, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1501749, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1507210, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1507210, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1512671, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1512671, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1518132, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1518132, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1523593, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1523593, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1529054, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1529054, "NoteOn", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1534515, "NoteOff", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1534515, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1539976, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1539976, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1545436, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1545436, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1550897, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1550897, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1556358, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1556358, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1561819, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1561819, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1567280, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1567280, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1572741, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1572741, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1578202, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1578202, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1583663, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1583663, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1589124, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1589124, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1594585, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1594585, "NoteOn", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1600045, "NoteOff", "Note" -> 62, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1600045, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1605506, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1605506, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1610967, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1610967, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1616428, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1616428, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1621889, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1621889, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1627350, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1627350, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1632811, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1632811, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1638272, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1638272, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1643733, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1643733, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1649194, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1649194, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1654655, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1654655, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1660115, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1660115, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1665576, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1665576, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1671037, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1671037, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1676498, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1676498, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1681959, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1681959, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1687420, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1687420, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1692881, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1692881, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1698342, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1698342, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1703803, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1703803, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1709264, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1709264, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1714725, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1714725, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1720185, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1720185, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1725646, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1725646, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1731107, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1731107, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1736568, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1736568, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1742029, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1742029, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1747490, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1747490, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1752951, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1752951, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1758412, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1758412, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1763873, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1763873, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1769334, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1769334, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1774795, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1774795, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1780255, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1780255, "NoteOn", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1785716, "NoteOff", "Note" -> 63, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1785716, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1791177, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1791177, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1796638, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1796638, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1802099, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1802099, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1807560, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1807560, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1813021, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1813021, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1818482, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1818482, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1823943, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1823943, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1829404, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1829404, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1834865, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1834865, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1840325, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1840325, "NoteOn", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1845786, "NoteOff", "Note" -> 64, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1845786, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1851247, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1851247, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1856708, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1856708, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1862169, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1862169, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1867630, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1867630, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1873091, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1873091, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1878552, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1878552, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1884013, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1884013, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1889474, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1889474, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1894935, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1894935, "NoteOn", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1900395, "NoteOff", "Note" -> 65, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1900395, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1905856, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1905856, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1911317, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1911317, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1916778, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1916778, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1922239, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1922239, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1927700, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1927700, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1933161, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1933161, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1938622, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1938622, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1944083, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1944083, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1949544, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1949544, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1955005, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1955005, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1960465, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1960465, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1965926, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1965926, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1971387, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1971387, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1976848, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1976848, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1982309, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1982309, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1987770, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1987770, "NoteOn", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1993231, "NoteOff", "Note" -> 67, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1993231, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1998692, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1998692, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2004153, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2004153, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2009614, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2009614, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2015074, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2015074, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2020535, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2020535, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2025996, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2025996, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2031457, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2031457, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2036918, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2036918, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2042379, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2042379, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2047840, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2047840, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2053301, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2053301, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2058762, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2058762, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2064223, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2064223, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2069684, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2069684, "NoteOn", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2075145, "NoteOff", "Note" -> 69, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2075145, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2080605, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2080605, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2086066, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2086066, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2091527, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2091527, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2096988, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2096988, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2102449, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2102449, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2107910, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2107910, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2113371, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2113371, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2118832, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2118832, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2124293, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2124293, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2129754, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2129754, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2135214, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2135214, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2140675, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2140675, "NoteOn", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2146136, "NoteOff", "Note" -> 71, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2146136, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2151597, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2151597, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2157058, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2157058, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2162519, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2162519, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2167980, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2167980, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2173441, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2173441, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2178902, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2178902, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2184363, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2184363, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2189824, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2189824, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2195284, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2195284, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2200745, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2200745, "NoteOn", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2206206, "NoteOff", "Note" -> 73, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2206206, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2211667, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2211667, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2217128, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2217128, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2222589, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2222589, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2228050, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2228050, "NoteOn", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2233511, "NoteOff", "Note" -> 74, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2233511, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2238972, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2238972, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2244433, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2244433, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2249894, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2249894, "NoteOn", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2255354, "NoteOff", "Note" -> 75, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2255354, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2260815, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2260815, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2266276, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2266276, "NoteOn", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2271737, "NoteOff", "Note" -> 76, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2271737, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2277198, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2277198, "NoteOn", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2282659, "NoteOff", "Note" -> 77, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2282659, "NoteOn", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2288120, "NoteOff", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2288120, "NoteOn", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2293581, "NoteOff", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2293581, "NoteOn", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2299042, "NoteOff", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2299042, "NoteOn", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2304503, "NoteOff", "Note" -> 78, "Channel" -> 0, "Velocity" -> 
                 0]}], 
              Sound`MIDITrack[{
                Sound`MIDIEvent[0, "SetTempo", "Tempo" -> 1000000], 
                Sound`MIDIEvent[
                0, "ProgramCommand", "Channel" -> 1, "Value" -> 13], 
                Sound`MIDIEvent[
                0, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 127], 
                Sound`MIDIEvent[
                5461, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                5461, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                10922, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                10922, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                16383, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                16383, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                21844, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                21844, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                27305, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                27305, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                32767, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                32767, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                38228, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                38228, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                43689, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                43689, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                49150, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                49150, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                54611, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                54611, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                60072, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                60072, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                65534, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                65534, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                70995, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                70995, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                76456, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                76456, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                81917, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                81917, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                87378, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                87378, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                92839, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                92839, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                98301, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                98301, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                103762, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                103762, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                109223, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                109223, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                114684, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                114684, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                120145, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                120145, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                125606, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                125606, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                131068, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                131068, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                136529, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                136529, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                141990, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                141990, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                147451, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                147451, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                152912, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                152912, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                158373, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                158373, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                163835, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                163835, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                169296, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                169296, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                174757, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                174757, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                180218, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                180218, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                185679, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                185679, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                191140, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                191140, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                196602, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                196602, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                202063, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                202063, "NoteOn", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                207524, "NoteOff", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                207524, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                212985, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                212985, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                218446, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                218446, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                223907, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                223907, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                229369, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                229369, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                234830, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                234830, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                240291, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                240291, "NoteOn", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                245752, "NoteOff", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                245752, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                251213, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                251213, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                256674, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                256674, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                262136, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                262136, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                267597, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                267597, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                273058, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                273058, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                278519, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                278519, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                283980, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                283980, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                289441, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                289441, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                294903, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                294903, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                300364, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                300364, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                305825, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                305825, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                311286, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                311286, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                316747, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                316747, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                322208, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                322208, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                327670, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                327670, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                333131, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                333131, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                338592, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                338592, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                344053, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                344053, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                349514, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                349514, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                354975, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                354975, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                360437, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                360437, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                365898, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                365898, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                371359, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                371359, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                376820, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                376820, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                382281, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                382281, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                387742, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                387742, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                393204, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                393204, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                398665, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                398665, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                404126, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                404126, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                409587, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                409587, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                415048, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                415048, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                420509, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                420509, "NoteOn", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                425971, "NoteOff", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                425971, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                431432, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                431432, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                436893, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                436893, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                442354, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                442354, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                447815, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                447815, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                453276, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                453276, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                458738, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                458738, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                464199, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                464199, "NoteOn", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                469660, "NoteOff", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                469660, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                475121, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                475121, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                480582, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                480582, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                486043, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                486043, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                491505, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                491505, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                496966, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                496966, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                502427, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                502427, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                507888, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                507888, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                513349, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                513349, "NoteOn", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                518810, "NoteOff", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                518810, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                524272, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                524272, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                529733, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                529733, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                535194, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                535194, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                540655, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                540655, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                546116, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                546116, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                551577, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                551577, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                557039, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                557039, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                562500, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                562500, "NoteOn", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                567961, "NoteOff", "Note" -> 71, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                567961, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                573422, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                573422, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                578883, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                578883, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                584344, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                584344, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                589806, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                589806, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                595267, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                595267, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                600728, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                600728, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                606189, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                606189, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                611650, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                611650, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                617111, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                617111, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                622573, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                622573, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                628034, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                628034, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                633495, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                633495, "NoteOn", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                638956, "NoteOff", "Note" -> 69, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                638956, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                644417, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                644417, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                649878, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                649878, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                655340, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                655340, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                660801, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                660801, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                666262, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                666262, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                671723, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                671723, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                677184, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                677184, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                682645, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                682645, "NoteOn", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                688107, "NoteOff", "Note" -> 67, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                688107, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                693568, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                693568, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                699029, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                699029, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                704490, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                704490, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                709951, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                709951, "NoteOn", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                715412, "NoteOff", "Note" -> 65, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                715412, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                720874, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                720874, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                726335, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                726335, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                731796, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                731796, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                737257, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                737257, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                742718, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                742718, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                748179, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                748179, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                753641, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                753641, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                759102, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                759102, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                764563, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                764563, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                770024, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                770024, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                775485, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                775485, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                780946, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                780946, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                786408, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                786408, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                791869, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                791869, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                797330, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                797330, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                802791, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                802791, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                808252, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                808252, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                813713, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                813713, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                819175, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                819175, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                824636, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                824636, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                830097, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                830097, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                835558, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                835558, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                841019, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                841019, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                846480, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                846480, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                851942, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                851942, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                857403, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                857403, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                862864, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                862864, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                868325, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                868325, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                873786, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                873786, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                879247, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                879247, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                884709, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                884709, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                890170, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                890170, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                895631, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                895631, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                901092, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                901092, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                906553, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                906553, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                912014, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                912014, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                917476, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                917476, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                922937, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                922937, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                928398, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                928398, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                933859, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                933859, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                939320, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                939320, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                944781, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                944781, "NoteOn", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                950243, "NoteOff", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                950243, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                955704, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                955704, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                961165, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                961165, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                966626, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                966626, "NoteOn", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                972087, "NoteOff", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                972087, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                977548, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                977548, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                983010, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                983010, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                988471, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                988471, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                993932, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                993932, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                999393, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                999393, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1004854, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1004854, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1010315, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1010315, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1015777, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1015777, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1021238, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1021238, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1026699, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1026699, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1032160, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1032160, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1037621, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1037621, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1043082, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1043082, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1048544, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1048544, "NoteOn", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1054005, "NoteOff", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1054005, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1059466, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1059466, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1064927, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1064927, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1070388, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1070388, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1075849, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1075849, "NoteOn", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1081311, "NoteOff", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1081311, "NoteOn", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1086772, "NoteOff", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1086772, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1092233, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1092233, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1097694, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1097694, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1103155, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1103155, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1108616, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1108616, "NoteOn", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1114078, "NoteOff", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1114078, "NoteOn", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1119539, "NoteOff", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1119539, "NoteOn", "Note" -> 76, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1125000, "NoteOff", "Note" -> 76, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1125000, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1130461, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1130461, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1135922, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1135922, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1141383, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1141383, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1146845, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1146845, "NoteOn", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1152306, "NoteOff", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1152306, "NoteOn", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1157767, "NoteOff", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1157767, "NoteOn", "Note" -> 76, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1163228, "NoteOff", "Note" -> 76, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1163228, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1168689, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1168689, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1174150, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1174150, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1179612, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1179612, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1185073, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1185073, "NoteOn", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1190534, "NoteOff", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1190534, "NoteOn", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1195995, "NoteOff", "Note" -> 75, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1195995, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1201456, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1201456, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1206917, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1206917, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1212379, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1212379, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1217840, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1217840, "NoteOn", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1223301, "NoteOff", "Note" -> 74, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1223301, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1228762, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1228762, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1234223, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1234223, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1239684, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1239684, "NoteOn", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1245146, "NoteOff", "Note" -> 73, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1245146, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1250607, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1250607, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1256068, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1256068, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1261529, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1261529, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1266990, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1266990, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1272451, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1272451, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1277913, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1277913, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1283374, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1283374, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1288835, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1288835, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1294296, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1294296, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1299757, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1299757, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1305218, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1305218, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1310680, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1310680, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1316141, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1316141, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1321602, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1321602, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1327063, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1327063, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1332524, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1332524, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1337985, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1337985, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1343447, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1343447, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1348908, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1348908, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1354369, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1354369, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1359830, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1359830, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1365291, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1365291, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1370752, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1370752, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1376214, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1376214, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1381675, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1381675, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1387136, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1387136, "NoteOn", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1392597, "NoteOff", "Note" -> 64, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1392597, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1398058, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1398058, "NoteOn", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1403519, "NoteOff", "Note" -> 63, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1403519, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1408981, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1408981, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1414442, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1414442, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1419903, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1419903, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1425364, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1425364, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1430825, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1430825, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1436286, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1436286, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1441748, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1441748, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1447209, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1447209, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1452670, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1452670, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1458131, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1458131, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1463592, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1463592, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1469053, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1469053, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1474515, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1474515, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1479976, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1479976, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1485437, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1485437, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1490898, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1490898, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1496359, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1496359, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1501820, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1501820, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1507282, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1507282, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1512743, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1512743, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1518204, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1518204, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1523665, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1523665, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1529126, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1529126, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1534587, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1534587, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1540049, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1540049, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1545510, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1545510, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1550971, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1550971, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1556432, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1556432, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1561893, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1561893, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1567354, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1567354, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1572816, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1572816, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1578277, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1578277, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1583738, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1583738, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1589199, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1589199, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1594660, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1594660, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1600121, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1600121, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1605583, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1605583, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1611044, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1611044, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1616505, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1616505, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1621966, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1621966, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1627427, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1627427, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1632888, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1632888, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1638350, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1638350, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1643811, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1643811, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1649272, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1649272, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1654733, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1654733, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1660194, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1660194, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1665655, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1665655, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1671117, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1671117, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1676578, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1676578, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1682039, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1682039, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1687500, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1687500, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1692961, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1692961, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1698422, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1698422, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1703884, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1703884, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1709345, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1709345, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1714806, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1714806, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1720267, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1720267, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1725728, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1725728, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1731189, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1731189, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1736651, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1736651, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1742112, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1742112, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1747573, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1747573, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1753034, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1753034, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1758495, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1758495, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1763956, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1763956, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1769418, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1769418, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1774879, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1774879, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1780340, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1780340, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1785801, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1785801, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1791262, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1791262, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1796723, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1796723, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1802185, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1802185, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1807646, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1807646, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1813107, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1813107, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1818568, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1818568, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1824029, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1824029, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1829490, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1829490, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1834952, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1834952, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1840413, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1840413, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1845874, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1845874, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1851335, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1851335, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1856796, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1856796, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1862257, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1862257, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1867719, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1867719, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1873180, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1873180, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1878641, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1878641, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1884102, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1884102, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1889563, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1889563, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1895024, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1895024, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1900486, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1900486, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1905947, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1905947, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1911408, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1911408, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1916869, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1916869, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1922330, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1922330, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1927791, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1927791, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1933253, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1933253, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1938714, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1938714, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1944175, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1944175, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1949636, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1949636, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1955097, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1955097, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1960558, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1960558, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1966020, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1966020, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1971481, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1971481, "NoteOn", "Note" -> 79, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1976942, "NoteOff", "Note" -> 79, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1976942, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1982403, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1982403, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1987864, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1987864, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1993325, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1993325, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1998787, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1998787, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2004248, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2004248, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2009709, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2009709, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2015170, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2015170, "NoteOn", "Note" -> 79, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2020631, "NoteOff", "Note" -> 79, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2020631, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2026092, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2026092, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2031554, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2031554, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2037015, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2037015, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2042476, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2042476, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2047937, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2047937, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2053398, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2053398, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2058859, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2058859, "NoteOn", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2064321, "NoteOff", "Note" -> 60, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2064321, "NoteOn", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2069782, "NoteOff", "Note" -> 61, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2069782, "NoteOn", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2075243, "NoteOff", "Note" -> 62, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2075243, "NoteOn", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2080704, "NoteOff", "Note" -> 66, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2080704, "NoteOn", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2086165, "NoteOff", "Note" -> 68, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2086165, "NoteOn", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2091626, "NoteOff", "Note" -> 70, "Channel" -> 1, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2091626, "NoteOn", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2097088, "NoteOff", "Note" -> 72, "Channel" -> 1, "Velocity" -> 
                 0]}], 
              Sound`MIDITrack[{
                Sound`MIDIEvent[0, "SetTempo", "Tempo" -> 1000000], 
                Sound`MIDIEvent[
                0, "ProgramCommand", "Channel" -> 2, "Value" -> 46], 
                Sound`MIDIEvent[
                0, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 127], 
                Sound`MIDIEvent[
                5461, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                5461, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                10922, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                10922, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                16383, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                16383, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                21844, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                21844, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                27305, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                27305, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                32767, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                32767, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                38228, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                38228, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                43689, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                43689, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                49150, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                49150, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                54611, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                54611, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                60072, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                60072, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                65534, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                65534, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                70995, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                70995, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                76456, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                76456, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                81917, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                81917, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                87378, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                87378, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                92839, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                92839, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                98301, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                98301, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                103762, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                103762, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                109223, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                109223, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                114684, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                114684, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                120145, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                120145, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                125606, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                125606, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                131068, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                131068, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                136529, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                136529, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                141990, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                141990, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                147451, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 0\
], 
                Sound`MIDIEvent[
                147451, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                152912, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                152912, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                158373, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                158373, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                163835, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                163835, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                169296, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                169296, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                174757, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                174757, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                180218, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                180218, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                185679, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                185679, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                191140, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                191140, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                196602, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                196602, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                202063, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                202063, "NoteOn", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                207524, "NoteOff", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                207524, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                212985, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                212985, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                218446, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                218446, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                223907, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                223907, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                229369, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                229369, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                234830, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                234830, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                240291, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                240291, "NoteOn", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                245752, "NoteOff", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                245752, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                251213, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                251213, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                256674, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                256674, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                262136, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                262136, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                267597, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                267597, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                273058, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                273058, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                278519, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                278519, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                283980, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                283980, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                289441, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                289441, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                294903, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                294903, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                300364, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                300364, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                305825, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                305825, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                311286, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                311286, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                316747, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                316747, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                322208, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                322208, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                327670, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                327670, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                333131, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                333131, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                338592, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                338592, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                344053, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                344053, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                349514, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                349514, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                354975, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                354975, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                360437, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                360437, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                365898, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                365898, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                371359, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                371359, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                376820, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                376820, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                382281, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                382281, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                387742, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                387742, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                393204, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                393204, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                398665, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                398665, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                404126, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                404126, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                409587, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                409587, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                415048, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                415048, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                420509, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                420509, "NoteOn", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                425971, "NoteOff", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                425971, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                431432, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                431432, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                436893, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                436893, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                442354, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                442354, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                447815, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                447815, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                453276, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                453276, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                458738, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                458738, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                464199, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                464199, "NoteOn", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                469660, "NoteOff", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                469660, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                475121, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                475121, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                480582, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                480582, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                486043, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                486043, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                491505, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                491505, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                496966, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                496966, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                502427, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                502427, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                507888, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                507888, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                513349, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                513349, "NoteOn", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                518810, "NoteOff", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                518810, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                524272, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                524272, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                529733, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                529733, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                535194, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                535194, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                540655, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                540655, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                546116, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                546116, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                551577, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                551577, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                557039, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                557039, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                562500, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                562500, "NoteOn", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                567961, "NoteOff", "Note" -> 71, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                567961, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                573422, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                573422, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                578883, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                578883, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                584344, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                584344, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                589806, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                589806, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                595267, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                595267, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                600728, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                600728, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                606189, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                606189, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                611650, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                611650, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                617111, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                617111, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                622573, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                622573, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                628034, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                628034, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                633495, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                633495, "NoteOn", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                638956, "NoteOff", "Note" -> 69, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                638956, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                644417, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                644417, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                649878, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                649878, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                655340, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                655340, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                660801, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                660801, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                666262, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                666262, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                671723, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                671723, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                677184, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                677184, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                682645, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                682645, "NoteOn", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                688107, "NoteOff", "Note" -> 67, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                688107, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                693568, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                693568, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                699029, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                699029, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                704490, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                704490, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                709951, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                709951, "NoteOn", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                715412, "NoteOff", "Note" -> 65, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                715412, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                720874, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                720874, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                726335, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                726335, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                731796, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                731796, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                737257, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                737257, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                742718, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                742718, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                748179, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                748179, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                753641, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                753641, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                759102, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                759102, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                764563, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                764563, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                770024, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                770024, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                775485, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                775485, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                780946, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                780946, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                786408, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                786408, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                791869, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                791869, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                797330, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                797330, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                802791, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                802791, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                808252, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                808252, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                813713, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                813713, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                819175, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                819175, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                824636, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                824636, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                830097, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                830097, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                835558, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                835558, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                841019, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                841019, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                846480, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                846480, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                851942, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                851942, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                857403, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                857403, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                862864, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                862864, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                868325, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                868325, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                873786, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                873786, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                879247, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                879247, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                884709, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                884709, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                890170, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                890170, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                895631, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                895631, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                901092, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                901092, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                906553, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                906553, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                912014, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                912014, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                917476, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                917476, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                922937, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                922937, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                928398, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                928398, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                933859, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                933859, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                939320, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                939320, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                944781, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                944781, "NoteOn", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                950243, "NoteOff", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                950243, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                955704, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                955704, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                961165, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                961165, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                966626, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                966626, "NoteOn", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                972087, "NoteOff", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                972087, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                977548, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                977548, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                983010, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                983010, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                988471, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                988471, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                993932, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                993932, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                999393, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                999393, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1004854, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1004854, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1010315, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1010315, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1015777, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1015777, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1021238, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1021238, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1026699, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1026699, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1032160, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1032160, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1037621, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1037621, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1043082, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1043082, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1048544, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1048544, "NoteOn", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1054005, "NoteOff", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1054005, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1059466, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1059466, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1064927, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1064927, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1070388, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1070388, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1075849, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1075849, "NoteOn", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1081311, "NoteOff", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1081311, "NoteOn", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1086772, "NoteOff", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1086772, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1092233, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1092233, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1097694, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1097694, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1103155, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1103155, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1108616, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1108616, "NoteOn", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1114078, "NoteOff", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1114078, "NoteOn", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1119539, "NoteOff", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1119539, "NoteOn", "Note" -> 76, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1125000, "NoteOff", "Note" -> 76, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1125000, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1130461, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1130461, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1135922, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1135922, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1141383, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1141383, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1146845, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1146845, "NoteOn", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1152306, "NoteOff", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1152306, "NoteOn", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1157767, "NoteOff", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1157767, "NoteOn", "Note" -> 76, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1163228, "NoteOff", "Note" -> 76, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1163228, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1168689, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1168689, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1174150, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1174150, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1179612, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1179612, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1185073, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1185073, "NoteOn", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1190534, "NoteOff", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1190534, "NoteOn", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1195995, "NoteOff", "Note" -> 75, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1195995, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1201456, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1201456, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1206917, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1206917, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1212379, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1212379, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1217840, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1217840, "NoteOn", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1223301, "NoteOff", "Note" -> 74, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1223301, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1228762, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1228762, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1234223, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1234223, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1239684, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1239684, "NoteOn", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1245146, "NoteOff", "Note" -> 73, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1245146, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1250607, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1250607, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1256068, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1256068, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1261529, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1261529, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1266990, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1266990, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1272451, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1272451, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1277913, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1277913, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1283374, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1283374, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1288835, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1288835, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1294296, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1294296, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1299757, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1299757, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1305218, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1305218, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1310680, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1310680, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1316141, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1316141, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1321602, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1321602, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1327063, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1327063, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1332524, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1332524, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1337985, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1337985, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1343447, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1343447, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1348908, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1348908, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1354369, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1354369, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1359830, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1359830, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1365291, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1365291, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1370752, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1370752, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1376214, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1376214, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1381675, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1381675, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1387136, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1387136, "NoteOn", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1392597, "NoteOff", "Note" -> 64, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1392597, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1398058, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1398058, "NoteOn", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1403519, "NoteOff", "Note" -> 63, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1403519, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1408981, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1408981, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1414442, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1414442, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1419903, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1419903, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1425364, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1425364, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1430825, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1430825, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1436286, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1436286, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1441748, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1441748, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1447209, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1447209, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1452670, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1452670, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1458131, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1458131, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1463592, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1463592, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1469053, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1469053, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1474515, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1474515, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1479976, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1479976, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1485437, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1485437, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1490898, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1490898, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1496359, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1496359, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1501820, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1501820, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1507282, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1507282, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1512743, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1512743, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1518204, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1518204, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1523665, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1523665, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1529126, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1529126, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1534587, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1534587, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1540049, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1540049, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1545510, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1545510, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1550971, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1550971, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1556432, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1556432, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1561893, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1561893, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1567354, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1567354, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1572816, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1572816, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1578277, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1578277, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1583738, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1583738, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1589199, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1589199, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1594660, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1594660, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1600121, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1600121, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1605583, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1605583, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1611044, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1611044, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1616505, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1616505, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1621966, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1621966, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1627427, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1627427, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1632888, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1632888, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1638350, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1638350, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1643811, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1643811, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1649272, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1649272, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1654733, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1654733, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1660194, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1660194, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1665655, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1665655, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1671117, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1671117, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1676578, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1676578, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1682039, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1682039, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1687500, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1687500, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1692961, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1692961, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1698422, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1698422, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1703884, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1703884, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1709345, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1709345, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1714806, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1714806, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1720267, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1720267, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1725728, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1725728, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1731189, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1731189, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1736651, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1736651, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1742112, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1742112, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1747573, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1747573, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1753034, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1753034, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1758495, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1758495, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1763956, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1763956, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1769418, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1769418, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1774879, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1774879, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1780340, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1780340, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1785801, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1785801, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1791262, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1791262, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1796723, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1796723, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1802185, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1802185, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1807646, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1807646, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1813107, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1813107, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1818568, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1818568, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1824029, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1824029, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1829490, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1829490, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1834952, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1834952, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1840413, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1840413, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1845874, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1845874, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1851335, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1851335, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1856796, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1856796, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1862257, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1862257, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1867719, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1867719, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1873180, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1873180, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1878641, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1878641, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1884102, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1884102, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1889563, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1889563, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1895024, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1895024, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1900486, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1900486, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1905947, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1905947, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1911408, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1911408, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1916869, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1916869, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1922330, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1922330, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1927791, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1927791, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1933253, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1933253, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1938714, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1938714, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1944175, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1944175, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1949636, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1949636, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1955097, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1955097, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1960558, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1960558, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1966020, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1966020, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1971481, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1971481, "NoteOn", "Note" -> 79, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1976942, "NoteOff", "Note" -> 79, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1976942, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1982403, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1982403, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1987864, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1987864, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1993325, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1993325, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                1998787, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                1998787, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2004248, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2004248, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2009709, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2009709, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2015170, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2015170, "NoteOn", "Note" -> 79, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2020631, "NoteOff", "Note" -> 79, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2020631, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2026092, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2026092, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2031554, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2031554, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2037015, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2037015, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2042476, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2042476, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2047937, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2047937, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2053398, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2053398, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2058859, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2058859, "NoteOn", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2064321, "NoteOff", "Note" -> 60, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2064321, "NoteOn", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2069782, "NoteOff", "Note" -> 61, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2069782, "NoteOn", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2075243, "NoteOff", "Note" -> 62, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2075243, "NoteOn", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2080704, "NoteOff", "Note" -> 66, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2080704, "NoteOn", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2086165, "NoteOff", "Note" -> 68, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2086165, "NoteOn", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2091626, "NoteOff", "Note" -> 70, "Channel" -> 2, "Velocity" -> 
                 0], 
                Sound`MIDIEvent[
                2091626, "NoteOn", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 127], 
                Sound`MIDIEvent[
                2097088, "NoteOff", "Note" -> 72, "Channel" -> 2, "Velocity" -> 
                 0]}]}, "DivisionType" -> "PPQ", "Resolution" -> 32767]]; 
          Sound`EmitSampledSound[None, "Preemptive"]), PassEventsDown -> 
         Automatic, PassEventsUp -> True}]],
      DynamicBox[
       ToBoxes[
        FEPrivate`FrontEndResource["FEStrings", "playText"], StandardForm]]],
     Annotation[#, 
      Dynamic[
       FEPrivate`FrontEndResource["FEStrings", "playText"]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[{
        {GrayLevel[0.9], RectangleBox[{34, -158}, {58, -135}]}, 
        {GrayLevel[0.3], RectangleBox[{42, -150}, {50, -143}]}, 
        {GrayLevel[0.5], 
         StyleBox[
          LineBox[{{34, -158}, {34, -135}, {58, -135}, {58, -158}, {
           34, -158}}],
          Antialiasing->False]}},
       EventHandlerTag[{"MouseClicked" :> (Sound`EmitSampledSound[
            SampledSoundList[{{0.}}, 8000], "Preemptive"]; Sound`StopMIDI[]), 
         PassEventsDown -> Automatic, PassEventsUp -> True}]],
      DynamicBox[
       ToBoxes[
        FEPrivate`FrontEndResource["FEStrings", "stopText"], StandardForm]]],
     Annotation[#, 
      Dynamic[
       FEPrivate`FrontEndResource["FEStrings", "stopText"]], "Tooltip"]& ], 
    {GrayLevel[0.75], 
     StyleBox[LineBox[{{0, 0}, {360, 0}, {360, -164}, {0, -164}, {0, 0}}],
      Antialiasing->False]}},
   ContentSelectable->False,
   ImageSize->250,
   PlotRange->{{0, 360}, {-164, 0}},
   PlotRangePadding->1],
  Sound[{
    Sound[
     Sound[{
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[6, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[8, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[10, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[12, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[2, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[2, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[2, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[2, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[3, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[4, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[5, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[7, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[9, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[11, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[13, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[14, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[15, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[16, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[17, 
        Rational[1, 6], "Piano"], 
       SoundNote[18, 
        Rational[1, 6], "Piano"], 
       SoundNote[18, 
        Rational[1, 6], "Piano"], 
       SoundNote[18, 
        Rational[1, 6], "Piano"], 
       SoundNote[18, 
        Rational[1, 6], "Piano"]}], {0, 70.33}], 
    Sound[
     Sound[{
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[11, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[11, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[11, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[11, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[11, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[11, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[9, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[7, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[5, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[15, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[15, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[14, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[14, 
        Rational[1, 6], "Harp"], 
       SoundNote[15, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[14, 
        Rational[1, 6], "Harp"], 
       SoundNote[15, 
        Rational[1, 6], "Harp"], 
       SoundNote[16, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[14, 
        Rational[1, 6], "Harp"], 
       SoundNote[15, 
        Rational[1, 6], "Harp"], 
       SoundNote[16, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[14, 
        Rational[1, 6], "Harp"], 
       SoundNote[15, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[14, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[13, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[4, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[3, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[19, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[19, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"], 
       SoundNote[0, 
        Rational[1, 6], "Harp"], 
       SoundNote[1, 
        Rational[1, 6], "Harp"], 
       SoundNote[2, 
        Rational[1, 6], "Harp"], 
       SoundNote[6, 
        Rational[1, 6], "Harp"], 
       SoundNote[8, 
        Rational[1, 6], "Harp"], 
       SoundNote[10, 
        Rational[1, 6], "Harp"], 
       SoundNote[12, 
        Rational[1, 6], "Harp"]}], {0, 64}], 
    Sound[
     Sound[{
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[11, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[11, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[11, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[11, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[11, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[11, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[9, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[7, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[5, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[15, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[15, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[14, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[14, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[15, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[14, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[15, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[16, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[14, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[15, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[16, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[14, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[15, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[14, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[13, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[4, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[3, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[19, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[19, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[0, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[1, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[2, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[6, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[8, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[10, 
        Rational[1, 6], "Xylophone"], 
       SoundNote[12, 
        Rational[1, 6], "Xylophone"]}], {0, 64}]}]]], "Output",
 CellChangeTimes->{
  3.5639023740177813`*^9, 3.5639025512187757`*^9, {3.5639026125436*^9, 
   3.5639026389380074`*^9}, 3.564166004286289*^9, 3.564166799186243*^9, 
   3.5641669927643223`*^9, 3.5641672769838247`*^9, 3.564167505349518*^9, 
   3.564167741797141*^9, 3.5641680855243998`*^9, 3.564168317803734*^9, 
   3.564420706231089*^9, 3.564421435878318*^9, 3.5644215952435207`*^9}]
}, Open  ]],

Cell[TextData[{
 "and ",
 ButtonBox["rules that sound interesting when their features are sonified",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/2012/alumni/belli.html"], 
    None},
  ButtonNote->"http://wolframscience.com/summerschool/2012/alumni/belli.html"],
 " (check out ",
 ButtonBox["Wolfram",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://tones.wolfram.com"], None},
  ButtonNote->"http://tones.wolfram.com"],
 StyleBox[ButtonBox["Tones",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://tones.wolfram.com"], None},
  ButtonNote->"http://tones.wolfram.com"],
  FontSlant->"Italic"],
 "):"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ/b7vUdHChleOEt6TK0B00K+bNSDaazPPZBDN9kNq
OoiutNsyD0Qv4ijZCKLn65RvAtEpyjd2vAHSasF3wbTof8WDIPpKtROY3iXj
UWrQ8srxSfI1MP2TOakWRP9JEmsA0X2qlQJ/W185KrdJCoPoeuUnPJc6XjlG
380RAdFfjN01QfQUJSUtEJ0dOscARJ/d3WoIosXa3X5dBtJZzbvA9JMcT4Yr
QHqjswojiC71vMgOot1sAzlA9AXttUIgOj5+kyyI1njWqA+ipb5BaIlFd/1B
dETm0SAQvSq3/45M3yvHEqP7j0C02Y0fqon9rxzDghjVQLTMlgYtEP14bSeY
nlPNkN8JpO8821kEogFtsLmw
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compressed Outputs of Rules", "Subsection",
 CellChangeTimes->{{3.563903197068426*^9, 3.563903201996687*^9}, {
  3.565003569522114*^9, 3.565003574496874*^9}}],

Cell["\<\
And here are some of the compressed outputs from the student submissions:\
\>", "Text",
 CellChangeTimes->{{3.557100791676693*^9, 3.557100849558629*^9}, {
   3.55896630658988*^9, 3.5589663245952463`*^9}, 3.559909565797371*^9, {
   3.561399079305615*^9, 3.5613991446929903`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulestoshow", "=", 
   RowBox[{"{", 
    RowBox[{
    "291408415736013963231875", ",", "306348580587603138865926", ",", 
     "1080228952069739329181238", ",", "118092828950265984164380", ",", 
     "46868392993848058768517", ",", "494436011706344114840739", ",", 
     "382784415773470871062475", ",", "1079574175721242184175862", ",", 
     "654284170828991479950528", ",", "1107926433466231544254084", ",", 
     "578870483740283859310689", ",", "644848724890336249172854", ",", 
     "430668276334908560862918", ",", "268913976372430922572919", ",", 
     "2906713368153224924918", ",", "169850843303314304904918", ",", 
     "579574175721242184176207", ",", "329442898398309215968044", ",", 
     "128258964068024222052158", ",", "1080228952069739329181238"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5570985720152283`*^9, 3.5570985741835337`*^9}, {
   3.557100024593854*^9, 3.557100024992033*^9}, 3.5571000800798273`*^9, {
   3.563904441998683*^9, 3.563904445391667*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rightleftcompress", "[", "evol_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"maxright", ",", "maxleft"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"Reap", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"maxright", "=", 
        RowBox[{"evol", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"maxleft", "=", 
        RowBox[{"evol", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], ">", "maxright"}], ",",
              "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"maxright", "=", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
              RowBox[{"Sow", "[", "#", "]"}]}]}], "\[IndentingNewLine]", 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"If", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], "<", "maxleft"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"maxleft", "=", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
              RowBox[{"Sow", "[", "#", "]"}]}]}], "\[IndentingNewLine]", 
            "]"}]}], "\[IndentingNewLine]", "}"}], "&"}], "/@", "evol"}]}], 
      "\[IndentingNewLine]", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.550283155672865*^9, 3.5502832527891483`*^9}, {
  3.550283385283328*^9, 3.550283457744259*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rasterize", "@", 
  RowBox[{"Grid", "@", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Button", "[", 
        RowBox[{
         RowBox[{"Framed", "[", 
          RowBox[{
           RowBox[{"ArrayPlot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"rightleftcompress", "[", 
               RowBox[{"TuringMachine", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"#", ",", "4", ",", "4"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", 
                 "5000"}], "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "90"}], ",", 
             RowBox[{"Frame", "\[Rule]", "False"}], ",", 
             RowBox[{"ColorRules", "\[Rule]", "$TMColors"}]}], "]"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", "LightGray"}]}], "]"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"rulestoshow", ",", "#"}], "]"}], ",", 
         RowBox[{"Appearance", "\[Rule]", "None"}]}], "]"}], "&"}], "/@", 
      "rulestoshow"}], ",", "4", ",", "4", ",", "1", ",", 
     RowBox[{"{", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.557098579635502*^9, 3.557098660836109*^9}, {
  3.55709872145105*^9, 3.557098725224321*^9}, {3.5570988400628233`*^9, 
  3.5570988649695797`*^9}, {3.563904449732222*^9, 3.5639044609556227`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsnQdYFEn6/9lwt3t3e7f/S5vz7m/3NrjqmnNWTJiIIpJUMCAq5oiBZEYF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   "], {{0, 0}, {427, 
   518}}, {0, 255},
   ColorFunction->RGBColor],
  ImageSize->{427, 518},
  PlotRange->{{0, 427}, {0, 518}}]], "Output",
 CellChangeTimes->{3.564420740776079*^9, 3.5644214427092133`*^9, 
  3.564421600753221*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Search Scripts", "Section",
 CellChangeTimes->{{3.558966707099535*^9, 3.558966708642933*^9}, {
  3.565003690042715*^9, 3.565003692569628*^9}}],

Cell[TextData[{
 "I decided I wanted to do a search too. I wrote a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " script to do an automated search for Turing machines that met certain \
criteria:"
}], "Text",
 CellChangeTimes->{{3.558966343311668*^9, 3.558966390451436*^9}, {
   3.558966424387743*^9, 3.558966630666869*^9}, {3.558967415475442*^9, 
   3.5589674563386993`*^9}, {3.5613991623508472`*^9, 3.561399193578724*^9}, {
   3.561399277552197*^9, 3.5613992782475967`*^9}, {3.561475770838273*^9, 
   3.561475803139234*^9}, {3.561475853323159*^9, 3.561475861840253*^9}, {
   3.561477875740182*^9, 3.5614778827959347`*^9}, {3.5639049984067593`*^9, 
   3.563904999997925*^9}, {3.563905047117135*^9, 3.563905091843357*^9}, {
   3.563905154226499*^9, 3.563905157282192*^9}, 3.5648316742359056`*^9, {
   3.5648331222490826`*^9, 3.564833122358162*^9}}],

Cell[CellGroupData[{

Cell["Functions", "Subsection",
 CellChangeTimes->{{3.55896706215762*^9, 3.55896706294667*^9}, {
  3.5650036995753307`*^9, 3.565003699878263*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"runtm", "[", 
   RowBox[{"rl_Integer", ",", 
    RowBox[{"steps_:", "50"}]}], "]"}], ":=", 
  RowBox[{"TuringMachine", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rl", ",", "4", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "steps"}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"numtm", "[", 
   RowBox[{"s_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "s", " ", "k"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"s", " ", "k"}], ")"}]}]}], "\n", 
 RowBox[{
  RowBox[{"randomtm", "[", 
   RowBox[{"s_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"RandomInteger", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"numtm", "[", 
       RowBox[{"s", ",", "k"}], "]"}], "-", "1"}]}], "}"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"CleanTM", "[", "evol_", "]"}], ":=", 
  RowBox[{"Catch", "@", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "diffs", ",", "growthrate", ",", "growthdirection", ",", "rotate", ",", 
       "rotatefactor", ",", "dy", ",", "dx", ",", "posdiffs"}], "}"}], ",", 
     RowBox[{
      RowBox[{"diffs", "=", 
       RowBox[{"Differences", "[", "evol", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"posdiffs", "=", 
       RowBox[{"Differences", "[", 
        RowBox[{"Position", "[", 
         RowBox[{"diffs", ",", 
          RowBox[{"x_Integer", "/;", 
           RowBox[{"x", "=!=", "0"}]}], ",", 
          RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"posdiffs", "\[Equal]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"Throw", "[", "evol", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"dx", ",", "dy"}], "}"}], "=", 
       RowBox[{"Mean", "/@", 
        RowBox[{"Transpose", "@", "posdiffs"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"growthrate", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"dx", "=!=", "0"}], ",", 
         RowBox[{"dy", "/", "dx"}], ",", "0"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"growthdirection", "=", 
       RowBox[{"Sign", "@", "growthrate"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotate", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"growthdirection", "<", "0"}], ",", "RotateRight", ",", 
         "RotateLeft"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotatefactor", "=", 
       RowBox[{"Abs", "[", "growthrate", "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"MapIndexed", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rotate", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Round", "[", 
            RowBox[{
             RowBox[{"#2", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "*", "rotatefactor"}], "]"}]}], 
          "]"}], "&"}], ",", "diffs"}], "]"}]}]}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"randomreplace", "[", "evol_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"nonzeroboundary", ",", "nonzeropos", ",", "vals"}], "}"}], ",", 
    
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"vals", "=", 
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "@", "evol"}], "]"}]}], ";"}], "*)"}], 
    RowBox[{
     RowBox[{"nonzeropos", "=", 
      RowBox[{"Position", "[", 
       RowBox[{"evol", ",", 
        RowBox[{"x_", "/;", 
         RowBox[{"x", "\[NotEqual]", "0"}]}], ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vals", "=", 
      RowBox[{"Union", "@", 
       RowBox[{"Flatten", "@", 
        RowBox[{"Extract", "[", 
         RowBox[{"evol", ",", "nonzeropos"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"nonzeroboundary", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"s", "=", 
            RowBox[{"SortBy", "[", 
             RowBox[{"#", ",", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "&"}]}], "]"}]}], "}"}], ",", 
          
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"s", "\[Equal]", 
             RowBox[{"{", "}"}]}], ",", 
            RowBox[{"{", "}"}], ",", 
            RowBox[{"s", "[", 
             RowBox[{"[", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}], "}"}], "]"}], "]"}]}], "]"}]}], "]"}], 
        "&"}], "/@", 
       RowBox[{"GatherBy", "[", 
        RowBox[{"nonzeropos", ",", "First"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Fold", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Module", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"rownum", "=", 
             RowBox[{"#2", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
            RowBox[{"ci", "=", "#"}], ",", 
            RowBox[{"leftnonzero", "=", 
             RowBox[{"#2", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
            RowBox[{"rightnonzero", "=", 
             RowBox[{"#2", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
          
          RowBox[{
           RowBox[{
            RowBox[{"ci", "[", 
             RowBox[{"[", 
              RowBox[{"rownum", ",", 
               RowBox[{"leftnonzero", ";;", "rightnonzero"}]}], "]"}], "]"}], 
            "=", 
            RowBox[{"RandomChoice", "[", 
             RowBox[{"vals", ",", 
              RowBox[{"rightnonzero", "-", "leftnonzero", "+", "1"}]}], 
             "]"}]}], ";", "\[IndentingNewLine]", "ci"}]}], "]"}], "&"}], ",",
        "evol", ",", 
       RowBox[{"Select", "[", 
        RowBox[{"nonzeroboundary", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "@", "#"}], ">", "0"}], "&"}]}], "]"}]}], 
      "]"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"compressionratio", "[", "evol_", "]"}], ":=", 
   RowBox[{
    RowBox[{"StringLength", "@", 
     RowBox[{"Compress", "[", "evol", "]"}]}], "/", 
    RowBox[{"StringLength", "@", 
     RowBox[{"Compress", "[", 
      RowBox[{"randomreplace", "[", "evol", "]"}], "]"}]}]}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "distinct", " ", "run", " ", 
    RowBox[{"lengths", ":"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"firstmoment", "[", "headpos_", "]"}], ":=", 
  RowBox[{"Length", "@", 
   RowBox[{"Tally", "[", 
    RowBox[{"Length", "/@", 
     RowBox[{"Split", "@", 
      RowBox[{"Differences", "@", "headpos"}]}]}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Number", " ", "of", " ", "distinct", " ", "run", " ", "length", " ", 
    RowBox[{"frequencies", ":"}]}], "*)"}], 
  RowBox[{
   RowBox[{"secondmoment", "[", "headpos_", "]"}], ":=", 
   RowBox[{"Length", "@", 
    RowBox[{"Tally", "[", 
     RowBox[{"Length", "/@", 
      RowBox[{"Gather", "@", 
       RowBox[{
        RowBox[{"Tally", "[", 
         RowBox[{"Sort", "[", 
          RowBox[{"Length", "/@", 
           RowBox[{"Split", "@", 
            RowBox[{"Differences", "@", "headpos"}]}]}], "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"-", "1"}]}], "]"}], "]"}]}]}], "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{"moments", "[", "headpos_List", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"firstmoment", "[", "headpos", "]"}], ",", 
    RowBox[{"secondmoment", "[", "headpos", "]"}]}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"rightleftcompress", "[", "evol_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"maxright", ",", "maxleft"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{
       RowBox[{"maxright", "=", 
        RowBox[{"evol", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"maxleft", "=", 
        RowBox[{"evol", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], ">", "maxright"}], ",", 
             RowBox[{
              RowBox[{"maxright", "=", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
              RowBox[{"Sow", "[", "#", "]"}]}]}], "]"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], "<", "maxleft"}], ",", 
             
             RowBox[{
              RowBox[{"maxleft", "=", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
              RowBox[{"Sow", "[", "#", "]"}]}]}], "]"}]}], "}"}], "&"}], "/@",
         "evol"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"Boundaries", "[", "ca_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "a", "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "=", 
            RowBox[{"Position", "[", 
             RowBox[{"#", ",", 
              RowBox[{"x_", "/;", 
               RowBox[{"x", "\[NotEqual]", "0"}]}]}], "]"}]}], ")"}], 
          "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"{", "}"}], ",", 
         RowBox[{"Union", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"a", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "+", "1"}], ",", 
            RowBox[{"a", "[", 
             RowBox[{"[", 
              RowBox[{"-", "1"}], "]"}], "]"}]}], "}"}]}]}], "]"}], "]"}], 
      "&"}], "/@", 
     RowBox[{"Map", "[", 
      RowBox[{"Differences", ",", "ca"}], "]"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"Trim", "[", "ca_", "]"}], ":=", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{"Take", ",", 
     RowBox[{"{", 
      RowBox[{"ca", ",", 
       RowBox[{"Boundaries", "@", "ca"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"{", "}"}], "\[Rule]", 
    RowBox[{"Sequence", "[", "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NonperiodicQ", "[", 
    RowBox[{"ca_", ",", 
     RowBox[{"fraction_:", "0.5"}]}], "]"}], "/;", 
   RowBox[{"fraction", "\[LessEqual]", "1"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tca", ",", "len", ",", "block", ",", "tcablock", ",", "tcablocklen"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{"tca", "=", 
      RowBox[{"Trim", "[", "ca", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tcablock", "=", 
      RowBox[{"tca", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"Round", "[", 
          RowBox[{
           RowBox[{"Length", "@", "tca"}], "/", "2"}], "]"}], ";;", 
         RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tcablocklen", "=", 
      RowBox[{"Length", "[", "tcablock", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"block", "=", 
      RowBox[{"MapIndexed", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{"#", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Min", "[", 
              RowBox[{
               RowBox[{"First", "@", "#2"}], ",", 
               RowBox[{"Length", "@", "#"}]}], "]"}], ",", 
             RowBox[{"Min", "[", 
              RowBox[{
               RowBox[{"tcablocklen", "+", 
                RowBox[{"First", "@", "#2"}]}], ",", 
               RowBox[{"Length", "@", "#"}]}], "]"}]}], "}"}]}], "]"}], "&"}],
         ",", "tcablock"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Length", "@", 
         RowBox[{"Union", "@", "block"}]}], "/", 
        RowBox[{"Length", "@", "block"}]}], ")"}], "\[GreaterEqual]", 
      "fraction"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"CyclicUnion", "[", "lists_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "t", "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "&"}], "/@", 
     RowBox[{"Split", "[", 
      RowBox[{"Last", "@", 
       RowBox[{"Reap", "[", 
        RowBox[{"(", 
         RowBox[{"First", "/@", 
          RowBox[{"Split", "[", 
           RowBox[{"Sort", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sow", "[", 
                 RowBox[{"#", ",", 
                  RowBox[{"t", "=", 
                   RowBox[{"invariant", "[", "#", "]"}]}]}], "]"}], ";", 
                "t"}], ")"}], "&"}], "/@", "lists"}], "]"}], "]"}]}], ")"}], 
        "]"}]}], "]"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"invariant", "[", "list_", "]"}], ":=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"RotateRight", "[", 
      RowBox[{"list", ",", "r"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "1", ",", 
       RowBox[{"Length", "@", "list"}]}], "}"}]}], "]"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"minentropy", "[", "tapeevol_List", "]"}], ":=", 
  RowBox[{
   RowBox[{"Plus", "@@", 
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"N", "@", 
            RowBox[{"Entropy", "@", 
             RowBox[{"Partition", "[", 
              RowBox[{"#", ",", "i", ",", "1"}], "]"}]}]}], "/", 
           RowBox[{"N", "@", 
            RowBox[{"Log", "@", 
             RowBox[{"Length", "[", "#", "]"}]}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}], "&"}], "/@", 
      "tapeevol"}], "]"}]}], "/", 
   RowBox[{"N", "@", 
    RowBox[{"Length", "@", "tapeevol"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.558967054120371*^9, 3.558967054122547*^9}, {
  3.5589673291357107`*^9, 3.558967342654427*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Script"
}], "Subsection",
 CellChangeTimes->{{3.558967030631261*^9, 3.558967031970789*^9}, {
  3.564162743063208*^9, 3.564162745828144*^9}, {3.56500370343222*^9, 
  3.56500370371143*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"outfile", "=", "\"\<tm-4-4-search.txt\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"log", "[", 
   RowBox[{"logline_String", ",", "logfile_String"}], "]"}], ":=", 
  RowBox[{"PutAppend", "[", 
   RowBox[{
    RowBox[{"DateString", "[", "]"}], ",", "logline", ",", "logfile"}], 
   "]"}]}], "\n", 
 RowBox[{"PutAppend", "[", 
  RowBox[{
   RowBox[{"DateString", "[", "]"}], ",", "outfile"}], "]"}], "\n", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "1"}], ",", 
   RowBox[{"i", "<", "1"}], 
   RowBox[{"(*", "Infinity", "*)"}], ",", 
   RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rl", "=", 
        RowBox[{"randomtm", "[", 
         RowBox[{"4", ",", "4"}], "]"}]}], ",", "plot", ",", "evol", ",", 
       "cleanplot", ",", 
       RowBox[{"steps", "=", "25"}], ",", "imoments"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "@", 
          RowBox[{"Union", "@", 
           RowBox[{"CleanTM", "[", 
            RowBox[{"Last", "/@", 
             RowBox[{"TuringMachine", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"rl", ",", "4", ",", "4"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", "steps"}], "}"}], ",", 
                 RowBox[{"Table", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", 
                    RowBox[{"2", "*", "steps"}], "}"}]}], "]"}]}], "}"}], ",",
                "steps"}], "]"}]}], "]"}]}]}], "/", "steps"}], ">", "0.5"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"evol", "=", 
         RowBox[{"runtm", "[", 
          RowBox[{"rl", ",", "1000"}], "]"}]}], ";", 
        RowBox[{"imoments", "=", 
         RowBox[{"moments", "[", "evol", "]"}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"If", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"imoments", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ">", "1"}], "&&", 
           RowBox[{
            RowBox[{"imoments", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ">", "5"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"comp", ",", 
              RowBox[{"longevol", "=", 
               RowBox[{"runtm", "[", 
                RowBox[{"rl", ",", "5000"}], "]"}]}], ",", "cratio", ",", 
              "npQ", ",", "head", ",", "entropy"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"comp", "=", 
              RowBox[{
               RowBox[{"rightleftcompress", "[", "longevol", "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"npQ", "=", 
              RowBox[{"NonperiodicQ", "[", 
               RowBox[{"comp", ",", "0.3"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", "\[IndentingNewLine]", 
              RowBox[{"npQ", ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"cratio", "=", 
                 RowBox[{"N", "@", 
                  RowBox[{"compressionratio", "[", 
                   RowBox[{"comp", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Min", "[", 
                    RowBox[{"10", ",", 
                    RowBox[{"Length", "@", "comp"}]}], "]"}], ";;", 
                    RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"entropy", "=", 
                 RowBox[{"minentropy", "[", "comp", "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"PutAppend", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"\"\<Rule\>\"", "\[Rule]", "rl"}], ",", 
                    RowBox[{"\"\<Moments\>\"", "\[Rule]", "imoments"}], ",", 
                    RowBox[{"\"\<CompressionRatio\>\"", "\[Rule]", "cratio"}],
                     ",", 
                    RowBox[{"\"\<Entropy\>\"", "\[Rule]", "entropy"}]}], 
                   "}"}], ",", "outfile"}], "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"head", "=", 
                 RowBox[{"Framed", "@", 
                  RowBox[{"ListLinePlot", "[", 
                   RowBox[{
                    RowBox[{"longevol", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
                    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}]}]}], ";",
                 "\[IndentingNewLine]", 
                RowBox[{"plot", "=", 
                 RowBox[{"ArrayPlot", "[", 
                  RowBox[{"comp", ",", 
                   RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
                   RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Export", "[", 
                 RowBox[{
                  RowBox[{"\"\<tm-\>\"", "<>", 
                   RowBox[{"IntegerString", "[", "rl", "]"}], "<>", 
                   "\"\<.png\>\""}], ",", 
                  RowBox[{"Column", "[", 
                   RowBox[{"{", 
                    RowBox[{"plot", ",", "head"}], "}"}], "]"}]}], "]"}], 
                ";"}]}], "\[IndentingNewLine]", "]"}]}]}], 
           "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.5589669092559443`*^9, 3.55896702373792*^9}, 
   3.5589671330776176`*^9, {3.563904630129386*^9, 3.5639047149821577`*^9}, 
   3.563904748419942*^9, {3.563904796529592*^9, 3.563904876801401*^9}, 
   3.563904936702668*^9, {3.564166632325261*^9, 3.564166634405098*^9}, {
   3.564420782361123*^9, 3.564420783838327*^9}},
 FontSize->12],

Cell["\<\
The script chooses random rule numbers to run and test, and then writes the \
rule number and some statistics to a file called tm-4-4-search.txt for each \
Turing machine rule that passes through the various filters.\
\>", "Text",
 CellChangeTimes->{{3.561475872420533*^9, 3.561476042649868*^9}, {
  3.561476081185758*^9, 3.561476095488728*^9}, {3.561476628492221*^9, 
  3.561476836411479*^9}, {3.5614770351468563`*^9, 3.5614770353603992`*^9}, {
  3.561477802710532*^9, 3.561477853972628*^9}, {3.561477924483927*^9, 
  3.561477952151156*^9}, {3.561478057081334*^9, 3.561478065824366*^9}, {
  3.563905164705586*^9, 3.563905225120182*^9}, {3.5639054798015003`*^9, 
  3.563905548214224*^9}, {3.5639060093411293`*^9, 3.5639060093425627`*^9}, {
  3.5648316773974075`*^9, 3.5648316776310163`*^9}, {3.564833137005994*^9, 
  3.564833138657771*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Entropy Measure", "Subsection",
 CellChangeTimes->{{3.564162767903488*^9, 3.564162771586364*^9}, {
  3.565003711389021*^9, 3.565003714388487*^9}}],

Cell[TextData[{
 "The filters are run in stages, with faster filters running before the \
slower ones, to minimize the time spent running the slower filters on rules \
that don't have a chance of making it through anyway. The final filter \
measures the complexity of the compressed tape using this ",
 ButtonBox["block-entropy",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/nksonline/page-1084e-text"], None},
  ButtonNote->"http://www.wolframscience.com/nksonline/page-1084e-text"],
 " measure (which was thought up by ",
 ButtonBox["one our fine high school students",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/2012/alumni/palasek.html"], 
    None},
  ButtonNote->
   "http://wolframscience.com/summerschool/2012/alumni/palasek.html"],
 " this year):"
}], "Text",
 CellChangeTimes->{{3.561475872420533*^9, 3.561476042649868*^9}, {
   3.561476081185758*^9, 3.561476095488728*^9}, {3.561476628492221*^9, 
   3.561476836411479*^9}, {3.5614770351468563`*^9, 3.5614770353603992`*^9}, {
   3.561477802710532*^9, 3.561477853972628*^9}, {3.561477924483927*^9, 
   3.561477952151156*^9}, {3.561478057081334*^9, 3.561478065824366*^9}, {
   3.563905164705586*^9, 3.563905225120182*^9}, {3.5639054798015003`*^9, 
   3.563905548214224*^9}, {3.5639060093411293`*^9, 3.5639060468324347`*^9}, {
   3.563906108114929*^9, 3.5639061241819887`*^9}, {3.563906171576273*^9, 
   3.5639061834600563`*^9}, 3.5639063278692293`*^9, 3.5648316810728483`*^9, {
   3.5648331498306384`*^9, 3.564833164213563*^9}, {3.56491570081539*^9, 
   3.564915726391082*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"minentropy", "[", "tapeevol_List", "]"}], ":=", 
  RowBox[{
   RowBox[{"Plus", "@@", 
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"N", "@", 
            RowBox[{"Entropy", "@", 
             RowBox[{"Partition", "[", 
              RowBox[{"#", ",", "i", ",", "1"}], "]"}]}]}], "/", 
           RowBox[{"N", "@", 
            RowBox[{"Log", "@", 
             RowBox[{"Length", "[", "#", "]"}]}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}], "&"}], "/@", 
      "tapeevol"}], "]"}]}], "/", 
   RowBox[{"N", "@", 
    RowBox[{"Length", "@", "tapeevol"}]}]}]}]], "Input",
 CellChangeTimes->{3.56140032850196*^9}],

Cell["\<\
A Turing machine with very random-looking compressed output would have an \
entropy closer to 1, and one that has a lot of structure or organization to \
it would have an entropy closer to 0.\
\>", "Text",
 CellChangeTimes->{{3.56390622278938*^9, 3.5639062467788467`*^9}, {
  3.564833175448762*^9, 3.5648331808715763`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example Image Sent by Email", "Subsection",
 CellChangeTimes->{{3.5614765771644793`*^9, 3.561476585130784*^9}, {
  3.5650042614239063`*^9, 3.5650042702262983`*^9}}],

Cell["\<\
If a rule makes it through this final entropy filter, the script outputs a \
little summary image of the rule as a .png file. I made sure the summary \
image was small enough for me to easily glance at in Mail.app on my iPhone 4. \
Here\[CloseCurlyQuote]s an example:\
\>", "Text",
 CellChangeTimes->{{3.561475872420533*^9, 3.561476042649868*^9}, {
  3.561476081185758*^9, 3.561476095488728*^9}, {3.561476628492221*^9, 
  3.561476836411479*^9}, {3.5614770351468563`*^9, 3.5614770353603992`*^9}, {
  3.561477802710532*^9, 3.561477853972628*^9}, {3.561477924483927*^9, 
  3.561477952151156*^9}, {3.561478057081334*^9, 3.561478065824366*^9}, {
  3.563905164705586*^9, 3.563905225120182*^9}, {3.5639054798015003`*^9, 
  3.563905548214224*^9}, {3.5639060093411293`*^9, 3.5639060239626913`*^9}, {
  3.563906289380066*^9, 3.5639062917293863`*^9}, {3.5639063455998163`*^9, 
  3.563906381422799*^9}, {3.564831683845002*^9, 3.564831686539287*^9}, {
  3.564833228258871*^9, 3.564833230346966*^9}, {3.5648332773141108`*^9, 
  3.5648332776258087`*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztfT1oXcfaru69LlykcHEKF6fwhVMcQ4pjOMXZkCK6pAgiRdCHCwtSRJAL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    "], {{0, 417}, {210, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{210, 417},
  PlotRange->{{0, 210}, {0, 417}}]], "Input"],

Cell[TextData[{
 "The compressed tape is shown at the top, followed by a few statistics (more \
on those in a second), and then a ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/mathematica/ref/ListPlot.html"], None},
  ButtonNote->"http://reference.wolfram.com/mathematica/ref/ListPlot.html"], 
  "FunctionLink"],
 " of the head movement for the first 5,000 time steps."
}], "Text",
 CellChangeTimes->{{3.561476937983069*^9, 3.561476994782257*^9}, 
   3.5648333133619847`*^9, {3.56491581164212*^9, 3.5649158116454153`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shell Script Daemon", "Subsection",
 CellChangeTimes->{{3.558966716318006*^9, 3.558966720227049*^9}, {
  3.564162810227414*^9, 3.564162812456935*^9}, {3.565004367205327*^9, 
  3.56500437120802*^9}}],

Cell[TextData[{
 "I ran the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " script on my Linux server back at the Wolfram headquarters in Champaign, \
Illinois. To alert me when interesting rules were found, I wrote a simple \
daemon shell script to poll the log file for new results and email me \
whenever an interesting new rule was found:"
}], "Text",
 CellChangeTimes->{{3.563905028038328*^9, 3.563905040060649*^9}, {
   3.5639051047941523`*^9, 3.563905121003455*^9}, {3.563905377267754*^9, 
   3.563905434218103*^9}, {3.5639055550618143`*^9, 3.563905649707999*^9}, 
   3.564831500248642*^9, 3.564831690043414*^9, {3.564833319440096*^9, 
   3.5648333212167745`*^9}}],

Cell["\<\
#!/bin/bash

num=`ls -1 images | wc -l`; 
newnum=$num;
file=\[CloseCurlyDoubleQuote]tm-4-4-search-02.txt\[CloseCurlyDoubleQuote]
while [ 0 ]; do 
    newnum=`ls -1 images | wc -l`; 
    if [ \[OpenCurlyDoubleQuote]$newnum\[CloseCurlyDoubleQuote] -gt \
\[OpenCurlyDoubleQuote]$num\[CloseCurlyDoubleQuote] ] 
    then 
        newfile=`ls -tr1 images | tail -n 1`
        mutt -s \[OpenCurlyDoubleQuote]pauljeanlx: new class 3 4,4 tm search \
result!\[CloseCurlyDoubleQuote] -a images/$newfile paul-jean@wolfram.com \
<<-HERE
        $newnum total stage 3 results
        newest result:
        `grep \[OpenCurlyQuote]\[CloseCurlyDoubleQuote]Rule\
\[CloseCurlyDoubleQuote] -> \[OpenCurlyQuote] $file | tail -n 1`
HERE
        num=$newnum; 
    fi  
done\
\>", "Text",
 CellChangeTimes->{
  3.55896671131775*^9, {3.561476122908883*^9, 3.561476125488331*^9}, {
   3.561476339741605*^9, 3.561476368305588*^9}},
 FontFamily->"Courier New",
 FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Number of Turing Machiness Searched\
\>", "Subsection",
 CellChangeTimes->{{3.5614794480078497`*^9, 3.561479453325959*^9}, {
  3.565004381524901*^9, 3.5650043883256683`*^9}}],

Cell["\<\
The search ran for 16 days, searching a total of 373 million Turing machines, \
at a rate of about 270 Turing machines per second. It ended up finding about \
13,000 interesting rules. On average, the search script emailed me an \
interesting rule about once every two minutes or so.\
\>", "Text",
 CellChangeTimes->{{3.558966343311668*^9, 3.558966390451436*^9}, {
   3.558966424387743*^9, 3.558966630666869*^9}, {3.558967415475442*^9, 
   3.5589674563386993`*^9}, {3.5613991623508472`*^9, 3.561399164610797*^9}, 
   3.5613992937535667`*^9, {3.561399841782487*^9, 3.561399864790206*^9}, {
   3.561399932572407*^9, 3.5613999336137047`*^9}, {3.561472444520253*^9, 
   3.5614724478212433`*^9}, {3.561475618442244*^9, 3.561475621257442*^9}, {
   3.5614771562845507`*^9, 3.561477159361918*^9}, {3.561477731306755*^9, 
   3.5614777724874067`*^9}, {3.561478413448881*^9, 3.5614786263746157`*^9}, {
   3.561482923392088*^9, 3.561482923757751*^9}, 3.564831705150098*^9, {
   3.5648333423654833`*^9, 3.56483334912933*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numsearched", "=", "373463333"}], ";"}]], "Input",
 CellChangeTimes->{{3.5518058119937487`*^9, 3.551805816737061*^9}, {
  3.561479468594317*^9, 3.561479473751586*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numpassed", "=", "13188"}], ";"}]], "Input",
 CellChangeTimes->{{3.5614783288560123`*^9, 3.5614783371450367`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rate of Search", "Subsection",
 CellChangeTimes->{{3.561477341173623*^9, 3.5614773433000393`*^9}, {
  3.565004482063444*^9, 3.565004484477973*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"startdate", "=", "\"\<4 Jul 2012 16:16:28\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.5614775179445333`*^9, 3.561477518652071*^9}, {
  3.5614775540478773`*^9, 3.5614775585194807`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"enddate", "=", "\"\<20 Jul 2012 15:43:29\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.561477549317954*^9, 3.561477562471943*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"startdatelist", "=", 
  RowBox[{"DateList", "[", "startdate", "]"}]}]], "Input",
 CellChangeTimes->{{3.56147756941641*^9, 3.5614776048217297`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2012", ",", "7", ",", "4", ",", "16", ",", "16", ",", "28.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.561477573721054*^9, 3.561477605299658*^9, 
  3.564166587004675*^9, 3.5641668057036457`*^9, 3.564166999158908*^9, 
  3.564167283461268*^9, 3.564167511958209*^9, 3.564167748229164*^9, 
  3.5641680974784813`*^9, 3.564168324504414*^9, 3.564420755760508*^9, 
  3.564421445331676*^9, 3.5644216012738113`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"enddatelist", "=", 
  RowBox[{"DateList", "[", "enddate", "]"}]}]], "Input",
 CellChangeTimes->{{3.56147756941641*^9, 3.561477607814885*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2012", ",", "7", ",", "20", ",", "15", ",", "43", ",", "29.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.561477579027079*^9, 3.5614776082868137`*^9}, 
   3.564166587038444*^9, 3.564166805732078*^9, 3.56416699918648*^9, 
   3.564167283500842*^9, 3.564167512015057*^9, 3.5641677482601213`*^9, 
   3.56416809754373*^9, 3.564168324571787*^9, 3.564420755794291*^9, 
   3.564421445447047*^9, 3.5644216013173027`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totalseconds", "=", 
  RowBox[{"DateDifference", "[", 
   RowBox[{"startdatelist", ",", "enddatelist", ",", "\"\<Second\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.561477583175902*^9, 3.561477695453032*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1380421", ",", "\<\"Second\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.561477635772399*^9, 3.561477647135742*^9}, {
   3.561477685613658*^9, 3.561477696017282*^9}, 3.5614781850579853`*^9, 
   3.564166587141964*^9, 3.564166805802297*^9, 3.5641669992370768`*^9, 
   3.564167283535961*^9, 3.5641675120490017`*^9, 3.5641677482928343`*^9, 
   3.564168097599475*^9, 3.564168324623231*^9, 3.564420755827005*^9, 
   3.564421445535187*^9, 3.5644216013603687`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totalminutes", "=", 
  RowBox[{"DateDifference", "[", 
   RowBox[{"startdatelist", ",", "enddatelist", ",", "\"\<Minute\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.561477583175902*^9, 3.561477695453032*^9}, {
  3.561478190523396*^9, 3.561478202796135*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"23007.016666666666`", ",", "\<\"Minute\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.561478203099753*^9, 3.564166587238406*^9, 
  3.564166805834552*^9, 3.5641669992704163`*^9, 3.564167283568416*^9, 
  3.564167512098427*^9, 3.5641677483381643`*^9, 3.564168097659802*^9, 
  3.564168324674721*^9, 3.564420755862502*^9, 3.564421445586074*^9, 
  3.564421601420472*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totalhours", "=", 
  RowBox[{"DateDifference", "[", 
   RowBox[{"startdatelist", ",", "enddatelist", ",", "\"\<Hour\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.561477583175902*^9, 3.561477695453032*^9}, {
  3.561478190523396*^9, 3.561478202796135*^9}, {3.561478281978149*^9, 
  3.5614782911870613`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"383.4502777777778`", ",", "\<\"Hour\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.5614782918879347`*^9, 3.564166587481786*^9, 
  3.56416680587823*^9, 3.56416699932006*^9, 3.564167283597022*^9, 
  3.5641675121307983`*^9, 3.564167748371106*^9, 3.564168097702312*^9, 
  3.564168324724321*^9, 3.5644207558937063`*^9, 3.564421445635228*^9, 
  3.564421601477293*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totaldays", "=", 
  RowBox[{"DateDifference", "[", 
   RowBox[{"startdatelist", ",", "enddatelist", ",", "\"\<Day\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.561477583175902*^9, 3.561477695453032*^9}, {
  3.561477760010407*^9, 3.5614777623703957`*^9}, {3.56147818810956*^9, 
  3.561478188788226*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15.977094907407407`", ",", "\<\"Day\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.561477762942266*^9, 3.561478189087906*^9, 
  3.564166587521269*^9, 3.564166805917001*^9, 3.564166999370429*^9, 
  3.564167283628724*^9, 3.564167512165277*^9, 3.564167748404723*^9, 
  3.56416809777276*^9, 3.564168324775632*^9, 3.564420755926949*^9, 
  3.564421445669697*^9, 3.5644216015345173`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"TMs", " ", "searched", " ", "per", " ", 
   RowBox[{"second", ":"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.5614777123661947`*^9, 3.561477723913815*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "@", "numsearched"}], "/", 
  RowBox[{"totalseconds", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.56147735058869*^9, 3.561477380421185*^9}, {
   3.561477703341289*^9, 3.56147770647628*^9}, 3.5614794799116907`*^9}],

Cell[BoxData["270.5430683827615`"], "Output",
 CellChangeTimes->{{3.561477375911742*^9, 3.561477381232918*^9}, 
   3.5614777069159603`*^9, 3.5614794811338577`*^9, 3.564166587654461*^9, 
   3.564166805986643*^9, 3.564166999495347*^9, 3.5641672836934834`*^9, 
   3.564167512229678*^9, 3.564167748474416*^9, 3.56416809785434*^9, 
   3.564168324881007*^9, 3.564420756002842*^9, 3.56442144576759*^9, 
   3.564421601625779*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rate of Emails", "Subsection",
 CellChangeTimes->{{3.56147955061098*^9, 3.561479552027153*^9}, {
  3.565004488720316*^9, 3.5650044916813602`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"number", " ", "of", " ", "emails", " ", "per", " ", 
   RowBox[{"hour", ":"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.561478267277679*^9, 3.561478268867075*^9}, {
  3.561478315472516*^9, 3.561478321944215*^9}, {3.5614783803276978`*^9, 
  3.5614783902477016`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "@", "numpassed"}], "/", 
  RowBox[{"totalhours", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.56147735058869*^9, 3.561477380421185*^9}, {
   3.561477703341289*^9, 3.56147770647628*^9}, {3.561478208222331*^9, 
   3.561478242652319*^9}, {3.561478299810821*^9, 3.561478300258707*^9}, 
   3.561478343554687*^9}],

Cell[BoxData["34.392985907922295`"], "Output",
 CellChangeTimes->{3.5614782433157377`*^9, 3.5614783015004683`*^9, 
  3.564166587756336*^9, 3.564166806036668*^9, 3.564166999597946*^9, 
  3.564167283760936*^9, 3.564167512295888*^9, 3.564167748543687*^9, 
  3.564168098038576*^9, 3.564168324951768*^9, 3.564420756132472*^9, 
  3.564421445860815*^9, 3.5644216017271957`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Number of 5x10 grids", "Subsection",
 CellChangeTimes->{{3.5614795291173353`*^9, 3.5614795656345778`*^9}, {
  3.565004495122929*^9, 3.565004495452655*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ceiling", "[", 
  RowBox[{"numpassed", "/", "50."}], "]"}]], "Input",
 CellChangeTimes->{{3.561479568732492*^9, 3.56147957435642*^9}, {
  3.561480015225987*^9, 3.561480019566742*^9}}],

Cell[BoxData["264"], "Output",
 CellChangeTimes->{3.561479574858839*^9, 3.561480020161025*^9, 
  3.564166587805682*^9, 3.564166806063699*^9, 3.56416699963732*^9, 
  3.564167283796981*^9, 3.564167512348423*^9, 3.564167748597704*^9, 
  3.5641680981076937`*^9, 3.564168325089241*^9, 3.564420756177127*^9, 
  3.564421445908248*^9, 3.564421601780002*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Minutes to Look Through All Grids at 10 Seconds per Grid\
\>", "Subsection",
 CellChangeTimes->{{3.561479786916253*^9, 3.5614798146591263`*^9}, {
  3.5650044970223627`*^9, 3.565004509338142*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ceiling", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"numpassed", "/", "50."}], ")"}], "*", 
   RowBox[{"10", "/", "60."}]}], "]"}]], "Input",
 CellChangeTimes->{{3.561479568732492*^9, 3.56147957435642*^9}, {
  3.561479745297673*^9, 3.561479764887072*^9}, {3.561479798709746*^9, 
  3.561479798788682*^9}, {3.561480022574073*^9, 3.561480024894557*^9}}],

Cell[BoxData["44"], "Output",
 CellChangeTimes->{3.561479765312892*^9, 3.561479800932858*^9, 
  3.561480025379779*^9, 3.56416658784335*^9, 3.564166806097809*^9, 
  3.5641669998118067`*^9, 3.564167283833449*^9, 3.564167512380575*^9, 
  3.56416774864705*^9, 3.5641680981729918`*^9, 3.564168325155962*^9, 
  3.5644207562103786`*^9, 3.564421445935031*^9, 3.56442160190175*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Grids of Compressed Turing Machine Tapes\
\>", "Section",
 CellChangeTimes->{{3.561475726572836*^9, 3.561475733995204*^9}, {
  3.565004512524247*^9, 3.565004520455864*^9}}],

Cell["\<\
That was way too many emails for me to look through exhaustively. So after \
the summer school was over, I took all the winning rule numbers and jammed \
their compressed outputs into little 5x10 grids like so:\
\>", "Text",
 CellChangeTimes->{{3.561478637677639*^9, 3.561478780649919*^9}, {
   3.5614790384122543`*^9, 3.5614790563137074`*^9}, 3.56147924275904*^9, 
   3.564831707564052*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "Format in a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Session"
}], "Subsection",
 CellChangeTimes->{{3.561479362568084*^9, 3.5614793698587008`*^9}, {
  3.565004646361637*^9, 3.5650046500888033`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"entropies", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], ",", 
        "\"\<tm-4-4-search-entropies.txt\>\""}], "}"}], "]"}], ",", 
     "Expression"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.552071458373756*^9, 3.558967226003738*^9, {3.5635624908731003`*^9, 
   3.563562536407349*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rightleftcompress", "[", "evol_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"maxright", ",", "maxleft"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"Reap", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"maxright", "=", 
        RowBox[{"evol", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"maxleft", "=", 
        RowBox[{"evol", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], ">", "maxright"}], ",",
              "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"maxright", "=", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
              RowBox[{"Sow", "[", "#", "]"}]}]}], "\[IndentingNewLine]", 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"If", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], "<", "maxleft"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"maxleft", "=", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
              RowBox[{"Sow", "[", "#", "]"}]}]}], "\[IndentingNewLine]", 
            "]"}]}], "\[IndentingNewLine]", "}"}], "&"}], "/@", "evol"}]}], 
      "\[IndentingNewLine]", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.550283155672865*^9, 3.5502832527891483`*^9}, {
  3.550283385283328*^9, 3.550283457744259*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "@", 
  RowBox[{"Partition", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Framed", "[", 
       RowBox[{
        RowBox[{"ArrayPlot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"rightleftcompress", "[", 
            RowBox[{"TuringMachine", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\"\<Rule\>\"", "/.", "#"}], ",", "4", ",", "4"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", 
              "5000"}], "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "50"}], ",", 
          RowBox[{"Frame", "\[Rule]", "False"}], ",", 
          RowBox[{"ColorRules", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"0", "\[Rule]", "White"}], ",", 
             RowBox[{"1", "\[Rule]", "Orange"}], ",", 
             RowBox[{"2", "\[Rule]", "Red"}], ",", 
             RowBox[{"3", "\[Rule]", 
              RowBox[{"Darker", "@", "Gray"}]}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", "LightGray"}]}], "]"}], "&"}], "/@", 
     
     RowBox[{"RandomSample", "[", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"entropies", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"0.3", "<", "\"\<ArrayEntropy\>\""}], "/.", "#"}], "&"}]}],
         "]"}], ",", "100"}], "]"}]}], ",", "10", ",", "10", ",", "1", ",", 
    RowBox[{"{", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5614789464304667`*^9, 3.5614789472746563`*^9}, 
   3.5614789829057837`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBmIeIAaxIeCDPQMaCAsFgav26DSq+gdo+oaLOC4aAUZG
+JBKI8DwCh9q0QgwNMOH1jQCDO7wGSgaAQZH+Aw2GgHoGz4jjR654UNcuiI1
3IYPTVm+G/40Zeln6NEA+5jFXg==
        "], {{0, 0}, {12, 11}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3U2OJLcRQOEGdBKfZO4gwF7bBrzWabX3EXQES+hFYehm5E8Fm8HkF8Dg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        "], {{0, 0}, {97, 96}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlsEJwkAQRResQ8FK0oOgBQierda7JVhCEryYUSK74zozu+9DePIQEfIZ
/v58PVw2KaXt9OymZ/78zGNY531Ii3zzMnj8L3xuD3OZ+/t4vMbLlPaWPuM9
+Npkh+A13lufudt4jZex7i19xmt8FLJD+vSt9pm73aeXse4bfcZrfG9kh8Ty
9LmM3u4MPn2MdU+i0Nt7xEMN2SH/8fTZlt7uVXQvY/1+e6O3PkT30JbskHVP
n9ugt7vHfoAaeusV+wFq2OoOoc/wld7uJ/sBauitn9xbqKG3HUKfYQ2yH2BL
ZD/AlkifYUuUKe1/7u9AWIMypX2G0BdPxzm3Ny6/R59hRMpY/x+o5Qin2INs

        "], {{0, 0}, {30, 29}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztl1EKwjAQRAueQv88Se8g6AEEvz2t/x7BI9gSJCQQm7RpdnYzA+XJMmyb
dnCT8/15eRyGYThO12m65t9On/E/3+PPebvOeo0x6V/nD+teqT5amFpXWF8m
2vfS7g/rXtJ5yc3P3nnb1od+x+W82arXYml/+h2t5k2KuPMLzR/WvaTn57o5
K0+074vmD+teGPlZfp7Qr4W4eegtb233//JEy4PVvJXeN+UP69pZui4tfu3n
BassXa8Wv5a8kY6481HLPLW1/29HtPyg5a20/9bvQc7qN2997//laTVvpX1S
/rXvlcxhrFZ+tPMC2YaxrOeNxKS+ecr9vw2i5W2bn7RB+f+3VB+M90PuxVp5
S9WZNzLNWNvzllcn+2Ss2nkjyRzWOi+QZBm5HyPlGEv6eerzCzizW2c=
        "], {{0, 
        0}, {26, 25}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3O2tI8kNheEBHIkj2RwM2AEY8G+nYAfp/w7BIXgXi8JY5bk9XS2yi2w9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        "], {{0, 0}, {129, 128}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztllEKhCAURYXZQC1hVuIeglrAwHzPavtvCS2hIoaHMhJPr47VvSAnHmJ5
DPX5+nTvhzGmWVu7tu15z2zNz3zrk0XXh37LaH1q+2vHQX0niu57Q5SgPNC/
xv/xuuT2Rv8aSlB+6B9BSdl50X/qumj9aD1rx7+W//jzJXf93v7L3cdCdfrX
0E/6fkX/CPop7/ne/uP3Mbc/fr3q8FAb/eQ7L+qY71koyXNPJuMoSbt3kVhK
+P/XSa7Lf7kAZD0bZw==
        "], {{0, 0}, {17, 16}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2J+IAaxIeCDPX4aHYyKo4o/sMcuTipNa3cOdXFq0QgQ
FgoCV+3Radq4f6iI05qmtfsHSpxa5cBoOOMXH2w0Agyv8mSo0KT6i9big60c
GK7hPFxpBBgc5clIo9HBaDlAGxodjKZP2tAIQFl5MkqTR4+WA6M0dWgAGMcw
dg==
        "], {{0, 0}, {15, 14}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt20Gu5DQQBuAncRJOMndAgh0skFhzWvYcgSMwo7cAV8atTrcdVzlfSaNv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        "], {{0, 0}, {94, 93}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt2tFpG0EQBmCBK0kDcQnpIZAUEPBzqs17SkgJsZOAHYVTdnV7NzO734H4
zM8iiZPwDL/97svXj08Pl8vl/fPj8fnx8vPnTy/Xtw97vfy6fvzx9Rr1/Mzp
1ucul/f7/er5znqfva/rfK3z8rnz/2veyVvy6H2Kx9r2fTha80u+J8+2Xzl/
3/nxHv17Mvr3N/ts+37K58izqc9xvuW8vFYer/m4Zh69T7HPts+3uuad/G2e
bb9yvqr6nLnd+lzkFfLV1OeseV4em8+veTpHHr1PrW7b58Xbmo9z59n2q1nP
81p9Ti237rM8IudY9TlznJePzblX8zdnHr1PzWbb/Wes5mmtPNt+VeU8z1af
E+vWfZOPyFlLfU7O8/LbObNrXp+TR+9T2W27n5xb8zc2z7Zf6Vs4Rn1OxLyW
k/+qzznn/Go5V9d8vy+P3qdy7m/kHs3rsXm2/Urfwhj1OSPm+6w5eab6nPvO
V8/JY7UP/L6i9yl9C7nafO/Ns+1X+hbWcLU+Z+t91szJmdTn5MzJ2s66P0Tv
U/oWstfq+0Bvrm8hz7B6n7P1ujlyku3O2uccnZO8ZZV9I8e+RPI4s+0Pvbm+
hcxotj5n63mOyUnmsUqf05uTjDSqz9G3kPzbbH2OvoWcwdx/tyK5jlF7DsmZ
9f8tJHM4as8hyVf37TMkOcrrK/r9MLs/AcA8oNg=
        "], {{0, 0}, {47, 46}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3WGKHMcdxuGFnCQn0R0CzgEM/uwDJNf09xwhR7CMGCxKqp2pnuru91/1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        "], {{0, 0}, {124, 123}}, {0,
         1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmMEJwkAQRRfsQk9WYg+CFiB4tlrvlmAJJqKE0RCTOLszO3kD4XkYPol5
7ge3p8v+vEoprZtr01zt5+OhnevuX6bn3L9ITowcuXd78T1zc+bfv7fvhxxb
D6fmT6WWnzA2tXzL7aHV75ec4Ry5p9+zWsTD2Dlyr1zPatG6B2BeWvtV2kOt
fHL69v32rBbx0GeO3KuvZ7Vo3Sewn9Ze1OqhVn7tOXIvfs9qEQ/LeIhv82jd
S9Fo/T5rJedk3z49W5p4OOwhvtnSut+80Po9LJ21n5Nyj56tlVE9xLcYtO5J
ehZanpNyj55dOr15iG8wh5/0LNRjN+P8+Zzxnvt4XuiT3Uz1EN+gBw993D+M
wW4436A//v6/BfrkA+gNU4E=
        "], {{0, 0}, {27, 26}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztnEFuFEEMRSNxEk7CCWCBBAdAYs1p2XMEjkAiFsCQnil32eX/q1+k6CHL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        "], {{0, 0}, {78, 
        77}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlkEKgzAQRQe8Q117ktyhUA9QcN3Tdt8jeASVLkpDDUlNyEx8A+Hp5yMI
PzMz3B/XqRORy3r69WzP75pdmC8nXzV7776Ovw3/np6Ln++Pt62ezmeZ/8Kf
109O8Mf4S+ckdX6h69Rr0co9OptfW06YXzr95ER+Fv443Tq1zXHrequ0ck+1
+c+WE+bXf35yEiY5CeswTG17AnuITlrpA6l+clKXVuYXOalLcgKPkD0ExpC+
AUsw1/wiJ22TnMA0khN4pM/E6RDq4gLtkNWs
        "], {{0, 0}, {23, 22}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2J+IAaxIeCDPQMaCAsFgav2I53GFT6o4g/ssYvjokfD
mbxwJpUeDWf84UwteviEM3HpkNT8PhrO9Mnvo+FMn/w+fMIZl3tQxQcqv4+0
cB7qNAIMjnAerjT54YzLHFTxoZ7fh0o4j9IMaGA0v9OHHk23g4lGBwPtnsFL
AwCdtHK3
        "], {{0, 0}, {15, 14}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt2F1Kw0AUhuGAK/FKd9E9CLoAwWtX671LcAm2eDF6MM20zWR+8nwQ3lCm
bw6hH5Rz//r+9HY3TdPD8Xo8Xqf7n3wdzjPl5fmUj0Pk3/Of4XtLn1/qj7n9
uTw8LXjyfv/XU395ePrtb978c1zrPZR+Lg9Pyx795eHp1zNqf0vPw8NTwlOL
l86pvzw87TPFvotnJM+2+6X61F+ekTx76+/ce8g7b9/F06NnVMboL8+InlEZ
U7u/pefhGcOD07/RX54ePHieKfZdPPZL/VJ/efR3FMYsnbfv4snx4DaM0V+e
NTy4DWNq97f0PDzXebBNxugvD/bPFPuuvjz2S/ib+tuXR39xnjFL5+272vTg
Phmjv316cJ+Mqd3f0vP04kHMYYz+tuFBvIUp9l1rzI9Yh/q7xvyILTBm6bx9
F2I7jNHfPA9iC4yp3d/S8yCOxBj9ReyfKa3tu+yXEPOpv4ijM6WNviPiNdRf
xFEYs3TePgqxHcboL2L/TPF/GLE3xtSeBxH1GrfmN4L2gi0=
        "], {{0, 0}, {40, 
        39}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlOEJwyAUhIVu0E7QSdyh0A4QyO9M2/8doSM0QULIEV/QND6e3oF84RB8
8fDu3fDoL86567hu45q+g75eJmr2P37bj+2nL/vLfb6ek94eud6fyv1zj81P
PzB2n/9i6rmp89Mvw9i5zDHw7D5kjmX8s/uQOZbxrTA2v/UcrfQhc5R9K33I
HGW/NaK0c2ytD+vPce2TMlHaOZJ5ROXmyD7UJep4jrr/0ypRuTmSukTt5ch3
Z4sovse6iNKep37+ALn+lY8=
        "], {{0, 0}, {19, 18}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJeIAaxIeCDPTodFgoCVzFoVHXoYLiLP7DHLj4abvjF
yadHRngSTlek0iMj3OhHD83wpH66IpUemuE2eOnBEZ4Dn65IpQdHuA0fGld4
UoseaP8NLI0rf6GDgXbnwNPEpZ+hV17Rmh4q+Q4AgVPsxA==
        "], {{0, 0}, {13, 
        12}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztld0Jg0AQBhfswFRgJfYgxAICPlut75ZgCf4QIiwJnufqnbn5QEZG8MHh
sHi1VZOJSD5dj+ma7+vnvK7UlGXDm3pDqXnsPXg/b/X96XiN3yYdY/L+pGMI
b086numvIx0tfHjScY+Pl3T85u/HtDv+D9PoCEUt7l6/PNSkY0rUC+2hK4+d
0/7z3Op/Df1o1dHNw7PIOUqJ69y6w9hJR1uOMGoqJA==
        "], {{0, 0}, {19, 18}}, {
        0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3VGO3FQQBdCRWAkr4RO+kWABSHyzWv5ZQpaQBNJSVGjGbbftW2WfJ0Un
XFldV49pv57OqOfHP/769c8f3t7efv7y55cvf77+/fffvq6/f6q+/bs+ffOf
bz7Wp/Lfz+ZrH6fb3G59UnO79UnN7dYnNXdKH/msfFnn15rru/VJze3WJzW3
W5/U3Cl95LPyvVz7+HVtffxuc7v1sQ/Zud362Af5lfK9rGsp93py3z6pud36
pOZ265OaO6WPvGeesi7P03P7pOZ265Oa261Pau6UPvKeeTfX9pz+/kOqj33I
zu3Wxz7IJ+bdrGspn/L6LdUnNbdbn9Tcbn1Sc6f0kWfz6dbleXrM9UfP7dYn
Nbdbn9TcKX3k2fyq1rV0fep51O39kNTcbn3sQ3bulD7ybH4369p736Y/T7vd
H+xDto99kHfO+Z/Or+zcbn3sQ3bulD7ybM7qc58HctXnabf7g33I9rEP8s45
93X687Tb/cE+ZPvYB3nnnNusa+v+v/c4ax9/r+uPntutT2putz6puVP6yM/J
eY51TXuepuZ265Oa261Pau6UPvJzch6lz8lfc323Pqm53fqk5k7pI983Zxed
X2uu79YnNbdbn9TcKX3k++ac5dr/j3Vtffxuc7v1sQ/ZuVP6yPfNOcu6lnKv
q/ftk5rbrU9q7pQ+8m05r21d7lfn9knN7dYnNXdKH/m2nPd07dfD9PdhUn3s
Q3bulD7ybTnvaV1L+ZTXsak+qbnd+qTmTukj/zgnn7Eu96tjrj96brc+qblT
+sg/zslXrGvp+tT9pNv7Qqm53frYB/krOXmEde399Tn9ftXtPmkfevaRf5yT
Z+r8ys7t1sc+yF/JyYx+z0tibrc+9kH+Sk5OdPr9qtt90j707CP/OCc7W9fW
r/P3Hmft4+91/dFzu/VJzZ3SR05ez7qm3a9Sc7v1Sc2d0kdOXkGfk7/m+m59
UnOn9LlbTt5L59ea67v1Sc2d0uduOcn/2+3f31Nzu/WxD/Lvc5LP33/ey31/
sW+f1Nwpfa6ak3zdus66X6XmduuTmjulz1Vzkse59nk3/f2oVB/7cM+c5HHW
tZRPeT2f6pOaO6XP9JxkH+va+/621+NMuW+n5k7pMz0n2d+6lq5P3Ve7vT+W
mjulz/Sc5Fzr2vs+MP2+nZo7pc/0nOT1dH5l507pMz0neWX9npfE3Cl9puck
+Z7T79upuVP6TM9Jsq5HPuXn61Jzp/SZkpPkWut65FPu26m5U/pMyUlyWZ+T
v+b6KX265SS5v86vNddP6dMtJ8mU3X4OITV3Sp9uOUmmrGsp933WOX2cRyT5
sXUt5c6vc/o4v0hym2vvb9Pfl+vWx/lFktusaymf8n1Ntz7OI5Lc17qW8inn
Rbc+zi+SPMe6lq5PnS/eJyRJPmNdj3yv+61/59qWkyS36fzK5iTJV73373lx
fpHkPXV+bctJkudY1yP3c4Ykyc7W9cidXyTJXs78nHznEUneXecXSfK6XvXn
MUiS17aupTz1fRZJkt9b11Lu/CJJdraupeu9H0iSzPjcz3vU9cidRyTJjM4v
kuR1reuRO79IkhN1fpEkZ/va5+GTPMPPI1pgLA==
        "], {{0, 0}, {72, 71}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3WGK4zYYBuCBnqQn2Qu0fwrtAQr93dP2f4/QI+wOIZhR41iyJfmT9AiW
Z3kJjsaW9U4yk92f//z7t79++vj4+OXHn19//Pn8+2P89+292/jj98/xz7dW
fn3ef5Pn//988h4vl7fN26zz8Z736+O3Ufr4vPz8eWgzn1HyUc5bv3V47X45
Vm/K5fH7S2/W2H9K5zNKPsp5m6c38zx/Hkrza9fx/v1WvmbepnfmuY/W7rXW
ud6M2Zt7Rru/7t8/5WvmerPlfOTvc705Vm/u2frrSsfd+f3vg9W6X1azzXrY
y+fZ30rzGOd/1nyedbV2b27qzcfQmzFtsx728nn2t9I8xvmfNZ9nXenNEs+f
hzbnrf46LJ3PtfXcbx3Gvk+j5fPsb6X52te9dT7PutKb59Sb75/36+PToTdj
5/Psb6X52te9dT7PutKbLU1H/Ptdb95xn0bL59nfSvO1r3vrfJ51pTfvMO79
rjfvuE+j5fPsb6X52te9dT7PutKbkdxGm/OcjlXvC/n7fJTrqDfHyudZV3oz
pnrTfnVfPsp11Jtj5fOsK705sttovQ6vXV95lLz1/X6XeechHfK+ud7Um7HU
m/II97velO/nelNvjmg6Rlsn8t55revY5vu0dPTf/+WPEft6leaj7Ie811HW
ibx3rjdf5fdfl2h57OtVmo+yH7K3rd8H837aSvnxuooxz9Z56Xmo//1J3693
tXzPWsfXj9HVm/J6ud5M1Zsz5rV6k6OqN+X1cr2Z2vp97L7P6z49l3v9OJt6
U14v15upenOlnKuoN+X1cr2ZOkpvlh4/7/Hb6Pv+8/E821wXrqLelNfL9Waq
3nz/dY3Sm3nH5yrqTXm9XG+m6s33X1e0eeYdh6vb9z7dO85xfu2+qzX/Wvej
PDfv2zut89L1U9oXpZ+7XG09e/3IOurNkvmvts/cn+vNkuPrTbKHerNk/rPu
M3FzvfkYd91fe/PJO/7x19vm+pJt1Zsl89ebvXO9+Rh6s+T4ZFv1Zsn89Wbv
XG8+xqy9ee045D3qzZL519oH5Lm53nyMGL15/vhfc68fObZ6s2T+pfue/Gqu
Nx9jzN4k51Rvlsy/dN+TX8315mNEu7+u3S/k2OrNkvmX7nvyq7nefIzY9xe5
lqv1Zoz+PX8e5spLeyRufu261//cZZvvN0h+Okpf6M0Z8+P9f5R89N7MOz7J
T0fpC705Y368/4+SR+vNvJzkGUfpi1F6M+/x/h37NLn2+miU+RyvE++vkvHV
m3ozQq43azwvyR7qTb0ZIdebNY5Dsod6U29GyMfszVrP6/UjOZJ6U29GyNfo
TZIzqDf1ZoR8lN68tn5IzqDe1JsR8tF78+txSHIb1/aTWvve8efdrvXg8XFq
nYdax5/VaNc3bx2S5Kbe7LP/89x5a31989YhSZa6jbv21dK81j4sr5u3Xg96
k2Q09aZcb5LkWdPxzEv31b3jlOal85T3zvu+/7+X60eSd5mOZ6435a/zvr1J
ktFMxzPXm/Irea31RpL3e+3nhqX5nnuPr/X/StSa/zb6/tyt/vxj5PqR5Hjq
zXO53izJSXI1txHj92/TcZS3/rzn+fncNc8Y15Ek5zfGfpuOo1xvpjOJcR1J
kh8vxzOP+3nDvPnXyvUmSTJHvXl1nnqTJOe21n7b5n3d1n295958ttHm6z2e
T5vrQpLMVW++cm8+2xilN/OOT5LMVW++cm8+27irN68dhyR5Vb35yr35bKPv
z2G9fiTJKOrNV+7NZxttepMkGV29+cq9+Wyjze+1kiSjqzdfuTefbehHkuS+
22jzOcF09M/bfJ+w97wkyVXUmyWP33tekuQq9v090lFyv+9Kknzt2r1JkuQV
0/HM474fm5d7/UiSbGE6nvkovUmSZAS30eb3iM7/vyR5xydJ8h71JkmS+cb4
fIp+JEmOYd/eJElyBdPxzGv9O34kSa6g3iRJMt9t+PfSSZI8Mh13z4fkDH4H
uI/nwA==
        "], {{0, 0}, {77, 76}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztl8EJwkAUBRcsQy9WYg+CFiB4tlrvlpASTCQSWHyQYDb7//5ZkNFBFsTh
icfb43zfpZT2/ePQP4bn18twnqec6XO6ka+R39Nlr3Ov3q+o7sH78up7n/y8
3iaW7nPe/eoevE2/foeK7Cde++06VGQ/8RY6VGQ/I3m7HSqyny16fx0qsp+e
fTsdKrKfHnz7HSqyn5Z83A4V2c8ang7nkv0s6enwX7Kfa3g6LEX2c4mnw63J
fv7ydGiFsfeTDq0zxn7SoVe2tZ902Bp97icdRqHt/aTD6LTd51r3Q6/02SeM
wm375HcZLmOtPmt9XtgGy3SrPIQlSJ/QI/NDn7Au+b8DS/ANU4UyUQ==
        "], {{0, 
        0}, {28, 27}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmEEKgzAQRQO9Q117ktyhUA8guO5pu+8RegQVcSPGQjTM/PQFwpNPFuo8
w8S2fz2GWwjhPs1mmvP1Mr7xmJ+4ruye83jHLVPryZXzfOLJP+Wl6e15yfPy
65naZ6AW8cQnz33Xv/tGKx/wxLa+Kj6oe6JSX3UfrDyptb61+pAi9cWH68j/
uuMcbokneznMo7c64okXWvcF9CEarPXcZP1ea6O3+uKDMr2dm6B34gkssf+U
yaEq6UNgiX0GH+CZ/cf6viBU4giMCwzn
        "], {{0, 0}, {23, 22}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3FFqFFEQBdCAK3EfSvYg6AIEv12t/y7BJZgwPzOFaSfT/brr9jsF4cjl
YlqcrgyPnnz8/vPLjw9PT0+fXr4+v3y9/vkyf56XrSOXy+Xyt/JvX1/n1/Mo
b7/ve/1drldfX19f/768zqN72N7W19fX37Zvb+vr6+tn9d/794y2jlwul+fm
vc+lR5vyc1BfX18/5XzD3tbX19df7tvb+vr6+ln9bufSo035f9HXv6dfR36u
nBe73Xf6+mv6deTnynmx232nr7+mX0eemXPZbvedvn6H76t/bJ/L1pHL5TPn
cz8XnW63n7/6+vr792d7vi7dlNeVvr7+uL69nWXK60pfX39c37l0lnXkcnnn
3Lk03zblfYK+/sx95xu8NuV1q68/c9/e5rUpr1t9/Zn7zqV5bcrrVn+ffh35
vjl5j932hv6x/TryfXPyHrvtDf1j+3XkY3Jyjd32hv62/ZTrnK1PrrGOXH7u
3HPRPK/d3p/o64/oe76OZzLlvtPXX9O3t3kmU+47ff01fefSPJMp953+Pv06
aTk5g932hv6x/TppOTmD3faG/rH9Ol1zcma77Q39bfsp1+n8mZzn/u3WryO/
zUmut9veS+/Xkd/mJNfbbe+l9+vMmpMcZ7e9162fcp3d+iTHWUeenvu9HOSs
dnv/pv9Y3+e7yXlM2Uv6y317m5zHlL2kv9x3Lk3OYx356Ny5NMkxprzPTO87
3yC5lSl7L71vb5PcypS9l953Lk1yK7vtvTppOUmO1t7eNifJ0drbj+UkeZR+
H8i2/y6SHG2d/rnnoknyX3Z7f+v5OpJc1t4mySzT9zZJzma350BIksva2ySZ
5VF7myT5mHX2ykmS2+rzLCTZXZ9nIclk6xx9PSTJZescfT0k+X//AqeC5IY=

        "], {{0, 0}, {61, 60}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztnUtu3DAMQAfoSXqGdj93KJAeIEDXPW32OcIcIQm8EMYI9bFIkZIegeCl
hMChFfuFHg/Sn6////z7cbvdfn1+/f78+vr+iMc9z/f77Skep3+f89L61nxr
fWm9lLc+3hR/X77i7V7L1jrS8bSurzve6/tQt/76eaK1z895/fOkr08t+l9H
fftQ3s+6Psd5oC4/ez9a+2x9vUjHK+XxW74OfjtXiO03a89ozXtSXuu69jp/
vOq01rf+vaO1z1Iev+Xzu/nN6zyX8omt+9m3b/jtIH47r8dvR6zlN+vz3+u+
Br/lid/O6/HbEXv4zeu6kPKrng/47Voev+Xz+E2X/vNe33opH9fzY+/rW/u0
fp/W6+fbmsdva/gtrgfm7MfLD1o/33HXUd3xSnn8dq6A3zQYbd6T8hK16kR7
H9Lr/s76PlHr/MFv+K2H/vNVtOe5Ma53ad/wWz6P3/BbDf3nPfyWX4/fvsvj
N/zWQ/95L0Z967zUJ37L5/EbfrOg/7zXt17Kj/N833leriMdT2v9/L7gt9b6
+G1mru8lm3609llrTtM6Lvx2roDfZmYK6/fN6vL656HWepv+tfzQ2qd1XqtP
r/MtxdjfO1CXKfAbftPL4zcYgSnwG37Ty5f3wWYuKueZx3ZiCvyG3/Tyq/oN
rsFoz1ulvNb1Hq2O/+dSxr6uVF/K6+8zfoMRnm+2Xkd95+31Pvvq4Ld8Hr/B
kfSf9/DbEfhNt/+614V70n/ea60fw5P4LZ/HbzAy/ec96/pzega/4TcY33vS
einv1Y+XT1qPV+vnaN2/tG9SHr/BCPSfx+ryWted/vVbV7/8ujbzoX8/+A3G
o/+8F/t5blyfROsHv8F56D/v4Tf8BuFY+s97rfVX9Um0fvAbXJf+8560fuxz
hH19i9/gfvR6fhotnwK/Qbg61/eYtL7PJ+X6rX3iNwhn857+eq37XJvnxfgN
wvhMofWctG8u0spf77Ov/2ivC+HOTIHfZvAbhBC/RfNbuZ++OhBC/Fbuk/tE
CFdhCvyG3yDcg7N8nqRM6+envG8G4WxMYTOPXfdPa/3W42J+g3B1psBvzGMQ
rsUUa/mtfLx9dSCE8ZliD79BCPdhCvwGIdyDXn+Prlyf980ghDb0//+z8BuE
cCz5exoQwt2odd+K3yCE0ZiC5wsQwrWYgs/ZQgj34Dm8+4EQQrgLPwDVYAxV

        "], {{0, 0}, {52, 51}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmkFuwjAQRS31JLQHyR2Q2gMgse5p2XMEjtCgbMiIKbE9jj3D+1L00JPl
QPBX5MDh9Hs8f6SUPufjaz7ur5fcpoXXKa2y3f9833OZJK3mtzov42OMt2Ld
+9RIjxjvY3zrHq29FWVKz6vNk+vt+4iP6GVKfWvSI/zIXmbUHlnd13L9aN8X
fkwvE71Hve5r+Njeav14IT3Ct/Dv1iOr+xoe/+jp0UKewzPe5jl23e9B3kmP
GG/To7WH6WlKr5s2T64f7TkVPj1N73XrhfQI/+hleq/PqJShR7G8TO/15p3+
9ll4Cw/3oUzp96LNg+/rYV/Soxge+qIMfgwPxyT7rFrP76eQHvW+DjA2ZUrX
gzZPVM/zariF9Oh/T49gC8pE9/QI1tDfPqv1/1HXHsIaypSuN22eXM//dmAk
0iMI96cMPYJQp799Vt7ng7AnZUrXszaPlYfQI+kRhPtThh5BqLP1PgvCd6bM
q35BCLeTHkEI7fkHbOF8fw==
        "], {{0, 0}, {35, 34}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmlGqwjAQRQuu5H3oNrqHB7oAwW9X+/5dgktQ6ceYgr6MNp2b5AzIkYOE
ms5tmurP8fx72gzDsL2/dvfX4/1U1/E9L+OQFB6Pz/GH/aP+xjnTz3tplTf+
vHTmB4/X88szL6dq84DH+/yrPvcyHZ884vGf+FrymNJqqeOHUIHePl83d5/n
MW+c+OshHq+wH1yXavOJ78XXef9JHvFtevI4MXofAGG9+0HWTXybntx5aOW9
vqU+/rzja/Ywl3k5VTu/+FKe/WAsySOePKrSKvo5AYyhtx80+rZVWn03//HX
eXxJDzWp1if4uef+syfG9xv+vSePbTN6fwN9TM+fFbnrifHrAn4qcgefy3vd
Tn18P/fhYe/My6la38Z79oOQPOp48gjL0yr6+Yc6vfOmcX5hXbT6rq/i1y8N
D+GaVOt/7j9hz4zP0VKePMIaGb1vYz8IoZfx653XkzvYLq3a+h8ChG2y9O+e
3vFZH2HPJI8QqtKqzPPM/8fXmAcIFWhVOo8a3xdCZVqV+V8QhLAceS4KoQ7J
I4T6nFf08fTLG+3SJXc=
        "], {{0, 0}, {38, 37}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBmIeIAaxw0JB4Ko9Os0ABh+gNALgUj/UaVT/IuiRFj64
wmGkhQ+p4TBcw4da4TDUw4fW4TBUwmegwmGwhc9A+3uwhM9A+2+whM9A+2Ow
hM9Au5fe9EhLD6TSAL25/I0=
        "], {{0, 0}, {12, 11}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPYR+YM+AAmDiuGhc6hHiYaEgcNV+uNGU
hc/IDU/iwmE0PKkbbiM3PGkTbsM/POkbbsMnPAdHuA298Bwc4TP0wnNwhMPQ
C8/B4d/BFs7oAFN8NDyx0dRKt6M0Ok1cekMHA+/uoU2jg4F2D/1oAFtSY/A=

        "], {{0, 0}, {14, 13}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlt0JwjAYRT9wAztBJ8kOgg5Q6LPT+u4IjmCCDyGXRFHz9yX3QDly6UP1
IOm6XU/7QUSO9lrs5T6/eBiJUmtP+W7i94+6ey5nx82gw/tTRtix7o58+n3Y
sc89lxH2KrOXNsKO4e757/xix7Y70roXO/62azHCXjqNaOvo6fv8Ysf3+7fP
M6oRbR1picJeOo3k7uiZ+/wap2PZ7zG7kdwd6bZG+L8by+yo1Xw/6dNPWj7b
EQ==
        "], {{0, 0}, {19, 18}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmU1KA0EYBQdyEjfmGHMHQQ8guM5p3XsEj2CCCxnxhU5M532vuwZCheJj
flPMDHl4PTy97ZZleTx+9sfP6fv38rme58e6bBY83utfnk/L+/qb2/kfts1f
uv77zavjaqP/euHxM3St9vN/9F8XPH6krtV2+9B//vH4xK7VevrQfz7x+Ho+
hXWfN5hnPv891H//pWvmR5rf+nTWfY9gnnk67dev8nTNPJ3m9qs8XTNPp7n9
Kk/XzNNpbr/K0/XY81sPr6O/00s9XWfNq+sCb0F/j7fydE2n89HfXW9P13Q6
Lv19uTxd02k+/R1V87N1rY4LJtDfS4pP71rtJ0ymv4t0X61rtV04Iv2//1F9
767VeuCI9P+e8X95CFtY93lvtnl1niFs6Vd5uqZTWJV13+PS59V5gLBCv8rP
1rU6LggT+1U+vWu1nxDO0K/y1bpW24WwHv39Ks//pBDW6bGPh3AG1n1e5b4J
YXu/ylfr2nu+IKxE3kMhrE/eQyHMJfdNCOuT+yaE9UmPEOby+udhCOH9mdLp
FwqJdeE=
        "], {{0, 0}, {39, 38}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlsFNxEAQBC0RCR8IwzkgHQEg8SZa/oRACOcTH3bEGXvt3emdqZasOpXu
Oa3tx7ePl/eHaZqelu95+W6/f/I9r/Nrnorg8XX+9XLL52xZ/t8GX3p6Wudt
8Pg9/t5d7aVaL9S8DR6/x7emWl/wKp59u8fT0z7eBp/bn7Vj6em53gaf249C
tR7hW3n27V9+FPrfT19vg4/l1XYsPa3zNvhYPhvV+oXf6nPv22z0v7c23gav
7aPuWHq67m3w2h7WUa13eX2OfQvr6H+fx7wNvq9nx/ahWu/o6Vge+lKtj3F8
rH0Lfel/z9u8Df6YZ8eORbU+0tM+HsagWk91/Zj7Fsag//2X3gZfenZsTtLT
sTyEv6nWX/YthDo9tYnu2bHwCOlpHw9hC/rv0rO8xr6FsAV5T9c9OxYqkJ6u
ewiV6b9j7/m++xZCZUZ9T9mxMBKj9hTCDBx930KYgWrvKTsWQv2eQgjb9fes
fQshPN5Tm/88OxZC/Z5CCD25bd9CCPuTHQvb8gpA7Zu5
        "], {{0, 0}, {39, 38}}, {
        0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2J+IAaxIeCDPXn0A3sGFPABjT90xMNCQeCqPTqNqh6X
f2lNj4YzfeiRFs4DRQ+fcEYVH2w0/cJ5cOfr0XAeHvRgC+fhSg9U+TzSaEQ4
j+x8PRrOw4MmNZxHafLo0fRJXRoBRtPtQNDoYKDdM3hpAH5Sl4M=
        "], {{0, 0}, {15,
         14}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztm+Ft2zAUhA10km6QTJAdCrQDBMjvTpv/GaEjJEEQKHoOK1Em9e7I7wDj
CwiCPJJ6F1m2fz7+/fX043K53L297t9e739/6N9D5J/f73q+4rrfy8PnCKX+
vVnyv+YiDZ/4cfWDz57+X4LfrboeP6/UzrGVf8/16vrBZ0//x3OpxNnyqtRe
Oy/1rumn1bmr+c/OobNzqUT3vMrqP1sOqPmpbXfxn51DKrlUonteqZ07fo75
adXusq7sHFLPpRI98yr/3PFzzE+rdpd1ZeeQay6VqJZX63kXaZwvfsglLZ+j
5lKJanm1z8/2+8FSu4Z/XT9Z7S77kJ1Ds+RSieSVpn8Nn9v76bn/uj7Jpf9z
trwqtdfO677e3u0a14muT3LpGN3zKqs/ufQhjetB1ye51JbuebXmInzW+IzC
J7mkyVHzqtSeVV8a+5a/P+4+yaVczpZXpfbaeWfLvVb7U3uO2esjl7TonldZ
/cmlY/vpuV5ySYXuebXmIg2f8/pR2wdyyZlRW/1L51jbXjt+LWcbJ+qsc8ya
d7v9tv93MJdR5JLGOL3nbX8/3Hv8PvfbUJ1jXW9R1+34P8c/78tgO0Zt9e99
H1U7L/7b+lfzSf7MyajsunCpl1H9u/iEYzNK9XpzrxcX/1k+IfzKqOy6UKuX
2fy3f36+b14IvzIquy7c67p23lbjuHxOAeEeRrnVtZr/UdfL+y94JqOy69ql
TmfLJQjPZJTqde5Sp+7rhVCBUdl1rVanarnE82c4A6Oy63rUXDrvufQ+nxAq
Myq7rmvnbTVO/udZ5A+E15ztd3Ol9tp5+V0YhORVq9zo3Z9cgvAsRm31132e
o7EuPi+DsCXd76PWXKThMyr/vCF0pmdeLVLzk32eEI5Mtbxaz7uIXIIQrtn7
e4NR5BKEcD/Jpe98Qgh96fd9ztvGhxDq0yWXIIQjUPv5ObkEIYw6mg/8fh9C
2Jvt86T2Pk1jHyCEiiSXIITabP/cSWNdEEJfRn228zk+hFCN5BKE0IXk0mh8
Bbht5AY=
        "], {{0, 0}, {49, 48}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBmIeIAaxIeCDPX76gT0DCviAxh9u4qTSwzV8qEUP9fCh
NT1Uwmeg6MEWPoONHqjwGSo0rcNnqNPUCp/hSpPqX1LVD3Wa1PQzSjNgBQPt
HurTABSiWbM=
        "], {{0, 0}, {12, 11}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgB2IBIAaxIeCDPXn0A3sGFEBIHB0Md3Fc4UAtejT8ITSt
w3k0/CH0QIXzSAv/wRbOwzX8h0o4D/XwH+rhPFTCf7iG82AL/5EWzgMV/qPh
jJ+mVviPhjM6HRYKAleJpokzFxHOlJkzSuOnSc0XozR16dFwphVNm3JplKYu
jQ4G2j2DlwYAuazDiw==
        "], {{0, 0}, {16, 15}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztnFFKBDEMhhc8iW96Cu8g6AEEnz2t7x7BI+wuMohZ6rQzSds/8wWWT360
k9T5N52seP/28fx+dzqdHi6vx8vr+vVPfD9Zvr5c4/OGf7/Pxu06dd/fT6+r
68v83Px1lfSYer32IXr939i3D9uvW6dH31frzOr3Ol09fy+9dR+8uD1/fO3B
0vqlfVPvj1nritZH7VvrdaPz9Fo/mtH5l9YfpWetK1pX8XX07wtf/7/+KD1r
XdE6vt52XXzdR89aV7Su7muVPrudWedpR5ufz6F77Vt0n/LKX49Z/V6nj89/
7jnwbHq0H73WmZdZ/a7Z373uw+g8o3V8HcWsfq/TVfLP+j6Ar8fSxqJnnV+p
1KWSp5eef27Wlzay31cqdank6aXj373Mej7XfB5v1cfn2Xd+CPcyq9/rdPX8
S/qoulrptQ6sZVa/H6O/t+qjfBe9PtxGG2u+UPGLev6jdOZgOWgjiy/U8x+l
419VZj2f1+nj89f8+zeoyqx+13web71udJ4wG7P6vU5XyT/6fQAekzYWPetz
rkpdzMHgHtpQu/9bdZW68C9sY9bz+WzP4zFzNgj30MbafThbvyvp6v/nBMI9
tDHaF176bL6GMJZZz+d1+qj8IZyBNhZdvY+XdM7PMCez9vG+czYIFWljzRcq
fZx+DY9MG9l9DWFOqpzP+RwZQm/aWPMRnyNDOD9tzOprCOE8vqb/QngcX0MI
PTnHPA1C2J82Fp1zNYS6tIF/IVRkzPkcQjg/bYzOB/bmGcwSF/w=
        "], {{0, 0}, {41,
         40}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmtFpwzAURQWZpKR7eIdCO0Ch3522/x2hIyQhhCY3lWvZit6T3rlgTjgE
W9i6CBk/vX++fOxSSvvj8Xw8Tr/P+ZnO/J7STS4+x9z/8fjIvpQa6/F78xp8
bF+LufN7m//RfOnzwtf1tVjruXubn3j8Ev9o0iN8BO+NGuv7w74Mv8X3wtz4
vfWid196//HzvheyX8N79r2THuE9+GjUWN9/9lNje5j+jHW/2O+M4eE8Ndb9
8ubp+7yH82Qfh1/iYV1qrJ9v717Tm4d1yfv/mB62IT0a20Of1FjPE29e49VD
n2Rd68vDMaixnlesX3Aksq7ZehiTmlbzLXfdUT2E19Ss7VHp+Uf1EC6hZm3v
ovURwi3U1O5d7z2FcAt5fwJhe2qs539uPLU8hB6oadWv0vGUegg9sPfvkyH0
THoEYXtqWvUod10II1Cztkel54cwAh+9X4MQ3lPzn6dfEC7nb1/eXk/5mpQ+
xgnhSGSdas0DrLOwJw==
        "], {{0, 0}, {36, 35}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPX4aAcJCQeCqPTqNS/1gEyfV/ZT5l1Sa
WvYOlDit/UVr+gGa/QMdnrjcM9hoBBhs6ZY49xD2F3HqR1o4k+9+yswZPuGM
y/zBXU4OlXBG0CMjPEmlSa3vhkp9NBqeQ4tGANq0z0dp/PRoOiSPRoDRdEhd
eqDCEwAxjWcg
        "], {{0, 0}, {14, 13}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt2tGJFFEQhtEBIzGSfdEEDEHw2ZQNwRBcGXzQoVuq+/btqrpnQY4MPx8q
u1NM48ev3798+/B4PD69//r8/uv3759fP9+e/nh7/PX15/Ut//36X2fr9a2O
vr7+On37nPvo+3+04+7o6+u7O/Zn9qO8+h65a/r6+vY99lXuTvWfF319/fMd
+zn76Pt2tOPu6OvrZ+vb19pn0/M3fX39bO+T9mP32XQv9PX1s71PrraPvt9G
O9l0d/T19bO9D9vv77vq+Zu+vr59zn1X3Qt9/XX69mP30ffJaKer7o6+/jp9
+3v33NfzN339fn37e/fc173Q16/btz+2j76/RTvc193R16/bt5+z5xw9f9PX
z9+3n7PnHN0Lff08ffv9ffR9KdrhHN0dff08ffuxe9bS8zd9/fl9+7F71tK9
0Ne/rm+/79Y+2mEt3R19/ev69sf2XFPP3/T1z/ftj+25pu6Fvv75Ttd99H0g
2uGaujv6+uc79mT+e+Su6Vfs2+/vyTO6F/or97vuoz+/0Q55RndHf+W+PZlH
z9/0V+jbk3l0L/Q79avvoz930Q6ZQXdHv1N/tT3ZSc/f9Cv2V9uTnXQv9DP3
q+yjPy/RDtlJd0c/c7/rnuSrnr/pZ+h33ZN81b3Qn9nPto9+n0c7JF91d/Rn
9qvvSV6n52/6V/Sr70lep3uhf6Z/1z76/RntkLxOd0f/TL/KnmR+PX/TP9PJ
tieZX/dCf+Y++n0V7ZDMr7ujn3lPch09f1uzn21Pch3di979Ufvo90O0Q3Id
3Z3e/bv2JBnV87ce/bv2JBnVvajV99yMZHXdnVp9n19IdtXzt5x9d4dkV92L
e/tb++i/f7RDknfp7tzbH7Unyep6/janP2pPktV1L8b2o/9u0Q5JVtfdGdv3
+YUkj+n527G+u0OSx1ztXmy9Hv37RjskyafuzrEOSXKsnr/t70mSY61+L6J/
zq3XSZJzrH53fH4hyR52ff5GksxptrsTfZ0kWctsn1O2XidJ9jbb5yCSZG+v
vhfRPUlyTf0/Z5LkTD03I0nONPr/B0iSvEJ3h+RxfwGkD0m9
        "], {{0, 0}, {69, 
        68}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlcEJgDAQBANWoB1YSXoQtADBt9X6twRLUPGxcGBIxHgm2YEw4RBz3GJs
x7mbKmNMfazmWOf+YrNug6E/Wax06Hv8nof9zl3FObnUQw2YV8z6WwbM6416
bAPmFVLXMmBez/r/1qDsvFIxKCOv1A3yyitXgzTzKs3g33nRRhBnbrzHdA14
j8U08JuzhN/LtwahefH/omHA+afsu3tMot0n7bZEu5/8vQPYx0/e
        "], {{0, 0}, {18,
         17}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztnE1uHEcMRgfISXwSLZO1AfsABrzOabPPEXIEW9DCPRWX1Kz+WPzpR0B4
xgeCzWKJJNAaz6dvf3/+/sfj8fjz589fP39e//1m/7288d+Xx5P56V+/vNo/
LyOt/lY+x/9lqvjW53rX2aqr8s9Wtyr3ElU3VT9yrj2MqkOOuTdjfJ9a/dlf
Wp39tRZfpVefb5xrD6PqsLd/rYzvU6s/+0urs7/W4qv06vONc+1hVB188lQx
vk+t/uwvrc7+Wouv0qvPN861h9nqcE73ZnyfWv3ZX1qd/bUWX6V3nW+cS8ts
dXjWoxjfp1Z/9pdWZ3+txVfpXecb59IyRx2yMb5Prf7sL63O/lqLr9J7zbf7
nkvlfy3Ox/U5p1dhfJ9a/dlfWp39tRZfpd9tznc9l8r/WpyP6/OsV2d8n1r9
2V9anf21Fl+l323Odz2Xyv9anFl9ujK+T63+7C+tzv5ai6/S7zbnu55L5X8t
Dnz81nbp1nyq1yeq/t51VsXxvq9sfaHKP5t/lTyz+VfpryocLWv/VqlD1zqr
4njfV9ff/2z+VfLM5l+lv+px7/u3bBxt17yKem71/vI+l0qvMlet/lXyzOZf
pb+6crRqc6BKfbz7y1uvUp+o+ayKE3Uu7/p09a8yx+7G0brMq6g6RM1PlV6l
Pt5zZuavihN1Lu/6dPWvMsfuS95DHi16jqnysepV6hM1n1Vxos7lXZ+u/lH3
C7UcbZde5fdnlo9Vj6p/lTp7z5mZvypO1Lm869PVv2tfwMdvTa1X+f2Z5WPV
qbOW1vxn/qo4Uefyrk9X/659AUfyHvJou+Zh1HOr0Jr/zF8VJ+pc3vXp6t+1
L+D7jP/+BKs/3yui1fleEUUc/LPc+7MOezPbnGR/7dbZX4o4+MfeO7wns81J
9tdunf2liIP/nnuH8Mhsc5L9tVtnfyni4H/W/5wO4Rlmm5Psr906+0sRB/+1
/QXhFWabk+yv3Tr7SxEH//f9IdzJ0Xbp1nyq1yeq/t51VsXxvi/vOPhDmIej
qfUqfTHLx6p3rbMqjvd9ecfBH8KM3Pv+LRtHW9W946ueq6pPtvvyjoM/hHU5
2i69Sn/N8rHq3vPHW69SH9X9RsXP5g9hRY6m1qv01ywfq+49f7z1KvVR3W9U
/Gz+ENYm7yGPtqp7zx9vvUp9VPcbFT+bP4R34Gi79Cp9OsvHqkfVv0qdVfcS
FT+bP4R35mhqvUqfzvKx6tRZS+/8rfGz+UMIX8l7yKOt6t7xVc+tQu/8rfGz
+UMIr/e7t16l32f5WPWo+nvXuUqeXeNDCM/3nUqv0u+zfKx61zpXybNrfAjh
e+Q95NFWde/4qudWqY/3/VaJDyE8z2zfo3vf7zfOVp/Zc6/lv16HqHM96xDC
PGR/sb9seV7Lf70Oe88FIcxP9hf7y5bntfzX6+BzLghhXbK/2F+2PK/lr6/D
OR1C2I/sL/aXLc9r+evr8KxDCO9D9hf7y5bntfxVdYAQwhlH26Vb86leH+/z
VnlulXuHENblaGrd+tzqdfA+b5XnVrl3CGEH7n3/lo2jrerW+Ko8sz3XOw6E
EFo52i7dmg/1WfOvEgdCCFUcTa1bn9u1DjPduz7Z4kAIoZ68hzzaLt2aj+pc
UXEghNCb/T/Pz+fwLTqEEFYh++ue+wtCCKuT/dV7f0EIYVeyv7Lsr2t1hhDC
u5H9VWt/QQghfCP7K+f+ghBC+D7r7S+V/7U4o63WB0II4RrZX2txRvsoPoQQ
Qi3ZX2txRou+RwghvBvZX2txIIQQ5uRou3RrPip/7zgQQghjOZpatz5X5e8d
B0IIYRbu/Ry7laNFx4EQQpiT8f/P6zn+aP9/7jkdQghhb1bfXxBCCO/JKvsL
QgghPDL+c+856gAhhLAW+T5bCCGEFcn32UIIIezE0dT+EEIIYQaOFp0PhBBC
eCR/z4KwEn8AcqBTew==
        "], {{0, 0}, {72, 71}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3F1qWzEQBlBDV9IlpBvwHgrtAgp97mr73iV0CYkJQb5qFZP7p9HoDJgT
PuYhse8dS7LJ5x+/vv78dLlcnl4eX14et59f6+/11T/Xt+T7t1v9vtbq168/
X/8yr+usvPX7tIz7fOrXrz/7vPqocZ9P/fr19+5vWdfa9ZJ5pV+//l7zqpel
Wn8X2b7OW9ezPHfey2hzPk//Mq9LLo+UH72/M6+i9y/zuuTySPkoxr3f9ev3
/pJ9vWRe6de/pn+Z1zVaPpulWq87Y9p6HeUz5bMZ933wmP7Hc1su75dn3d+Z
V+v6zSt55JzrLNV730POs+/mOqOti/Qf1b/M65Jvy+3vzjHu/aXfvBon5znG
vb/0629b19659VJMo12f+vXf9/eaVxzLUq3rijFtvY7yj+TMYSn3ozxvzhw6
75WPmDuPmlPzSj5iTt5bqvf5jX2o/N+cvDfr50TymLn9HbdoXsnPzMkjLNV7
P8cxbF0/Ma5n5jba9w/z9C/zukbL7e8Ywbj3++j9y7yu0XIygnHvd/3/629Z
16PceokjGu1+1H/OvCIzWar3+W4UW8/PmDmZyWjriqznQnvl9necWfNqrJyc
2bjzKkZ/y7rW5tZLpHk1yrwiud1Svc+/c5+rk9zTXPMhWk7yOJ2Hv587jyLj
aF69n5OM42zn4dZL5LjONq9IZrD353vnnPOTzGyMddFeOUm2rKt3TnJGY3wv
y/k5ycfGmFckud5zz7tIspd1PcpJcn+3/b8skjzPbftEkjefAS9kJjk=
        "], {{0, 
        0}, {50, 49}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2J+IAaxIeCDPTodFgoCV0c8jRou6AAz3ChTP3LDf6DC
eaSFP65wI049/eiBDqeREs5DPfxJdf9Ah+tQDf/hGs6DLfxR3YEO6F8PDhQ9
Gs4DQT9A8x+mOLXKDVQaHQx0OAy9dI5qLgIM1/KZWvRoOA8sPdreGJz0aDjT
ksZVzxKmAZxJeEA=
        "], {{0, 0}, {15, 14}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3W2K5DYUheGGrCQryR4CyQICSX5mtfmfJWQJmaEpplFGrpbryrpXfi4M
7yAO8umyPg5dsvvH3/76+fcf3t7e/vjy788v/77+/73+/entu/Vo/+ensfYe
o/SjPkf1UX5Gr1vFz2g//PDDz338zF7/6ekz69s6qx9l1Lzuta/6eaP899jT
z/48V/mpso/www8/efyMrlf09BX1s3PaN/76y9f6+3/8nJ8o/3JaTj+77iP8
8MPPPD9V9ll6+lf01+W0HP7ltJx+dt1H+OGHn3l+quyz9PSv6LPltNk+5bSc
fnbdR/jhh595fqrss/T0r+ir5LRR/6vOv82+j3IaP/zww88x6el30lfPad+Y
4/zb7Psop/HDDz/8HJOefif9Pjntcxz9ueS0a/zsuo/www8/8/xU2Wfp6V/R
3y2nRX0Oo+1V7m+Un6j1fNV1d93X+OFnJz9V9ll6+lf0ctrxzzu6Lo1+zlH3
JUq/yn9UP732bPsLP/zw83n97HWJnv5KfVvR++aubOvs+lPl/s72M3rdKn5G
++GHH37m+cm2/9LTf2xv66wejxm1zvTaV93f6t+HZvNTZV/jh587+xldH+jp
Z+jltFnM8TypnJbTz677Gj/87OSnyj5Ov7deTlvLtqLvl5yW08+u+xo//Ozk
p8o+Tr+3Xk7LyVX5Kqqf0f57ejmNH374kdPo76yX02ox2/m32eNWTuOHH37k
NPo76+W0qsxx/m32uJXT+OGHHzmN/s56OW1vtnXVeIjSy2n88MOPnEZ/Z72c
dk9GrWO99irjOcpP1P6y6rq77rP88POKn1XrGD39R8pp92RbZ9fJ0XEVNQ6j
9Kv8R/XTa8+23/HDT2Y/s9cBevqP7W1F7yO4B9s6ux5WGc+z/Yxet4qf0X74
4WcnP7PXN/q99W2d1SN+ZNS612tfNZ6rfx+azU+VfZYffq70Mzof6e+pl9Mw
hjmeJ5XTcvrZdZ/lh59X/IzOR/p76uU0vJJtRY9POS2nn133WX74ecVP1DpJ
v7deTsMMXJWvovoZ7b+nl9P44ec+fkbnI/099XIaZma282+z56mcxg8/9/Ez
ez2h30Mvp2EN5jj/Nnueymn88HMfP7PXE/o99HIa7sS2rhr/UXo5jR9+7uNn
9npCv4deTsM7MGpd7bVXmb9RfqL2u1XX3XXf56eWn1XrBn0tvZyGd2Bbz8Z/
1PenUfMuSr/Kf1Q/vfZs+y8//Hxsnz3v6Gvp24peVxErsq1n86L6/J3tZ/S6
VfyM9sMPP6/0M3s9oV+rb+usHvHOnH0ebNX8rf59aDY/VfZ9fvb2Mzr+6XPq
5TTEM8zxPKmcltPPrvs+P7X8jI5/+px6OQ1xHtuKno9yWk4/u+77/NTyE7Uu
0a/Vy2mI13NVvorqZ7T/nl5O44efeX5Gxz99Tr2chpiH2c6/zV6X5DR++Jnn
Z/b8pb9GL6chZmSO829R60xPL6fxw888P7PnL/01ejkNsS7bumq+R+nlNH74
medn9vylv0YvpyHux6h1vtfe42x99fy26rq75hB+jttXzVP6WL2chrgf23o2
36O+Px3Vj/oc1a/yH9VPrz1bHuBnrZ/Z45w+Vt9W9DqDiHWZ7TmFbPmnx57e
97b8ZPAzOk7oc+rlNET8xhzPKchpOf1kyyH8HPczOk7oc+rlNEQcZVvP9HLa
Hn6y5RB+jvuJmr/0a/VyGiJGcVW+iupntP+eXk7jJ4Of0XFCn1MvpyHibGY7
/9ZjlF5O4yeDn9njnP4avZyGiNcxx/m3HqP0cho/GfzMHuf01+jlNETMxrae
6bPtX3IaPxn8zB7n9Nfo5TRErMKofbDX3uNsffX8tuq62XJRNj+rxjN9rF5O
Q8QqbOvRPrqv9ZjtfSPZ/Ef102vfNS9luy/0a/VtRd93RMRVbOvRLqdd4z+q
n1773XLabD+zxwn9sb6t6HmHiJiNbT3as+1foz5H9VF+Rq9bxc9oP9n8zB5v
s8f/3fRtndUjIu7K2ef2V63P1c+tZfNTJaeN+sk2fujfKachIrbM8d4POS2n
Hzkttn/6Y8ppiIjn2NYzvZy2hx85LbZ/+mPKaYiIsVyVr6L6Ge2/p5fTavnJ
Nn7o3ymnISJew2zn33qM0stptfyMjtuo/umPKachIl7NHOffeozSy2m1/ESN
q9H+6Y8ppyEi5mRbz/Ry2jV+5LTY/umPKachItZi1L7Za+9xtr56flt1XTlt
b72chohYi2092r2n91z/o9fN9nlWvy9307cVfd8RETEnsz2n4HnVnH6q35dd
9XIaIuJdmOM5hep5QE47ppwWq5fTEBHxI9t6pr9bHpDTjimnxerlNERE/Ay9
p/f4utX9VL8vu+rlNEREfIXZzr/1GKWX044pp8Xq5TRERIxhjvNvPUbp5bRj
ymmxejkNERGvZFvP9HLaNX7ktJx6OQ0REa9kW4/22Tlhtr7ns8p73lb1k+0+
ZhsnPT0iIuKV9PcUYv1UyWk9fa991X2crZfTEBExM9t6tFd5/3+V3y/1/Iy2
+z3bsb6ts3pERMQMbOvRLqed63/0utn6l8cQERHzM9t7P6qft6+e00b9jH4+
UXo5DRER78Uc7/2Q067pX05DRETcj20908tpsX7ktHfKaYiIiJ+nv3t1fF05
LVYvpyEiIr7ObOffeozSy2nX6OU0RETESOY4/9ZjlF5Ou0YvpyEiIl7Ptp7p
5bRz/ctpiIiIOMq2Hu13+7tXPf1oP1Xeqzbqp6dHRETE6+nvXh237/p7NjkN
ERGxLrM9p5DtedWoz6fH2Xo5DRERcQfmeE5BTovVy2mIiIj3YVvP9HLaMWfr
5TRERETc9T29choiIiLuymzn33oc7V9OQ0RExH2Y4/xbjz29nIaIiIj49t16
ppfTjimnISIiYhTberRne09vtuvKY4iIiDibbT3aqz9fEOVHHkNERMRszPb3
FGY/HxH1OSAiIiLOZluP9tm/1xrVj/qM0iMiIiJmY7b3fmR7jxwiIiLieuZ4
74echoiIiHiObT3Ty2mIiIiIa5ktX8lpiIiIiG/frUd7tvNviIiIiPhOOQ0R
ERExO3M8p4CIiIiI59jWM72choiIiHgN23q0y2OIiIiIOSmnISIiIuZkW6v9
YBb+B26xEhM=
        "], {{0, 0}, {103, 102}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJeIAaxw0JB4Ko9Os0ABh+gNDoY7uIP7LGLE6Zxhedw
pUkNH1LDjbJ4HGzi5KcrUumBTheDJV1RK9xQ1aGDgRanX7oilR7odDRY0hW1
wg1VHToYOemKVHo0XVE33FDVoYORk65IpUfT1UDQIze9UUYPfLgBAAABopo=

        "], {{0, 0}, {13, 12}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3WFqHEcXhlFBVpKVeA3xEgL5nS1nCVlCHEyDuXEpKk1V93u7T0E4H5fm
6ZHQ9P2sccivv//59Y9f3t7efvv2z9dv//z7v7+fv7+8bz3H/K8vP5+PrtfR
0dHRuUdntj/b6T6vZ/X3Z9bZ+46u19HR0dHp1Vl137vO67l6X6f9/Ojo6Ojo
rO3Mzkfe9frd81Wm/Vzp6Ojo6KztzM7T9mnavk5z9DrTfg51dHR0dN7v+Jz6
/Xk9n+2kOft1ja7X0dHR0Tmns+q+d53Xc5d9bY/r6OjoZHae9ufoeq7+/y3d
rafbz7+Ojo5Ol86q+3aZ13P196e7aT/POjo6Ot07s/ORXa5Pm9/VtJ9zHR0d
ne6d2Xna/k3b13zfelLfFzo6Ojppnad9Tn3V95PvW0+395GOjo7O7s6q+3af
12Nfn2va+0JHR0fnqs7sfGSX69O+b3zftPeLjo6OzlWd2Xna/r1qX/Na60l9
f+no6Ois6jztc+p6Vn+9vNZ6ur0fdXR0dFbN0/avfc0fTXt/6ejo6Mx2Zucj
u1y/e85M0953Ojo6OrOd2Xna/t29r3lv60l9n+ro6Oj4nPpzHd7berq9r3V0
dO7XWXXfLvN67GvOWE/q+1pHR6dvp/ufo0evc9XcvuYr1tPt+aCjo5PTWXVf
+5r8r2nvdx0dnfzO7HzkVdenzcmPmPYc0NHRye/Mzmf36e7rd8/JM60n9bmh
o6Nzfqf759RXfX/IM62n23NGR0fn9c6q+6bN61n9dZFnmvbc0NHR2deZnY+8
6vq07wN5pmnPEx0dnX2d2fnIq65f9X0g72Q9qc8fHR2dj3e6f049ep2jud9v
88nW0+15paPz5M6q+9rXZL5pzx8dHZ3X5yOvun73nHyCac8lHR2d1+cjr7p+
dk7y49aT+hzT0XlC566fU/v9NrnPero993R0OnZW3de+JllP6nNPRye5k/bn
6NF9V83tazLHero9P3V0zuysuq99TXLWtOehjk5CZ3Y+ctX1aXOS55v2nNTR
SejMzkeuun73nGRf6znmac9VHZ0dnbTPqa/6ekn2tZ6znic6Omd2Vt3XviZ5
lWnPVR2dVzqz85Grrk/7ukj2Ne15q6PzSmd2PnLV9au+LpIcWc8xT3s+6+i8
0vf7bZJ3tZ5j3uV5rnPvzqr72tcku5v2fNZ5Zmd2PnLV9bvnJDlr2nNb55md
2fnIVdevej0kudt6jnnac17nHp0un1P7/TbJLtZzzLvsBZ3Mzqr72tck+b71
HPO0vaBzbWf3fpx9nbNz+5rkXa3nmHfZLzprO6vu2+X1kGQX0/aFzjmd2fnI
3fddNSfJ7qbtEZ1zOrPzkbvvO/t6SPJp1nPM0/aOzuc6V/1971F/1X1Jkm8/
Pce8y57SWXtf+5okM03bOzpr5yO7vE6S5HfT9pHO2vnI3a+TJHmO9RzztP31
tE7av0/t99skmWk9x7zLvuveWXVf+5ok723a/rprZ3Y+cvd9Z18PSfIc0/ba
XTuz85G7+yTJXtZzzNP2YJfOVZ9T+/02ST7Teo55l715VWfVfe1rkuQr1nPM
0/Zm2p+jd8/ta5LkR6znmHfZv7OdtLl9TZL8iGn79K57eXZOkuSPpu3Zu+5r
kiR3WM8xT9vLu//e1+7XQ5LkDus55ml7/Kr72tckyQTt5c/NSZI8U/uaJMm+
1nPM0z6n3n1fkiQ7Ws8x7/L3wO1rkuQT7LKXZ+ckSd7JLvuaJMknm/b3sWev
J0nyydZzzP13r0iSzLeez87ta5Ik91nP6jlJknzdev5vTpIkc/T7bZIk+2pf
kyv9Bwa0VeQ=
        "], {{0, 0}, {82, 81}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBmIeIAaxw0JB4Ko9Os0ABh+g9AMojVv9YKNR3Y8AxKlH
0CMtfHCFw8gOH/LpwRY+uOKd1uEw1MOH1uEwNMNn4OmBCp+B9jd1afLDB9Uc
dDDQ/qJfehsNH/z0aPhQg0YHA+0ewjQAHi7VSQ==
        "], {{0, 0}, {12, 11}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3FFu20YQgGEBPUlPkjsUaPIeoM89bd97hB6hCfQQ78q0NDSXnJ39CBRf
MSDgH7ZFrrKUf//+9x9//Xa73b7++O/bj/9+/v/9+O/L3X+/3JrD3Py9eX88
m+vRo0ePnpw9W/Mts92PzHPO+2O214UePXr0zN5z1H08arb7kXnOeX+s+jrV
o0ePnqt6ovfx4/3658/jnwfb8/rDfPb51s/9KPXo0aNHz76eaGd7/mhH74OY
55xXXYfr0aNHz+w9W/OrtE5Yc57tdaFHjx49s/dE77Pn7SN8TuuENedVX6d6
9OjRc1VP9D47n6P3a5jT9vegPx7nevTo0aNnX2d7/uyOXu+Z55z3x6rvC/To
0aMn2rM1r2q2+5f5OfP+mO11qkePHj2j9wvq7CN8zmz3L/Nz5v2x6nVDjx49
6/RE74PsHb2PY37OPNu+nh49evR4rqCio/dxzM+ZV31foEePHj3Rnq0592md
UGOe7XWqR48ePaP3C+wjnKN1Qo151euGHj161umJ3qd4tqP3m3iO7c+1Px7n
evTo0XNVT7SzPZ/XOnq9an7OvD+ezfXo0aPHcwV8xWz3O/N98/6Y7bqhR4+e
/D1H3Uc4l9nud+b75v2x6nVMjx49475u9D7Cao7ehzLfN8+2z6hHj551eqKd
7fms7eh9KPN986rvU/To0ZO/Z2vONbVOyDnPdt3Qo0dP/p7odd4+Al/ROiHn
vOp1TI8ePeO+bvQ6T8YcvV/GfbY/p/54nOvRo2ednmhnez75GUevt833zfvj
2VyPHj3r9GzNyRFmuz+a3949ZruO6dGj53F+1HWYPNNs90fz27vHqtdVPXoq
9USvw2QuR++jmd+PbPueevTo8VwBGXf0Ppr53arvm/To0fP6nJxR64Rz5tmu
Y3r06HmcR6+T9hG4gtYJ58yrXlf16KnUE71Okms5er+Pd9vve388zvXo0eO5
AjKf2T4XUHXeH8/mevToGdezNSf5aLb7adV5f8x2XdWjJ0PPUdcxkq+b7X5a
dd4fZ11X9eip1BO9jpE80tH7gFXn2fZh9eip1BPtbM8nOc7R+4BV51Xfx+nR
k6Fna07yfK0T9s2zXVf16MnQE73O2Ecg82udsG9e9TqvR89n5tHrDMmZHL1f
WdX2+9gfj3M9eir1RDvb80nOa7bPEcwy749ncz16KvVszUnWM9v9d5Z5fzyb
69GToeeo6wDJdcx2/51l3h/P5nr0ZOiJXgdI8pej9zFnmWfbF9ajx3MFJPPp
8xF3q76v1LNmz9acJKNaJ9zNdp3Xs2ZP9HVqH4HkaK0T7la97+iZqyf6OiXJ
8xy93zqL7felPx7nevR4roDkemb73IHPO+hZoWdrTpLZzHa/tk7Qk7nnqNcR
Sc5itvu1dYKezD3R1xFJ1nH0PuxV82z71Hrm6ol2tueTZFWrfj6i6vtcPef0
bM1JcjWtE/bN9eTsif6e20cgyY+1Ttg315OzJ/p7TpJ81av/zkGWfWo9c/VE
O9vzSZL7zPY5hdnf5+o5p2drTpI81mz3d/fB2j1H/R6SJM8x2/199vugno/n
0d9DkmQWZ/l7C9n2zfV83BPtbM8nSeZ0ls9HVH3fXbVna06SnEvrBD1v59Hf
E/sIJFlb6wQ9b+fR3xOS5Cpe/XcRVtnHz9YT7WzPJ0muabbPNWR73121Z2tO
kuRbs60Hqt6XPVdAkpzRbOuBbPflbD3RnyNJksd41d9byLaPn60n2tmeT5Lk
CK/6fETVfwfwXAFJspLWCcd+3ej32T4CSTKz1gnHft3o95kkyTn09xM8V0CS
5Gv6vMO+nq05SZKVXG2dcNT3gSTJFbRO2Hc+SZJr6bkCzxWQJPma2f4dwHMF
JEnmMds6IdppH4EkyXHOvk4gSZJn6LkCkiT5mp4rIEmSW3qugCRJbum5ApIk
+dzocwieKyBJktYDJEmSJMlX/B+KG97l
        "], {{0, 0}, {87, 86}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3VGKHMsRBVCBV+KVaA8GewEGf3sD9jL97yV4Ce899FFWo56qiM7Iyqg8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        "], {{0, 0}, {125, 124}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt2tGNEzEUheFIVEILUMD2gAQFIPFMtbxTAiXsRjyEDMmsPR7P3Gt/lqJ/
dWRdZ+L47LGdj99/fvnx4XK5fHp7fX57Xf/+2/68LPnt67X9auZ93d8vl7v2
nn5rZfWXrbx+7bi170edY+rQx9bLvg/PWOs/230p+zpS55g69Jn0Z35SSz42
e517/fx5p4+o7+VXfEydx3Xu9e3z3tafPobe26/eZ+26KFsvzs3UKZkX+hj6
sh3vY72fK8Y6Uqf1/4L9Iz1C7qqlnLY+bna/ilaHHlMvm8cslNPU2acOPYOe
L3eVkY9lrVM2L+4l59RH9Ss+NlqdsnlxLzm2Pptfvc/a9VW27pybjVEn2j0a
/fKwne8jsSinZa3zbF7sHzPrclcr5bT1cbP7Hn+LqZd9/riNctrsdeg9dbnr
GPKxKPvEsz5n+h46vzqXfCyrj7X1p2/T+VV0tp6XPV6/zs3OrRPtPi67vmzn
r1tco5wWJafZP56hy12jUU5bH3cs/5xXL/vccAzKaVnr0B/pctec5GP75kD3
ksfo/Ar/JR872sfa+s+m8yuso3Oz9XGP9c9o93ruEzEj5bRW/7R/rNHlLuxL
OW193Bj+mU8ve17EHpTT+FWLLndhBI7vY9GeK6fOrzAy+Vjpc7X1z6LzK8xN
52br485xL7ls538vEbdz3pw2x/5R7sK5KKetj5vF39wnIm71n3w5Lbtf3ety
F2ImH4v9fnrr/AqRj9XWeda/t86vEPfk3Odm7hMRx2O+nBZ7/yh3IZ7JuXPa
dt19ImJUxs1pMfKY3IWYiTlz2v55TO5CHIW9z6mi/b5C7kIcj+f7WFv/2jqI
ODJz7jdr+yPiPNw/px2b9xARs+w3ERGfcfvvNPrsQxERt7PPudmtOddCxN50
roWIc3DZ/tflLkTMyVvjY4iYk/aPiFe+Ai6b0Yo=
        "], {{0, 0}, {51, 50}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBmIeIAaxIeCDPTodFgoCV0cMjSscSKUH2h+DPXyGa7jR
OnyGergNVPgMlXAb6PAgNnwGypyhQlMW7w+gNAxgig/X8BwNH2qEDy4aHQy8
f+hFU5auRmkITX74AAAQxeKt
        "], {{0, 0}, {12, 11}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJeIAaxIeCDPYR+YA8TCQsFgav26DSqenQwXMQf2GMX
x0WPhht59HANN1LTz2i40YceKuFG6/QzXMNtsNEDFW6DLf0MlXAbPjS1wo04
c0YajSt/IcBouJFCI8BouJFCo4OBdg/1aQAjuuIr
        "], {{0, 0}, {13, 12}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3UGKJDcQheEBn8Qn8R0MNthLg9c+rfc+go9gD6bIHrm7WlJJqQjpC2j+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        "], {{0, 0}, {90, 89}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztk80JgDAMhQNOoBs4SXcQdADBs9N6dwRHsKUnfyoYQtKWFwhf+06lH6+f
12FpiKj12/kN5ziH++bu6DLH7Y5cJk/981/Cl04uRfji5VJ9gS+d3IrwFWnV
F/ji5aWwVl+l9AW+6mYpvmrtS62+wEgrX+gLj1a+QB6lfKEvOpTyBeow5Qt9
yYXTGGZ70Ppd4DvhK0+edyUmGQ==
        "], {{0, 0}, {18, 17}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztnVGOJDcORAfYk/gkvsMC9gEW2G8D3rP630fwEXaM+dBWYbtSTJGKoPIJ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        "], {{0, 0}, {115, 114}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztm1FKA1EMRQdcib+6iO7BJQh+u2WX4BKs9EdCH+U+k5fkzQmUI5dwZ8Tm
ZqZTn98/3z6ejuN4ub5er6/fn2/1fTnu1qzuRdX/63K/f6SP/NV+1SfaH5+a
PtG6ep7q3Kl6Fr3mPXp+1fPBZw+frH6v/TvSvfa42u+VA6rexR+fNT7Rutd+
75IDXj7R9wVd/NXj4jPn02W/Z+VA1nG95oscOKdPtJ6137vngMpq7wfmupfP
rvs9eh5H/aruxaznAqp/93np4hOtd9nv1XIg2qfLdb7qM+rHp2Z/d9rq1l/t
eR854OsTre+637vngMqs/OdzwjU+7Pc1tOXto+rROTDSq10/VPu92O9709aq
HPA6n2pzVO18qvmw32vS1ip/VffKgS73EV7nE+0TrbPf19BWdg6ojJ6LajlT
zYf9vgdtZZ9PdA50+Z7hqD/aJ1pnv/eiraq6mg9Z89Llc8LofvXvBXNpK1v3
mndyoGY/rElb3vOrHtcrB0b+WfNYLa9Unev8vWlrVQ6orPa9oFG/l85+hytp
y3vevXy6zGMXnf0O/9LWqveD6l9tv3fZ12o/PCdtefd3yYGs54leOvsd/oe2
VuWAymqfB6o6+x1Wpq1sn+gc2LUfwgjaytaj7wvU/KmmQxhBW4/0aH/u6yHc
LwfU43aZU+7r4U605d2flQPc10MYlw/Repfr+RHZ+3An2sqeu2o5MOqHcCfa
mtVV/2rX8+x3eGbaWuVT7f92ITwzba06Lvsdwvq05a2r+cD3cyCskwNePjy/
g7Avbc3qKtn7ENahLe+5Hvkz7xDWp63Z3GDvQ7gfbc3ONTkAYV/aejTXo34I
4XnI3ofwPGTeIZzhDydaKQU=
        "], {{0, 0}, {43, 42}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztl1EKgCAMhgedoG7QSbxDUAcIeu60vXeEjpDRQ2RILk1t/QP5fBBx+9jA
uh+boSCiUq9Kr22/x6JMdu0W04Xnc7OiU1zvsZ233S+VbnXj1hO+0vp6Tvh6
01d4whcn3/D9wiV8hcgXvqTNMfjivDPffuHyH77kUJYv+XSrgxnu8wf9EpZ5
+wJNvuPrfk6mzvurjOsL9CV8fZlH+HkE41D+f1MW4SUXrjCX0JU=
        "], {{0, 0}, {18,
         17}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPTodFgoCV4csjeofBKC1+bjCc6iH81AJ
z6ESzkM9PAdbOA/X8ByocB4NT2zupBaNy78P4PKUhefA00MlPOkdLuTSAxWe
Qz3ccNGDI30Of3q41heDgx4+9cXgoIdPfTFQ9FAPNwB5lLQI
        "], {{0, 0}, {14, 
        13}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3U2uJLcVROEGtBKvpPcgwJ5LgMZareZegpdgCT0oJdVVnT9kMi7zu4Bw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        "], {{0, 0}, {98,
         97}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBmIeIAaxIeCDPTodFgoCVzFoVHUP7BlQwAc0/lAVJ0yP
jPAhnx5e4UN9emiGD/3owR0+A08PjvAZvDR9w2fo0bQJn+FKk+pfUtWPNBod
DLR7Blu+Gz40AL3Wo0w=
        "], {{0, 0}, {12, 11}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlsEJgDAQBAOWoA1YSXoQtADBt9X6twRLMMGXCepFSHLJ7UEYWQ5ERxb7
eR2WRinVmtOZY6+vOfQ7d61u4+fTaGfTLrGfZp+Wf/t9ui+YhjRfoYRfLozj
F72dep+HX3iPtU/L8/vN3WfcycMX/MJvmPfQ76H0fRl+5Xqn5bWynj7n8T65
EX5lkm9vw29M5vdOy8F/TNfnPJ5XGuG3brrj5/BVMt2BXxnE/w8oiyfuFZvw

        "], {{0, 0}, {20, 19}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPX76gT0DCiBefVgoCFy1H240ceEwGp7U
DbeRG560CbfhH570DbfhE56DI9yGXngOjvAZeuE5OMJh6IXn4PDv0AvPweGv
oReeg8P9g40eDR/q0qPhSSk9Wu6RRwMA5aNxtA==
        "], {{0, 0}, {14, 13}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJeIAaxIeCDPQMaCAsFgav26DQu9ajiD+yHpzguGgFG
driRSiPAyAg3atEIMLzCjdY0AgzNcBsoGgEGd7gNNhoBBke4DRUaHRASR9DE
hfNQDx9qhRsCEBduw5VGB5Snw5FBo4PR8KGMHq7lEvk0ACu37yw=
        "], {{0, 0}, {13,
         12}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmUEKgCAQRYWOUBfoJN4hqAMErTtt+47QEVJcFUQR6nzHL8iLYRaDTx2h
fl6HpTHGtG52bvrvMA4buFtzGW/xJzJfNh6rTrT1RMuXWk/6xcyP5TG1d8a/
xqfRj83eec1H84t2LkrZt1Kk3zz10C9mfikeU3vXE8fom2h+0e7V0vsm/eap
RyvR/KaukwxEuz9r65tofqX2CRmXfP/oJtp/EDIPeX51kx7rJN+9tZB+//EE
aaC1Rw==
        "], {{0, 0}, {20, 19}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgAmJuIAaxIeCDPTodFgoCVwc9jepudIDpL8rUD97wGahw
GGzhM9jCYaDCZ6iEA63DZ6iHA7XChzL7Bm840Nf91DJnqNPoYKDdQ31/0SYf
DRUaHRCvHwAFrwFp
        "], {{0, 0}, {11, 10}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt10EKwjAQheGAZ7B7T9I7CPYAgmtP694jeIS2uFBHkDZ0zEvmHwhfeas2
eZT2cL4eL7uU0n5a3bTm6+c8+m299+ljyLVzzp38PffWTm6utm+t5uUdTvPc
vvR5XvLfeXnpg1Jei6/7pz+eeTTV9l8tb1W1fa4lj6ad3FztHOmDl7G/T9BK
H3C9rf7vYFnpQ0zVzp0+aGonN6cPUfzv9wmqSx9wvVv972Ct+rw3sFaX9cFO
+ftGH5f1Id8RO4K0Ng==
        "], {{0, 0}, {22, 21}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztllEKwjAQRAueQf89Se4g6AEEvz2t/x7BI7SlH8GhG5K4STZxBsorQ1jS
7sDu+f68PA7TNB2X57Q86/umjwsTleu/Hf0cH/V7ndt11cshv897xp239t9G
9VHxdVL7LpF5sOSjcuuUpnTPVN/a/++971KdVpTuk+pb65fdvmvNBS1yvqT4
qPr7QGkyDyk+yuo+wDmi66NG2QeYk7CvdR+vXuaCFseaL6j4Ov/Wd4nMw55P
holqPUe06kt1yDyitHOSep77QG3WnS+o+Drsex32kofc7yNLsFUepPOkTWrl
wYtzoS/G9QvFvo9KrTy0/g6yJrkfkvvkXNg4A0Tvot0=
        "], {{0, 0}, {22, 21}}, {
        0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJeIAaxIeCDPX4aHQx+8bBQELhqTyxNnPmk0tT31+AW
pxZNa3dSX5y4dEVrmvr+oq/4QNHUcj8CDI7yZ+iFG2XiQ4Um1V+ExQdH+TP0
wo2+7qcfPTLKn8GW3kYuPTLKn1Ga3jQA+ZDX4g==
        "], {{0, 0}, {13, 12}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPQNWABN/YE+aOC4al/lDXZxU/46GJ3k0
LnNGWnhSi8Zl/nANT1rTuOwd6uE5UDQu9wyV8BxsNC53DrbwHCo0LvcPVHgO
dRqXv2gdnsOVxuVfaoXnSKPRwWh4Ukajg9Fwo4xGBwPtnqFHAwBnluIj
        "], {{0, 
        0}, {14, 13}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztnOFp3EAQRgWuJCXEDVwPgaSAQH672vxPCS4hNke4aOxZpLvZ3W9m34B5
ycOIiXx6+GTFX36+fPv1tG3b17eP57eP9z9f5/Vy5Z/LtptX8/ejvvdxZnlv
T8+z/5reTvR5jj/+j+/v8/ti+djnn93T8x7pVdt7e3qe/df0dqr3JMqfJb1q
e29Pz6vtP+s83ObsdVfL2+n3+tHuWxTpVdt7e3pebX96Ndprd6O370161fbe
np5X239+r8bumeX8ZO/eLNKrtvf29Lza/vSql9fuSZRXI71qe29Pz6vtP+56
3Hs72c6bt6fns/ctC+lV23t7el5tf3p11Gv3JMpnJ71qe29Pz6vtn8XbiT7P
8cfX7ltV0qu29/b0vNr+Wbyd6j2J8quRXo3xdo771Z4H2Hs7/V4/2n2DV9Kr
Md4OvfK8djd6e9gmvRrj7XB+9t7O4+dBu3vwPtKrMd4O50e7J1EexpJe9fKr
PQ9wbE/PZ+8bHEN61cuv1ivtnkR5OJf0qoa3E32e44+v3TeoSXpVw9up3pMo
D3MxS2fO7nOb1Z4H2Hs7/b6O2n2DNTj/dd5nn9us1ivtbvT2sDbr92rsnnW+
j9LuHlyT9Cqr1+5JlIfwf+r2arXnAY7t6fnsfYPwCHWv99V6pd2TKA/hI6xz
vT/m7UT/e+OPr903CHuQXm2fTvWeRHkIFRh1HfW+f17Vz/q5w9njQKhFejXD
0ysI+/Hs65+OtT29gnA87dCrY55eQTiCtf7/i517O5D9/jyENZm9V9rd6O0h
hB8563qv+j6U93cQjiC9ivD0CkIdZrn/PMvTKwj1aWf29T7L0ysIFalxP9/O
R6993x5CWLlX2v3xPIRQh1GdsZPNQwjzcrXnJSCEFUivIIS1mP15CQghtHOv
p1cQwt5U+/kghBCe5azfvwohhPeTXkEIazHq969CCOEs2vnn6RWEUI10CcIW
/wJ57Cxg
        "], {{0, 0}, {50, 49}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztnFtuGzEMRQ1kJd1BswLvoUC7gAL57mr73yVkCU2QD1VM5dGDlEjpEAhO
czHgXNGeW9ke58vPX99enm6329e3n+e3n/d/f9Tr/YN/7resXsXv7fqP7+/1
+y6pdd7W/lp+rPvU9e/vY81Vc/M2/5KfKHNo7TOml0gu1fqJcl2QS2vnj5//
9W9lvFzy5jPK86q1j5a+Kg9zvUR9n3n/9Xnb2mdM1+fYuvr7zN3/tOaz9fGy
xve9vufZuq55/59a+7Ses01+eqOsK33VdZHKdx5e+/S2v4qyT/DWf2xf199f
67x1Orkkjy/5IZfm+CGXHvffK5e8Uct/qlXX42nHe5u/Nz/ectU6P+v0KNRa
V6ooz8Pox1vP31r3tg+s85Po+/GKztK6Svq5uaS1Xm8+rder5SfKHFr7jOm7
srTekk4uja7Xm0/r9eKnz0+un0ZZ5+SSln9vPr2t19p/q07+RKAscolcmvN4
lfpo6d7mk+vwMWX5ySUtndyYM4coc2vtM6bDPsoil7xdF1FyyZt/az+5DnUp
a79c0tK9XRercsZmXYne5lzyCS0pi1wq6d6uF3Jpjh/oibK09RJ3/R5uq67l
p/96H8sH63m29o/yfVVYy7nPT7/3V8e8rsmlPp8wFmV91sf2z1FyQ2u9132i
rDfKnHMd7kFZ5BK5FGHOcG/KIpdW5ZKWn+hzy3V4JmWRS6flUum8c3UI/6Us
P7lk4+e6j7Ufm32Fvp/W89bpENZQFrlk7WfM//Xj6GO/BKEFZWk/P/3eRzT3
dZP1fPrXO+YfwpmU1duHXKr1s2q9Y/4h9EBZcfOEXCKX4H6c+74K33PR9QMh
XHldW79vP/dzAXIJQnJp/fG5Ti5BqEnrz+tLfbzd57Cqz5gO4Z6Mkkut563r
3+/f2k+uQ3gyU9l8/iWrXtd63578gTAaU5FLc/xACMfzqu546/skr89b579/
XXU6hHBGLmnlzF77H1mrHy8IT2AqcumxHwjhasq6Ot7v90HGfEII/TDVXvsf
WavnDCEklyCE55DXZRDCVfR7X7eP+UAI55O/qw8h9Eub+8YhhLCfY6+zWnUI
IbymTS5BCKE1eb0GIfRGWav9QBiDfwGXP0n0
        "], {{0, 0}, {49, 48}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGAQAGJBIAaxIeCDPYR+YA8TCQsFgav26PRAqUcVRwfDRRwX
PRov9BEnlR6NF+qKU4sejRfyxGlNj8YLfvGBokfjZXDSIy1ehgo9XONlqNND
PV6GKz1U4mWk0YMtXkZpCD0azoOdJi6c0QEhc0lVP0qTR6OD0XgZmjQ6GGj3
jDR6tB1FKQ0ADp3kUA==
        "], {{0, 0}, {17, 16}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt11EKgkAURuGBdpFPrWT2ENQCgp5bbe8uoSWoDJIJ6qQzzr3XMyBf/IQV
nYe6PF7X58k5d26vqr26x+F8fLD2/XK/deftx/4+f8rv2XafenQ/dlv78vdO
h+z5e6ND9hx7KumQPWbPLR2yD/dS0uExd2nSoe1di3RoY9cuHerarUqHMvej
SYdldwzS4T47zkuHaXdcJx2u2zGtdDi/4z7SIUqwVIf/vi692VZfh9veJ8pU
S4doWy2/D9G26Tucun/cjjh0uc9Uyvi8KF06RHny/wIlS58oSzrEGBsavKdm

        "], {{0, 0}, {27, 26}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztltEJg0AMhg9coQ7gJO5QaAcQ+uy0fe8IHUHFJ6ViYo8kel/g+OQnHkd+
Lrmm6++vKqV0G1c9rul7jm+75vMxxVvM5f+fNi1Crmv3Jz9H/feJ7+fKl+m5
GLcOpeXL9OP0mgvoGt2OvBNs8mW6P/G9TN9ljFvnaPkyPS55J+TQr0PeCZrz
X5/4/kuHM+P6iO82PMu8+G8fKCW+w23693N896XtvND2JWhNfIfb1PbtdXif
Hx4j97oUcq9hhHs9ALJO/Ac=
        "], {{0, 0}, {21, 20}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2J+IAaxIeCDPTodFgoCVzFoVHUP7BlQAPHiuMwf6jRx
4UAqPRrO9Aln8sN/oMNjeIczOhju4rSmyQ9n4tIJYXPoKz5QNPXDeXCE/2Cj
6RfOtAn/oUIPfDgTF/7Dhx6odjhx5ow0ejScB5YeDWf60NRqh4/SxNKj6XYw
0YM3nAHJ025m
        "], {{0, 0}, {15, 14}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztk9EJwkAQBQ9swRRgJenBEgS/07IlWIKRIMgjCXKse5vbGTgmPAIJDHe5
Tdf7qZRyns8wn/fzwnPct/LZH+P6vuWt99nrdqW2C9372K2s0P0/u+LVl+4x
91ZW6P7brkTtS3ef/ShWsnZXeulL97q9Vyu9dFey9s3Wnb77VqJ2t/pPXFaJ
2p2+tla8ult9F9dZaX3fsY8Vr+64rRXr7jimudf42wp9c5i+OU33o/oFWl7g
cA==
        "], {{0, 0}, {21, 20}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3FFqHTcUgOELXUlW4j0UEtrXQJ+72r5nCVlCbMxF6ZhBI4/OzJH0CcLX
CvHfEJI7x+Px/fL93z//+ePxePz1+uvv119v//2+fr68++Pl8b/1c/P/R8+3
dur7376+rf9eturo6Ojo6Ohc1dm7vu9prtDR0dHR0dHZ63zemHlm73x9P8ef
p46Ojo6OzsqdaPde11yho6Ojo6MzXyfa1u+DtO73el0dHR0dHZ2ITlmt1+sc
c0Lrn0O05godHR0dnZU7ZY05V2TTXKGjo6Ojs3KnrOi54tj5bPcfWjVX6Ojo
6Ois3Ckrx1wxuuYKHR0dHR2d851e52e1Ptf12s/x/SkdHR0dHZ0rO+sa85zq
3vn6fo6/Dzo6Ojo6Okc67ld8zu0yV+jo6Ojo6JgrPqvnNHR0dHRydsrKcZ2d
tWN+6Ku5QkdHRydnp6wc199ZO+yruUJHR0dn7k7r+bJar9c55gT3H+7VXKGj
o6Mzd6f1fFljzhW8V3OFjo6Oztyd1vNlRc8Vx867/zCW5godHR2duTut58vK
MVdwLM0VOjo6OnN3Rnldzm19ju21n+P7cTo6OjrrdnL8/rmKMc/l7p2v7+f4
+6+jo6OzbifmukD+7naZK3R0dHRm7ZgrGK/nNHR0dHT6dsrKNocc2zc/8Izm
Ch0dHZ2+nbLGnCvIM5ordHR0dHJ2ot+3yQjNFTo6Ojo5O9GvS15p/f5er/1s
9wl1dHR0xuyYK5jZ1rmidX7e69T3c/z71dHR0TE/kOYKHR0dndE75NjGzNV7
5+v7Of5d6+jo6JgryDi367lvrtDR0dHp2yFX0M+V6Ojo3NUpq/V6nWNO8LwE
ef59Y5T3Kx0dnfydssacK0ief98Y5f1KR0cnf6es6Lni2Hn3H8jzmit0dHTu
6pSVY64geV5zhY6OzuidXudJxln/+qLXfo7vk+ro6KzTIXmnMc9L752v7+d4
X9LR0cnfcb+CHNftqv273jtf38/xfqWjo5O/Y64gx9VzGjo6H8+XleM6O2vH
/EDOp7lCR+fj+bJyXH9n7ZCcT3OFjk5cp/V8Wa3X6xxzgvsPJM0VOjpxndbz
ZY05V5CkuUJHJ67Ter6s6Lni2Hn3H0i2aq7Q0YnrtJ4vK8dcQZKtmit0dOI6
o7wuSUZb/3qq136O7wvr6NzTyfH7J8nrjHk+fO98fT/H+7COzohziPsVJEdx
u5775godnZ4dcwXJNfSchs5MnbKyzSHH9s0PJEfXXKEzU6esMecKkhxdc4WO
Ttzruv9AcjXNFTo6178uSa6mn1fV0fFcJUn2snWuaP06bq9T389xHdFZs2N+
IMnPaa7Q0fnYIUmeNebru73z9f0c1xedNTskyWvcrue+uUJnpg5J8hr9XMma
nbJar9c55gTPS5BkTs0Va3bKGnOuIEnm1FyxZqes6Lni2Hn3H0hyDs0Va3bK
yjFXkCTn0Fyhc6bT6zxJcm59bqdORIckubo+B0PHz2uQJK91u5775oo1O+YK
kuQZsz2nUVaO6+ysHfMDSTJCc8WaHZIkI8w2V9z18w5ljfl5U+4/kCQzaK54
bNaYcwVJkhk0Vzw2K8fnTbn/QJIcUXPFY7NyzBUkSY6oueLe1yVJcgXn/9xO
z0WQJHm9Prezx+u6X0GS5HG367lvrnjXXEGS5HF7PY9RVo7vU7Tumx9Ikjyv
uYIkSfYy28+VRP8+SZJknLPOFSRJ8nrv+lyL7artmx9IkszvKHMFSZIc1+j7
DK0dkiQ5rq3zgOcqSZLkntFzBUmSXFGfV0mSJK91u5775gqSJNmq+YEks/gL
4dyeRA==
        "], {{0, 0}, {89, 88}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgB2IBIAaxIeCDPQNWABPHRT+wx64elznDVRwXTWv1o+FP
XZpU84dr+FMrfEbDnzzxgaJJdc9QCf+BSs+j4T+0aFLdP1DhP1TS80gL/6FO
k+pfaoX/cE3PQz38RxqNDsgN/9H0TB6NDqgd/qM0fhodjIb/QNFhoSBwFYNG
VTca/gNLj4Y/pTQA8rKOFg==
        "], {{0, 0}, {16, 15}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2J+IAaxw0JB4Ko9Os0ABh8I0A+gNPXMGV7iCHo0nKkh
TpgeDWdSxMmnR8MZmzj16ZEdzvSjR0Y4Dzw9vMJ58NJDM5yHHj24w3n40IMj
nIc/PRrO9KGJC5/R8KSUJi7c0MHAu3u40KPplro0AGzkNbc=
        "], {{0, 0}, {15, 
        14}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztm1FKQ0EMRQuuxF9dhHsQdAGC367Wf5fgEmylMNyBoZ3XmZfc6QmUIyHc
yUuTvPYVHz++Xj8fDofD0/H1fHyd/n5/O9n3y608/NvvmT9n9utn03HPP5uO
e/3VXyzbdbXyVH+hS/1d+jZb/tl03Ouv/mJz5nf8vLfoUn+Xvs2WfzYd9/qr
v1iOPbCdLvV36dts+WfTca+/+ovN3gPqH0+X+rv0bbb8s+msmn+vvsbXNm/e
W1z1/Rql457/qjpR7M1f42vbf95bpP/30XE5N1ud1V8s23W18lR/Xrr0g7uO
y7nZ6qz+YnPmd/15b9GlH9x1XM7NVmf1F8uxB9ahSz+467icm63O6i82ew+o
f3269IO7zr2dOzv/Xn2Nry1+DqO5av9k07m3/Jl3L67at6vqrMre+mh8bfFz
5cZ761uX6xqVZ0tH/cWyXVcrz0t9DfvoPi/sgW066i82Z36Z9+x0nxf2wDYd
9RfLsQfg3nSfF/bANh31F5u9B67tS7gv3efFZQ+MOnd2/r36Gl9bfH/D65ht
XpjHnHXQ+Nri+xjeRvc+d8nTpT4aX1t8v8I5XPW+GXUu8w4dyR7ImT/zDjMw
+v7mylF11rjLz9tH6UDouAc07/jf17jvw5UYPd+ue6A3n9via4vvG7gWo+eb
PXBNPIRzGT3f974HZr+/EGbeA5pH3uf8vfoaX1v8+w3hzD2guvG/uzHvEN6+
BzTOb66Zdwjn7YdsHHVdGtf6/s73eggj90NvPho36vk8ewDCkXtAdXm+B6ET
sz1P6D1X42uLry+EzuT7PoSwRb7vQwhbzP05AUKYfw/wHABCeHmfaBz3fQh9
yX0fQsj/50II+TwP4Uj+AXjv8Kg=
        "], {{0, 0}, {43, 42}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3VGq1DAUgOEBV+JK7pMuQNAFCD67Wt9dgkvwXhFGytRJ06Q5J/kK8kkY
/pv60NjetvP+6/dP397dbrcPr38+vv55+/uXz2/bj5ettz/br79ut2fje47q
3Ldz+xttv3R0dHTm6ay2HpX1o81fR0dHZ9ZO7+Pw3vjPl8fjozpH+9Hmr6Oj
o5OlM8osx/Oj/Wjz19HR0cnSaW+W63t95nnd/HV0dHTm6qy7HpW5t75n318d
HR2dUR3rUWnHeZOOjo5Oi854s69HZZ933qSjo6MT3VmPw86bdHR01u7kc9b1
aG/c87M6OjpzdeZxtfWorB9t/jo6Ojq8Pdxqx6Pdb3+0H23+Ojo683XY1izH
86P9aPPX0dGZr8NSs1zfcz+Djo5Ozg5LzbIelek+cB0dnVEdnjX78dl5k46O
zrUd9jL7elT2eedNOjo6Rzu82lmPw86bdHR0yjqM4qzr0d6452d1dFbtMLqr
rUdl/Wjz19HRKe9wbrdb7Xi05wiO9qPNX0dn5Q5ZYpbj+dF+tPnr6Kzc4epm
ub7nfgYdndk7XN0s61GZ7gPX0YnfIR+b/fjsvElHJ2qHPGb29ajs886bdHT6
dcg2znocdt6ko9O6Q/Z11vVob9zzszo644875CNXW4/K+tHmr6PTo0NmdLvV
jkd7PuJoP9r8dXRKPk+ubJbj+dF+tPnr6JR8npzTLNf33M+go0PObZb1qEz3
gevM1CHXMvvx2XmTTv4OyTezr0d74+4D14nXIfk/Z12PyjpZ5qmTq0Oyn9ut
djzLfU1Z5qkztkMyvtmP81nmqTO2Q3Kka1zfyzJPnbEdkvHdbrXj0f7/3Luv
E7NDch2zXDfr3deJ2SE5g1mu72WZp86IDsl13G6146Puc3j+Xohr56lT1yHJ
o466vmc9mrtDknejXTcrm8/9uOe9EJk7JHk353q0Z6t1qv1+rd0hyedGO263
Wo/KPh/33yFnhyTrjXYcPjqfa983vjdev785OyTZ3uzrUdnPbbW/9fuVs0OS
17naenTO5/PP2SHJ8UZbj87tz9F+q/He+9uqQ5LZ3W6141neE95q3HM9JDnW
aM/PHu23GrcekWQvY1/fe95f434Gkpzf7OvROVv93FHzJ8nV3G6146O+tyLa
93GQJK9x1O+DrEckyX/dbrXjrd77bT0iSZbY+3sorEckyRLvW5/3r1qPSJIl
Pv9eiWvfs7pnqw5JMqb133MU+/kjkmQue38/7J57nVZ9kuQcRrufgSS5pr2/
r3xvnCTJEludN2230ftFkszlqN83kSR5xu02ej4kydk89/wsSd79DW2dXRk=

        "], {{0, 0}, {70, 69}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlVsKwjAQRQOuQv9cSfcg6AIEv12t/y7BJdgiol6tSR9pMsm5EE65SDri
Ydwez7vTyjm3bs+mPd3zI7fG/cyzf/Gw73L54ufnrk3ce/rmpE/b+3/3sHvw
jT6kH0r/PfhWUz90X+Eb/ZQ+Nv3vxTfLfex9hW/0731u9M+Jbzn1ue0rfCu7
t07/98K3mL31fYVvtvraqMG3aX1t+wrf0vbwPzX4FjYPHEcNvvXND+egpnTf
2FdpqSndN5iWGmu+sa9sUWPNN1gGNT4f5tpLQ3tYNjVje3yDIdQs5SGsk5q5
ewhDyP8jXJIavIIxqUk9D8yFd+fFvJ4=
        "], {{0, 0}, {26, 25}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmk1OwzAQhS1xEhZwDe6ABAdAYs1p2XMEjkArVp3GbZzMeH7yPSn6qqdo
Mnb8lLrN48fX6+dDa+3pdDyfjvPnf/2+3KbUvfNH2auPj7/G11pX1utfqx9y
ih/Z98pRtDySU/wIvjW1rturo1WfnOJH8LOvf69+yCm+he+1rqrmkZzi7/Gz
MN+43t/O+r7i5Xk/Yhz3/N548X390fuYxZeKn7t9tB5Xrz5+TN/6eWRdpyqt
x9urj+/rW6+HaP1kpxQ5reV7rZ/Rfrz6z0Ip7/uIv83PkiOtOkejFDmN7WfJ
kVYd2BZFTmP4We67V/9HoxQ5netrzVv2dQJvU4qc2vhZ1n+0fmBbFDnd52dh
9v7rkPeOlvxo79VYv58Do5A8LvlZcjTqwxqUmlU/u681Xus6sAalyOmlbz1v
Wv3A2pQ6ak695tmrHxiFtfah2fePEK6h1Kz6Xr5Wn17zCY9JqSo5tR6vVh0I
11AqW06zzw88OmPsQ7PsHyG0Za08jl6350MYmVKz6o/6WvUhjMW5z03+p4Bw
P6Vm1R+9rnWfEPrQ5rnJ7zAQxsmj1FYfQnhNqWz1IaxEvn9CGIdSW30IYZz8
QgjJnT//ABYFKkI=
        "], {{0, 0}, {38, 37}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmEEKwjAQAAO+Qm++pH/wCYJnv+wT+gQruWhgxY2bZDedhTLtENJC55Tz
9X65HVJKx+06bdfrPs+6ZD6W9DFr8Vx6idJ67f5W79Wux9t6ifSG/8drSW/4
X7wV6Q3/7luT3vbpR5He5vbeSG9z+Cikt1g+OunNp5+V9DbW74301sfDTHqz
9bCO5dT2I60f9V5pvZWHtqS37x72ofR/o/Sm/R7tPrAP6Q16Zjn0Bi3Yuger
frT7Q5+M0hucm+XU9tn63A/OTXqDnklvsAW1537ljP5+GIva8z0IW5AOvfAJ
t5+1kQ==
        "], {{0, 0}, {26, 25}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3FHK3TYQxfELXUlXkvf2rZAsINDnrrbvWUKWkIQQBl8iy7Y0PmfkvyD8
ilF1xyPZp19v+P78/N8///7xer3++v7n7+9/fvzzz/H1w7ufPv4Y/x+2tc7W
Lx9+feLZ9Y99bqw/63PPrl+9Hq5z3eHc8lzcc31Wn6uch7H86ufjsX+fHHSv
h+tcdzi3PBf3XCcHfzc/W3LQvR6uc93h3PJc3HOdHPzd/FnGGKu/v05rfqsP
Z+fPql9VD6LDuc2er+6fi7P6PJYXVT432/59nd3HKrnjVg+iw7nNnq/un4uz
+nxvHvXnj/VBZYxZ+1gld9zqQXQ4t9nz1f1z0a3PrfVz6nezf78efevPr34O
ER3ObfZ8df9c9sXtPOTUU8XrfTi7Tmv+9jo5iKg8t9nz1f1z2Zcq5+HY51Y3
xqz+u+1XlXoQHc5t9nx1/1z2RfW+Hat/VWOo9mV7nRxEVJ7b7Plu+eJm636P
ze+/51t9O7bOqsYgB7X1IDqc2+z55KD2frfr4OttkIPaehAdzm32fLdccNvH
nH3HfWN472N/vtv7RP2cYQ2rn/Ps+j1yp//+PNufnPvCa8YgB7X14DOtfs6z
6181B8/251g9eM0Y5KC2Hnym1c95dv3V+zxWD95jDI99JwdRY/Z5cJtfpZ/H
1u+/37w/F7XGIAe19aDW7PPgNr9KP1U52Jo/1gf0NAY5qK0HtWafB7f51fvp
/b7CWsbwPlf9+dWfU9SafR7c5mf3x21fcurBNYxBDmrrQa3Z58Ft/tNy8Gyd
2/m4tjHIQW09qDX7PLjNd8vB1vr3vn/wmcYgB7X14LX9Ur233fpQ5b7G9rH/
Hmv14dg6+ExjuL2Xzs4nB9e21f9V82LV+8quf7sO4hFjuL2Xzs4nB9e21f9V
86L6fWXv1/Y64ogxvM95fz45uLat/qvyIvv8zJp/rP7++2HW5471GTHDGG7v
pbPz3d5j6txYzVb/ycH9+aocbM0n79DPGG7vpbPz3d5j6txYzVb/ycFr8z36
j+hgDI/nQv9cq+pxyxfVfWXvS/Z89X7OfU77741jfUN0NgY5qK3H7T2puq/s
fcmer97Pu/d3uw5iRWOQg9p6Vn1Puu1L9ny3fczpM+JKxvB+7vrz3d636nxz
ycGn9e3Y/P7z2OrP2c8duy/EJxiDHNTW4/Y+V/VZ3Y+qOXi2n8fqQXyCMchB
bT1u73NVn9X9cLmv1vpj9SDinmPPacvs3z/fyqlZ75/++tXrWfX6rD5XOZ/8
3IeYJzm4v371ela9Tg6eeU4RMU9y0L2eVa+Tg+Qg4r3GGHuu++u05m+v8z3j
as7q81heVPlcRLzfGOSgtp5VndVnVQ625o/1ARF9jEEOautZVbc+t9bPqR8R
/Y3h/T7pz6/+fq6iqg+z9iunHkSsawxyUFtPFVV9UO3Xdj4irmcMclBbTxVV
+3LvOUTE5xiDHKxVjzoPs/J07Oeyft+OrYOIzzEGOVirHnWO1fq5EhGxZQxy
sFY96hzzPCeIiNfN+e9tfi/N3fXMWn/W/HvXQUScLzm4v75bPeQgIqKT5ODd
9ZCDiIhac95j5GnWdY/8IgcRcX3Jwf31Vdc98oscRETclxzMuu6RX+QgIuLr
bYy9D/vrtOZvr9f7fTJjfejvy9n+5NwXIuKqxiAH18jBs/05Vg8i4qrGIAfn
5uCsOnP6jIiI7+b8f7N1vmesXuex/UJExHfJwbnrqOo8tl+IiDhXctClzrF9
RETEfWN4fP91/e9Vnr1f789FRMR7jEEO7n9ua37O97OIiHiPMarkYGu+d/2I
iOhuzs81fM+IiIi1JQdnrIOIiM+UHERExCcYw/t7uut1kneIiNg2RpUcbM0n
7xARccRV/76Nuq+IiFhbchAREfGq5CAiIj7BGB7fMyIiImpUfc+ovm9ERMQ9
yUFERMSrkoOIiPgE38ev6/y9F0REfJb83IeIVfwGGI5Tdw==
        "], {{0, 0}, {75, 
        74}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3EFuJUUMh/FInISTzAVggwQHQGLNadlzBI4wM8oC4sUj7q7qsqt+lqJv
VNJ8f6fTbevlJfnx9z9/+eOHt7e3n759/Pzt4/u/3+ufL6/595e3D3X1PEu5
cuU+fx7r6uc76jpk++Hnn+HPenadP3LlVs5d5ZnNXecq/97+rKf7/JEr9+Tc
Luexnrpu2Vz+M/1Zzyh2nz9y5VbO7e5ZNWdi8fOP8FS7z3ede3LlVshd1U+s
qrn8Z/qznlXs8rzLldsxd3b/XeZGLH7+EZ5qrDZ/5Mo9IXe2P1bVXP4z/VlP
F3aZP3LldsyNtXq+VZur/Hv7s57urDZ/5MrtmDu7z1hVc/nP9Gc9u/K0uSdX
boXzWKuf62w//Gf6s57T2H3uyZVb2VPt+Y3Fzz/Cg++sNvfkyq2Q2+U81lPX
LZvLX9Of9eBrdp97cuWe4Fn1vMfi7+nPevAaq809uXIr5K7qJ1bVXP6a/qwH
x7LLnJEr907u7P67PL+x+Hv6sx58htXmnly5T+bO9seqmstf05/14Fp2mXty
5d7JjbV6flab2/xr/VkP1mS1uSdX7p3c2X3GqprLX9Of9WAvnjZv5fbKnX0e
a/Xzle2Hv6Y/68E92H3eyu2Vu8pT7TmKxd/Tn/Xg3qw2b+XK7Xge66nrls3l
v+bPevBMdp+3cnvldveseu5i8c/xZz2I/2W1eStXboV+YlXN5b/mz3oQP8Mu
803uHrmz++/yHMXin+PPehDvsNq8lXtm7mx/rKq5/Nf8WQ/iDHaZt3L3yI01
uv+sf1Uu/zV/1oP4JKvNW7l75M7uM1bVXP5r/qwHsQJPm/Nya57HWn2fZ/vh
v+bPehArs/ucl3std5Wn2v0ci3+OP+tB7Mhqc15uzdwu57Geum7Z3F39WQ/i
Tuw+5+Vey+3uWXX/xzrVn/UgnsBqc15uzdxV/cSqmrurP+tBPJld5qrcsbmz
++9yP8c61Z/1IOL953fX/SL3GX+sqrm7+rMeRJw3l07bL7vmxhrdf9a/KndX
f9aDiPdZbc7LHZs7u89YVXN39Wc9iDiPp+2X7rmzz2Otvt+y/ezqz3oQ8Xl2
3y/dc1d5qt1XsU71Zz2IWIfV9ovcPc5jPXXdsrn2JiKOYvf90j23u2fVfRir
qj/rQcS+rLZf5NbsJ1bVXHsTEVexyzzfNXd2/13uq1hV/VkPIp7DavtF7jP+
WFVz7U1E7MIu+2XX3Fij+8/6V+Xam4jYndX2y665s/uMVTXX3kTEXXnaXqv2
eyWr5r+9iYg4lt332qjcVZ5qX99YVf1ZDyLibFbba11yu5zHeuq6ZXPtTUTs
zu57bVRud8+q+yHWVX/Wg4hYjdX2Wpdcv+dyzT+qf0TEauyyR6q9Hqz288Cj
+ox11Z/1ICJ2Z7W9Vi13tj9W1Vx7ExHxNbvstdm5sUb3n/WvyrU3ERGvsdpe
q/Z9VHsTERE/w+77tMvvm4y6Dtl+7E1ExGdYbZ+u8lS7zrGu+rMeRES8xmr7
dNfzWKOv2yg/IiJeY7V92t0z++sSa3WfiIj4zmr7tEs/sUbnjvIjIuIzrLa/
Zvdf7TrHWt0nIiJeY7V96vUmIiJ2ZLV9Gmt0/1n/7P4REXEP+rsK13JH+RER
cQ9W+72San9XYXYuIiLuwWo/X7Tq8421uk9ERKzC3379Xn99mh//f7XXp/+e
3/u8EBER73D9Hrx3joiIWIHVvq/r+66IiNiRXj8iIiK+Yvb9xFH82Mf/v7+5
+johIiJ+nt3/vhAiIuJczn796HUlIiKeR+9vIiIivuKc9zcRERFPpvcrERER
X7Ha68qvGoYZYg==
        "], {{0, 0}, {77, 76}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPYR+YM+AAmDiuGh0MNzFSQ2f0fDEL04q
PdLCk1T/joYnfnFa00M9PGmd3kZaeA42erCF52BLb0M9PIc6TevwHOrpbbCF
50ijad3+H2n0aPjQh0YHA+2ewUsDAGxP4UQ=
        "], {{0, 0}, {14, 13}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3VGK3EYQBuCBnCQn8R0CNiSPgTzntH7PEXIEewkBu3Y1LfWo1VXqr8B8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        "], {{0, 0}, {90, 89}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt11sKwjAQheGAC1FX4h4EXYDgs6v1vUtwCbZSCA3WS24zyfwD5ZPBapse
aGZ/uR2vG+fcdjx24zF9Pp+muh9K6V71mB1my/8v4noOvWm/40v6/hA/5TzN
Ich77Pfp06/Zl1LbOtC32c9v3fcX8wK+t3TOc+V/eb4v6fXDNpTKeZrMC/RL
9HtV2zrT19lvz7rvR+aFVpXOqZb8L8/3Jf18MI/SedQp84LNPsap7TnSj+tj
aN33L/MC+xxdMi+0pXRebMq8oLOPOtWWk177WFvmBfY5lmVeIOf4TeaFuD7a
VFsOyT/mkXmBfY5lrc0L0uuNLdrrvIBYQm05J/+Yx1b2/9LrhJbVtl9C1Cz5
xz4tvV+Svj/E3/X1b/51XD9iCddyHpb0dSLWNCzp6+nfJ+Q/+pU=
        "], {{0, 0}, {32,
         31}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztlcEJgDAQBAN2oBVYiT0IWoDg22r9W4IlmODLBSNqEu/MLsjIoA+zHlcP
UzsWxpjSXpW93P2etfETQx/b953L3CCPzy/w3lWPZ8/Tp/GhKO27tPu758we
ZXppxNDH2WuxKe0/l+a1UNq5/XWvscewPjdi5Hude41z6vfkTi29sEc/tfRI
PiPmvede+4Kcu38TE3oeyTQ8my8M51ELue9yIntEboHh7+8=
        "], {{0, 0}, {19, 
        18}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]},
    {
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3FuuHDUUheEjMRJGkjkgwQC4PDNa3hkCQyAhilo5nC73qrLL3lVfS9GP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        "], {{0, 0}, {
        100, 99}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPTodFgoCVzFoVHUP7BlQwAc0PgMDLnNo
TeNyJ7X8hSvcRsMTm3rq06PhORqepLuTfvTwCs+Bp0l151CpFwaKHhzhOXzo
0fCkLk3r8Bxo/w0sjQ4wxYkLT1zmjNIMaGA0PKlBD5/6d3DT6GCg3UM/GgB9
vlgK
        "], {{0, 0}, {14, 13}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3W+u5TgRhvErsRJWwh6QYAFIfIbN8p0lsARm6BmZROf0jU/K8evkV1Lr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        "], {{0, 0}, {
        112, 111}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt2FFKA0EMxvEFT+JDvcbeQdADCD57Wt89gkdol1Ii6Ox23JnZL8k/UH7y
EbTayWbw8e3j+f1hmqbT5fV0eS1fX+t7vvo135LXl6U+Z8TF0jkhb5Fve9/n
YkU//WXVzr9a3korjfNAv69+5retee+3Yz8v8hj5ODWet2r9PP/Jf+ZqWmnM
i1o/8xs7VzPv/da7+85httyfGvuIfvZ7jzyqVhrnjX7m9548qnHut6Xfi9xz
nleN53nv/qj7ImqO61ppzFfvfub32BzXjXO/VbP0d86R41419le2/qj7Gsdo
pXGes/V7mV8co+79tvQ+yXvmqKLGvqjt97JfvOToSyuNeaztZ37Xc/Sl7v2W
+3NNjtHU2Hdq/dvPMY0cc2qlMS9q/UfNL+Z03P229HNz54h/m3sfMY/oUSvm
t0WOuEfd/9+W3qdGjthXjf1Y27/9nOmTIypopTGPtf2t5hdRwf/fb0vfRztH
9KH2/mIeEX9r5XN+ESPp5X6LmEvt/YiYS/Ygojdr58tq3z5FxP1zasU8Ih4t
91XEI2UPtvUM5ZjcYw==
        "], {{0, 0}, {38, 37}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWI+IAaxIeCDPQNWABN/YI9dnLD6sFAQuGo/3GhU/+Ki
R8OTvHAbDU/qhtvIDU/ahNvwD0/6htvwCc+BDa+hG54DGy5DNzwH1v8DHZ6j
NHk04fAc2emQ+vRoeJJHj4YPLWl0MNDuGXgaAGJcXRg=
        "], {{0, 0}, {14, 13}}, {
        0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztk8EJgDAQBA+sQDuwEnsQtADBt9X6twRLSCIBwd9JopvLHhwTjiWvnX7Z
xrURkdZv5ze85ynMPjwp15yRRyTz/+S1vP/nPef9PTF6VVs+N9H6Wcr9O2L0
sPQ8GtH6bN8jLTF6i5YvnWj9t++Rlhg9p0dpieaLfY+0xPCCHqUlPUInPbJI
eoROemSR9AidtXnkAHW6wzk=
        "], {{0, 0}, {18, 17}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJzt3V2OHDUUBtCRWAkryR4QYQFIPLNa3lkCSyCjUQnhpHq6qm3fe+1jCR1k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        "], {{0, 0}, {85, 
        84}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztmE0KwjAQRgPeQdeepHcQ9ACCa0/r3iN4hLa4iI5aM38hk34flFdCmKb2
OZruz9fDZZNS2k7Hbjrm82cewzJzTsc5t4GSO7+szp3Uk45z6V3Hqr73fcnX
CU8s6vTvia7+r3EaeOLD1jzhkgae+LAfT+r+rnGva/Xc4YmW8MSTUdbpfb95
HJ5YXDe6J/X60vt8eNI3aaTz4ck6SVOrz0TZT8GTZdJI/eHOb61fwRMZaf6N
c+vAk6jk7rvL+gb3uVjt71p779cP63pCo+8/uvWApYzuidfnAkpI8zle93sN
T2IxR/f/AZ6skzTwBPzGHOxTQDvCE/CV2M+CJWy3P4y/uxNl
        "], {{0, 0}, {23, 
        22}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztl1EKwyAQRIWeofnvSXqHQnuAQr972v73CD1CE/oROmh0caOrzoC8MIi7
ypDE0/15eRycc8d5TPNYnn/6nLeJov/vS/mG9WK+tK60/1BdKaV1e/WZB91+
Wvel5zBaHkbLCfOgS2n/1nwtMg+6+6rlMw978XZd9Eqm9Bzy1omfm3T9tPn6
dUPrWONoecjz137S6rZH5kHi233PlyWqtl9rX8zDNlHMA+kjqlQetOaHfOZB
lyjmYTRq/a/yntgH976/pPn93xNbobU8lNo3mUMU80D6iGIeSB9RMZ8ck6ja
/ZA2afd78QUaqX90
        "], {{0, 0}, {22, 21}}, {0, 1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False], 
     FrameBox[
      GraphicsBox[RasterBox[CompressedData["
1:eJztl9EJwjAYhAOOYBdwku4g2AEEn53Wd0dwhLb4UDyNSckf/ly4g/CVo/RP
70ihp+v9fDuEEI7LGpa1Xr/1Gv8TZe0/x99+7bkbp8uqxxdj97cxN5ZbzLdi
+r3y9hN7jpWvfnNZZ58o9ftJr/Pr9Z3f66tfX6JazdlrLl+/nDl7zeXrN4+o
cl/9MhOl88vOvbmp3x6JsvbT+avflogqz1/9+rJ2/uqXgaj8865+mZnOWf32
yE3qtw96/X+JDESpX06ivPcj2hJV/twZHBMgNA==
        "], {{0, 0}, {20, 19}}, {0, 
        1}],
       Frame->False,
       FrameLabel->{None, None},
       FrameTicks->{{None, None}, {None, None}},
       ImageSize->50],
      FrameStyle->GrayLevel[0.85],
      StripOnInput->False]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.561478964635467*^9, 3.561479000649564*^9, 
  3.564166592175373*^9, 3.5641667488767347`*^9, 3.564166829244203*^9, 
  3.564167022686883*^9, 3.5641673072822847`*^9, 3.564167537510704*^9, 
  3.564167776453477*^9, 3.5641681272528048`*^9, 3.5641683511904297`*^9, 
  3.56442146802535*^9, 3.5644216233522053`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PDF Format", "Subsection",
 CellChangeTimes->{{3.561479356963024*^9, 3.561479357944789*^9}, {
  3.565004657054047*^9, 3.5650046586530533`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsnQl4FFX29kEQBEWGDxRxQxRRBEVAEdxBUHYcZxyRgCBoFBAJi0BAYQwg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   "], {{0, 0}, {672,
    528}}, {0, 255},
   ColorFunction->RGBColor],
  ImageSize->{672, 528},
  PlotRange->{{0, 672}, {0, 528}}]], "Output",
 CellChangeTimes->{3.5614792249277887`*^9}],

Cell["\<\
This way I could look at grids of 50 rules at a time, and the total result \
set of 13,188 rules only occupied 264 grids. I could get a pretty good \
feeling for the rules in one grid in about 10 seconds, so the entire process \
of looking through all 13,000 rules only took about 45 minutes.\
\>", "Text",
 CellChangeTimes->{{3.558966343311668*^9, 3.558966390451436*^9}, {
   3.558966424387743*^9, 3.558966630666869*^9}, {3.558967415475442*^9, 
   3.5589674563386993`*^9}, {3.5613991623508472`*^9, 3.561399164610797*^9}, 
   3.5613992937535667`*^9, {3.561399841782487*^9, 3.561399864790206*^9}, {
   3.561399932572407*^9, 3.5613999336137047`*^9}, {3.561472444520253*^9, 
   3.5614724478212433`*^9}, {3.561475618442244*^9, 3.561475621257442*^9}, {
   3.5614771562845507`*^9, 3.561477159361918*^9}, {3.561477731306755*^9, 
   3.5614777724874067`*^9}, {3.561478413448881*^9, 3.561478610654649*^9}, {
   3.561479088456624*^9, 3.5614790930961933`*^9}, {3.5614792620356083`*^9, 
   3.561479273675138*^9}, {3.561479304386345*^9, 3.561479307913692*^9}, {
   3.561479596251923*^9, 3.561479741061212*^9}, {3.561479829292453*^9, 
   3.561479962254201*^9}, {3.5614829718463507`*^9, 3.561482978292454*^9}, 
   3.564831710647684*^9, {3.5648333814524126`*^9, 3.5648333865019207`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Favorite 4-4 Turing Machine", "Section",
 CellChangeTimes->{{3.561399569177206*^9, 3.561399576662592*^9}, {
  3.5650046927598257`*^9, 3.5650046976324987`*^9}}],

Cell[TextData[{
 "After all that, I chose my favorite 4-state 4-color Turing machine, rule \
number ",
 ButtonBox["348,371,888,147,308,385,687,045",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframalpha.com/input/?i=turing+machine+348%2C371%2C888%\
2C147%2C308%2C385%2C687%2C045&a=TuringMachineRuleSpace_**%7F4.%7F4-.*%7F8.%\
7F2-.*%7F2.%7F8--"], None},
  ButtonNote->
   "http://www.wolframalpha.com/input/?i=turing+machine+348%2C371%2C888%2C147%\
2C308%2C385%2C687%2C045&a=TuringMachineRuleSpace_**%7F4.%7F4-.*%7F8.%7F2-.*%\
7F2.%7F8--"],
 ". Here\[CloseCurlyQuote]s what the compressed outputs look like, \
compressing by keeping just the steps where the head had moved further left \
than ever before:"
}], "Text",
 CellChangeTimes->{{3.558966343311668*^9, 3.558966390451436*^9}, {
   3.558966424387743*^9, 3.558966630666869*^9}, {3.558967415475442*^9, 
   3.5589674563386993`*^9}, {3.5613991623508472`*^9, 3.561399164610797*^9}, 
   3.5613992937535667`*^9, {3.561399841782487*^9, 3.561399864790206*^9}, {
   3.561399932572407*^9, 3.5613999336137047`*^9}, {3.561472444520253*^9, 
   3.5614724478212433`*^9}, {3.561475618442244*^9, 3.561475669568056*^9}, {
   3.561482448837071*^9, 3.561482500533517*^9}, 3.5639058172991457`*^9, 
   3.564831713513282*^9, {3.5648443144872007`*^9, 3.564844351909083*^9}, 
   3.564844389149275*^9, {3.564844422906921*^9, 3.564844424010058*^9}, {
   3.564844467526835*^9, 3.564844476158552*^9}, {3.564915882947423*^9, 
   3.564915889774057*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evol", "=", 
   RowBox[{"TuringMachine", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"348371888147308385687045", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "}"}]}], "}"}], ",", "200000"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"leftcompress", "[", "evol_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"maxleft", "=", 
      RowBox[{"evol", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Reap", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], "<", "maxleft"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"maxleft", "=", 
            RowBox[{"#", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
           RowBox[{"Sow", "[", "#", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
        "&"}], "/@", "evol"}], "\[IndentingNewLine]", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.549842038664111*^9, 3.54984205209445*^9}, {
   3.549842470247589*^9, 3.5498425090098553`*^9}, 3.5498425822016163`*^9, 
   3.549842758684678*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"leftcompress", "[", "evol", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
   RowBox[{"ColorRules", "\[Rule]", "$TMColors"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.561399621585678*^9, 3.5613996253506193`*^9}, {
  3.5614000360942993`*^9, 3.561400042084487*^9}, {3.56140009198004*^9, 
  3.561400098490037*^9}, {3.56416324870886*^9, 3.564163250855055*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsu9GxJLuyZHeNlIQyUIDRgSLQjN+kBhSWCrQInCGtbayqBnu3Z3kk3JGr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   "], {{0, 0}, {880, 639}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->400]], "Output",
 CellChangeTimes->{{3.561399612568535*^9, 3.561399626509774*^9}, 
   3.561400045626801*^9, 3.561400099934516*^9, {3.561473344583853*^9, 
   3.561473361324122*^9}, 3.564163269620099*^9, 3.564165718463663*^9, 
   3.564166626438438*^9, 3.5641668483362417`*^9, 3.564167041345869*^9, 
   3.5641673263815937`*^9, 3.564167565570661*^9, 3.564167805018618*^9, 
   3.564168148534629*^9, 3.56416837476217*^9, 3.564421482324972*^9, 
   3.564421640271758*^9}]
}, Open  ]],

Cell[TextData[{
 "And here\[CloseCurlyQuote]s what the tape output looks like when \
compressing by keeping just the steps where the head has moved further ",
 StyleBox["right",
  FontSlant->"Italic"],
 " than ever before:"
}], "Text",
 CellChangeTimes->{{3.561400241296908*^9, 3.561400276266478*^9}, {
  3.561472551487505*^9, 3.561472633849065*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rightcompress", "[", "evol", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
   RowBox[{"ColorRules", "\[Rule]", "$TMColors"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.561399642233142*^9, {3.5614000577889442`*^9, 3.561400082730144*^9}, 
   3.564163272904065*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzs/FGO7LoWreltoFriNrgBtw9ugoF6tvvsDtwmVLnqIe9ShlI5IyeDY0qf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   "], {{0, 0}, {880, 240}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->400]], "Output",
 CellChangeTimes->{
  3.561399643808414*^9, 3.561400059289894*^9, 3.5614001036193666`*^9, {
   3.561473344647003*^9, 3.5614733653871517`*^9}, 3.564163277603138*^9, 
   3.564165724357465*^9, 3.564166629125453*^9, 3.564166850285907*^9, 
   3.564167043310297*^9, 3.564167328477683*^9, 3.564167567675086*^9, 
   3.564167807626247*^9, 3.564168150618964*^9, 3.564168376923024*^9, 
   3.564421484889488*^9, 3.564421642095251*^9}]
}, Open  ]],

Cell[TextData[{
 "This rule popped up in my search because it had ",
 ButtonBox["irregular head movement",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/nksonline/page-888f-text"], None},
  ButtonNote->"http://www.wolframscience.com/nksonline/page-888f-text"],
 ":"
}], "Text",
 CellChangeTimes->{{3.561400414366737*^9, 3.561400454340569*^9}, {
  3.561400952136944*^9, 3.5614009607581387`*^9}, {3.561472520364522*^9, 
  3.561472523483222*^9}, {3.564915930847316*^9, 3.5649159387431917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"evol", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"1", ";;", "5000"}], ",", "1", ",", "2"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5613996987274*^9, 3.5613997624996367`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxdnX941eddv2PFGit2scMaETFDrLEiZh1jGTKWMcYyxljGkEVEljFWY2U0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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 543.},
  Method->{},
  PlotRange->{{0, 5000.}, {543., 679.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{100., 100.}, {2.72, 2.72}}]], "Output",
 CellChangeTimes->{{3.5613997154908*^9, 3.561399762930543*^9}, 
   3.561473344729933*^9, 3.5641632792370453`*^9, 3.564166631167303*^9, 
   3.564166850421574*^9, 3.5641670434533377`*^9, 3.564167328612068*^9, 
   3.564167567849716*^9, 3.5641678079499607`*^9, 3.564168150771864*^9, 
   3.564168377112574*^9, 3.564421485024293*^9, 3.564421642221006*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"evol", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"1", ";;", "10000"}], ",", "1", ",", "2"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5613996987274*^9, 3.5613997624996367`*^9}, {
  3.561400840994133*^9, 3.561400853611377*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxcnX+41/f8/49JMskxmUzmSCaTHJMcSY4kZ0k7khxJjmSOadsxbY6WHMkk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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 501.},
  Method->{},
  PlotRange->{{0, 10000.}, {501., 694.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{200., 200.}, {3.86, 3.86}}]], "Output",
 CellChangeTimes->{{3.561400845491189*^9, 3.561400854367382*^9}, 
   3.561473344796178*^9, 3.5641632850455303`*^9, 3.5641666313855124`*^9, 
   3.564166850635458*^9, 3.5641670436399393`*^9, 3.5641673288372498`*^9, 
   3.564167568035884*^9, 3.564167808173884*^9, 3.564168150964123*^9, 
   3.564168377298072*^9, 3.564421485338008*^9, 3.564421642396985*^9}]
}, Open  ]],

Cell["\<\
I quantified this by measuring the number of distinct distances the head \
traveled continuously in one direction before turning around and going the \
other direction (which I call a \[OpenCurlyDoubleQuote]run length\
\[CloseCurlyDoubleQuote]):\
\>", "Text",
 CellChangeTimes->{{3.561400979073266*^9, 3.561401074610853*^9}, {
  3.564833460623705*^9, 3.5648334628211756`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "distinct", " ", "run", " ", 
    RowBox[{"lengths", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"firstmoment", "[", "headpos_", "]"}], ":=", 
   RowBox[{"Length", "@", 
    RowBox[{"Tally", "[", 
     RowBox[{"Length", "/@", 
      RowBox[{"Split", "@", 
       RowBox[{"Differences", "@", "headpos"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{3.561400778046156*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"firstmoment", "[", 
  RowBox[{"evol", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "1", ",", "2"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.561400794552753*^9, 3.56140082426819*^9}}],

Cell[BoxData["270"], "Output",
 CellChangeTimes->{{3.561400812746986*^9, 3.561400824873446*^9}, 
   3.561473345047854*^9, 3.564163298302759*^9, 3.56416663149823*^9, 
   3.564166850750918*^9, 3.564167043754252*^9, 3.564167328949478*^9, 
   3.5641675681410713`*^9, 3.5641678082829037`*^9, 3.56416815109564*^9, 
   3.5641683774233303`*^9, 3.564421485496997*^9, 3.564421642511464*^9}]
}, Open  ]],

Cell[TextData[{
 "But in this case there was also a rather large number of run length ",
 StyleBox["frequencies",
  FontSlant->"Italic"],
 ", meaning the number of run lengths that appeared once, twice, three times, \
etc:"
}], "Text",
 CellChangeTimes->{{3.5614010431157703`*^9, 3.561401233926168*^9}, {
  3.56140142625583*^9, 3.5614014996877728`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Number", " ", "of", " ", "distinct", " ", "run", " ", "length", " ", 
    RowBox[{"frequencies", ":"}]}], "*)"}], 
  RowBox[{
   RowBox[{"secondmoment", "[", "headpos_", "]"}], ":=", 
   RowBox[{"Length", "@", 
    RowBox[{"Tally", "[", 
     RowBox[{"Length", "/@", 
      RowBox[{"Gather", "@", 
       RowBox[{
        RowBox[{"Tally", "[", 
         RowBox[{"Sort", "[", 
          RowBox[{"Length", "/@", 
           RowBox[{"Split", "@", 
            RowBox[{"Differences", "@", "headpos"}]}]}], "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"-", "1"}]}], "]"}], "]"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.561400778046156*^9, 3.561400781544364*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondmoment", "[", 
  RowBox[{"evol", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "1", ",", "2"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.561400901390209*^9, 3.5614009104195833`*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.56140091125954*^9, 3.561473345157935*^9, 
  3.564163300162497*^9, 3.564166631612525*^9, 3.564166850894475*^9, 
  3.564167043881401*^9, 3.564167329077791*^9, 3.5641675682841*^9, 
  3.564167808419932*^9, 3.5641681512072477`*^9, 3.564168377571165*^9, 
  3.5644214856432047`*^9, 3.564421642629004*^9}]
}, Open  ]],

Cell["\<\
A strictly nested pattern will often have a lot of different run lengths but \
a small number of run length frequencies. For example, the head might just be \
bouncing from left to right on the tape, going a little farther each time. In \
that case, there would be a slightly larger run length every time it changed \
direction. But there would only be one run length frequency, equal to 1, \
because every run length would occur exactly once.\
\>", "Text",
 CellChangeTimes->{{3.5614014863334627`*^9, 3.56140172352743*^9}, {
  3.561472942711562*^9, 3.561472943959547*^9}, {3.564831716129697*^9, 
  3.5648317220633526`*^9}, {3.564833526438738*^9, 3.564833538314431*^9}}],

Cell["\<\
This rule, however, has four different run length frequencies, which means \
the head probably wasn\[CloseCurlyQuote]t just moving in a steadily growing \
pattern, but was zigzagging around in an irregular way.\
\>", "Text",
 CellChangeTimes->{{3.561401726034945*^9, 3.561401785256501*^9}, {
  3.5614018538915*^9, 3.561401902930019*^9}, {3.561472789408593*^9, 
  3.561472862409851*^9}, {3.5614729246800222`*^9, 3.561472925479763*^9}, {
  3.564833550252465*^9, 3.5648335588864994`*^9}}],

Cell["\<\
But despite having fairly complex head movement, there\[CloseCurlyQuote]s \
obviously quite a lot of structure to the compressed tape output\[LongDash]it \
certainly doesn\[CloseCurlyQuote]t look random.\
\>", "Text",
 CellChangeTimes->{{3.561473000596126*^9, 3.561473110642427*^9}, {
   3.561473219536653*^9, 3.561473294598877*^9}, {3.56147551392024*^9, 
   3.561475528881818*^9}, {3.5614827790470257`*^9, 3.561482791194151*^9}, 
   3.563906100105851*^9, {3.5648317245707507`*^9, 3.5648317248355074`*^9}, {
   3.564833568595892*^9, 3.5648335708089476`*^9}, 3.5649159825816307`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Array Entropy Distribution", "Section",
 CellChangeTimes->{{3.5520713864456043`*^9, 3.5520713943934813`*^9}, {
  3.5650047412483997`*^9, 3.5650047456690073`*^9}}],

Cell["\<\
This is the distribution of entropies in the 13,000 Turing machines returned \
by my \[UDoubleDot]ber-search:\
\>", "Text",
 CellChangeTimes->{{3.561473423562251*^9, 3.5614734842149897`*^9}, {
  3.5648335753287086`*^9, 3.5648335767625837`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"entropies", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], ",", 
        "\"\<tm-4-4-search-entropies.txt\>\""}], "}"}], "]"}], ",", 
     "Expression"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.552071458373756*^9, 3.558967226003738*^9, {3.5635624908731003`*^9, 
   3.563562536407349*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "@", "entropies"}]], "Input",
 CellChangeTimes->{{3.563562545917993*^9, 3.563562546509851*^9}}],

Cell[BoxData["13188"], "Output",
 CellChangeTimes->{3.55207146658556*^9, 3.55896723050275*^9, 
  3.5614735764526663`*^9, 3.563562546896285*^9, 3.5641634421808*^9, 
  3.5641666321001587`*^9, 3.5641668512246447`*^9, 3.5641670441889877`*^9, 
  3.564167329390572*^9, 3.564167568634872*^9, 3.564167808786454*^9, 
  3.5641681515206614`*^9, 3.564168377898163*^9, 3.5644214860111523`*^9, 
  3.5644216429286203`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"entropies", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.561473582228572*^9, 3.561473585410334*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"Rule\"\>", "\[Rule]", "123359054799193891109569"}], ",", 
   RowBox[{"\<\"ArrayEntropy\"\>", "\[Rule]", "0.1706425593179003`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.561473585793339*^9, 3.56416344305224*^9, 
  3.5641666321413813`*^9, 3.564166851288458*^9, 3.5641670442364273`*^9, 
  3.564167329423374*^9, 3.56416756870183*^9, 3.564167808815329*^9, 
  3.564168151549562*^9, 3.564168377961565*^9, 3.5644214860400333`*^9, 
  3.56442164297466*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Quantile", "[", 
  RowBox[{
   RowBox[{"\"\<ArrayEntropy\>\"", "/.", "entropies"}], ",", "0.2"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.56147535075764*^9, 3.5614753687682543`*^9}}],

Cell[BoxData["0.19501906156137383`"], "Output",
 CellChangeTimes->{{3.56147536173291*^9, 3.561475369021596*^9}, 
   3.564163444335487*^9, 3.564166632188875*^9, 3.5641668513718977`*^9, 
   3.564167044304409*^9, 3.564167329477386*^9, 3.564167568816854*^9, 
   3.56416780887284*^9, 3.564168151615699*^9, 3.5641683780414963`*^9, 
   3.5644214860957937`*^9, 3.564421643016193*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", 
  RowBox[{"\"\<ArrayEntropy\>\"", "/.", "entropies"}], "]"}]], "Input",
 CellChangeTimes->{{3.56147535075764*^9, 3.5614753687682543`*^9}, {
  3.561475405016437*^9, 3.561475411791047*^9}}],

Cell[BoxData["0.2413316695170759`"], "Output",
 CellChangeTimes->{3.5614754124256773`*^9, 3.5641634448327208`*^9, 
  3.564166632434771*^9, 3.5641668514996862`*^9, 3.564167044402266*^9, 
  3.564167329525386*^9, 3.5641675688895283`*^9, 3.5641678089097757`*^9, 
  3.5641681517130203`*^9, 3.564168378149716*^9, 3.56442148666565*^9, 
  3.564421643066594*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Labeled", "[", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"\"\<ArrayEntropy\>\"", "/.", "entropies"}], "]"}], ",", "100", 
     ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", "Gray"}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"Scaled", "@", "0.1"}]}], "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{"\"\<normalized entropy\>\"", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
     RowBox[{"Style", "[", 
      RowBox[{"\"\<frequency\>\"", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<entropy distribution of complex Turing machines\>\"", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Bottom", ",", "Left", ",", "Top"}], "}"}], ",", 
   RowBox[{"RotateLabel", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.558967238278125*^9, 3.558967264790506*^9}, {
  3.558967516913478*^9, 3.5589677549552383`*^9}, {3.5589678175077744`*^9, 
  3.558967818339356*^9}, {3.5641634511771183`*^9, 3.564163487183218*^9}, {
  3.564163523720231*^9, 3.5641635292641*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{
     RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[
      Opacity[0.161]], {}, {
      RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[
       Opacity[0.161]], 
      RectangleBox[{0.095, 0.}, {0.1, 3.}, RoundingRadius -> 0], 
      RectangleBox[{0.1, 0.}, {0.105, 1.}, RoundingRadius -> 0], 
      RectangleBox[{0.105, 0.}, {0.11, 2.}, RoundingRadius -> 0], 
      RectangleBox[{0.11, 0.}, {0.115, 2.}, RoundingRadius -> 0], 
      RectangleBox[{0.115, 0.}, {0.12, 4.}, RoundingRadius -> 0], 
      RectangleBox[{0.12, 0.}, {0.125, 7.}, RoundingRadius -> 0], 
      RectangleBox[{0.125, 0.}, {0.13, 20.}, RoundingRadius -> 0], 
      RectangleBox[{0.13, 0.}, {0.135, 24.}, RoundingRadius -> 0], 
      RectangleBox[{0.135, 0.}, {0.14, 46.}, RoundingRadius -> 0], 
      RectangleBox[{0.14, 0.}, {0.145, 64.}, RoundingRadius -> 0], 
      RectangleBox[{0.145, 0.}, {0.15, 95.}, RoundingRadius -> 0], 
      RectangleBox[{0.15, 0.}, {0.155, 144.}, RoundingRadius -> 0], 
      RectangleBox[{0.155, 0.}, {0.16, 183.}, RoundingRadius -> 0], 
      RectangleBox[{0.16, 0.}, {0.165, 186.}, RoundingRadius -> 0], 
      RectangleBox[{0.165, 0.}, {0.17, 263.}, RoundingRadius -> 0], 
      RectangleBox[{0.17, 0.}, {0.175, 267.}, RoundingRadius -> 0], 
      RectangleBox[{0.175, 0.}, {0.18, 257.}, RoundingRadius -> 0], 
      RectangleBox[{0.18, 0.}, {0.185, 309.}, RoundingRadius -> 0], 
      RectangleBox[{0.185, 0.}, {0.19, 377.}, RoundingRadius -> 0], 
      RectangleBox[{0.19, 0.}, {0.195, 378.}, RoundingRadius -> 0], 
      RectangleBox[{0.195, 0.}, {0.2, 426.}, RoundingRadius -> 0], 
      RectangleBox[{0.2, 0.}, {0.205, 474.}, RoundingRadius -> 0], 
      RectangleBox[{0.205, 0.}, {0.21, 463.}, RoundingRadius -> 0], 
      RectangleBox[{0.21, 0.}, {0.215, 548.}, RoundingRadius -> 0], 
      RectangleBox[{0.215, 0.}, {0.22, 537.}, RoundingRadius -> 0], 
      RectangleBox[{0.22, 0.}, {0.225, 615.}, RoundingRadius -> 0], 
      RectangleBox[{0.225, 0.}, {0.23, 593.}, RoundingRadius -> 0], 
      RectangleBox[{0.23, 0.}, {0.235, 563.}, RoundingRadius -> 0], 
      RectangleBox[{0.235, 0.}, {0.24, 469.}, RoundingRadius -> 0], 
      RectangleBox[{0.24, 0.}, {0.245, 482.}, RoundingRadius -> 0], 
      RectangleBox[{0.245, 0.}, {0.25, 457.}, RoundingRadius -> 0], 
      RectangleBox[{0.25, 0.}, {0.255, 420.}, RoundingRadius -> 0], 
      RectangleBox[{0.255, 0.}, {0.26, 410.}, RoundingRadius -> 0], 
      RectangleBox[{0.26, 0.}, {0.265, 350.}, RoundingRadius -> 0], 
      RectangleBox[{0.265, 0.}, {0.27, 344.}, RoundingRadius -> 0], 
      RectangleBox[{0.27, 0.}, {0.275, 300.}, RoundingRadius -> 0], 
      RectangleBox[{0.275, 0.}, {0.28, 269.}, RoundingRadius -> 0], 
      RectangleBox[{0.28, 0.}, {0.285, 229.}, RoundingRadius -> 0], 
      RectangleBox[{0.285, 0.}, {0.29, 206.}, RoundingRadius -> 0], 
      RectangleBox[{0.29, 0.}, {0.295, 219.}, RoundingRadius -> 0], 
      RectangleBox[{0.295, 0.}, {0.3, 201.}, RoundingRadius -> 0], 
      RectangleBox[{0.3, 0.}, {0.305, 181.}, RoundingRadius -> 0], 
      RectangleBox[{0.305, 0.}, {0.31, 162.}, RoundingRadius -> 0], 
      RectangleBox[{0.31, 0.}, {0.315, 161.}, RoundingRadius -> 0], 
      RectangleBox[{0.315, 0.}, {0.32, 156.}, RoundingRadius -> 0], 
      RectangleBox[{0.32, 0.}, {0.325, 144.}, RoundingRadius -> 0], 
      RectangleBox[{0.325, 0.}, {0.33, 116.}, RoundingRadius -> 0], 
      RectangleBox[{0.33, 0.}, {0.335, 114.}, RoundingRadius -> 0], 
      RectangleBox[{0.335, 0.}, {0.34, 108.}, RoundingRadius -> 0], 
      RectangleBox[{0.34, 0.}, {0.345, 94.}, RoundingRadius -> 0], 
      RectangleBox[{0.345, 0.}, {0.35, 80.}, RoundingRadius -> 0], 
      RectangleBox[{0.35, 0.}, {0.355, 85.}, RoundingRadius -> 0], 
      RectangleBox[{0.355, 0.}, {0.36, 72.}, RoundingRadius -> 0], 
      RectangleBox[{0.36, 0.}, {0.365, 77.}, RoundingRadius -> 0], 
      RectangleBox[{0.365, 0.}, {0.37, 53.}, RoundingRadius -> 0], 
      RectangleBox[{0.37, 0.}, {0.375, 55.}, RoundingRadius -> 0], 
      RectangleBox[{0.375, 0.}, {0.38, 58.}, RoundingRadius -> 0], 
      RectangleBox[{0.38, 0.}, {0.385, 46.}, RoundingRadius -> 0], 
      RectangleBox[{0.385, 0.}, {0.39, 30.}, RoundingRadius -> 0], 
      RectangleBox[{0.39, 0.}, {0.395, 34.}, RoundingRadius -> 0], 
      RectangleBox[{0.395, 0.}, {0.4, 40.}, RoundingRadius -> 0], 
      RectangleBox[{0.4, 0.}, {0.405, 15.}, RoundingRadius -> 0], 
      RectangleBox[{0.405, 0.}, {0.41, 22.}, RoundingRadius -> 0], 
      RectangleBox[{0.41, 0.}, {0.415, 14.}, RoundingRadius -> 0], 
      RectangleBox[{0.415, 0.}, {0.42, 16.}, RoundingRadius -> 0], 
      RectangleBox[{0.42, 0.}, {0.425, 14.}, RoundingRadius -> 0], 
      RectangleBox[{0.425, 0.}, {0.43, 7.}, RoundingRadius -> 0], 
      RectangleBox[{0.43, 0.}, {0.435, 11.}, RoundingRadius -> 0], 
      RectangleBox[{0.435, 0.}, {0.44, 2.}, RoundingRadius -> 0], 
      RectangleBox[{0.44, 0.}, {0.445, 3.}, RoundingRadius -> 0], 
      RectangleBox[{0.445, 0.}, {0.45, 2.}, RoundingRadius -> 0], 
      RectangleBox[{0.45, 0.}, {0.455, 1.}, RoundingRadius -> 0], 
      RectangleBox[{0.46, 0.}, {0.465, 4.}, RoundingRadius -> 0], 
      RectangleBox[{0.465, 0.}, {0.47, 1.}, RoundingRadius -> 0], 
      RectangleBox[{0.47, 0.}, {0.475, 1.}, RoundingRadius -> 0], 
      RectangleBox[{0.5, 0.}, {0.505, 1.}, RoundingRadius -> 0], 
      RectangleBox[{0.51, 0.}, {0.515, 1.}, RoundingRadius -> 0]}, {}, {}}, 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
    Axes -> {True, True}, AxesOrigin -> {0.095, 0.}, Frame -> True, 
    FrameLabel -> {None, None}, FrameStyle -> GrayLevel[0.5], 
    FrameTicks -> {{Automatic, None}, {Automatic, None}}, FrameTicksStyle -> 
    GrayLevel[0], GridLines -> {None, None}, 
    PlotRange -> {{0.095, 0.515}, {All, All}}, 
    PlotRangePadding -> {{0, 0}, {0, 
       Scaled[0.1]}}, Ticks -> {Automatic, Automatic}],StyleBox[
   "\"normalized entropy\"", StripOnInput -> False, FontFamily -> 
    "Helvetica"],StyleBox[
   "\"frequency\"", StripOnInput -> False, FontFamily -> "Helvetica"],
   StyleBox["\"entropy distribution of complex Turing machines\"", 
    StripOnInput -> False, FontFamily -> "Helvetica"]},
  "Labeled",
  DisplayFunction->(GridBox[{{"", 
      ItemBox[#4, DefaultBaseStyle -> "LabeledLabel"]}, {
      ItemBox[
       RotationBox[#3, BoxRotation -> 1.5707963267948966`], DefaultBaseStyle -> 
       "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {"", 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {2, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", 
       RowBox[{"{", 
         RowBox[{#2, ",", #3, ",", #4}], "}"}], ",", 
       RowBox[{"{", 
         RowBox[{"Bottom", ",", "Left", ",", "Top"}], "}"}], ",", 
       RowBox[{"RotateLabel", "\[Rule]", "True"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.552071774242325*^9, 3.558967234077135*^9, {3.558967575420723*^9, 
   3.5589676680153933`*^9}, 3.558967703349318*^9, {3.558967746224061*^9, 
   3.558967756166697*^9}, 3.558967819750115*^9, {3.5641634698784447`*^9, 
   3.564163490920528*^9}, {3.564163525829467*^9, 3.564163529954817*^9}, 
   3.5641666334212523`*^9, 3.5641668518021107`*^9, 3.5641670447965927`*^9, 
   3.5641673298261423`*^9, 3.564167569156118*^9, 3.5641678091400537`*^9, 
   3.564168152013077*^9, 3.5641683783701897`*^9, 3.5644214873819313`*^9, 
   3.5644216432548847`*^9}]
}, Open  ]],

Cell["\<\
My favorite rule has a relatively low entropy of 0.12 (on my normalized \
scale), well below the average (which is about 0.24), indicating that it is \
highly organized:\
\>", "Text",
 CellChangeTimes->{{3.56147339516461*^9, 3.5614734067055693`*^9}, {
   3.561473498079755*^9, 3.561473527581921*^9}, {3.5614753308913317`*^9, 
   3.561475338127693*^9}, {3.5614754263830557`*^9, 3.561475485763302*^9}, {
   3.5614831186186647`*^9, 3.561483241445249*^9}, {3.5614845456455727`*^9, 
   3.561484553589755*^9}, 3.5639062064769163`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"minentropy", "[", 
  RowBox[{
   RowBox[{"rightcompress", "[", "evol", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.561400470017713*^9, 3.561400476324484*^9}, {
  3.561400554574726*^9, 3.5614005794917173`*^9}}],

Cell[BoxData["0.12411352535288203`"], "Output",
 CellChangeTimes->{
  3.5614005062723427`*^9, {3.561400563933551*^9, 3.561400581939474*^9}, 
   3.5614733449041653`*^9, 3.5614733756226254`*^9, 3.564166634893568*^9, 
   3.56416685303797*^9, 3.5641670460335493`*^9, 3.564167331103076*^9, 
   3.5641675704971647`*^9, 3.56416781059855*^9, 3.5641681534847383`*^9, 
   3.564168379693493*^9, 3.564421488912704*^9, 3.564421644525517*^9}]
}, Open  ]],

Cell["\<\
And you can see that structure clearly in the compressed output, with the \
three distinct domains of behavior you see scanning the tape from left to \
right:\
\>", "Text",
 CellChangeTimes->{{3.5614830821067533`*^9, 3.5614831034171133`*^9}, {
  3.5614832913090363`*^9, 3.561483436174817*^9}, {3.561483478595621*^9, 
  3.561483481005644*^9}, {3.561483520222327*^9, 3.5614835206687737`*^9}, {
  3.561484504370388*^9, 3.5614845200705338`*^9}, {3.561484585973102*^9, 
  3.561484589780443*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rightcompress", "[", "evol", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
   RowBox[{"ColorRules", "\[Rule]", "$TMColors"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.561399642233142*^9, {3.5614000577889442`*^9, 3.561400082730144*^9}, 
   3.564163272904065*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzs/FGO7LoWreltoFriNrgBtw9ugoF6tvvsDtwmVLnqIe9ShlI5IyeDY0qf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   "], {{0, 0}, {880, 240}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  ImageSize->400]], "Output",
 CellChangeTimes->{3.564165735177833*^9, 3.564166637095221*^9, 
  3.564166855024012*^9, 3.564167048302971*^9, 3.564167333090041*^9, 
  3.564167572707808*^9, 3.5641678127776423`*^9, 3.5641681556483803`*^9, 
  3.5641683817283173`*^9, 3.564421491460374*^9, 3.5644216462551107`*^9}]
}, Open  ]],

Cell[TextData[{
 "It would be interesting to study these three domains of behavior in detail, \
and find out what this Turing machine is ",
 ButtonBox["ultimately computing",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframscience.com/summerschool/resources/TuringAnalysis-mz-\
nks-ss07.cdf"], None},
  ButtonNote->
   "http://wolframscience.com/summerschool/resources/TuringAnalysis-mz-nks-\
ss07.cdf"],
 ". Could we program it to behave like a fluctuating molecule, or a flock of \
birds, or a human brain? Stephen Wolfram\[CloseCurlyQuote]s ",
 ButtonBox["Principle of Computational Equivalence",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/nksonline/page-715-text"], None},
  ButtonNote->"http://www.wolframscience.com/nksonline/page-715-text"],
 " says that a Turing machine with such complex-looking output is probably \
capable of universal computation, meaning we could use it to compute ",
 StyleBox["anything",
  FontSlant->"Italic"],
 " we want to with a suitable encoding of the initial conditions."
}], "Text",
 CellChangeTimes->{{3.5614830821067533`*^9, 3.5614831034171133`*^9}, {
   3.5614832913090363`*^9, 3.561483436174817*^9}, {3.561483478595621*^9, 
   3.561483481005644*^9}, {3.561483520222327*^9, 3.561483523835994*^9}, {
   3.5614837525751667`*^9, 3.561483985494441*^9}, {3.561484016088483*^9, 
   3.561484139625745*^9}, {3.561484597071892*^9, 3.5614846138198967`*^9}, {
   3.561485310491457*^9, 3.561485329853417*^9}, {3.5648317289314427`*^9, 
   3.5648317319683533`*^9}, 3.564833618329379*^9, {3.5649160306466913`*^9, 
   3.56491606330622*^9}}],

Cell[TextData[{
 "I\[CloseCurlyQuote]ve shown you how awesome Turing machines are, and how \
much fun it is to search for them in ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"],
 " I think Turing would have been proud to see all the cool Turing machines \
unearthed by our students this year. If you want to take your hunting skills \
to the next level, you can apply to ",
 ButtonBox["Wolfram Science Summer School",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframscience.com/summerschool/application.cgi"], None},
  ButtonNote->"http://www.wolframscience.com/summerschool/application.cgi"],
 " to try your hand at exploring your favorite part of the computational \
universe. ",
 "Here\[CloseCurlyQuote]s the hunting party from last summer:"
}], "Text",
 CellChangeTimes->{{3.561483593620001*^9, 3.561483626160482*^9}, {
   3.561483661880228*^9, 3.561483667471772*^9}, {3.561484643090892*^9, 
   3.561484754599402*^9}, 3.561484784837468*^9, {3.561484823887846*^9, 
   3.561484846996594*^9}, {3.561484881980545*^9, 3.5614849730327473`*^9}, {
   3.56148508015168*^9, 3.561485121500396*^9}, {3.563906620116786*^9, 
   3.5639066683028097`*^9}, {3.563906713157123*^9, 3.56390673444421*^9}, {
   3.563906810531684*^9, 3.563906841141796*^9}, {3.564831735799533*^9, 
   3.5648317422782755`*^9}, {3.5648336643380704`*^9, 3.564833670198256*^9}, {
   3.564834121405966*^9, 3.56483412234112*^9}, {3.564916090251729*^9, 
   3.564916096950614*^9}, {3.5649385258121977`*^9, 3.564938527634137*^9}, 
   3.564940376982922*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJyMvAV0lGe7772//Z3z7b3P2RUgxCcZt4y7u2vGkpG4u5IEggT34q6FAi3a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    "], {{0, 344}, {526, 0}}, {0, 
    255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJydlndUVNcWxs+9d3qhzTACUoZehyZlAOm9Sa+iMswMMJQBhxkQ7IqoYEQR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      "], "RGB", "XYZ"], Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{526, 344},
  PlotRange->{{0, 526}, {0, 344}}]], "Text"],

Cell["See you at the Wolfram Science Summer School in 2013!", "Text",
 CellChangeTimes->{{3.561484985283286*^9, 3.5614850000709667`*^9}, {
   3.5639067659718847`*^9, 3.563906804532482*^9}, 3.5639069608475533`*^9}],

Cell["\<\
(No Turing machines were harmed in the making of this blog post.)\
\>", "Text",
 CellChangeTimes->{{3.563906873548839*^9, 3.5639068853688173`*^9}, 
   3.5639069608477173`*^9}]
}, Open  ]]
},
WindowSize->{740, 867},
WindowMargins->{{Automatic, 165}, {-128, Automatic}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 20, \
2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 185, 4, 115, "Section"],
Cell[1673, 41, 918, 14, 68, "Text"],
Cell[2594, 57, 471, 8, 49, "Text"],
Cell[3068, 67, 1747, 33, 125, "Text"],
Cell[4818, 102, 516, 6, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5371, 113, 101, 1, 80, "Section"],
Cell[5475, 116, 356, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[5856, 129, 467, 13, 28, "Input"],
Cell[6326, 144, 1406, 28, 53, "Output"]
}, Open  ]],
Cell[7747, 175, 336, 8, 30, "Text"],
Cell[8086, 185, 485, 15, 28, "Input"],
Cell[CellGroupData[{
Cell[8596, 204, 36, 0, 28, "Input"],
Cell[8635, 206, 730, 19, 28, "Output"]
}, Open  ]],
Cell[9380, 228, 329, 10, 28, "Input"],
Cell[9712, 240, 1379, 39, 148, "Input"],
Cell[11094, 281, 345, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[11464, 295, 97, 1, 28, "Input"],
Cell[11564, 298, 1494, 45, 46, "Output"]
}, Open  ]],
Cell[13073, 346, 1211, 34, 114, "Input"],
Cell[14287, 382, 721, 21, 63, "Input"],
Cell[15011, 405, 1793, 50, 114, "Input"],
Cell[16807, 457, 399, 10, 28, "Input"],
Cell[17209, 469, 558, 17, 28, "Input"],
Cell[CellGroupData[{
Cell[17792, 490, 1620, 45, 114, "Input"],
Cell[19415, 537, 2152, 46, 53, "Output"]
}, Open  ]],
Cell[21582, 586, 717, 12, 49, "Text"],
Cell[CellGroupData[{
Cell[22324, 602, 1281, 33, 97, "Input"],
Cell[23608, 637, 6792, 150, 68, "Output"]
}, Open  ]],
Cell[30415, 790, 395, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[30835, 801, 514, 14, 46, "Input"],
Cell[31352, 817, 1512, 32, 52, "Output"]
}, Open  ]],
Cell[32879, 852, 451, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[33355, 866, 2091, 55, 182, "Input"],
Cell[35449, 923, 8919, 221, 109, "Output"]
}, Open  ]],
Cell[44383, 1147, 845, 15, 30, "Text"],
Cell[45231, 1164, 6672, 157, 403, "Input"],
Cell[CellGroupData[{
Cell[51928, 1325, 305, 5, 28, "Input"],
Cell[52236, 1332, 17482, 399, 87, "Output"]
}, Open  ]],
Cell[69733, 1734, 361, 6, 49, "Text"],
Cell[70097, 1742, 579, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[70701, 1755, 1620, 45, 114, "Input"],
Cell[72324, 1802, 2055, 45, 53, "Output"]
}, Open  ]],
Cell[74394, 1850, 224, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[74643, 1859, 331, 6, 28, "Input"],
Cell[74977, 1867, 17373, 398, 87, "Output"]
}, Open  ]],
Cell[92365, 2268, 291, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[92681, 2278, 1546, 44, 114, "Input"],
Cell[94230, 2324, 3004, 66, 74, "Output"]
}, Open  ]],
Cell[97249, 2393, 487, 8, 49, "Text"],
Cell[97739, 2403, 355, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[98119, 2413, 285, 6, 28, "Input"],
Cell[98407, 2421, 17381, 398, 87, "Output"]
}, Open  ]],
Cell[115803, 2822, 228, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[116056, 2831, 1570, 44, 114, "Input"],
Cell[117629, 2877, 3850, 85, 94, "Output"]
}, Open  ]],
Cell[121494, 2965, 314, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[121833, 2975, 229, 5, 28, "Input"],
Cell[122065, 2982, 17355, 398, 87, "Output"]
}, Open  ]],
Cell[139435, 3383, 444, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[139904, 3395, 1595, 45, 114, "Input"],
Cell[141502, 3442, 4713, 104, 114, "Output"]
}, Open  ]],
Cell[146230, 3549, 448, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[146703, 3560, 1624, 46, 114, "Input"],
Cell[148330, 3608, 16123, 371, 439, "Output"]
}, Open  ]],
Cell[164468, 3982, 648, 14, 49, "Text"],
Cell[CellGroupData[{
Cell[165141, 4000, 17749, 426, 1134, "Input"],
Cell[182893, 4428, 7914, 173, 556, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[190856, 4607, 173, 4, 80, "Section"],
Cell[191032, 4613, 1342, 29, 50, "Text"],
Cell[192377, 4644, 1377, 39, 148, "Input"],
Cell[193757, 4685, 600, 9, 49, "Text"],
Cell[194360, 4696, 608, 15, 28, "Input"],
Cell[194971, 4713, 257, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[195253, 4722, 566, 12, 28, "Input"],
Cell[195822, 4736, 1229, 26, 429, "Output"]
}, Open  ]],
Cell[197066, 4765, 322, 6, 49, "Text"],
Cell[197391, 4773, 174, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[197590, 4781, 297, 7, 28, "Input"],
Cell[197890, 4790, 3862, 62, 243, "Output"]
}, Open  ]],
Cell[201767, 4855, 233, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[202025, 4862, 665, 17, 46, "Input"],
Cell[202693, 4881, 17242, 290, 241, "Output"]
}, Open  ]],
Cell[219950, 5174, 469, 8, 49, "Text"],
Cell[220422, 5184, 320, 8, 49, "Text"],
Cell[220745, 5194, 1152, 32, 63, "Input"],
Cell[CellGroupData[{
Cell[221922, 5230, 822, 21, 46, "Input"],
Cell[222747, 5253, 1023, 22, 185, "Output"]
}, Open  ]],
Cell[223785, 5278, 388, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[224198, 5289, 862, 20, 46, "Input"],
Cell[225063, 5311, 2013, 37, 241, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[227125, 5354, 166, 2, 80, "Section"],
Cell[227294, 5358, 410, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[227729, 5369, 305, 5, 28, "Input"],
Cell[228037, 5376, 17307, 397, 79, "Output"]
}, Open  ]],
Cell[245359, 5776, 411, 9, 49, "Text"],
Cell[245773, 5787, 1400, 38, 148, "Input"],
Cell[CellGroupData[{
Cell[247198, 5829, 208, 5, 28, "Input"],
Cell[247409, 5836, 17376, 398, 79, "Output"]
}, Open  ]],
Cell[264800, 6237, 266, 5, 30, "Text"],
Cell[265069, 6244, 381, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[265475, 6258, 1674, 46, 114, "Input"],
Cell[267152, 6306, 9553, 212, 236, "Output"]
}, Open  ]],
Cell[276720, 6521, 798, 15, 49, "Text"],
Cell[277521, 6538, 531, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[278077, 6550, 1724, 47, 114, "Input"],
Cell[279804, 6599, 14879, 341, 398, "Output"]
}, Open  ]],
Cell[294698, 6943, 715, 11, 49, "Text"],
Cell[295416, 6956, 1031, 16, 106, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[296484, 6977, 181, 4, 80, "Section"],
Cell[296668, 6983, 1595, 26, 106, "Text"],
Cell[298266, 7011, 844, 14, 68, "Text"],
Cell[CellGroupData[{
Cell[299135, 7029, 1739, 44, 80, "Input"],
Cell[300877, 7075, 13210, 418, 420, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314124, 7498, 932, 23, 63, "Input"],
Cell[315059, 7523, 6829, 213, 216, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[321925, 7741, 945, 24, 63, "Input"],
Cell[322873, 7767, 6832, 214, 216, "Output"]
}, Open  ]],
Cell[329720, 7984, 247, 6, 28, "Input"],
Cell[CellGroupData[{
Cell[329992, 7994, 2134, 52, 114, "Input"],
Cell[332129, 8048, 12574, 310, 669, "Output"]
}, Open  ]],
Cell[344718, 8361, 608, 10, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345363, 8376, 166, 2, 80, "Section"],
Cell[345532, 8380, 1338, 27, 87, "Text"],
Cell[346873, 8409, 421, 10, 46, "Input"],
Cell[CellGroupData[{
Cell[347319, 8423, 152, 3, 28, "Input"],
Cell[347474, 8428, 337, 5, 28, "Output"]
}, Open  ]],
Cell[347826, 8436, 476, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[348327, 8448, 154, 3, 28, "Input"],
Cell[348484, 8453, 490, 6, 28, "Output"]
}, Open  ]],
Cell[348989, 8462, 97, 1, 30, "Text"],
Cell[349089, 8465, 397, 7, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349523, 8477, 150, 2, 80, "Section"],
Cell[349676, 8481, 597, 9, 68, "Text"],
Cell[350276, 8492, 1101, 19, 49, "Text"],
Cell[CellGroupData[{
Cell[351402, 8515, 152, 2, 44, "Subsection"],
Cell[351557, 8519, 1315, 23, 30, "Text"],
Cell[352875, 8544, 510, 14, 28, "Input"],
Cell[353388, 8560, 669, 18, 46, "Input"],
Cell[CellGroupData[{
Cell[354082, 8582, 628, 16, 46, "Input"],
Cell[354713, 8600, 20399, 352, 476, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[375161, 8958, 148, 2, 44, "Subsection"],
Cell[375312, 8962, 1314, 23, 30, "Text"],
Cell[376629, 8987, 582, 15, 28, "Input"],
Cell[CellGroupData[{
Cell[377236, 9006, 677, 17, 46, "Input"],
Cell[377916, 9025, 13914, 234, 365, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[391879, 9265, 165, 2, 44, "Subsection"],
Cell[392047, 9269, 1369, 24, 30, "Text"],
Cell[393419, 9295, 657, 16, 28, "Input"],
Cell[CellGroupData[{
Cell[394101, 9315, 317, 8, 28, "Input"],
Cell[394421, 9325, 13551, 224, 365, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[408021, 9555, 153, 2, 44, "Subsection"],
Cell[408177, 9559, 1244, 23, 30, "Text"],
Cell[409424, 9584, 710, 17, 28, "Input"],
Cell[CellGroupData[{
Cell[410159, 9605, 480, 14, 46, "Input"],
Cell[410642, 9621, 15411, 261, 441, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[426102, 9888, 164, 2, 44, "Subsection"],
Cell[426269, 9892, 1110, 30, 30, "Text"],
Cell[427382, 9924, 414, 13, 28, "Input"],
Cell[CellGroupData[{
Cell[427821, 9941, 415, 13, 46, "Input"],
Cell[428239, 9956, 35430, 588, 134, "Output"]
}, Open  ]],
Cell[463684, 10547, 10340, 258, 624, "Input"],
Cell[474027, 10807, 3550, 106, 301, "Input"],
Cell[CellGroupData[{
Cell[477602, 10917, 211, 3, 28, "Input"],
Cell[477816, 10922, 527812, 12039, 130, "Output"]
}, Open  ]],
Cell[1005643, 22964, 1110, 30, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1006790, 22999, 164, 2, 44, "Subsection"],
Cell[1006957, 23003, 288, 5, 30, "Text"],
Cell[1007248, 23010, 1023, 18, 182, "Input"],
Cell[1008274, 23030, 2243, 58, 284, "Input"],
Cell[CellGroupData[{
Cell[1010542, 23092, 1633, 38, 182, "Input"],
Cell[1012178, 23132, 94588, 1554, 533, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1106827, 24693, 148, 2, 80, "Section"],
Cell[1106978, 24697, 856, 15, 49, "Text"],
Cell[CellGroupData[{
Cell[1107859, 24716, 146, 2, 44, "Subsection"],
Cell[1108008, 24720, 14885, 435, 1168, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1122930, 25160, 255, 7, 44, "Subsection"],
Cell[1123188, 25169, 6374, 148, 502, "Input"],
Cell[1129565, 25319, 850, 13, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1130452, 25337, 152, 2, 44, "Subsection"],
Cell[1130607, 25341, 1618, 30, 87, "Text"],
Cell[1132228, 25373, 825, 24, 97, "Input"],
Cell[1133056, 25399, 333, 6, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1133426, 25410, 170, 2, 44, "Subsection"],
Cell[1133599, 25414, 1049, 16, 68, "Text"],
Cell[1134651, 25432, 22238, 369, 432, "Input"],
Cell[1156892, 25803, 591, 12, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1157520, 25820, 204, 3, 44, "Subsection"],
Cell[1157727, 25825, 678, 13, 68, "Text"],
Cell[1158408, 25840, 958, 28, 334, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1159403, 25873, 184, 4, 44, "Subsection"],
Cell[1159590, 25879, 1022, 15, 68, "Text"],
Cell[1160615, 25896, 202, 4, 28, "Input"],
Cell[1160820, 25902, 149, 3, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1161006, 25910, 153, 2, 44, "Subsection"],
Cell[1161162, 25914, 222, 4, 28, "Input"],
Cell[1161387, 25920, 166, 3, 28, "Input"],
Cell[CellGroupData[{
Cell[1161578, 25927, 171, 3, 28, "Input"],
Cell[1161752, 25932, 448, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1162237, 25945, 165, 3, 28, "Input"],
Cell[1162405, 25950, 453, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1162895, 25963, 240, 5, 28, "Input"],
Cell[1163138, 25970, 498, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1163673, 25983, 289, 6, 28, "Input"],
Cell[1163965, 25991, 404, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1164406, 26003, 336, 7, 28, "Input"],
Cell[1164745, 26012, 401, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1165183, 26024, 333, 7, 28, "Input"],
Cell[1165519, 26033, 420, 7, 28, "Output"]
}, Open  ]],
Cell[1165954, 26043, 202, 4, 28, "Input"],
Cell[CellGroupData[{
Cell[1166181, 26051, 283, 6, 28, "Input"],
Cell[1166467, 26059, 421, 6, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1166937, 26071, 152, 2, 44, "Subsection"],
Cell[1167092, 26075, 317, 6, 28, "Input"],
Cell[CellGroupData[{
Cell[1167434, 26085, 377, 8, 28, "Input"],
Cell[1167814, 26095, 370, 5, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1168233, 26106, 161, 2, 44, "Subsection"],
Cell[CellGroupData[{
Cell[1168419, 26112, 207, 4, 28, "Input"],
Cell[1168629, 26118, 349, 5, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1169027, 26129, 205, 4, 44, "Subsection"],
Cell[CellGroupData[{
Cell[1169257, 26137, 378, 8, 28, "Input"],
Cell[1169638, 26147, 372, 5, 28, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1170071, 26159, 182, 4, 80, "Section"],
Cell[1170256, 26165, 401, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[1170682, 26176, 230, 7, 44, "Subsection"],
Cell[1170915, 26185, 455, 13, 63, "Input"],
Cell[1171373, 26200, 2243, 58, 284, "Input"],
Cell[CellGroupData[{
Cell[1173641, 26262, 1819, 48, 182, "Input"],
Cell[1175463, 26312, 121718, 2510, 657, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1297230, 28828, 149, 2, 44, "Subsection"],
Cell[1297382, 28832, 132853, 2181, 543, "Output"],
Cell[1430238, 31015, 1280, 18, 68, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1431567, 31039, 165, 2, 80, "Section"],
Cell[1431735, 31043, 1499, 27, 68, "Text"],
Cell[1433237, 31072, 377, 12, 28, "Input"],
Cell[1433617, 31086, 1262, 34, 148, "Input"],
Cell[CellGroupData[{
Cell[1434904, 31124, 520, 11, 28, "Input"],
Cell[1435427, 31137, 147677, 2424, 310, "Output"]
}, Open  ]],
Cell[1583119, 33564, 350, 8, 49, "Text"],
Cell[CellGroupData[{
Cell[1583494, 33576, 428, 11, 28, "Input"],
Cell[1583925, 33589, 54835, 902, 136, "Output"]
}, Open  ]],
Cell[1638775, 34494, 526, 11, 30, "Text"],
Cell[CellGroupData[{
Cell[1639326, 34509, 254, 7, 28, "Input"],
Cell[1639583, 34518, 23061, 382, 240, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1662681, 34905, 304, 8, 28, "Input"],
Cell[1662988, 34915, 45099, 743, 236, "Output"]
}, Open  ]],
Cell[1708102, 35661, 386, 7, 49, "Text"],
Cell[1708491, 35670, 469, 12, 46, "Input"],
Cell[CellGroupData[{
Cell[1708985, 35686, 221, 5, 28, "Input"],
Cell[1709209, 35693, 380, 5, 28, "Output"]
}, Open  ]],
Cell[1709604, 35701, 353, 8, 49, "Text"],
Cell[1709960, 35711, 769, 21, 97, "Input"],
Cell[CellGroupData[{
Cell[1710754, 35736, 225, 5, 28, "Input"],
Cell[1710982, 35743, 347, 5, 28, "Output"]
}, Open  ]],
Cell[1711344, 35751, 680, 10, 106, "Text"],
Cell[1712027, 35763, 495, 8, 49, "Text"],
Cell[1712525, 35773, 592, 9, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1713154, 35787, 168, 2, 80, "Section"],
Cell[1713325, 35791, 254, 5, 30, "Text"],
Cell[1713582, 35798, 455, 13, 63, "Input"],
Cell[CellGroupData[{
Cell[1714062, 35815, 128, 2, 28, "Input"],
Cell[1714193, 35819, 407, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1714637, 35830, 151, 3, 28, "Input"],
Cell[1714791, 35835, 506, 10, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1715334, 35850, 208, 5, 28, "Input"],
Cell[1715545, 35857, 375, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1715957, 35867, 224, 4, 28, "Input"],
Cell[1716184, 35873, 353, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1716574, 35883, 1846, 45, 131, "Input"],
Cell[1718423, 35930, 7902, 130, 278, "Output"]
}, Open  ]],
Cell[1726340, 36063, 538, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[1726903, 36076, 303, 7, 28, "Input"],
Cell[1727209, 36085, 428, 6, 28, "Output"]
}, Open  ]],
Cell[1727652, 36094, 500, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[1728177, 36107, 428, 11, 28, "Input"],
Cell[1728608, 36120, 54691, 899, 136, "Output"]
}, Open  ]],
Cell[1783314, 37022, 1622, 31, 125, "Text"],
Cell[1784939, 37055, 1537, 27, 106, "Text"],
Cell[1786479, 37084, 606737, 9952, 358, "Text"],
Cell[2393219, 47038, 213, 2, 30, "Text"],
Cell[2393435, 47042, 185, 4, 30, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature OSESZfutjwwXouAUbxtAuoet *)
